(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    309874,      11186]*)
(*NotebookOutlinePosition[    313915,      11324]*)
(*  CellTagsIndexPosition[    313225,      11296]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[" The Riemannian Sphere", "Title",
  Evaluatable->False,
  CellHorizontalScrolling->False,
  TextAlignment->Center,
  FontFamily->"Times New Roman"],

Cell["by", "Subsubtitle",
  Evaluatable->False,
  CellHorizontalScrolling->False,
  TextAlignment->Center,
  FontFamily->"Times New Roman",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]],

Cell["Rolf Sulanke", "Text",
  Evaluatable->False,
  CellHorizontalScrolling->False,
  TextAlignment->Center,
  FontFamily->"Times New Roman",
  FontSize->24],

Cell["April 30, 2004", "Text",
  Evaluatable->False,
  CellHorizontalScrolling->False,
  TextAlignment->Center,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "Created with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " v. 4.2"
}], "Text",
  Evaluatable->False,
  CellHorizontalScrolling->False,
  TextAlignment->Left,
  FontFamily->"Times New Roman",
  FontSize->12],

Cell[CellGroupData[{

Cell["Summary", "Subsubsection",
  TextAlignment->Left,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "M\[ODoubleDot]bius geometry originated as the elementary part of geometric \
complex function theory. On the other hand, it can be considered as the \
geometry on the sphere as an elliptical quadric in the 3-dimensional real \
projective space. In this notebook we shall construct ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " functions useful for elementary geometric function theory, and  \
transition functions to the 2-dimensional real M\[ODoubleDot]bius geometry in \
the projective framework. In particular, the  notebook describes the M\
\[ODoubleDot]bius invariants for pairs consisting of 0-spheres (point pairs) \
or  circles in the Riemannian sphere  ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox["S", "2"], TraditionalForm]]],
  ", or, by stereographic projection, in the euclidean plane, which we \
identify with the complex Gaussian plane. Perhaps the main point is the \
calculation of Wilker`s matrix in section 7,  giving a homomorphism of  the \
complex special linear group SL(2,C) to the connected component of unity of \
the Lorentz group SO(3,1)+.  This example demonstrates the very strong \
capabilities of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " in symbolic calculations."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Contents", "Subsubsection"],

Cell[TextData[{
  "In the notebooks pairs.nb and mcircles.nb, see [",
  ButtonBox["S3",
    ButtonData:>"S3",
    ButtonStyle->"Hyperlink"],
  "],  the M\[ODoubleDot]bius invariants of such pairs are treated  as \
special cases of invariants in the more general real n-dimensional M\
\[ODoubleDot]bius geometry (n=3), see [",
  ButtonBox["S1",
    ButtonData:>"S1",
    ButtonStyle->"Hyperlink"],
  "].  Now we emphasize  the complex point of view, and adapt the procedures \
used in these notebooks to the complex plane. We  use the constructs \
contained in the packages euvec.m and pseuvec.m of the item Spheres [S3] \
being valid in any dimension. For the  M\[ODoubleDot]bius geometry of the \
sphere ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox["S", "2"], TraditionalForm]]],
  "one needs the 4-dimensional pseudo-euclidean vector space of index 1(see \
section 1).  In section 2 we introduce the Riemannian sphere and the \
transition from the Gaussian plane to it and vice versa by stereographic \
projection. Section 3 treats the M\[ODoubleDot]bius group of the Riemannian \
sphere in the original complex way. The Riemannian sphere is the complex \
projective line, and the M\[ODoubleDot]bius group is the group of  broken \
linear or conjugate linear transformations, preserving the cross ratio, or \
conjugating it, respectively. The isomorphism to the subgroup (two \
components) of the pseudo-orthogonal group O(3,1) is shown; this group is the \
M\[ODoubleDot]bius group (conformal group) of the sphere ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox["S", "2"], TraditionalForm]]],
  " from the real point of view. Especially, we obtain the isomorphism of \
SL(2,C)/{\[PlusMinus]1} with the connected component of unity of the \
pseudo-orthogonal group O(3,1), which is the group of orientation preserving \
conformal maps of the standard sphere ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox["S", "2"], TraditionalForm]]],
  ". An explicit matrix function describing this isomorphism can be found in \
the paper [",
  ButtonBox["W",
    ButtonData:>"W.",
    ButtonStyle->"Hyperlink"],
  "] of J. B. Wilker. In section 7 we calculate Wilker's matrix function.  \
Section 4 relates the M\[ODoubleDot]bius invariants of two 0-spheres to the \
cross ratio of their four points. Sections 5 and 6 treat  the \
M\[ODoubleDot]bius geometry of circles. We  shall find the M\[ODoubleDot]bius \
invariant of two circles and of  a circle and a 0-sphere. These invariants \
are related to the Coxeter invariant of two circles.\nThe appendix A1 imports \
 MathGL3d developed by J.-P. Kuska [",
  ButtonBox["K",
    ButtonData:>"Kuska",
    ButtonStyle->"Hyperlink"],
  "], which can be applied for animations of 3D-graphics created with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". A2 collects the usages of the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " functions defined in the accompanying packages. In A3 some tools of more \
technical character are given. A4 contains simple tests verifying the wanted \
properties of the defined ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " functions. The appendix A5 describes the changes we introduced in  Pekka \
Janhunen's package Declare.m, see [",
  ButtonBox["J",
    ButtonData:>"J.",
    ButtonStyle->"Hyperlink"],
  "], which admits defining types of variables, e.g. Real, or Integer. We \
used it often in calculations describing transitions from the complex to the \
real model of M\[ODoubleDot]bius geometry. Finally, A6 is devoted to \
calculations and tests concerning Wilker's matrix function for the \
isomorphism mentioned above."
}], "Text",
  Evaluatable->False,
  FontFamily->"Times New Roman"]
}, Closed]],

Cell[CellGroupData[{

Cell["Background literature", "Subsubsection"],

Cell[TextData[{
  "For the concepts of M\[ODoubleDot]bius geometry applied here see my paper \
[",
  ButtonBox["S1",
    ButtonData:>"S1",
    ButtonStyle->"Hyperlink"],
  "] or section 2.7 in the textbook [",
  ButtonBox["O.-S.",
    ButtonData:>"O.-S.",
    ButtonStyle->"Hyperlink"],
  "]. A very clear and elementary presentation of M\[ODoubleDot]bius geometry \
is the article of J. B. Wilker [",
  ButtonBox["W",
    ButtonData:>"W.",
    ButtonStyle->"Hyperlink"],
  "]; it contains a bibliography with 100 items.\nFor differential geometry \
with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " in the euclidean 3-space see Alfred Gray [",
  ButtonBox["G",
    ButtonData:>"Alfred",
    ButtonStyle->"Hyperlink"],
  "]."
}], "Text",
  Evaluatable->False,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "A systematic description of the circle space is contained in the diploma \
paper of Uwe May  [",
  ButtonBox["M",
    ButtonData:>"M.",
    ButtonStyle->"Hyperlink"],
  "]."
}], "Text",
  FontFamily->"Times New Roman"]
}, Closed]],

Cell[CellGroupData[{

Cell["Keywords: ", "Subsubsection",
  FontFamily->"Times New Roman"],

Cell["\<\
pseudo-euclidean geometry,  Moebius geometry, Riemannian sphere, \
rank of a matrix, random matrix, circles, invariants of pairs of subspheres, \
Coxeter invariant, double projection, stationary angles, eigenspheres, point \
pairs as 0-spheres, associated spheres,  point quadruples, throws, cross \
ratio, MathGL3d, homomorphism SL(2,C) to SO(3,1).\
\>", "Text",
  FontFamily->"Times New Roman"]
}, Closed]],

Cell[CellGroupData[{

Cell["Start. Initialization", "Section",
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "Please, before starting the notebook the first time,  consider this \
section. Also, if something went wrong with the initialization, check the \
necessary steps of the preparatorion described below carefully. If done once, \
you may ",
  StyleBox["start",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" the notebook",
    FontColor->RGBColor[1, 0, 0]],
  " in the standard way:  \n",
  StyleBox["Choose in the menu  ",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["Kernel/Evaluation/Evaluate Initialization.",
    FontVariations->{"CompatibilityType"->0}]
}], "Text"],

Cell[CellGroupData[{

Cell["Preparation", "Subsection"],

Cell[CellGroupData[{

Cell["The needed packages", "Subsubsection",
  FontFamily->"Times New Roman"],

Cell["\<\
Before initializing the present notebook ensure that the packages
euvec.m, pseuvec.m, mspher.m, mcirc.m,  and Declare.m
 are in your working directory. The first four packages are contained in the \
item \"Spheres\" [S3].
For the present notebook the package spiralsf.m is not needed; the packages \
mspher.m, mcirc.m are used only as base for the adaption of the concepts to \
the Riemannian sphere. Furthermore, the package Declare.m of Pekka Janhunen \
is very useful for defining types of variables, as Real or Complex, and the \
transition between them in complex calculations. We use a renewed version \
available as a download from my homepage, from which  the newest version of  \
item [S3] can be downloaded, too.  \
\>", "Text",
  FontFamily->"Times New Roman"]
}, Closed]],

Cell[CellGroupData[{

Cell["3D graphics, animations ", "Subsubsection",
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "In the notebook command lines using ThreeScript, or MVShow3D appear. They \
may used for 3D-representations and animations of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Graphics3D objects. To apply them you must have the necessary software on \
your computer, look in the last section. If you do not have or do not want \
the program MathGL3d, do not activate the next  cell:"
}], "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Get["\<MathGL3d`OpenGLViewer`\>"]\)], "Input",
  FontFamily->"Times New Roman"]
}, Closed]],

Cell[CellGroupData[{

Cell["Path of the working directory", "Subsubsection",
  FontFamily->"Times New Roman"],

Cell["\<\
The operation of this subsection are necessary only at the first \
use of this notebook on your computer.  If this is done once, and if the \
conditions of the subsection \"The needed packages\" are fulfilled, you may \
start calling the initialization as described in the next subsection. \
\>", \
"Text",
  FontFamily->"Times New Roman"],

Cell[TextData[StyleBox["At the moment, DO NOT CONFIRM THE EVALUATION OF THE \
INITIALIZATION CELLS !",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]]], "Text",
  FontFamily->"Times New Roman"],

Cell["If the result of the following command ", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    RowBox[{"Directory", "[", "]"}]], "Input",
  CellLabel->"In[100]:=",
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "does not coincide with the working directory, e.g. \"C:\\Eigene \
Dateien\\mymath\\spheres.v4\", containing the needed packages, insert the \
Path of your working directory in the next command line according to your ",
  StyleBox["OS",
    InitializationCell->True],
  ", select it, choose Cell/Cell Propertie/Initialization Cell, and activate \
\"Initialization: Cell\""
}], "Text",
  FontFamily->"Times New Roman"],

Cell[TextData[StyleBox["e.g. for Windows:",
  FontColor->RGBColor[1, 0, 0]]], "Text",
  FontFamily->"Times New Roman",
  FontSize->18],

Cell[BoxData[
    RowBox[{
    "SetDirectory", "[", 
      "\"\<C:\\\\Dokumente und Einstellungen\\\\rolf\\\\Eigene \
Dateien\\\\mymath\\\\mathwork\>\"", "]"}]], "Input",
  CellLabel->"In[1]:=",
  InitializationCell->True,
  FontFamily->"Times New Roman"],

Cell["\<\
C:\\Dokumente und Einstellungen\\rolf\\Eigene \
Dateien\\mymath\\mathwork\
\>", "Text",
  CellLabel->"Out[1]="],

Cell[TextData[StyleBox["or for Linux:",
  FontColor->RGBColor[1, 0, 0]]], "Text",
  FontFamily->"Times New Roman",
  FontSize->18],

Cell[BoxData[
    RowBox[{
    "SetDirectory", "[", "\"\<~/mymath/spheres/Riemannsph\>\"", 
      "]"}]], "Input",
  FontFamily->"Times New Roman"],

Cell["\<\
Save the notebook. Next time you can directly start the notebook \
with the evaluation of the initialization, as follows:\
\>", "Text",
  FontFamily->"Times New Roman"]
}, Closed]],

Cell[CellGroupData[{

Cell["Start", "Subsubsection",
  FontFamily->"Times New Roman"],

Cell[TextData[StyleBox["Activite Kernel/Evaluation/Evaluate Initialization \
from the menu.",
  FontSize->18,
  FontColor->RGBColor[1, 0, 0]]], "Text",
  FontFamily->"Times New Roman"],

Cell["\<\
The next cells make  available all commands contained in the needed \
packages euvec.m, pseuvec.m, mspher.m, mcirc.m, riemann.m, and the package \
Declare.m:\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    RowBox[{"Get", "[", "\"\<riemann.m\>\"", "]"}]], "Input",
  CellLabel->"In[2]:=",
  InitializationCell->True,
  FontFamily->"Times New Roman"],

Cell[BoxData[
    RowBox[{"Get", "[", "\"\<Declare`\>\"", "]"}]], "Input",
  CellLabel->"In[3]:=",
  InitializationCell->True,
  FontFamily->"Times New Roman"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
1 The sphere as a real elliptic quadric in the projective \
space\
\>", "Section",
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "We describe basic concepts of pseudo-euclidean linear algebra needed for \
the geometry of the sphere as an elliptic quadric in the 3-dimensional real \
projective space. The corresponding ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " modules are contained in the packages euvec.m and pseuvec.m."
}], "Text"],

Cell[CellGroupData[{

Cell["1.1 The sphere in pseudo-euclidean terms", "Subsection"],

Cell[TextData[{
  "As usually, the points of the n-dimensional projective space are defined \
to be the one-dimensional subspaces of the (n+1)-dimensional real vector \
space, see e.g. [",
  ButtonBox["O.-S",
    ButtonData:>"O.-S.",
    ButtonStyle->"Hyperlink"],
  ".]. In this textbook one finds a detailed exposition of the projective \
geometry of general quadrics and the theoretical backgrounnd of the concepts \
of M\[ODoubleDot]bius geometry applied later in this notebook. Since the \
sphere is considered as a quadric in the 3-dimensional projective space, the \
",
  StyleBox["dimension ",
    FontColor->RGBColor[1, 0, 0]],
  "of the underlying real vector space must be set as ",
  StyleBox["dim = 4",
    FontColor->RGBColor[1, 0, 0]],
  ". The elliptical quadrics correspond to non-degenerate, symmetric bilinear \
forms of  ",
  StyleBox["index ind =  1",
    FontColor->RGBColor[1, 0, 0]],
  ". The projective transformations preserving the sphere are generated by \
the linear transformations contained in the pseudo-orthogonal group ",
  StyleBox["O(3, 1)",
    FontWeight->"Bold"],
  ". The geometry of the sphere itself under the action of this group is the \
2-dimensional M\[ODoubleDot]bius geometry, Thus, we have to consider the \
4-dimensional pseudo-euclidean vectorspace with the scalar product pssp of \
index 1, the same as in the special theory of relativity:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"dim", " ", "=", "4"}], ";", " ", 
      RowBox[{"ind", " ", "=", " ", "1"}], ";"}]], "Input",
  CellLabel->"In[4]:=",
  InitializationCell->True,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "The scalar product of two ",
  StyleBox["vectors",
    FontColor->RGBColor[1, 0, 0]],
  " "
}], "Text"],

Cell[BoxData[
    \(\(?vec\)\)], "Input",
  CellLabel->"In[111]:="],

Cell[BoxData[
    \(\(\(vec[x]\)\(\ \)\)\)], "Input",
  CellLabel->"In[112]:="],

Cell[BoxData[
    \(vec[y]\)], "Input",
  CellLabel->"In[113]:="],

Cell["then is", "Text"],

Cell[BoxData[
    \(\(?pssp\)\)], "Input",
  CellLabel->"In[114]:="],

Cell[BoxData[
    \(pssp[vec[x], \ vec[y]]\)], "Input",
  CellLabel->"In[115]:="],

Cell[TextData[{
  StyleBox["Remark",
    FontSlant->"Italic"],
  ". If wanted, the basic constants dim and ind  may be changed any time, \
without restarting the notebook. "
}], "Text",
  Evaluatable->False,
  FontFamily->"Times New Roman"],

Cell["The standard basis", "Text"],

Cell[BoxData[
    \(\(?stb\)\)], "Input",
  CellLabel->"In[116]:="],

Cell[BoxData[
    \(Table[{stb[i]}, {i, 4}] // MatrixForm\)], "Input",
  CellLabel->"In[124]:="],

Cell["\<\
is orthonormal with respect to the indefinite scalar product pssp; \
the matrix of the scalar products of any orthonormal basis of the \
pseudo-euclidean vector space is\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(MatrixForm[Table[pssp[stb[i], \ stb[j]], {i, 4}, {j, 4}]]\)], "Input",
  CellLabel->"In[116]:=",
  FontFamily->"Times New Roman"],

Cell["\<\
The homogenius coordinates x[i], i = 1, ..., 4, of the points of \
the two-dimensional sphere fulfil the equation\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"pssp", "[", 
        RowBox[{
          RowBox[{"vec", "[", "x", "]"}], ",", 
          RowBox[{"vec", "[", "x", "]"}]}], "]"}], " ", "\[Equal]", " ", 
      "0"}]], "Input",
  CellLabel->"In[5]:=",
  InitializationCell->True,
  CellTags->"eq1"],

Cell["The solution is obtained by", "Text"],

Cell[BoxData[
    \(Solve[%, \ vec[x]]\)], "Input",
  CellLabel->"In[118]:="],

Cell["Of course, only the non trivial solutions are of interest:", "Text"],

Cell[BoxData[
    \(vec[x]\  \[NotEqual] \ null[]\)], "Input",
  CellLabel->"In[119]:="],

Cell[BoxData[
    \(\(?null\)\)], "Input",
  CellLabel->"In[120]:="],

Cell["Using the parameter representation  of the unit sphere:", "Text"],

Cell[BoxData[
    \(\(?unit\)\)], "Input",
  CellLabel->"In[121]:="],

Cell[BoxData[
    \(unit[{s, t}]\)], "Input",
  CellLabel->"In[122]:="],

Cell["\<\
one gets a sometimes more appropriate parameter representation of \
the solution:\
\>", "Text"],

Cell[BoxData[
    \(vu[s_, t_]\  := 
      Module[{v}, 
        v\  = \ unit[{s, t}]; \[IndentingNewLine]\ \ AppendTo[v, 
          1]]\)], "Input",
  CellLabel->"In[123]:="],

Cell[BoxData[
    \(vu[s, t]\)], "Input",
  CellLabel->"In[124]:="],

Cell[BoxData[
    \(pssp[vu[s, t], vu[s, t]]\)], "Input",
  CellLabel->"In[125]:="],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[126]:="],

Cell[TextData[{
  "The ",
  ButtonBox["equation",
    ButtonData:>"eq1",
    ButtonStyle->"Hyperlink"],
  " of the M\[ODoubleDot]bius sphere implies that the homogeneous coordinates \
of its points satisfy x[4] \[NotEqual] 0.  Dividing the equation by x[4]^2 we \
obtain the usual equation of the unit sphere in euclidean orthonormal \
coordinates"
}], "Text"],

Cell[BoxData[
    \(\(\(\ \)\(y[i_]\  := x[i]/x[4]; 
    pssp[vec[y], vec[y]]\  \[Equal] \ 0\)\)\)], "Input",
  CellLabel->"In[109]:="],

Cell["or", "Text"],

Cell[BoxData[
    \(y[1]^2 + y[2]^2 + y[3]^2\  \[Equal] \ 1\)], "Input",
  CellLabel->"In[110]:="],

Cell["\<\
Therefore we may visualize the objects of the 2-dimensional M\
\[ODoubleDot]bius geometzry on the unit sphere.The next command plots \
it:\
\>", "Text"],

Cell[BoxData[
    RowBox[{"sphereplot3D", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", "1"}], 
      "]"}]], "Input",
  CellLabel->"In[6]:=",
  InitializationCell->True,
  FontFamily->"Times New Roman"],

Cell[BoxData[
    RowBox[{"sph1", " ", "=", " ", "%"}]], "Input",
  CellLabel->"In[7]:=",
  InitializationCell->True,
  FontFamily->"Times New Roman"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["2 The Riemannian sphere as the complex projective line", "Section",
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "Introducing a projective parameter on the projective line over  an \
arbitrary field K one learns that the projective line is bijectively mapped \
on the set ",
  Cell[BoxData[
      \(TraditionalForm\`K\_\[Infinity]\)]],
  " := K\[Cup]{\[Infinity]}, the disjoint union of the field with a single \
new symbol \[Infinity] called ",
  StyleBox["infinity",
    FontColor->RGBColor[1, 0, 0]],
  ". The complex projective line is the Riemannian sphere. The transition \
from the complex to the real numbers corresponds to the transition from the \
Riemannian sphere to the M\[ODoubleDot]bius sphere ",
  Cell[BoxData[
      \(TraditionalForm\`S\^2\)]],
  "as the real projective quadric considered in the last section. Functions \
establishing this transition are defined in subsection 2.3."
}], "Text"],

Cell[CellGroupData[{

Cell["2.1 The point \" infy\": infy = ComplexInfinity", "Subsection",
  FontFamily->"Times New Roman"],

Cell["\<\
In this subsection we introduce the infinite element infy and \
discuss its properties.\
\>", "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  "2.1.1 Infinite elements in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " "
}], "Subsubsection"],

Cell[TextData[{
  " In ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " the symbol \[Infinity] exists as an character but seems not to have   a \
well defined mathematical meaning:"
}], "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(?? \[Infinity]\)], "Input",
  CellLabel->"In[109]:="],

Cell["\<\
On the other hand, it is used as an symbol of an infinite positive \
quantity, click on more after calling\
\>", "Text"],

Cell[BoxData[
    \(?? Infinity\)], "Input",
  CellLabel->"In[110]:="],

Cell[BoxData[
    \(Infinity\  \[Equal] \ \[Infinity]\)], "Input",
  CellLabel->"In[111]:="],

Cell[BoxData[
    \(\(\(\ \)\(\[Infinity]\  > 0\)\)\)], "Input",
  CellLabel->"In[112]:="],

Cell[BoxData[
    \(\(\(\ \)\(\[Infinity]\  > \(\(-\ \[Infinity]\)\(\ \)\)\)\)\)], "Input",
  CellLabel->"In[113]:="],

Cell[BoxData[
    \(\(\(\ \)\(\[Infinity]\  \[Equal] \ \(\(-\ \[Infinity]\)\(\ \)\)\)\)\)], \
"Input",
  CellLabel->"In[114]:="],

Cell[BoxData[
    \(\(-\ \[Infinity]\)\  > \ Pi\)], "Input",
  CellLabel->"In[115]:="],

Cell[BoxData[
    \(NumberQ[\[Infinity]]\)], "Input",
  CellLabel->"In[116]:="],

Cell[TextData[{
  "We recognize that in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " the symbol  \[Infinity] is used in the same way as in real analysis; \
thus, it cannot be used as the infinite element added to the fields of the \
real or complex numbers. ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " has another concept corresponding to the complex infinite element: "
}], "Text"],

Cell[BoxData[
    \(?? ComplexInfinity\)], "Input",
  CellLabel->"In[22]:="],

Cell["\<\
Both concepts Infinity and ComplexInfinity are special cases of \
\
\>", "Text"],

Cell[BoxData[
    \(?? DirectedInfinity\)], "Input",
  CellLabel->"In[23]:="],

Cell[TextData[{
  "Thus, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " may not know whether "
}], "Text"],

Cell[BoxData[
    \(\(\(\ \)\(\[Infinity]\  \[Equal] \ ComplexInfinity\)\)\)], "Input",
  CellLabel->"In[117]:="],

Cell["and leaves the answer open. Clearly one has", "Text"],

Cell[BoxData[
    \(\(\(\ \)\(\[Infinity]\  \[Equal] \ DirectedInfinity[1]\)\)\)], "Input",
  CellLabel->"In[118]:="],

Cell["\<\
The concept we need is ComplexInfinity; for abbreviation we write \
infy instead\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(?? infy\)], "Input",
  CellLabel->"In[108]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["2.1.2 Properties of infy", "Subsubsection",
  FontFamily->"Times New Roman"],

Cell["\<\
In many algebraic calculations infy behaves as expected; we mainly \
use it together with complex numbers as arguments of  broken linear \
transformations:\
\>", "Text"],

Cell[BoxData[
    \(1/infy\)], "Input",
  CellLabel->"In[100]:="],

Cell[BoxData[
    \(1/0 \[Equal] \ infy\)], "Input",
  CellLabel->"In[101]:="],

Cell["The next identity is incorrect, in general:", "Text"],

Cell[BoxData[
    \(a*infy\  \[Equal] \ infy\)], "Input",
  CellLabel->"In[119]:="],

Cell[BoxData[
    \(0*infy\)], "Input",
  CellLabel->"In[120]:="],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " yields the generic cases only; it neglects singular behaviour."
}], "Text"],

Cell[BoxData[
    \(a + infy\  \[Equal] \ infy\)], "Input",
  CellLabel->"In[108]:="],

Cell[BoxData[
    \(infy + infy\  \[Equal] \ infy\)], "Input",
  CellLabel->"In[109]:="],

Cell[BoxData[
    \(I*\[Infinity]\  \[Equal] \ \[Infinity]\)], "Input",
  CellLabel->"In[116]:="],

Cell[BoxData[
    \(I*\[Infinity]\  \[Equal] \ DirectedInfinity[I]\)], "Input",
  CellLabel->"In[119]:="],

Cell[BoxData[
    \(I*infy\  \[Equal] \ infy\)], "Input",
  CellLabel->"In[118]:="],

Cell[BoxData[
    \(Re[I*\[Infinity]]\)], "Input",
  CellLabel->"In[120]:="],

Cell[BoxData[
    \(Im[I*\[Infinity]]\)], "Input",
  CellLabel->"In[121]:="],

Cell[BoxData[
    \(Re[\ infy]\)], "Input",
  CellLabel->"In[122]:="],

Cell[BoxData[
    \(Im[infy]\)], "Input",
  CellLabel->"In[123]:="],

Cell[BoxData[
    \(Conjugate[infy]\)], "Input",
  CellLabel->"In[124]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Conjugate[infy] \[Equal] \ infy\)], "Input",
  CellLabel->"In[125]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Abs[infy]\)], "Input",
  CellLabel->"In[126]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(% > 0\)], "Input",
  CellLabel->"In[127]:="],

Cell[BoxData[
    \(24/0 \[Equal] \ infy\)], "Input",
  CellLabel->"In[129]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(ComplexExpand[z]\)], "Input",
  CellLabel->"In[130]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(ComplexExpand[z, {z}]\)], "Input",
  CellLabel->"In[136]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(ComplexExpand[infy]\)], "Input",
  CellLabel->"In[131]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(ComplexExpand[infy, {infy}]\)], "Input",
  CellLabel->"In[137]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(infy\  - infy\)], "Input",
  CellLabel->"In[138]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(infy*3\)], "Input",
  CellLabel->"In[139]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(infy*infy\)], "Input",
  CellLabel->"In[140]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(?Positive\)\)], "Input",
  CellLabel->"In[142]:="],

Cell[BoxData[
    \(Positive[infy]\)], "Input",
  CellLabel->"In[143]:=",
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "Remark. The ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function Positive[] is changed by some rules defined in the package \
Declare.m"
}], "Text"],

Cell[BoxData[
    \(?? Positive\)], "Input",
  CellLabel->"In[144]:="],

Cell[BoxData[
    \(Declare[x1, \ Positive]\)], "Input",
  CellLabel->"In[159]:="],

Cell[BoxData[
    \(Positive[x1]\)], "Input",
  CellLabel->"In[160]:="],

Cell["\<\
Very often, but not always, Positive returns reasonable \
results:\
\>", "Text"],

Cell[BoxData[
    \(Positive[1.2\  + \ Cos[x1]]\)], "Input",
  CellLabel->"In[155]:="],

Cell["\<\
Of  course, here should be returned True. Recommendation: Test the \
properties of Positive and other \"Declarations\", e.g.\
\>", "Text"],

Cell[BoxData[
    \(Declare[y, Real]\)], "Input",
  CellLabel->"In[167]:="],

Cell[BoxData[
    \(Positive[0.1\  + \ y^2]\)], "Input",
  CellLabel->"In[162]:="],

Cell[BoxData[
    \(Positive[infy\  + \ y^2]\)], "Input",
  CellLabel->"In[168]:="],

Cell[BoxData[
    \(infy\  + \ y^2\)], "Input",
  CellLabel->"In[169]:="],

Cell["Clear removes the declared properties:", "Text"],

Cell[BoxData[
    \(Clear[x1, y]\)], "Input",
  CellLabel->"In[170]:="],

Cell[BoxData[
    \(RealQ[y]\)], "Input",
  CellLabel->"In[164]:="],

Cell[BoxData[
    \(Positive[x1]\)], "Input",
  CellLabel->"In[165]:="],

Cell[BoxData[
    \(Positive[a]\)], "Input",
  CellLabel->"In[166]:="]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["2.2 Reality and Complexity", "Subsection",
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "In ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", a variable x in a function f[x] means a general symbol; it may be \
interpreted as a complex number, a real number, or something else, making the \
evaluation of f possible. Analytic Functions, e.g. almost all constructed by \
the help of elementary functions, may be considered in the real or in the \
complex domain. Sometimes it is useful to fix the type of a variable for \
getting proper evaluation and simplifications of the considered functions. \
This may be done by the package Declare.m  (see ",
  ButtonBox["below)",
    ButtonData:>"Declare",
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(?Declare\)\)], "Input",
  CellLabel->"In[228]:="],

Cell[BoxData[
    \(\(?NewDeclare\)\)], "Input",
  CellLabel->"In[229]:="],

Cell[TextData[{
  "Sometimes ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " may easier simplify expressions, or transite to their real components, \
using the following crRules:"
}], "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"crRules", "::", "usage"}], " ", "=", 
        "\"\<crRules gives  rules for calculating the functions Re, Im, and \
1/z.\>\""}], ";"}]], "Input",
  CellLabel->"In[8]:=",
  InitializationCell->True,
  FontFamily->"Times New Roman"],

Cell[BoxData[
    RowBox[{
      RowBox[{"crRules", " ", "=", 
        RowBox[{"{", " ", 
          RowBox[{
            RowBox[{
              RowBox[{"Re", "[", 
                RowBox[{"A_", "+", "B_"}], "]"}], "\[Rule]", " ", 
              RowBox[{
                RowBox[{"Re", "[", "A", "]"}], "+", 
                RowBox[{"Re", "[", "B", "]"}]}]}], ",", " ", 
            RowBox[{
              RowBox[{"Im", "[", 
                RowBox[{"A_", "+", "B_"}], "]"}], "\[Rule]", " ", 
              RowBox[{
                RowBox[{"Im", "[", "A", "]"}], "+", 
                RowBox[{"Im", "[", "B", "]"}]}]}], ",", " ", 
            "\[IndentingNewLine]", 
            RowBox[{
              RowBox[{"Re", "[", 
                RowBox[{"A_", "*", "B_"}], "]"}], " ", "\[Rule]", " ", 
              RowBox[{
                RowBox[{
                  RowBox[{"Re", "[", "A", "]"}], "*", 
                  RowBox[{"Re", "[", "B", "]"}]}], " ", "-", " ", 
                RowBox[{
                  RowBox[{"Im", "[", "A", "]"}], "*", 
                  RowBox[{"Im", "[", "B", "]"}]}]}]}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{
              RowBox[{"Im", "[", 
                RowBox[{"A_", "*", "B_"}], "]"}], " ", "\[Rule]", " ", 
              RowBox[{
                RowBox[{
                  RowBox[{"Re", "[", "A", "]"}], "*", 
                  RowBox[{"Im", "[", "B", "]"}]}], " ", "+", " ", 
                RowBox[{
                  RowBox[{"Im", "[", "A", "]"}], "*", 
                  RowBox[{"Re", "[", "B", "]"}]}]}]}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{
              RowBox[{"1", "/", "A_"}], " ", "\[Rule]", " ", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"Re", "[", "A", "]"}], "-", 
                    RowBox[{"I", "*", 
                      RowBox[{"Im", "[", "A", "]"}]}]}], ")"}], "/", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      RowBox[{"Re", "[", "A", "]"}], "^", "2"}], " ", "+", 
                    " ", 
                    RowBox[{
                      RowBox[{"Im", "[", "A", "]"}], "^", "2"}]}], ")"}]}]}], 
            ",", "\[IndentingNewLine]", 
            RowBox[{
              RowBox[{
                RowBox[{"Abs", "[", "A_", "]"}], "^", "2"}], " ", "\[Rule]", 
              " ", 
              RowBox[{
                RowBox[{
                  RowBox[{"Re", "[", "A", "]"}], "^", "2"}], " ", "+", " ", 
                RowBox[{
                  RowBox[{"Im", "[", "A", "]"}], "^", "2"}]}]}]}], "}"}]}], 
      ";"}]], "Input",
  CellLabel->"In[9]:=",
  InitializationCell->True,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "For testing the crRules, and the properties of Im, Re, Abs, see the \
Appendix ",
  ButtonBox["A11.1.1",
    ButtonData:>"crtest",
    ButtonStyle->"Hyperlink"],
  " ."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["2.3 Transition functions", "Subsection",
  FontFamily->"Times New Roman"],

Cell["\<\
Terminology: 
The Riemannian sphere is the Gaussian plane of comple numbers enlarged with \
the point infy, as described in 2.1.
The M\[ODoubleDot]bius sphere is the real elliptic quadric described in \
section 1. \
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
2.3.1 From the Riemannian sphere to the M\[ODoubleDot]bius sphere, \
and vice versa\
\>", "Subsubsection",
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "The M\[ODoubleDot]bius sphere ",
  Cell[BoxData[
      \(TraditionalForm\`S\^2\)]],
  " is represented by the generators of the isotropic cone of the \
4-dimensional pseudo-euclidean vector space of index 1 under consideration. \
The following functions define the correspondence of the complex plane and \
the Riemannian sphere as a M\[ODoubleDot]bius space; the complex plane is \
considered as the equatorial plane of the sphere, and the correspondence is \
constructed by the stereographic projection from the north pole (0,0,1)."
}], "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(?isotrop1\)\)], "Input",
  CellLabel->"In[66]:="],

Cell["Without norming the last component", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(?isotrop\)\)], "Input",
  CellLabel->"In[67]:="],

Cell[TextData[{
  "The inverse function invisotrop = ",
  Cell[BoxData[
      \(TraditionalForm\`isotrop\^\(-1\)\)]],
  ":"
}], "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(?invisotrop\)\)], "Input",
  CellLabel->"In[121]:="],

Cell["The corresponding Modules, defined in riemann.m, are", "Text"],

Cell[BoxData[
    \(isotrop1[z_] := 
      Module[{x, y, a}, 
        If[z \[Equal] Null, Print["\<Argument of isotrop1 is Null!\>"]; 
          Return[]]; \[IndentingNewLine]If[z \[Equal] ComplexInfinity, 
          Return[{0, 0, \(-1\), 1}]]; \[IndentingNewLine]x = 
          Re[z]; \[IndentingNewLine]y = Im[z]; \[IndentingNewLine]a = 
          Abs[z]^2; \[IndentingNewLine]Return[
          FullSimplify[{2\ x, 2\ y, 1 - a, 1 + a}/\((1 + a)\)]]]\)], "Input",
  Evaluatable->False],

Cell[BoxData[
    \(isotrop[z_] := 
      Module[{x, y, a}, 
        If[z \[Equal] Null, Print["\<Argument of isotrop is Null!\>"]; 
          Return[]]; \[IndentingNewLine]If[z \[Equal] ComplexInfinity, 
          Return[{0, 0, \(-1\), 1}]]; \[IndentingNewLine]x = 
          Re[z]; \[IndentingNewLine]y = Im[z]; \[IndentingNewLine]a = 
          Abs[z]^2; \[IndentingNewLine]Return[
          FullSimplify[{2\ x, 2\ y, 1 - a, 1 + a}]]]\)], "Input",
  Evaluatable->False],

Cell[BoxData[
    \(invisotrop[a_List] := 
      Module[{b}, If[Length[a] \[NotEqual] 4, Print["\<Argument of 
    invisotrop has incorrect dimension!\>"]; Return[]]; \[IndentingNewLine]If[
          a[\([4]\)] \[Equal] 0 || Simplify[Chop[pssp[a, a]]] \[NotEqual] 0, 
          Print["\<Incorrect argument of invisotrop!\>"]; 
          Return[]]; \[IndentingNewLine]b = 
          a[\([3]\)] + a[\([4]\)]; \[IndentingNewLine]If[b \[Equal] 0, 
          Return[ComplexInfinity]]; \[IndentingNewLine]Return[
          a[\([1]\)]/b + I*a[\([2]\)]/b]]\)], "Input",
  CellLabel->"In[10]:=",
  Evaluatable->False],

Cell[TextData[{
  StyleBox["ATTENTION!",
    FontColor->RGBColor[1, 0, 0]],
  " The function invisotrop returns Null and an error message, if the \
argument ist not an isotropic vector, e.g."
}], "Text"],

Cell[BoxData[
    \(invisotrop[\(-stb[4]\)]\)], "Input",
  CellLabel->"In[62]:="],

Cell[TextData[{
  "The function ",
  StyleBox["invisotrop is homogeneou",
    FontColor->RGBColor[0, 0, 1]],
  "s that means the rule (with r\[NotEqual] 0)"
}], "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(invisotrop[{x, y, z, \ Sqrt[x^2 + y^2 + z^2]}] \[Equal] \ 
      invisotrop[\(-{x, y, z, \ Sqrt[x^2 + y^2 + z^2]}\)*r]\)], "Input",
  CellLabel->"In[63]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(FullSimplify[%]\)], "Input",
  CellLabel->"In[64]:=",
  FontFamily->"Times New Roman"],

Cell["The homogenity is valid for arbitrary, e.g. complex factors:", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(invisotrop[{x, y, z, \ Sqrt[x^2 + y^2 + z^2]}] \[Equal] \ 
      invisotrop[\(-{x, y, z, \ Sqrt[x^2 + y^2 + z^2]}\)*I]\)], "Input",
  CellLabel->"In[113]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(FullSimplify[%]\)], "Input",
  CellLabel->"In[114]:="],

Cell[BoxData[
    \(Clear[w]\)], "Input",
  CellLabel->"In[115]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(invisotrop[{x, y, z, \ Sqrt[x^2 + y^2 + z^2]}] \[Equal] \ 
      invisotrop[\(-{x, y, z, \ Sqrt[x^2 + y^2 + z^2]}\)*w]\)], "Input",
  CellLabel->"In[116]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(FullSimplify[%]\)], "Input",
  CellLabel->"In[117]:=",
  FontFamily->"Times New Roman"],

Cell[TextData[{
  StyleBox["WARNING!",
    FontColor->RGBColor[1, 0, 0]],
  "  Of course, this yields an error in case w = 0:"
}], "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(invisotrop[{x, y, z, \ Sqrt[x^2 + y^2 + z^2]}] \[Equal] \ 
      invisotrop[\(-{x, y, z, \ Sqrt[x^2 + y^2 + z^2]}\)*0]\)], "Input",
  CellLabel->"In[118]:=",
  FontFamily->"Times New Roman"]
}, Closed]],

Cell[CellGroupData[{

Cell["2.3.3 Some basic points", "Subsubsection",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(isotrop1[0]\)], "Input",
  CellLabel->"In[65]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(isotrop1[1]\)], "Input",
  CellLabel->"In[66]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(isotrop1[\(-1\)]\)], "Input",
  CellLabel->"In[67]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(isotrop1[I]\)], "Input",
  CellLabel->"In[68]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(isotrop1[\(-I\)]\)], "Input",
  CellLabel->"In[69]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(invisotrop[{0, \(-a\), 0, a}]\)], "Input",
  CellLabel->"In[70]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(isotrop1[infy]\)], "Input",
  CellLabel->"In[71]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(isotrop1[\(-infy\)]\)], "Input",
  CellLabel->"In[72]:=",
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "Further teste see ",
  ButtonBox["below in subsection A4.1.2",
    ButtonData:>"riemT",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["2.3.4 Symbolic calculations", "Subsubsection"],

Cell["\<\
The maps isotrop, isotrop1, invisotrop may be used for symbolic \
calculations:\
\>", "Text"],

Cell[BoxData[{
    \(Clear[x, y]\), "\[IndentingNewLine]", 
    \(Declare[{x, y}, \ Real]\)}], "Input",
  CellLabel->"In[161]:="],

Cell[BoxData[
    \(RealQ[x]\)], "Input",
  CellLabel->"In[163]:="],

Cell[BoxData[
    \(isotrop1[x + I*y]\)], "Input",
  CellLabel->"In[164]:="],

Cell[BoxData[
    \(invisotrop[%]\)], "Input",
  CellLabel->"In[165]:="],

Cell["The maps act correctly also for complex x,y:", "Text"],

Cell[BoxData[
    \(Remove[x, y]\)], "Input",
  CellLabel->"In[166]:="],

Cell[BoxData[
    \(isotrop1[x + I*y]\)], "Input",
  CellLabel->"In[167]:="],

Cell[BoxData[
    \(invisotrop[%]\)], "Input",
  CellLabel->"In[168]:="],

Cell[BoxData[
    \(% \[Equal] \ x\  + \ I*y\)], "Input",
  CellLabel->"In[169]:="],

Cell[BoxData[
    \(FullSimplify[%]\)], "Input",
  CellLabel->"In[170]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["2.3.5 Spherical point plotting, the definitions", "Subsubsection",
  FontFamily->"Times New Roman"],

Cell["\<\
We model the Riemannian sphere as the  unit sphere in the \
3-dimensional euclidean space. The aim of this subsection is to define  \
functions yielding the coordinates of the point of this sphere which \
corresponds to the complex number z, and to plot it. Since isotrop1[z] is the \
isotropic vector representing  the corresponding point of the \
M\[ODoubleDot]bius sphere, which belongs to the 3-dimensional euclidean \
hyperplane\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(-pssp[stb[4], \ vec[x]]\)\  \[Equal] \ 1\)], "Input",
  CellLabel->"In[171]:="],

Cell[BoxData[
    \(\(\(-pssp[stb[4], \ isotrop1[z]]\)\(\ \)\)\)], "Input",
  CellLabel->"In[172]:="],

Cell["\<\
we simply have to take the first three coordinates of isotrop1[z] \
to obtain the wanted point:\
\>", "Text"],

Cell[BoxData[
    \(\(?rs2\)\)], "Input",
  CellLabel->"In[97]:="],

Cell[BoxData[
    \(rs2[z_] := \ Take[isotrop1[z], \ 3]\)], "Input",
  CellLabel->"In[12]:=",
  Evaluatable->False,
  FontFamily->"Times New Roman"],

Cell["The corresponding graphics object is", "Text"],

Cell[BoxData[
    \(\(?rs2point\)\)], "Input",
  CellLabel->"In[97]:="],

Cell[BoxData[
    \(rs2point[z_]\  := \ Point[rs2[z]]\)], "Input",
  CellLabel->"In[13]:=",
  Evaluatable->False,
  FontFamily->"Times New Roman"],

Cell["the plot of which is obtained by", "Text"],

Cell[BoxData[
    \(\(?rs2pointplot\)\)], "Input",
  CellLabel->"In[98]:="],

Cell[BoxData[
    \(rs2pointplot[z_, \ d_:  0.01]\  := \ 
      Show[Graphics3D[{PointSize[d], rs2point[z]}]]\)], "Input",
  CellLabel->"In[173]:=",
  Evaluatable->False,
  FontFamily->"Times New Roman"]
}, Closed]],

Cell[CellGroupData[{

Cell["2.3.6 Examples", "Subsubsection",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(rs2[1]\)], "Input",
  CellLabel->"In[99]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(rs2[0]\)], "Input",
  CellLabel->"In[100]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(rs2[infy]\)], "Input",
  CellLabel->"In[101]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(rs2[\((1 + I*Sqrt[3])\)/2]\)], "Input",
  CellLabel->"In[102]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(rs2[\((1 - I*Sqrt[3])\)/2]\)], "Input",
  CellLabel->"In[103]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(rs2[z]\)], "Input",
  CellLabel->"In[104]:="],

Cell[BoxData[
    \(% . %\)], "Input",
  CellLabel->"In[105]:="],

Cell[BoxData[
    \(FullSimplify[%]\)], "Input",
  CellLabel->"In[106]:="],

Cell[BoxData[
    \(ParametricPlot3D[rs2[Exp[I*t]], \ {t, 0, \ 2*Pi}]\)], "Input",
  CellLabel->"In[107]:="],

Cell["We join this circle with the unit sphere:", "Text"],

Cell[BoxData[
    \(Show[{%, sph1}]\)], "Input",
  CellLabel->"In[108]:="],

Cell["\<\
There is not much to see. We construct the image of a family of \
concentric circles with center 2*I:\
\>", "Text"],

Cell[BoxData[
    \(Table[
      ParametricPlot3D[rs2[2*I\  + r*Exp[I*t]], \ {t, 0, 2*Pi}], {r,  .5, 
        1.5,  .1}]\)], "Input",
  CellLabel->"In[109]:="],

Cell[BoxData[
    \(Show[%]\)], "Input",
  CellLabel->"In[110]:="],

Cell[BoxData[
    \(Show[{%, sph1}]\)], "Input",
  CellLabel->"In[111]:="],

Cell[BoxData[
    \(circles1\  = \ %\)], "Input",
  CellLabel->"In[112]:="],

Cell[TextData[{
  "Unfortunately, I do not know how to thicken 3D-curves in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". Thus, the image of the circle family is hardly to see on the sphere. \
Here helps ",
  ButtonBox["MathGL3D",
    ButtonData:>"MathGL",
    ButtonStyle->"Hyperlink"],
  " very well. If not done already,",
  ButtonBox[" link",
    ButtonData:>"getMGL3D",
    ButtonStyle->"Hyperlink"],
  " the program and call "
}], "Text"],

Cell[BoxData[
    \(MVShow3D[circles1, \ MVLineTubeSize\  -> \ 0.005]\)], "Input",
  CellLabel->"In[113]:="],

Cell["\<\
Use visual parameters, Wire frame, deactivate  black background and \
rotate or spin the picture. Clearly, one recognizes what is expected: a \
family of circles on the sphere. Try it with other circle families, and with \
the following family of lines:\
\>", "Text"],

Cell[BoxData[
    \(Table[
      ParametricPlot3D[rs2[2*I\  + Exp[I*r]*t], \ {t, \(-15\), 15}], {r, 0, 
        Pi, Pi/10}]\)], "Input",
  CellLabel->"In[114]:="],

Cell[BoxData[
    \(Show[%]\)], "Input",
  CellLabel->"In[115]:="],

Cell[BoxData[
    \(Show[{%, sph1}]\)], "Input",
  CellLabel->"In[116]:="],

Cell["Not much to see!", "Text"],

Cell[BoxData[
    \(circles2\  = \ %\)], "Input",
  CellLabel->"In[117]:="],

Cell["Use the same procedure as before:", "Text"],

Cell[BoxData[
    \(MVShow3D[%, \ MVLineTubeSize\  -> \ 0.002]\)], "Input",
  CellLabel->"In[118]:="],

Cell["\<\
You will recognize 11 cirles intersecting at the north pole and at \
the image \
\>", "Text"],

Cell[BoxData[
    \(rs2[2*I]\)], "Input",
  CellLabel->"In[66]:="],

Cell["Join the pictures:", "Text"],

Cell[BoxData[
    \(Show[{circles1, circles2}]\)], "Input",
  CellLabel->"In[120]:="],

Cell[BoxData[
    \(circles3\  = \ %\)], "Input",
  CellLabel->"In[121]:="],

Cell["\<\
Using MathGL3D and turning the picture in an appropriate way one \
recognizes two circle families on the M\[ODoubleDot]bius sphere forming an \
orthogonal net. This corresponds to the well known properties of the \
stereographical projection, being conformal and mapping circles into circles \
or lines. (See the next subsection)\
\>", "Text"],

Cell[BoxData[
    \(MVShow3D[circles3, \ MVLineTubeSize\  -> \ 0.002]\)], "Input",
  CellLabel->"In[122]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["2.3.7 rs2 is the inverse of a stereographical projection ", \
"Subsubsection"],

Cell["\<\
Indeed, we show that rs2 is the inverse of a stereographical \
projection. In euvec.m the stereographic projection has been defined as \
projection of the sphere from its north pole {0,0,1} onto the equatorial \
plane:\
\>", "Text"],

Cell[BoxData[
    \(\(?sterproj\)\)], "Input",
  CellLabel->"In[123]:="],

Cell[BoxData[
    \(sterproj[{0, 0, 1}]\)], "Input",
  CellLabel->"In[124]:="],

Cell["Applying sterproj we get z back as point in the x,y-plane:", "Text"],

Cell[BoxData[
    \(sterproj[rs2[z]]\)], "Input",
  CellLabel->"In[67]:="],

Cell["Thus, rs2 is the inverse of sterproj", "Text"],

Cell[BoxData[
    \(%[\([1]\)]\  + \ I*%[\([2]\)] \[Equal] \ z\)], "Input",
  CellLabel->"In[68]:="],

Cell[BoxData[
    \(FullSimplify[%]\)], "Input",
  CellLabel->"In[69]:="],

Cell["The following calculation confirmes the statement once more:", "Text"],

Cell[BoxData[
    \(Clear[a, b]\)], "Input",
  CellLabel->"In[70]:="],

Cell[BoxData[
    \(v2\  = \ sterproj[{a, b, Sqrt[1 - a^2 - b^2]}]\)], "Input",
  CellLabel->"In[71]:="],

Cell[BoxData[
    \(rs2[v2[\([1]\)]\  + \ I*v2[\([2]\)]]\)], "Input",
  CellLabel->"In[72]:="],

Cell[BoxData[
    \(FullSimplify[%, \ a > 0 && \ b > 0 && \ a^2 + b^2 < 1]\)], "Input",
  CellLabel->"In[73]:="],

Cell[BoxData[
    \(Clear[a, b, v2]\)], "Input",
  CellLabel->"In[74]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["2.3.8 The plot function", "Subsubsection",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(?rs2pointplot\)\)], "Input",
  CellLabel->"In[134]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Attributes[rs2pointplot]\)], "Input",
  CellLabel->"In[135]:=",
  FontFamily->"Times New Roman"],

Cell["\<\
We want to plot the points on the M\[ODoubleDot]bius sphere \
corresponding to the following list of complex numbers:\
\>", "Text"],

Cell[BoxData[
    \(equilist\  = {0, 1, 
        infy, \((1 + I*Sqrt[3])\)/2, \((1 - I*Sqrt[3])\)/2}\)], "Input",
  CellLabel->"In[136]:=",
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "These points are of  interest for specific crossratios, considered ",
  ButtonBox["below",
    ButtonData:>"equith",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[BoxData[
    \(rs2point[equilist]\)], "Input",
  CellLabel->"In[137]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(rs2pointplot[I,  .05]\)], "Input",
  CellLabel->"In[138]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(rs2pointplot[equilist,  .05]\)], "Input",
  CellLabel->"In[139]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(equianharm\  = \ %\)], "Input",
  CellLabel->"In[140]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Show[{sph1, \ equianharm}]\)], "Input",
  CellLabel->"In[141]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(equipict\  = \ %\)], "Input",
  CellLabel->"In[142]:=",
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "In section 7.2.1 ",
  ButtonBox["equipict",
    ButtonData:>"equipict",
    ButtonStyle->"Hyperlink"],
  " is animated with MathGL3D, and  another application of rs2pointplot is \
shown."
}], "Text"],

Cell["", "Text"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["3 The M\[ODoubleDot]bius group", "Section",
  FontFamily->"Times New Roman"],

Cell["\<\
In this section  the special M\[ODoubleDot]bius group is introduced \
as the projective automorphism group of the complex line, i.e. the group of \
broken linear transformations of the Riemannian sphere. In complex function \
theory it is proved that this group coincides with the group of bijective \
meromorphic transformations of  the Riemannian sphere. From the geometric \
point of view it is the group of orientation preserving conformal \
transformations of the Riemannian sphere onto itself. Since conjugation \
reverses the orientation the group of all conformal transformations of the \
sphere onto itself is the union of the group of broken linear transformations \
with the set of broken conjugate-linear transgormations, considered in \
subsection 3.2.. \
\>", "Text"],

Cell[CellGroupData[{

Cell["3.1 The Elements", "Subsection",
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "The ",
  StyleBox["M\[ODoubleDot]bius group",
    FontColor->RGBColor[1, 0, 0]],
  " of the Riemannian sphere is the group of all transformations of shape"
}], "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(?g0\)\)], "Input",
  CellLabel->"In[93]:="],

Cell[BoxData[
    \(\(g0[a, b, c, d]\)[z]\)], "Input",
  CellLabel->"In[94]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(g0[a, b, c, d]\)[infy]\)], "Input",
  CellLabel->"In[95]:="],

Cell["or", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(?g1\)\)], "Input",
  CellLabel->"In[49]:="],

Cell[BoxData[
    \(\(\(\(g1[a, b, c, d]\)[z]\)\(\ \)\)\)], "Input",
  CellLabel->"In[96]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(\(\(g1[a, b, c, d]\)[infy]\)\(\ \)\)\)], "Input",
  CellLabel->"In[97]:=",
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "with ad-bc \[NotEqual] 0; one may assume ad-bc = 1. The transformations g0 \
form a subgroup G0, called the ",
  StyleBox["special M\[ODoubleDot]bius group",
    FontColor->RGBColor[1, 0, 0]],
  ". The map z \[RightTeeArrow] Conjugate[z] is of shape g1: "
}], "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(g1[1, 0, 0, 1]\)[z]\)], "Input",
  CellLabel->"In[97]:=",
  FontFamily->"Times New Roman"],

Cell["\<\
Therefore the set of maps g1 is G1=G0\[SmallCircle]Conjugate. Or \
else\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(g1[a, b, c, d]\)[Conjugate[z]] \[Equal] \ \(g0[a, b, c, d]\)[
        z]\)], "Input",
  CellLabel->"In[99]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(g0[a, b, c, d]\)[Conjugate[z]] \[Equal] \ \(g1[a, b, c, d]\)[
        z]\)], "Input",
  CellLabel->"In[100]:=",
  FontFamily->"Times New Roman"],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  FontFamily->"Times New Roman"],

Cell["\<\
We did not exclude the case as-bc = 0 in the Modules; the functions \
calculated in this case are not M\[ODoubleDot]bius transforms. They have \
indeterminate or constant values:\
\>", "Text"],

Cell[BoxData[
    \(\(g0[0, 0, 0, 0]\)[z]\)], "Input",
  CellLabel->"In[101]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(g0[1, 1, 2, 2]\)[z]\)], "Input",
  CellLabel->"In[102]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(% \[Equal] 1/2\)], "Input",
  CellLabel->"In[103]:="],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[104]:="],

Cell[BoxData[
    \(\(g0[1, 0, 1, 0]\)[z]\)], "Input",
  CellLabel->"In[105]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(g1[1, 2, 0, 0]\)[z]\)], "Input",
  CellLabel->"In[106]:=",
  FontFamily->"Times New Roman"],

Cell["Here are examples of M\[ODoubleDot]bius transforms: ", "Text"],

Cell[BoxData[
    \(\(g0[a, b, c, d]\)[z]\)], "Input",
  CellLabel->"In[107]:="],

Cell[BoxData[
    \(\(g1[a, b, c, d]\)[z]\)], "Input",
  CellLabel->"In[108]:="],

Cell[BoxData[
    \(\(g0[1, 0, 0, 1]\)[z]\)], "Input",
  CellLabel->"In[109]:=",
  FontFamily->"Times New Roman"],

Cell["\<\
Remember: ComplexInfinity = infy is an element of the Riemannian \
Sphere.\
\>", "Text"],

Cell[BoxData[
    \(\(g0[1, 0, 0, 1]\)[infy]\)], "Input",
  CellLabel->"In[110]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(g0[a, b, c, d]\)[infy]\)], "Input",
  CellLabel->"In[111]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(g1[1, 0, 0, 1]\)[z]\)], "Input",
  CellLabel->"In[112]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(g0[a, b, c, d]\)[\(-d\)/c]\)], "Input",
  CellLabel->"In[113]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(g1[a, b, c, d]\)[\(-d\)/c]\)], "Input",
  CellLabel->"In[114]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(FullSimplify[%]\)], "Input",
  CellLabel->"In[115]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(g1[a, b, c, d]\)[\(-Conjugate[d/c]\)]\)], "Input",
  CellLabel->"In[116]:=",
  FontFamily->"Times New Roman"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["3.2 The group structure", "Subsection",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Simplify[\(g0[a, b, c, d]\)[\(g0[u, v, w, x]\)[z]]]\)], "Input",
  CellLabel->"In[117]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \({{a, b}, {c, d}} . {{u, v}, {w, x}} // MatrixForm\)], "Input",
  CellLabel->"In[118]:=",
  FontFamily->"Times New Roman"],

Cell["\<\
These equations show that the special M\[ODoubleDot]bius group G0 \
is  the homomorphic image of the special linear group SL(2,C); the kernel of \
the homomorphism is \[PlusMinus]1. It can also be considered as the \
homomorphic image of the general linear group GL(2,C). The kernel of this \
homomorphism is the solution of\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Solve[{\(g0[a, b, c, d]\)[0] \[Equal] 0, \(g0[a, b, c, d]\)[1] \[Equal] 
          1, \(g0[a, b, c, d]\)[I] \[Equal] I}, {a, b, c, d}]\)], "Input",
  CellLabel->"In[119]:=",
  FontFamily->"Times New Roman"],

Cell["Thus, the maps", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(g0[a, 0, 0, a]\)[z]\)], "Input",
  CellLabel->"In[120]:=",
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "and only these give the identity. By ",
  Cell[BoxData[
      \(TraditionalForm\`a\^2\)]],
  "=1 we get the stated result. Obviously, g0[d,-b,-c,a] is the Inverse of \
g0[a,b,c,d]: "
}], "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Simplify[\(g0[a, b, c, d]\)[\(g0[d, \(-b\), \(-c\), a]\)[
          z]]]\)], "Input",
  CellLabel->"In[121]:=",
  FontFamily->"Times New Roman"],

Cell["Also we have: ", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Simplify[\(g0[a, b, c, d]\)[\(g1[d, \(-b\), \(-c\), a]\)[
          z]]]\)], "Input",
  CellLabel->"In[122]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Simplify[\(g0[a, b, c, d]\)[\(g1[u, v, w, x]\)[z]]]\)], "Input",
  CellLabel->"In[123]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Simplify[\(g1[a, b, c, d]\)[\(g0[u, v, w, x]\)[z]]]\)], "Input",
  CellLabel->"In[124]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(FullSimplify[\(g1[a, b, c, d]\)[\(g1[u, v, w, x]\)[z]]]\)], "Input",
  CellLabel->"In[125]:=",
  FontFamily->"Times New Roman"],

Cell["Thus we have", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(G0 . G0\  = \ \(G1 . G1 = 
        G0\), \ \ and\ G0 . G1\  = \ \(G1 . 
          G0\  = \ \(\(G1\)\(.\)\)\)\)], "Input",
  Evaluatable->False,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "On the other hand, the M\[ODoubleDot]bius group as the isotropy group of \
the elliptic quadric of  the 3-dimensional projectiv space is the group \
O(3,1)+ of time-preserving,  pseudo-orthogonal transformations of the \
4-dimensional pseudo-euclidean vector space. There exists an homomorphism of \
the complex special linear group onto the connected component of the group \
O(3,1) with kernel  {\[PlusMinus]1}, which consists of the time- and \
space-orientation preserving pseudo-orthogonal transformations, see ",
  ButtonBox["[O.-S.]",
    ButtonData:>"O.-S.",
    ButtonStyle->"Hyperlink"],
  ", section 2.7.  In section 7 below we describe this homomorphism."
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["4 Cross ratio and M\[ODoubleDot]bius invariants of point pairs", \
"Section",
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "On a projective line the crossratio is the basic invariant. We define the \
cross ratio for quadrupels of points of the Riemannian sphere and describe \
its properties in subsection 4.1. On the other hand, a quadrupel of points \
can be considered as a pair of 0-spheres  in the M\[ODoubleDot]bius sphere. \
Its position up to M\[ODoubleDot]bius transforms is characterized by two real \
invariants, see e.g.",
  ButtonBox[" [O.-S.] ",
    ButtonData:>"O.-S.",
    ButtonStyle->"Hyperlink"],
  "or ",
  ButtonBox["[S1]",
    ButtonData:>"S1",
    ButtonStyle->"Hyperlink"],
  ". In subsection 4.2 we describe these invariants und clear its relation \
with the cross ratio. "
}], "Text"],

Cell[CellGroupData[{

Cell["4.1 Cross ratios", "Subsection",
  FontFamily->"Times New Roman",
  CellTags->"CrRatio"],

Cell[CellGroupData[{

Cell["4.1.1 The definition", "Subsubsection",
  FontFamily->"Times New Roman"],

Cell["We consider two point pairs ", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(pz\  = \ {z1, \ z2}; \ pw\  = {w1, w2};\)], "Input",
  FontFamily->"Times New Roman"],

Cell["We put them together to the point quadrupel", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(pzw\  = \ Join[pz, pw]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "Any point quadrupel pq with  at least three of the four points different \
is called a ",
  StyleBox["throw",
    FontColor->RGBColor[1, 0, 0]],
  ". For throws the ",
  StyleBox["cross ratio ",
    FontColor->RGBColor[1, 0, 0]],
  "is defined as"
}], "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(?crossratio\)\)], "Input",
  CellLabel->"In[88]:="],

Cell["The cross ratio is defined in the package riemann.m as", "Text"],

Cell[BoxData[
    \(\(\(crossratio[p1_List, p2_List] := \ 
      Module[{p = Join[p1, p2]}, \[IndentingNewLine]If[
          Length[p]\  \[NotEqual] \ 4\ , \ Print["\<Incorrect Argument!\>"]; 
          Return[]]; \[IndentingNewLine]If[Length[Union[p]] < 3, \ 
          Print["\<Less than 3 points!\>"]; Return[]]; \[IndentingNewLine]If[
          p[\([1]\)]\  \[Equal] p[\([4]\)]\  || \ 
            p[\([2]\)]\  \[Equal] p[\([3]\)]\ , \ 
          Return[\ ComplexInfinity]]; \[IndentingNewLine]If[
          p[\([1]\)]\  \[Equal] p[\([3]\)]\  || \ 
            p[\([2]\)]\  \[Equal] p[\([4]\)], \ 
          Return[0]]; \[IndentingNewLine]If[
          p[\([1]\)]\  \[Equal] p[\([2]\)]\  || \ 
            p[\([4]\)]\  \[Equal] p[\([3]\)], \ 
          Return[1]]; \[IndentingNewLine]If[
          p[\([1]\)]\  \[Equal] \ ComplexInfinity, \ 
          Return[\((p[\([2]\)] - 
                  p[\([4]\)])\)*\((p[\([2]\)] - 
                    p[\([3]\)])\)^\(-1\)]]; \[IndentingNewLine]If[
          p[\([2]\)]\  \[Equal] \ ComplexInfinity, \ 
          Return[\((p[\([1]\)] - 
                  p[\([3]\)])\)*\((p[\([1]\)] - 
                    p[\([4]\)])\)^\(-1\)]]; \[IndentingNewLine]If[
          p[\([3]\)]\  \[Equal] \ ComplexInfinity, \ 
          Return[\((p[\([2]\)] - 
                  p[\([4]\)])\)*\((p[\([1]\)] - 
                    p[\([4]\)])\)^\(-1\)]]; \[IndentingNewLine]If[
          p[\([4]\)]\  \[Equal] \ ComplexInfinity, \ 
          Return[\((p[\([1]\)] - 
                  p[\([3]\)])\)*\((p[\([2]\)] - 
                    p[\([3]\)])\)^\(-1\)]]; \[IndentingNewLine]\((p[\([1]\)] \
- p[\([3]\)])\)*\((p[\([1]\)] - 
                p[\([4]\)])\)^\(-1\)*\((\((p[\([2]\)] - 
                    p[\([3]\)])\)*\((p[\([2]\)] - 
                      p[\([4]\)])\)^\(-1\))\)^\(-1\)]\)\(\[IndentingNewLine]\)\

    \)\)], "Input",
  CellLabel->"In[12]:=",
  Evaluatable->False,
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(SetAttributes[crossratio, \ Orderless]\)], "Input",
  CellLabel->"In[13]:=",
  Evaluatable->False,
  FontFamily->"Times New Roman"],

Cell["The main part of the definition is the last line:", "Text"],

Cell[BoxData[
    \(crossratio[{p1, p2}, {p3, p4}]\)], "Input",
  CellLabel->"In[98]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["4.1.2 Examples", "Subsubsection",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(crossratio[{z, w}, {w, w}]\)], "Input",
  CellLabel->"In[91]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(crossratio[{z, w}, {w, w, 1}]\)], "Input",
  CellLabel->"In[92]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(crossratio[{infy, 1}, {0, infy}]\)], "Input",
  CellLabel->"In[93]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(crossratio[{z, 1}, {0, infy}]\)], "Input",
  CellLabel->"In[99]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(crossratio[{1, infy}, {0, infy}]\)], "Input",
  CellLabel->"In[94]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(crossratio[{1, 0}, {infy, infy}]\)], "Input",
  CellLabel->"In[95]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(crossratio[{1, 0}, {c, c}]\)], "Input",
  CellLabel->"In[96]:=",
  FontFamily->"Times New Roman"]
}, Closed]],

Cell[CellGroupData[{

Cell["4.1.3 Identities for the crossratio", "Subsubsection",
  FontFamily->"Times New Roman"],

Cell["The cross ratio fulfils the identities", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(\(\ \)\(crossratio[{c, d}, {a, b}] == 
      crossratio[{a, b}, {c, d}]\)\)\)], "Input",
  CellLabel->"In[100]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(\(\ \)\(crossratio[{b, a}, {d, c}] == 
      crossratio[{a, b}, {c, d}]\)\)\)], "Input",
  CellLabel->"In[101]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(\(\ \)\(crossratio[{a, b}, {d, c}] \[Equal] 
      1/crossratio[{a, b}, {c, d}]\)\)\)], "Input",
  CellLabel->"In[103]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(\(\ \)\(crossratio[{a, c}, {b, d}] \[Equal] 
      1 - crossratio[{a, b}, {c, d}]\)\)\)], "Input",
  CellLabel->"In[104]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[105]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(\(\ \)\(crossratio[{a, d}, {b, c}] \[Equal] 
      1 - 1/crossratio[{a, b}, {c, d}]\)\)\)], "Input",
  CellLabel->"In[106]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[107]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(\(\ \)\(crossratio[{a, c}, {d, b}] \[Equal] 
      1/\((1 - crossratio[{a, b}, {c, d}])\)\)\)\)], "Input",
  CellLabel->"In[108]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[109]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(\(\ \)\(crossratio[{a, d}, {c, b}] \[Equal] 
      crossratio[{a, b}, {c, d}]/\((crossratio[{a, b}, {c, d}] - 
            1)\)\)\)\)], "Input",
  CellLabel->"In[110]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[111]:=",
  FontFamily->"Times New Roman"],

Cell["\<\
The last four identities imply, that the cross ratios of all the 24 \
permutations of the elements a,b,c,d give only at most six different values; \
with z = crossratio[{a,b},{c,d}] these are\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(?crvalues\)\)], "Input",
  CellLabel->"In[88]:="],

Cell["The definition in riemann.m is", "Text"],

Cell[BoxData[
    \(crvalues[z_] := 
      Union[FullSimplify[{z, \ 1 - z, \ 1/z, \ 1\  - \ 1/z, \ 
            1/\((1 - z)\), \ z/\((z - 1)\)}]]\)], "Input",
  CellLabel->"In[12]:=",
  Evaluatable->False,
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(crvalues[z]\)], "Input",
  CellLabel->"In[89]:="],

Cell["\<\
Less than six different values we obtain in the following cases:
The base points:\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(crvalues[0]\)], "Input",
  CellLabel->"In[90]:=",
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "The ",
  StyleBox["harmonic throws:",
    FontColor->RGBColor[1, 0, 0]]
}], "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(crvalues[\(-1\)]\)], "Input",
  CellLabel->"In[91]:=",
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "The ",
  StyleBox["equianharmonic throws:",
    FontColor->RGBColor[1, 0, 0]]
}], "Text",
  FontFamily->"Times New Roman",
  CellTags->"equith"],

Cell[BoxData[
    \(crvalues[\((1 + I*Sqrt[3])\)/2]\)], "Input",
  CellLabel->"In[92]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(crvalues[\((1 - I*Sqrt[3])\)/2]\)], "Input",
  CellLabel->"In[93]:=",
  FontFamily->"Times New Roman"],

Cell["\<\
Therefore, in the equianharmonic case we have only two distinct \
values, which are the roots of the quadratic polynomial\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Root[x^2\  - \ x\  + \ 1, 1]\)], "Input",
  CellLabel->"In[94]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Root[x^2\  - \ x\  + \ 1, 2]\)], "Input",
  CellLabel->"In[95]:=",
  FontFamily->"Times New Roman"]
}, Closed]],

Cell[CellGroupData[{

Cell["4.1.4 Projective scales", "Subsubsection",
  FontFamily->"Times New Roman"],

Cell["\<\
The cross ratios of throws with only three distinct points  have \
the following values:\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(crvalues[0]\)], "Input",
  CellLabel->"In[96]:="],

Cell[TextData[{
  "which serve as  ",
  StyleBox["the base points of the standard projective scale.  ",
    FontColor->RGBColor[1, 0, 0]],
  "Generally, the projective scale with a tripel {b,c,d} of   three different \
points as base points is ",
  "defined by the function"
}], "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(?scale\)\)], "Input",
  CellLabel->"In[86]:="],

Cell["The definition in riemann.m:", "Text"],

Cell[BoxData[
    \(\(scale[b_, c_, d_]\)[z_]\  := \ crossratio[{z, b}, {c, d}]\)], "Input",\

  CellLabel->"In[12]:=",
  Evaluatable->False,
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(scale[b, c, d]\)[z]\)], "Input",
  CellLabel->"In[87]:="],

Cell[BoxData[
    \({\(scale[b, c, d]\)[b], \(scale[b, c, d]\)[c], \(scale[b, c, d]\)[
        d]}\)], "Input",
  CellLabel->"In[89]:=",
  FontFamily->"Times New Roman"],

Cell[TextData[{
  StyleBox["Lemma.",
    FontColor->RGBColor[1, 0, 0],
    FontVariations->{"Underline"->True}],
  " Given three distinct points {u0,u1,u2}, there always exists a uniquely \
defined M\[ODoubleDot]bius transformation \ng0=g0[a,b,c,d] with the property  \
g0(0) = u0, g0(1) = u1, g0(infy) = u2.\nProof: We have to find parameters \
a,b,c,d with a*d-b*c = 1 which fulfil the conditions. The resilts of"
}], "Text"],

Cell[BoxData[
    \(\(g0[a, b, c, d]\)[0]\)], "Input",
  CellLabel->"In[91]:="],

Cell[BoxData[
    \(\(g0[a, b, c, d]\)[1]\)], "Input",
  CellLabel->"In[92]:="],

Cell[BoxData[
    \(\(g0[a, b, c, d]\)[infy]\)], "Input",
  CellLabel->"In[93]:="],

Cell["lead to the system of equations:", "Text"],

Cell[BoxData[
    \(Solve[{b - \ u0*d\  \[Equal] \ 
          0, \ \((a + b)\) - u1*\((c + d)\) \[Equal] \ 0, \ 
        a - u2*c\  \[Equal] \ 0, \ a*d - b*c \[Equal] 1}, \ {a, b, c, 
        d}]\)], "Input",
  CellLabel->"In[94]:="],

Cell["\<\
 The two solutions differ by sign only; thus the corresponding \
transformations are the same:\
\>", "Text"],

Cell[BoxData[
    \(va\  = \ {a, b, c, d} /. %[\([1]\)]\)], "Input",
  CellLabel->"In[95]:="],

Cell[BoxData[
    \(vb\  = {a, b, c, d} /. %%[\([2]\)]\)], "Input",
  CellLabel->"In[96]:="],

Cell[BoxData[
    \(va + vb\)], "Input",
  CellLabel->"In[97]:="],

Cell[BoxData[
    \(Together[%]\)], "Input",
  CellLabel->"In[98]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["4.1.5 Invariance of the cross ratio", "Subsubsection",
  FontFamily->"Times New Roman"],

Cell["\<\
The cross ratio is invariant under M\[ODoubleDot]bius \
transformations g0:\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(g00[z_]\  := \ \(g0[a, b, c, d]\)[z]\)], "Input",
  CellLabel->"In[99]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(SetAttributes[g00, \ Listable]\)], "Input",
  CellLabel->"In[100]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(w1 = vec[z, 2]; \ w2\  = \ vec[u, 2]\)], "Input",
  CellLabel->"In[101]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(g00[w1]\)], "Input",
  CellLabel->"In[102]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(crossratio[g00[w1], \ g00[w2]]\)], "Input",
  CellLabel->"In[103]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(FullSimplify[%]\)], "Input",
  CellLabel->"In[104]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(% \[Equal] crossratio[w1, w2]\)], "Input",
  CellLabel->"In[105]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[106]:=",
  FontFamily->"Times New Roman"],

Cell["\<\
Under the action of g1 the crossratio transforms into its  \
conjugate; consider g1[z] = g0[Conjugate[z]],  and calculate\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Conjugate[w1]\)], "Input",
  CellLabel->"In[107]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(g00[Conjugate[w1]]\)], "Input",
  CellLabel->"In[108]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(crossratio[g00[Conjugate[w1]], g00[Conjugate[w2]]] \[Equal] \ 
      Conjugate[crossratio[w1, w2]]\)], "Input",
  CellLabel->"In[109]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[110]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(FullSimplify[%]\)], "Input",
  CellLabel->"In[111]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Clear[g00, w1, w2]\)], "Input",
  CellLabel->"In[112]:=",
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "From the bijectivity of the projective scales, the lemma in 4.1.4,  and \
the invariance property just proved one concludes:\n",
  StyleBox["Theorem.",
    FontColor->RGBColor[1, 0, 0],
    FontVariations->{"Underline"->True}],
  " Two throws {x1,x2,x3,x4}, {y1,y2,y3,y4} are projectively equivalent, i.e. \
there exists a transformation \ng0 = g0[a,b,c,d] with g0[xi] = [yi], i = \
1,2,3,4, if and only if their cross ratios coincide:\n\
crossratio[{x1,x2},{x3,x4}] == crossratio[{y1,y2},{y3,y4}]."
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["4.2 A complete M\[ODoubleDot]bius invariant system for two point \
pairs", "Subsection",
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "We consider pairs of  0-spheres, i.e. point quadrupels {{z1,z2},{w1,w2}}. \
The cross ratio is a complex number, thus, as proved in the general theory ",
  ButtonBox["[S1]",
    ButtonData:>"S1",
    ButtonStyle->"Hyperlink"],
  ",  we have  two real invariants describing the mutual position of two \
point pairs in the M\[ODoubleDot]bius sphere. We first import the needed \
constructs from the notebook pairs.nb in ",
  ButtonBox["[S3]",
    ButtonData:>"S3",
    ButtonStyle->"Hyperlink"],
  ". Then we compare these invariants with the cross ratio of the \
corresponding four points on the Riemannian sphere."
}], "Text",
  FontFamily->"Times New Roman"],

Cell[CellGroupData[{

Cell["4.2.1 Preparations", "Subsubsection",
  FontFamily->"Times New Roman"],

Cell["\<\
The following procedure defines an adapted pseudo-orthogonal frame \
of the 4-space   to two given points of the complex plane; adaption means \
that the third and the last vectors span a pseudo-euclidean 2-space whose \
isotropic subspaces represent the corresponding  points of the Riemannian \
sphere:  \
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(?rspsframepp\)\)], "Input",
  CellLabel->"In[76]:="],

Cell["The definition in riemann.m is", "Text"],

Cell[BoxData[
    \(\(\(rspsframepp[z1_, z2_]\  := \ 
      Module[{\[IndentingNewLine]\ m = \ Table[null[], {4}], mv, \ 
          mw}, \n\t\tIf[z1 \[Equal] z2, \ Print["\<Incorrect arguments!\>"]; 
          Return[]]; \[IndentingNewLine]m[\([3]\)] = 
          isotrop[z1] - isotrop[z2]; \[IndentingNewLine]m[\([4]\)] = 
          isotrop[z1] + isotrop[z2]; \[IndentingNewLine]mv\  = \ 
          psCross[stb[1], m[\([3]\)], m[\([4]\)]]; \[IndentingNewLine]mw\  = 
          psCross[stb[2], m[\([3]\)], m[\([4]\)]]; \[IndentingNewLine]If[
          mv \[Equal] \ null[], m[\([1]\)] = mw, \ m[\([1]\)] = mv, 
          m[\([1]\)] = 
            mv]; \[IndentingNewLine]m[\([2]\)]\  = \ \(-psCross[m[\([1]\)], 
              m[\([3]\)], m[\([4]\)]]\); \n
        Return[Table[normalize[m[\([i]\)]], \ {i, 4}]]]\)\(\t\)\(\n\)
    \)\)], "Input",
  CellLabel->"In[136]:=",
  Evaluatable->False,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "For examples and tests see ",
  ButtonBox["A4.1.3",
    ButtonData:>"rspsframepp",
    ButtonStyle->"Hyperlink"],
  " ."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "4.2.2 The subspace of ",
  Cell[BoxData[
      \(TraditionalForm\`V\^4\)]],
  "orthogonal to the points isotrop1[z1], ",
  "isotrop1[",
  "z2]"
}], "Subsubsection",
  FontFamily->"Times New Roman"],

Cell["\<\
Of course, the two vectors of rspsframepp[z1,z2][[i]], i = 1,2, are \
an orthonormal basis of the orthogonal complement to  isotrop1[z1], \
isotrop1[z2]:\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(?rsvspacepp\)\)], "Input",
  CellLabel->"In[79]:="],

Cell["The definition in riemann.m:", "Text"],

Cell[BoxData[
    \(rsvspacepp[z1_, z2_]\  := \ 
      Module[{psf}, \[IndentingNewLine]psf\  = \ 
          rspsframepp[z1, z2]; \[IndentingNewLine]If[psf\  \[Equal] Null, \ 
          Return[Null]]; \[IndentingNewLine]{psf[\([1]\)], \ 
          psf[\([2]\)]}]\)], "Input",
  CellLabel->"In[11]:=",
  Evaluatable->False,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "Examples and tests s.",
  ButtonBox[" A.4.1.4",
    ButtonData:>"rsvspacepp",
    ButtonStyle->"Hyperlink"],
  " ."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["4.2.3 The defining operator", "Subsubsection",
  FontFamily->"Times New Roman"],

Cell["\<\
Let {a_list, b_list} = {{a1,a2},{b1,b2}} be two point pairs in the  \
complex plane, and Wa, Wb the corresponding  2-spaces, adapted with  \
rsvspacepp. Then the matrix of the corresponding double projection A\
\>", \
"Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(prb : \ Wa\  \[RightArrow] \ Wb, \ pra : \ Wb\  \[RightArrow] \ Wa, \ 
    A := \ pra\[SmallCircle]\(prb : \ Wa\)\  \[Rule] \ Wa\)], "Input",
  Evaluatable->False,
  FontFamily->"Times New Roman"],

Cell[" is defined by", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(?rsoperatorpp\)\)], "Input",
  CellLabel->"In[108]:="],

Cell["The definition in riemann.m:", "Text"],

Cell[BoxData[
    \(rsoperatorpp[a_List, \ b_List]\  := \ 
      Module[{av, \ bv, \ i, \ j, k}, \n\t\tav\  = \ 
          rsvspacepp[a[\([1]\)], \ a[\([2]\)]]; \n\t
        bv\  = \ rsvspacepp[b[\([1]\)], \ b[\([2]\)]]; \[IndentingNewLine]If[
          av\  \[Equal] \ Null || bv \[Equal] Null, \ 
          Return[]]; \[IndentingNewLine]If[a \[Equal] b, \ 
          Return[IdentityMatrix[2]]]; \n\t\tTable[
          Sum[pssp[av[\([j]\)], bv[\([k]\)]]*
              pssp[av[\([i]\)], bv[\([k]\)]], {k, 2}], \n\t\t\t{i, 2}, {j, 
            2}]]\)], "Input",
  CellLabel->"In[13]:=",
  Evaluatable->False,
  FontFamily->"Times New Roman"],

Cell["\<\
The eigenvalues of this matrix, i.e. of the self-adjoint operator \
A, and the rank\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    RowBox[{
      RowBox[{"rk", "[", 
        RowBox[{"a1_", ",", " ", "a2_", ",", " ", "b1_", ",", " ", "b2_"}], 
        "]"}], ":=", 
      RowBox[{"rank", "[", 
        RowBox[{"Join", "[", 
          RowBox[{
            RowBox[{"rsvspacepp", "[", 
              RowBox[{"a1", ",", " ", "a2"}], "]"}], ",", 
            RowBox[{"rsvspacepp", "[", 
              RowBox[{"b1", ",", " ", "b2"}], "]"}]}], "]"}], 
        "]"}]}]], "Input",
  CellLabel->"In[10]:=",
  InitializationCell->True,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  " are a complete invariant system for the M\[ODoubleDot]bius geometry of \
point pairs, compare ",
  ButtonBox["[O.-S.]",
    ButtonData:>"O.-S.",
    ButtonStyle->"Hyperlink"],
  " or  ",
  ButtonBox["[S1]",
    ButtonData:>"S1",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(?rank\)\)], "Input",
  CellLabel->"In[79]:=",
  FontFamily->"Times New Roman"],

Cell["If the two point pairs coincide, we get the identity matrix:", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(rsoperatorpp[{z, w}, \ {z, w}]\)], "Input",
  CellLabel->"In[110]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(rk[z, w, z, w]\)], "Input",
  CellLabel->"In[111]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(rsoperatorpp[{z, z}, \ {z, z}]\)], "Input",
  CellLabel->"In[112]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(rk[z, z, z, z]\)], "Input",
  CellLabel->"In[113]:=",
  FontFamily->"Times New Roman"],

Cell["rsoperatorpp is not good in symbolic calculations, e.g.:", "Text"],

Cell[BoxData[
    \(Clear[z, u, w]\)], "Input",
  CellLabel->"In[80]:="],

Cell[BoxData[
    \(Declare[{x, y, u1, u2, w1, w2}, \ Real]\)], "Input",
  CellLabel->"In[81]:="],

Cell[BoxData[
    \(z\  = \ x + I*y; \ u\  = \ u1 + I*u2; \ w = w1\  + \ I*w2;\)], "Input",
  CellLabel->"In[82]:="],

Cell["You will get a very long expression:", "Text"],

Cell[BoxData[
    \(rsoperatorpp[{z, u}, \ {z, w}]\)], "Input",
  CellLabel->"In[83]:=",
  FontFamily->"Times New Roman"],

Cell["\<\
but Mathematica  could simplify it in a comparatively short time; \
important, very likely, that the reality of the variables is declared. The \
result is the unity matrix.\
\>", "Text"],

Cell[BoxData[
    \(Simplify[%, 
      x > 0 && y > 0 && u1 > 0 && u2 > 0 && w1 > 0 && w2 > 0]\)], "Input",
  CellLabel->"In[84]:="],

Cell[BoxData[
    \(rk[z, u, z, w]\)], "Input",
  CellLabel->"In[85]:="],

Cell[BoxData[
    \(rsoperatorpp[{z, 1}, \ {z, infy}]\)], "Input",
  CellLabel->"In[86]:="],

Cell[BoxData[
    \(Simplify[%, \ x > 0 && y > 0]\)], "Input",
  CellLabel->"In[87]:="],

Cell["\<\
Clearly, any three distinct points of the Riemannian sphere are M\
\[ODoubleDot]bius equivalent; therefore we have the same invariants 1 for any \
pair of 0-spheres with a common point. It would have been enough to calculate\
\
\>", "Text"],

Cell[BoxData[
    \(rsoperatorpp[{0, 1}, \ {0, infy}]\)], "Input",
  CellLabel->"In[88]:="],

Cell[BoxData[
    \(rsoperatorpp[{\(-1\), 0}, \ {0, infy}]\)], "Input",
  CellLabel->"In[89]:="],

Cell[BoxData[
    \(rsoperatorpp[{1, 0}, \ {0, infy}]\)], "Input",
  CellLabel->"In[90]:="],

Cell[BoxData[
    \(rsoperatorpp[{1, 0}, \ {infy, \ 0}]\)], "Input",
  CellLabel->"In[91]:="],

Cell["Example: The 0-spheres {-I,1}, {0,infy}", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(rsoperatorpp[{\(-I\), 1}, {0, \ infy}]\)], "Input",
  CellLabel->"In[92]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Eigenvalues[%]\)], "Input",
  CellLabel->"In[93]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Eigensystem[%%]\)], "Input",
  CellLabel->"In[94]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(rk[\(-I\), 1, 0, infy]\)], "Input",
  CellLabel->"In[95]:=",
  FontFamily->"Times New Roman"]
}, Closed]],

Cell[CellGroupData[{

Cell["4.2.4 The pairs {z,1}, {0, infy}", "Subsubsection",
  FontFamily->"Times New Roman"],

Cell["\<\
Question: Express the eigenvalues by the cross ratio and vice \
versa. Since for the cross ratio one has z=(z,1;0,infy), and one always can \
find a M\[ODoubleDot]bius transform with {z1,z2,z3} -> {1,0,infy} for any \
tripel of different points, the example under consideration is of general \
interest.\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Clear[z, x, y]; \ Declare[{x, y}, \ Real]; \ 
    z\  = \ x\  + \ I*y;\)], "Input",
  CellLabel->"In[80]:="],

Cell["\<\
First we calculate the operator rsoperatorpp[{z,1}, {0,infy}] as  a \
function of x,y:\
\>", "Text"],

Cell[BoxData[
    \(rsoperatorpp[{z, 1}, \ {0, infy}]\)], "Input",
  CellLabel->"In[81]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(% //. \ Abs[A_]\  \[Rule] \ A\)], "Input",
  CellLabel->"In[82]:="],

Cell[BoxData[
    \(FullSimplify[%, x > 0 && y > 0]\)], "Input",
  CellLabel->"In[83]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(opB[x_, y_] = %\)], "Input",
  CellLabel->"In[84]:=",
  FontFamily->"Times New Roman"],

Cell["Factor[x^4 + 2*x^2*(-1 + y^2) + (1 + y^2)^2]", "Input",
  CellLabel->"In[85]:="],

Cell["\<\
Factor[((-1 + x)^2 + y^2)*((1 + x)^2 + y^2)*
   (4*y^2 + (-1 + x^2 + y^2)^2)]\
\>", "Input",
  CellLabel->"In[86]:="],

Cell["\<\
opB[x, y] //. {Sqrt[((-1 + x)^2 + y^2)*((1 + x)^2 + y^2)*
      (4*y^2 + (-1 + x^2 + y^2)^2)] -> (1 - 2*x + x^2 + y^2)*
     (1 + 2*x + x^2 + y^2), x^4 + 2*x^2*(-1 + y^2) + 
     (1 + y^2)^2 -> (1 - 2*x + x^2 + y^2)*(1 + 2*x + x^2 + y^2)}\
\>", "Input",\

  CellLabel->"In[87]:="],

Cell[BoxData[
    \(% //. 
      1/\@\(\((\((\(-1\) + x)\)\^2 + y\^2)\)\ \((\((1 + x)\)\^2 + y\^2)\)\ \
\((4\ y\^2 + \((\(-1\) + x\^2 + y\^2)\)\^2)\)\)\  \[Rule] \ 
        1/\((\((1 - 2\ x + x\^2 + y\^2)\)\ \((1 + 2\ x + x\^2 + 
                  y\^2)\))\)\)], "Input",
  CellLabel->"In[90]:="],

Cell["\<\
After these simplifications we define the operatorfunction \
explicitely:\
\>", "Text"],

Cell["\<\
operatorfct[x_, y_] := 
  {{(-1 + x^2 + y^2)^2/((1 - 2*x + x^2 + y^2)*
      (1 + 2*x + x^2 + y^2)), (2*y*(-1 + x^2 + y^2))/
     ((1 - 2*x + x^2 + y^2)*(1 + 2*x + x^2 + y^2))}, 
   {(2*y*(-1 + x^2 + y^2))/((1 - 2*x + x^2 + y^2)*
      (1 + 2*x + x^2 + y^2)), ((1 + x)^4 + 2*(3 + x*(2 + x))*y^2 + 
      y^4)/((1 - 2*x + x^2 + y^2)*(1 + 2*x + x^2 + y^2))}}\
\>", "Input",
  CellLabel->"In[11]:=",
  InitializationCell->True],

Cell["Clearly, one has again", "Text"],

Cell[BoxData[
    \(operatorfct[0, 0]\)], "Input",
  CellLabel->"In[93]:=",
  FontFamily->"Times New Roman"],

Cell[TextData[{
  StyleBox["In the real case",
    FontColor->RGBColor[1, 0, 0]],
  " z = x we obtain"
}], "Text"],

Cell[BoxData[
    \(operatorfct[\ x, 0]\)], "Input",
  CellLabel->"In[101]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Eigensystem[%]\)], "Input",
  CellLabel->"In[102]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(crossratio[{x, 1}, {0, infy}]\)], "Input",
  CellLabel->"In[107]:=",
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "The points (x,1), (0, infy) are real; its cross ratio is x, and the \
eigenvalues of the double projection are 1 and the square of the standard M\
\[ODoubleDot]bius invariant I(S1, S2), compare formula (2.7.21) in the book",
  ButtonBox[" [O.-S.]",
    ButtonData:>"O.-S.",
    ButtonStyle->"Hyperlink"],
  ".  Indeed, the M\[ODoubleDot]bius invariants: The generalized cosinus of \
the stationary angles, are the square roots of the eigenvalues, compare  \
(2.6.81). \nNow we are going to consider the ",
  StyleBox["general case",
    FontColor->RGBColor[1, 0, 0]],
  "."
}], "Text",
  FontFamily->"Times New Roman"],

Cell["We calculate the eigenvalues of this matrix", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Eigenvalues[operatorfct[x, y]]\)], "Input",
  CellLabel->"In[108]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(FullSimplify[%, \ 
      x \[Element] Reals && \ y \[Element] Reals]\)], "Input",
  CellLabel->"In[109]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(% //. \ 1/Abs[A_]^2\  \[Rule] 1/\ A^2\)], "Input",
  CellLabel->"In[112]:="],

Cell[BoxData[
    \(FullSimplify[%, \ x^2 + y^2\  \[Equal] \ Abs[z]^2]\)], "Input",
  CellLabel->"In[113]:="],

Cell["\<\
This result leads to the following formulas for the eigemvalues as \
functions of thr cross ratio:\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Clear[z]\)], "Input",
  CellLabel->"In[114]:="],

Cell[BoxData[
    \(\(\(\ \)\(crossratio[{z, 1}, {0, infy}]\)\)\)], "Input",
  CellLabel->"In[115]:=",
  FontFamily->"Times New Roman"],

Cell["namely ", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ev1", "[", "z_", "]"}], " ", ":=", " ", 
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"Abs", "[", "z", "]"}], "+", "1"}], ")"}], "^", "2"}], 
        "/", 
        RowBox[{
          RowBox[{"Abs", "[", 
            RowBox[{"z", "-", "1"}], "]"}], "^", "2"}]}]}]], "Input",
  CellLabel->"In[12]:=",
  InitializationCell->True,
  FontFamily->"Times New Roman"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ev2", "[", "z_", "]"}], " ", ":=", " ", 
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"Abs", "[", "z", "]"}], "-", "1"}], ")"}], "^", "2"}], 
        "/", 
        RowBox[{
          RowBox[{"Abs", "[", 
            RowBox[{"z", "-", "1"}], "]"}], "^", "2"}]}]}]], "Input",
  CellLabel->"In[13]:=",
  InitializationCell->True,
  FontFamily->"Times New Roman"],

Cell["\<\
We remember that this expression makes sense for x+Iy \[NotEqual] 1 \
only:\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(operatorfct[1, 0]\)], "Input",
  CellLabel->"In[118]:=",
  FontFamily->"Times New Roman"],

Cell[TextData[{
  StyleBox["In the real case ",
    FontColor->RGBColor[1, 0, 0]],
  "we get as above"
}], "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(operatorfct[x, 0]\)], "Input",
  CellLabel->"In[120]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(FullSimplify[%]\)], "Input",
  CellLabel->"In[121]:=",
  FontFamily->"Times New Roman"],

Cell["and this coincides with", "Text"],

Cell[BoxData[
    \({ev1[x], \ ev2[x]}\)], "Input",
  CellLabel->"In[125]:="],

Cell["\<\
Indeed, consider the cases x > 0 and x >0 separately. Again one has\
\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \({ev1[0], \ ev2[0]}\)], "Input",
  CellLabel->"In[127]:="],

Cell["\<\
One easily concludes: For positive values of z = x the eigenvalues \
are \
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(TraditionalForm\`{\((x + 1)\)\^2\/\((1 - x)\)\^2, \ 
      1}\)], "DisplayFormula",
  FontFamily->"Times New Roman"],

Cell["and for negative values of z =x one has ", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(TraditionalForm\`{1, \((x + 1)\)\^2\/\((x - 1)\)\^2}\)], \
"DisplayFormula",
  Evaluatable->False,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "This reflects the geometric fact: For x < 0 the point pair {x,1} separates \
the pair {0, \[Infinity]}, for x> 0 this is not the case, and for x = 0 the \
0-spheres have a single common point (they are \"tangent\" to each other). We \
remark that for real z one of the eigenvalues equals 1 always, since the four \
points  belong to a 1-sphere, here the real axis. The result proves formula \
(2.7.35) in ",
  ButtonBox["[O-.S.]",
    ButtonData:>"O.-S.",
    ButtonStyle->"Hyperlink"],
  " once more; it can be used for a proof of  theorem 2.7.17 there."
}], "Text",
  FontFamily->"Times New Roman"],

Cell[TextData[{
  StyleBox["The equianharmonic case:",
    FontColor->RGBColor[1, 0, 0]],
  " z = (1\[PlusMinus]I*Sqrt[3])/2"
}], "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(ev2[1/2 + I*Sqrt[3]/2]\)], "Input",
  CellLabel->"In[128]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(ev1[1/2 + I*Sqrt[3]/2]\)], "Input",
  CellLabel->"In[129]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(ev2[1/2 - I*Sqrt[3]/2]\)], "Input",
  CellLabel->"In[128]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(ev1[1/2 - I*Sqrt[3]/2]\)], "Input",
  CellLabel->"In[130]:=",
  FontFamily->"Times New Roman"]
}, Closed]],

Cell[CellGroupData[{

Cell["4.2.5 The crossratios for given invariants", "Subsubsection",
  FontFamily->"Times New Roman"],

Cell["\<\
We ask: The eigenvalues ev1, ev2 of the 0-spheres {{0, infy}, {z, \
1}} are expressed by the crossratio z = x+I*y =(z,1;0,infy). May these \
functions be inversed? The answer is: For a given pair of numbers ev1,ev2 \
with ev1 > ev2\[GreaterEqual] 0, ev1\[GreaterEqual]1\[GreaterEqual]ev2, there \
exist in general four values of the cross ratios z, or four points z of the \
complex plane z = x+I*y =(z,1;0,infy) such that the corresponding 0-spheres \
yield the same given invariants ev1,ev2. These are\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    RowBox[{
      RowBox[{"rex", "[", 
        RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", " ", 
      RowBox[{
        RowBox[{"(", 
          RowBox[{"u", "+", "v", "-", "2"}], ")"}], "/", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"Sqrt", "[", "u", "]"}], "+", 
              RowBox[{"Sqrt", "[", "v", "]"}]}], ")"}], "^", 
          "2"}]}]}]], "Input",
  CellLabel->"In[14]:=",
  InitializationCell->True,
  FontFamily->"Times New Roman"],

Cell[BoxData[
    RowBox[{
      RowBox[{"imy", "[", 
        RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", " ", 
      RowBox[{"2", "*", 
        RowBox[{
          RowBox[{"Sqrt", "[", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{"u", "-", "1"}], ")"}], "*", 
              RowBox[{"(", 
                RowBox[{"1", "-", "v"}], ")"}]}], "]"}], "/", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"Sqrt", "[", "u", "]"}], "+", 
                RowBox[{"Sqrt", "[", "v", "]"}]}], ")"}], "^", 
            "2"}]}]}]}]], "Input",
  CellLabel->"In[15]:=",
  InitializationCell->True,
  FontFamily->"Times New Roman"],

Cell[BoxData[
    RowBox[{
      RowBox[{"eta", "[", 
        RowBox[{"u_", ",", "v_"}], "]"}], ":=", " ", 
      RowBox[{
        RowBox[{"rex", "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", "+", " ", 
        RowBox[{"I", "*", 
          RowBox[{"imy", "[", 
            RowBox[{"u", ",", "v"}], "]"}]}]}]}]], "Input",
  CellLabel->"In[16]:=",
  InitializationCell->True,
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(FullSimplify[\((Abs[eta[u, v]]\  - 1)\)^2/Abs[eta[u, v] - 1]^2, 
      u > 1 && v < 1 && v > 0]\)], "Input",
  CellLabel->"In[82]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(FullSimplify[\((Abs[eta[u, v]]\  + 1)\)^2/Abs[eta[u, v] - 1]^2, 
      u > 1 && v < 1 && v > 0]\)], "Input",
  CellLabel->"In[83]:=",
  FontFamily->"Times New Roman"],

Cell["All tests ok! Also with the following points", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    RowBox[{
      RowBox[{"rexm", "[", 
        RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", " ", 
      RowBox[{
        RowBox[{"(", 
          RowBox[{"u", "+", "v", "-", "2"}], ")"}], "/", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"Sqrt", "[", "u", "]"}], "-", 
              RowBox[{"Sqrt", "[", "v", "]"}]}], ")"}], "^", 
          "2"}]}]}]], "Input",
  CellLabel->"In[17]:=",
  InitializationCell->True,
  FontFamily->"Times New Roman"],

Cell[BoxData[
    RowBox[{
      RowBox[{"imym", "[", 
        RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", " ", 
      RowBox[{"2", "*", 
        RowBox[{
          RowBox[{"Sqrt", "[", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{"u", "-", "1"}], ")"}], "*", 
              RowBox[{"(", 
                RowBox[{"1", "-", "v"}], ")"}]}], "]"}], "/", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"Sqrt", "[", "u", "]"}], "-", 
                RowBox[{"Sqrt", "[", "v", "]"}]}], ")"}], "^", 
            "2"}]}]}]}]], "Input",
  CellLabel->"In[18]:=",
  InitializationCell->True,
  FontFamily->"Times New Roman"],

Cell["We collect the solutions as graphics primitives:", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    RowBox[{
      RowBox[{"pts4", " ", "[", 
        RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", " ", 
      RowBox[{"Union", "[", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"Point", "[", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{"rex", "[", 
                    RowBox[{"u", ",", "v"}], "]"}], ",", 
                  RowBox[{"imy", "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "}"}], "]"}], ",", 
            RowBox[{"Point", "[", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{"rex", "[", 
                    RowBox[{"u", ",", "v"}], "]"}], ",", 
                  RowBox[{"-", 
                    RowBox[{"imy", "[", 
                      RowBox[{"u", ",", "v"}], "]"}]}]}], "}"}], "]"}], ",", 
            RowBox[{"Point", "[", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{"rexm", "[", 
                    RowBox[{"u", ",", "v"}], "]"}], ",", 
                  RowBox[{"imym", "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "}"}], "]"}], ",", 
            RowBox[{"Point", "[", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{"rexm", "[", 
                    RowBox[{"u", ",", "v"}], "]"}], ",", 
                  RowBox[{"-", 
                    RowBox[{"imym", "[", 
                      RowBox[{"u", ",", "v"}], "]"}]}]}], "}"}], "]"}]}], 
          "}"}], "]"}]}]], "Input",
  CellLabel->"In[19]:=",
  InitializationCell->True,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "The solution have been found by ",
  StyleBox["Mathematica ",
    FontSlant->"Italic"],
  "and some manual simplifications:"
}], "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Solve[{\((\((x - 1)\)^2 + y^2)\)^2*\((u - v)\)^2 \[Equal] \ 
          16*\((x^2 + y^2)\), \((\((x - 1)\)^2 + y^2)\)*\((u + v)\) \[Equal] 
          2*\((x^2 + y^2 + 1)\)}, {x, y}]\)], "Input",
  CellLabel->"In[84]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(FullSimplify[%]\)], "Input",
  CellLabel->"In[85]:=",
  FontFamily->"Times New Roman"],

Cell["\<\
The four quadrupels (z,1;0,infy) with given eigenvalues are M\
\[ODoubleDot]bius equivalent. First we plot the unit circle, and then a \
numerical example; we join it to a Graphics:\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(rsplotcircle3pts[1, \ I, \ \(-1\)]\)], "Input",
  CellLabel->"In[87]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(cir1 = %\)], "Input",
  CellLabel->"In[88]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    RowBox[{"Show", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{
            RowBox[{"Graphics", "[", 
              RowBox[{
                StyleBox["{",
                  "Text"], \(PointSize[0.08], pts4[1.2, 1/1.8]\), "}"}], 
              "]"}], ",", "cir1"}], "}"}], ",", \(Axes \[Rule] Automatic\), 
        ",", \(AspectRatio \[Rule] Automatic\)}], "]"}]], "Input",
  CellLabel->"In[91]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(pts4[5. , 1/6]\)], "Input",
  CellLabel->"In[90]:=",
  FontFamily->"Times New Roman"],

Cell["\<\
The spherical reflection at the unit circle acts on the real line \
as sph: 0 -> infy, infy -> 0, 1 -> 1; thus the 0-sphere pairs ((z,1), \
(0,infy)) and (sph[z], 1), (infy,0)) have the same eigenvalues:\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    RowBox[{
      RowBox[{"sphf", "[", 
        RowBox[{"x_", ",", "y_"}], "]"}], " ", ":=", " ", 
      RowBox[{"sphericalreflection", "[", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{"x", ",", "y"}], "}"}], ",", 
          RowBox[{"{", 
            RowBox[{"0", ",", "0"}], "}"}], ",", "1"}], "]"}]}]], "Input",
  CellLabel->"In[20]:=",
  InitializationCell->True,
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(sphf[0.45287209054463357`, 0.5222068624333007`]\)], "Input",
  CellLabel->"In[92]:=",
  FontFamily->"Times New Roman"],

Cell["\<\
The tests leads to the statement that the four points pts4 with the \
same invariants are symmetric with respect to the real axis, and to the unit \
circle. This will be confirmed now:\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \({rexm[u, v], imym[u, v]}\  \[Equal] \ 
      sphf[rex[u, v], imy[u, v]]\)], "Input",
  CellLabel->"In[93]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(FullSimplify[%]\)], "Input",
  CellLabel->"In[94]:=",
  FontFamily->"Times New Roman"],

Cell["\<\
We calculate the cross ratio of the four points of our \
solution:\
\>", "Text"],

Cell[BoxData[
    \(crtest[z_]\  := 
      crossratio[{z, \ 
          Conjugate[z]}, \ {\(sphf[Re[z], \ Im[z]]\)[\([1]\)]\  + \ 
            I*\(sphf[Re[z], \ Im[z]]\)[\([2]\)]\ , \ \(sphf[Re[z], \ 
                Im[z]]\)[\([1]\)]\  - \ 
            I*\(sphf[Re[z], \ Im[z]]\)[\([2]\)]}]\)], "Input",
  CellLabel->"In[95]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(crtest[z]\)], "Input",
  CellLabel->"In[96]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(FullSimplify[%]\)], "Input",
  CellLabel->"In[97]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(FullSimplify[% \[Equal] \ \((Abs[z]^2\  - 1)\)^2/
          Abs[z^2 - 1]^2]\)], "Input",
  CellLabel->"In[98]:=",
  FontFamily->"Times New Roman"],

Cell["Thus we may define", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    RowBox[{
      RowBox[{"crsolutions", "[", "z_", "]"}], ":=", " ", 
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"Abs", "[", "z", "]"}], "^", "2"}], " ", "-", "1"}], 
            ")"}], "^", "2"}], "/", 
        RowBox[{
          RowBox[{"Abs", "[", 
            RowBox[{
              RowBox[{"z", "^", "2"}], "-", "1"}], "]"}], "^", 
          "2"}]}]}]], "Input",
  CellLabel->"In[21]:=",
  InitializationCell->True,
  FontFamily->"Times New Roman"],

Cell["\<\
This cross ratio is real for all z\[NotEqual]1; it follows that the \
four points zj for which the 0-spheres {zj,1},{0,infy} have the same \
eigenvalues belong to a circle. But there are exceptional values u,v with u>v \
\[GreaterFullEqual]0, u\[GreaterFullEqual]1\[GreaterFullEqual]v  for which in \
pts4[u,v] there exist less than four points:\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell["For the harmonic throw {-1,1,0,infy} we have", "Text"],

Cell[BoxData[
    \(ev1[\(-1\)]\)], "Input",
  CellLabel->"In[135]:="],

Cell[BoxData[
    \(ev2[\(-1\)]\)], "Input",
  CellLabel->"In[136]:="],

Cell["and obtain the point z = -1 only:", "Text"],

Cell[BoxData[
    \(pts4[1, 0]\)], "Input",
  CellLabel->"In[120]:="],

Cell["Of course, crsolutions remains indeterminated", "Text"],

Cell[BoxData[
    \(crsolutions[\(-1\)]\)], "Input",
  CellLabel->"In[125]:=",
  FontFamily->"Times New Roman"],

Cell["For real points we have", "Text"],

Cell[BoxData[
    \(ev1[x]\)], "Input",
  CellLabel->"In[137]:="],

Cell[BoxData[
    \(ev2[x]\)], "Input",
  CellLabel->"In[138]:="],

Cell["Thus, in case x>0", "Text"],

Cell[BoxData[
    \(ux\  = \ \((1 + x)\)^2/\((1 - x)\)^2; \ vx\  = \ 1;\)], "Input",
  CellLabel->"In[139]:="],

Cell[BoxData[
    \(pts4[ux, 1]\)], "Input",
  CellLabel->"In[140]:="],

Cell["\<\
In spite of the fact that there are two solutions only, \
crsolutionns yields a value\
\>", "Text"],

Cell[BoxData[
    \(crsolutions[x]\)], "Input",
  CellLabel->"In[141]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(crsolutions[1\/2 - \@3\/2*I]\)], "Input",
  CellLabel->"In[116]:="],

Cell[BoxData[
    \(crsolutions[1\/2 + \@3\/2*I]\)], "Input",
  CellLabel->"In[117]:="],

Cell[BoxData[
    \(crsolutions[x]\)], "Input",
  CellLabel->"In[118]:="],

Cell["\<\
In the equianharmonic case there remained two points of pts4 only; \
as shown above, the invariants in this case are {u,v} = {4,0}: \
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(pts4[4, 0]\)], "Input",
  CellLabel->"In[100]:=",
  FontFamily->"Times New Roman"],

Cell["Clearly, the points belong to the unit circle.", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(sphf[1/2, Sqrt[3]/2]\)], "Input",
  CellLabel->"In[101]:=",
  FontFamily->"Times New Roman"],

Cell["\<\
Always, if the starting point z  belongs to the unit circle, we \
have this situation:\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Clear[t]; \ Declare[t, \ Real]\)], "Input",
  CellLabel->"In[102]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(ev2[Cos[t] + \ I*Sin[t]]\)], "Input",
  CellLabel->"In[103]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(FullSimplify[%]\)], "Input",
  CellLabel->"In[104]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(ev1[Cos[t] + I*Sin[t]]\)], "Input",
  CellLabel->"In[105]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(FullSimplify[%]\)], "Input",
  CellLabel->"In[106]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(pts4[1/\((Sin[t/2])\)^2, \ 0]\)], "Input",
  CellLabel->"In[107]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(FullSimplify[%]\)], "Input",
  CellLabel->"In[108]:=",
  FontFamily->"Times New Roman"],

Cell[TextData[{
  StyleBox["We resume",
    FontColor->RGBColor[0, 0, 1]],
  ": In general, the solution pts4[u,v] consists of 4 different points (i.e. \
quadrupels (z,1,0,infy)); it reduces to two points, if the point belongs to \
the real axis or the standard unit circle, and to one point, if both is the \
case, and the last takes place if and only if the throw is harmonic: -1 \
=(z,1;0,infy). "
}], "Text",
  FontFamily->"Times New Roman"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
4.2.6 A control of the theory
\
\>", "Subsubsection",
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "By a result of  J. B. Wilker",
  ButtonBox[" [W]",
    ButtonData:>"W.",
    ButtonStyle->"Hyperlink"],
  " the absolute value of the cross ratio is the fundamental invariant in M\
\[ODoubleDot]bius geometry. The consideration of the previous subsection show \
that by the reflection at the unit circle we have the M\[ODoubleDot]bius \
equivalence of the quadrupels"
}], "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(sphf : \ \((\[Eta], 
          1.0, \[Infinity])\)\  \[RightTeeArrow] \ \(\((sphf[\[Eta]], \ 
            1, \ \[Infinity], 0)\)\(.\)\)\)], "Input",
  Evaluatable->False,
  FontFamily->"Times New Roman"],

Cell["\<\
From the identities of the cross ratio, see subsection 4.1 above \
and [O.-S.], subsection 1.4.2, and the considerations in [O.-S.], example \
2.7.6,  it follows that the identities\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Abs[z]^2\  \[Equal] \ 1/Abs[sphf[z\ ]]^2\)], "Input",
  Evaluatable->False,
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Abs[1 - z]^2\  \[Equal] \ Abs[1\  - 1/sphf[z\ ]]^2\)], "Input",
  Evaluatable->False,
  FontFamily->"Times New Roman"],

Cell["\<\
must be true. The evaluation of these identities for the found \
solutions confirms this fact:\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(rex[u, v]^2\  + \ imy[u, v]^2\  \[Equal] \ 
      1/\((rexm[u, v]^2\  + \ imym[u, v]^2)\)\)], "Input",
  CellLabel->"In[142]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(FullSimplify[%, \ 
      u \[GreaterEqual] 0 && v \[GreaterEqual] 1]\)], "Input",
  CellLabel->"In[143]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\((1 - rex[u, v])\)^2\  + imy[u, v]^2\  - 
      Abs[1 - 1/\((rexm[u, v]\  + \ I*imym[u, v])\)]^2\)], "Input",
  CellLabel->"In[149]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(FullSimplify[%, \ u > v \[GreaterEqual] 0]\)], "Input",
  CellLabel->"In[150]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(% //. \ 1/Abs[A_]^2\  \[Rule] 
        1/\((\ Re[A]^2\  + \ Im[A]^2)\)\)], "Input",
  CellLabel->"In[151]:="],

Cell[BoxData[
    \(% //. {Im[A_]\  \[Rule] \ 0, \ Re[A_] \[Rule] \ A}\)], "Input",
  CellLabel->"In[152]:="],

Cell[BoxData[
    \(Simplify[%, \ u > v \[GreaterEqual] \ 0]\)], "Input",
  CellLabel->"In[153]:="],

Cell["OK!", "Text"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["5 Circles", "Section",
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "In this section  first we adapt the concepts of the real \
M\[ODoubleDot]bius geometry of circles on the sphere to the complex M\
\[ODoubleDot]bius geometry of the Riemannian sphere. For example: Given three \
distinct points in the Riemannian sphere;  we calculate the spacelike unit \
vector which defines the circle through these points. Then the \
M\[ODoubleDot]bius invariant of two circles is identified with their Coxeter \
invariant, sometimes called Coxeter distance. This is simply an expressioon \
of the M\[ODoubleDot]bius invariant by euclidean invariants. Similarly, we \
find two expressions of the M\[ODoubleDot]bius invariant of a pair (",
  Cell[BoxData[
      \(S\^1, S\^0\)],
    Evaluatable->False,
    FontFamily->"Times New Roman"],
  "), consisting of a circle ",
  Cell[BoxData[
      \(S\^1\)],
    Evaluatable->False,
    FontFamily->"Times New Roman"],
  " and a 0-sphere ",
  Cell[BoxData[
      \(S\^0\)],
    Evaluatable->False,
    FontFamily->"Times New Roman"],
  " = {z1,z2} by euclidean invariants of the pair. Clearly, any \
M\[ODoubleDot]bius invariant of a configuration being a conformal invariant \
is an euclidean invariant, too; therefore it must be possible to express the \
M\[ODoubleDot]bius invariants by invariants of a complete euclidean invariant \
system of the configuration. Such expressions give the possibility easier to \
find geometric interpretations of the M\[ODoubleDot]bius invariants."
}], "Text",
  FontFamily->"Times New Roman"],

Cell[CellGroupData[{

Cell["5.1 Circle through three points", "Subsection"],

Cell[CellGroupData[{

Cell["5.1.1 In the euclidean plane ", "Subsubsection",
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "Elementary operations for finding center and radius of the circle through \
three points in the Euclidean space of any dimension are given by the modules \
center3pts, radius3pts of the package mcirc.m (minor changes March 24, 2004), \
in the item Spheres on my ",
  ButtonBox["homepage",
    ButtonData:>"home",
    ButtonStyle->"Hyperlink"],
  " . There one finds a parameter representation of this circle, too."
}], "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(?circle3pts\)\)], "Input",
  CellLabel->"In[92]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(?center3pts\)\)], "Input",
  CellLabel->"In[93]:="],

Cell[BoxData[
    \(\(?radius3pts\)\)], "Input",
  CellLabel->"In[94]:="],

Cell[BoxData[
    \(\(circle3pts[{1, 0}, \ {0, 1}, {2, 2}]\)[t]\)], "Input",
  CellLabel->"In[81]:="],

Cell[BoxData[
    \(Simplify[Together[%]]\)], "Input",
  CellLabel->"In[82]:="],

Cell[BoxData[
    \(ParametricPlot[\(circle3pts[{1, 0}, \ {0, 1}, {2, 2}]\)[t], \ {t, 0, 
        2*Pi}, Axes\  \[Rule] \ True, \ 
      AspectRatio\  \[Rule] \ Automatic]\)], "Input",
  CellLabel->"In[83]:=",
  FontFamily->"Times New Roman"],

Cell["\<\
If the three points are collinear, we get the correct result:\
\>", \
"Text"],

Cell[BoxData[
    \(\(circle3pts[{0, 0}, \ {1, 1}, {2, 2}]\)[t]\)], "Input",
  CellLabel->"In[84]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(circle3pts[{1, 0}, \ {0, 0}, {0, 1}]\)[t]\)], "Input",
  CellLabel->"In[85]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(ParametricPlot[%, {t, 0, 2\ Pi}, \ 
      AspectRatio\  \[Rule] \ Automatic]\)], "Input",
  CellLabel->"In[86]:=",
  FontFamily->"Times New Roman"]
}, Closed]],

Cell[CellGroupData[{

Cell["5.1.2 In the complex plane", "Subsubsection",
  FontFamily->"Times New Roman"],

Cell["In complex coordinates z = x+I*y these modules are given by", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(\(rscenter1[z1_, z2_, z3_]\  := \ 
      Module[{p1 = {Re[z1], Im[z1]}, p2 = {Re[z2], Im[z2]}, 
          p3 = {Re[z3], Im[z3]}, ww}, 
        ww = center3pts[p1, p2, p3]; \[IndentingNewLine]If[
          ww\  \[Equal] \ \ Null, \ Return[]]; \[IndentingNewLine]If[
          ww\  \[Equal] \ {Infinity, Infinity}, \ Return[infy], 
          Return[ww[\([1]\)] + I*ww[\([2]\)]], 
          Return[ww[\([1]\)] + I*ww[\([2]\)]]]]\)\(\[IndentingNewLine]\)
    \)\)], "Input",
  CellLabel->"In[87]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(\(rsradius1[z1_, z2_, z3_]\  := \ 
      Module[{ww}, 
        ww = rscenter1[z1, z2, z3]; \[IndentingNewLine]If[
          ww\  \[Equal] \ \ Null, \ Return[]]; \[IndentingNewLine]If[
          ww\  \[Equal] \ infy, \ Return[infy], Return[Abs[ww - \ z1]], 
          Return[Abs[ww - \ z1]]]]\)\(\[IndentingNewLine]\)
    \)\)], "Input",
  CellLabel->"In[88]:=",
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "The evaluation with general elements give very long expressions, which may \
simplified using the methods of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ":"
}], "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Clear[a1, a2, a3]; \ rscenter1[a1, a2, a3]\)], "Input",
  CellLabel->"In[91]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(FullSimplify[%]\)], "Input",
  CellLabel->"In[92]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(% //. z_*Conjugate[z_] \[Rule] \ Abs[z]^2\)], "Input",
  CellLabel->"In[93]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(rsradius1[a1, a2, a3]\)], "Input",
  CellLabel->"In[94]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(FullSimplify[%]\)], "Input",
  CellLabel->"In[95]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(% /. \ z_*Conjugate[z_]\  \[Rule] \ Abs[z]^2\)], "Input",
  CellLabel->"In[96]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(% //. \ {Conjugate[a_] - Conjugate[b_] \[Rule] \ Conjugate[a - b], 
        z_*Conjugate[z_]\  \[Rule] \ Abs[z]^2}\)], "Input",
  CellLabel->"In[97]:=",
  FontFamily->"Times New Roman"],

Cell[TextData[StyleBox["The final definition of the complex versions",
  FontColor->RGBColor[0, 0, 1]]], "Text",
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "Since we obtained comparatively simple results by using the symbolic \
calculations with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", we take these results as definitions:"
}], "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(?rscenter3pts\)\)], "Input",
  CellLabel->"In[72]:="],

Cell[BoxData[
    \(\(?rsradius3pts\)\)], "Input",
  CellLabel->"In[73]:="],

Cell[BoxData[
    \(\(?rsplotcircle3pts\)\)], "Input",
  CellLabel->"In[74]:="],

Cell["The corresponding Modules in the package riemann.m are", "Text"],

Cell["\<\
rscenter3pts[a1_, a2_, a3_] := 
  ((-a2 + a3)*Abs[a1]^2 + (a1 - a3)*Abs[a2]^2 + 
    (-a1 + a2)*Abs[a3]^2)/((-a2 + a3)*Conjugate[a1] + 
    (a1 - a3)*Conjugate[a2] + (-a1 + a2)*Conjugate[a3])\
\>", "Input",
  CellLabel->"In[25]:=",
  Evaluatable->False,
  FontFamily->"Times New Roman"],

Cell["\<\
rsradius3pts[a1_, a2_, a3_] := 
  (Abs[a1 - a2]*Abs[a1 - a3]*Abs[a2 - a3])/
   Abs[(a2 - a3)*Conjugate[a1] + (-a1 + a3)*Conjugate[a2] + 
     (a1 - a2)*Conjugate[a3]]\
\>", "Input",
  CellLabel->"In[26]:=",
  Evaluatable->False,
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(\(\(rscircle3pts[a1_, a2_, a3_]\)[t_] := \ 
      Module[{m, r, cli}, \[IndentingNewLine]If[
          Chop[a1 - a2] \[Equal] 0 || \ Chop[a3 - a2] \[Equal] 0 || \ 
            Chop[a1 - a3] \[Equal] 0, \ Print["\<Less than 3 points!\>"]; 
          Goto[cli]]; \[IndentingNewLine]m = rscenter3pts[a1, a2, a3]; 
        r = rsradius3pts[a1, a2, a3]; \[IndentingNewLine]If[
          Chop[1/r] \[Equal] 0, 
          Goto[cli]]; \[IndentingNewLine]Return[{Re[m], Im[m]} + 
            r*{Cos[t], Sin[t]}]; \[IndentingNewLine]Label[
          cli]; \[IndentingNewLine]{Re[a1\  + t*\((a2 - a1)\)], 
          Im[a1\  + t*\((a2 - a1)\)]}]\)\(\[IndentingNewLine]\)
    \)\)], "Input",
  CellLabel->"In[87]:=",
  Evaluatable->False,
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(\(rsplotcircle3pts[a1_, a2_, a3_, \ x_:  0, \ y_:  2*Pi, opt___] := \ 
      Module[{m, r, cli}, \[IndentingNewLine]If[
          Chop[a1 - a2] \[Equal] 0 || \ Chop[a3 - a2] \[Equal] 0 || \ 
            Chop[a1 - a3] \[Equal] 0, \ Print["\<Less than 3 points!\>"]; 
          Goto[cli]]; \[IndentingNewLine]m = rscenter3pts[a1, a2, a3]; 
        r = rsradius3pts[a1, a2, a3]; \[IndentingNewLine]If[
          Chop[1/r] \[Equal] 0, Goto[cli]]; \[IndentingNewLine]Return[
          ParametricPlot[{Re[m], Im[m]} + r*{Cos[t], Sin[t]}, {t, x, y}, 
            AspectRatio -> Automatic, opt]]; \[IndentingNewLine]Label[
          cli]; \[IndentingNewLine]ParametricPlot[{Re[
              a1\  + t*\((a2 - a1)\)], Im[a1\  + t*\((a2 - a1)\)]}, \ {t, x, 
            y}, opt]]\)\(\[IndentingNewLine]\)
    \)\)], "Input",
  CellLabel->"In[76]:=",
  Evaluatable->False,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "For Examples and Tests see below ",
  ButtonBox["A4.1.5",
    ButtonData:>"circ3pts",
    ButtonStyle->"Hyperlink"],
  " ."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["5.1.3 The 3 points vector", "Subsubsection",
  FontFamily->"Times New Roman"],

Cell["In the package riemann.m we defined ", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(?rsvector3pts\)\)], "Input",
  CellLabel->"In[59]:="],

Cell[BoxData[
    \(rsvector3pts[z1_, z2_, z3_]\  := 
      psCross[isotrop[z1], isotrop[z2], isotrop[z3]]\)], "Input",
  CellLabel->"In[104]:=",
  Evaluatable->False,
  FontFamily->"Times New Roman"],

Cell[TextData[StyleBox["Tests. Examples",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["Orientation",
    FontColor->RGBColor[1, 0, 0]],
  ". rsvector3pts is  calculated by the help of psCross, which depend on the \
orientation of the pseudo-euclidean vector space. We take the standard basis \
as positively oriented, then the basis (stb[1], stb[2],stb[3]) can be taken \
as a positively oriented basis of the euclidean hyperplane x[4] == 1, thus \
defining the orientation of the sphere modelled as its standard unit sphere. \
In an oriented sphere we may distinguish positively and negatively oriented \
circles. Since the orientation of a circle is connected with the orde of \
three of its points, eg  a\[ShortRightArrow]b\[ShortRightArrow]c or a\
\[ShortRightArrow]c\[ShortRightArrow]b, defining the direction of the \
positive orientation, rsvector3pts changed the sign if one transposes two  of \
the points:, e.g."
}], "Text",
  CellTags->"Orient"],

Cell[BoxData[
    \(rsvector3pts[0, 1, infy]\)], "Input",
  CellLabel->"In[60]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(rsvector3pts[0, \ infy, \ 1]\)], "Input",
  CellLabel->"In[61]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(rsvector3pts[0, 1, 2]\)], "Input",
  CellLabel->"In[62]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(rsvector3pts[0, 1, \(-I\)]\)], "Input",
  CellLabel->"In[63]:="],

Cell[BoxData[
    \(rsvector3pts[0, \(-I\), 1]\)], "Input",
  CellLabel->"In[64]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(pssp[%, %]\)], "Input",
  CellLabel->"In[65]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(rsvector3pts[z, 1, infy]\)], "Input",
  CellLabel->"In[66]:="],

Cell[BoxData[
    \(pssp[%, isotrop[z]]\)], "Input",
  CellLabel->"In[67]:="],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[68]:="],

Cell[BoxData[
    \(rsvector3pts[z1, z2, z3]\)], "Input",
  CellLabel->"In[98]:="],

Cell[BoxData[
    \(pssp[isotrop[z2], \ %]\)], "Input",
  CellLabel->"In[99]:="],

Cell[BoxData[
    \(FullSimplify[%]\)], "Input",
  CellLabel->"In[100]:="],

Cell[BoxData[
    \(rsvector3pts[z1, z2, infy]\)], "Input",
  CellLabel->"In[101]:="]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["5.2 The rscirclevector", "Subsection",
  FontFamily->"Times New Roman"],

Cell[CellGroupData[{

Cell["5.2.1 The Definitions", "Subsubsection"],

Cell["\<\
The package mspher.m (new version April 2004)  contains the Module \
\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(?hspherevector\)\)], "Input",
  CellLabel->"In[91]:="],

Cell[BoxData[
    \(hspherevector[{x, y}, r]\)], "Input",
  CellLabel->"In[92]:="],

Cell[BoxData[
    \(pssp[%, %]\)], "Input",
  CellLabel->"In[64]:="],

Cell[BoxData[
    \(Simplify[Together[%]]\)], "Input",
  CellLabel->"In[65]:="],

Cell["Orientation and sign of the radius", "Text",
  FontColor->RGBColor[1, 0, 0]],

Cell[BoxData[
    \(\(?vradius\)\)], "Input",
  CellLabel->"In[66]:="],

Cell[BoxData[
    \(vradius[{x\/r, 
        y\/r, \(\(-1\) - r\^2 + x\^2 + y\^2\)\/\(2\ r\), \(1 - r\^2 + x\^2 + \
y\^2\)\/\(2\ r\)}]\)], "Input",
  CellLabel->"In[67]:="],

Cell[BoxData[
    \(Simplify[Together[%], {x, y, z, r} \[Element] \ Reals]\)], "Input",
  CellLabel->"In[68]:="],

Cell[BoxData[
    \(vradius[\(-{x\/r, 
          y\/r, \(\(-1\) - r\^2 + x\^2 + y\^2\)\/\(2\ r\), \(1 - r\^2 + x\^2 \
+ y\^2\)\/\(2\ r\)}\)]\)], "Input",
  CellLabel->"In[69]:="],

Cell[BoxData[
    \(Simplify[Together[%], {x, y, z, r} \[Element] \ Reals]\)], "Input",
  CellLabel->"In[70]:="],

Cell["\<\
The hypersphere is positively oriented in case r>0, and negatively \
oriented for r< 0, see the notebook mspheres.nb\
\>", "Text"],

Cell["\<\
In analogy to this Module we construct the spacelike vector \
corresponding to the circle in the Riemannian sphere with center m and radius \
r (in the package riemann.m) :\
\>", "Text"],

Cell[BoxData[
    \(\(?rscirclevector\)\)], "Input",
  CellLabel->"In[102]:="],

Cell[BoxData[
    \(\(\(rscirclevector[m, r]\)\(\ \)\)\)], "Input",
  CellLabel->"In[66]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Declare[{x, y, r}, Real]\)], "Input",
  CellLabel->"In[68]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(rscirclevector[x + I*y, \ r]\)], "Input",
  CellLabel->"In[69]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(FullSimplify[pssp[%, %]]\)], "Input",
  CellLabel->"In[70]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(?vcenter\)\)], "Input",
  CellLabel->"In[71]:="],

Cell[BoxData[
    \(vcenter[rscirclevector[x + I*y, r]]\)], "Input",
  CellLabel->"In[72]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(FullSimplify[%]\)], "Input",
  CellLabel->"In[73]:="],

Cell["\<\
The radius of the circle which corresponds to a spacelike vector is \
obtained as usual by\
\>", "Text"],

Cell[BoxData[
    \(\(?vradius\)\)], "Input",
  CellLabel->"In[103]:="],

Cell[BoxData[
    \(vradius[rscirclevector[x + I*y, r]]\)], "Input",
  CellLabel->"In[74]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(FullSimplify[%]\)], "Input",
  CellLabel->"In[75]:=",
  FontFamily->"Times New Roman"],

Cell["\<\
The spacelike unit vector represents the oriented circle; changing \
the sign reverts the orientation and the sign of the radius:\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(vcenter[\(-rscirclevector[x + I*y, r]\)]\)], "Input",
  CellLabel->"In[77]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(FullSimplify[%]\)], "Input",
  CellLabel->"In[78]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(FullSimplify[vradius[\(-rscirclevector[x + I*y, r]\)]]\)], "Input",
  CellLabel->"In[79]:=",
  FontFamily->"Times New Roman"],

Cell["\<\
For obtaining the center as a complex number we define in \
riemann.m:\
\>", "Text"],

Cell[BoxData[
    \(\(?rsvcenter\)\)], "Input",
  CellLabel->"In[63]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(rsvcenter[a_List] := \ 
      Module[{vm}, \[IndentingNewLine]If[Length[a]\  \[NotEqual] \ \ 4, \ 
          Print[Length[a], \ "\< incorrect dimension!\>"]; \ 
          Return[]]; \[IndentingNewLine]vm\  = 
          vcenter[a]; \[IndentingNewLine]If[
          vm[\([1]\)]\  \[Equal] Infinity, \ 
          Return[ComplexInfinity]]; \[IndentingNewLine]vm[\([1]\)]\  + \ 
          I*vm[\([2]\)]]\)], "Input",
  CellLabel->"In[96]:=",
  Evaluatable->False,
  FontFamily->"Times New Roman"]
}, Closed]],

Cell[CellGroupData[{

Cell["5.2.2 Examples", "Subsubsection"],

Cell["The imaginary axis corresponds to the vector", "Text"],

Cell[BoxData[
    \(normalize[rsvector3pts[I, 0, \(-I\)]]\)], "Input",
  CellLabel->"In[65]:="],

Cell["Therefore one gets", "Text"],

Cell[BoxData[
    \(rsvcenter[{1, 0, 0, 0}]\)], "Input",
  CellLabel->"In[66]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(vradius[{1, 0, 0, 0}]\)], "Input",
  CellLabel->"In[67]:="],

Cell["\<\
The circle with center 2+I an radius 2 corresponds to the \
vector\
\>", "Text"],

Cell[BoxData[
    \(vn\  = normalize[rscirclevector[2 + I, \ 2]]\)], "Input",
  CellLabel->"In[68]:="],

Cell[BoxData[
    \(rsvcenter[%]\)], "Input",
  CellLabel->"In[69]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(vradius[%%]\)], "Input",
  CellLabel->"In[70]:=",
  FontFamily->"Times New Roman"],

Cell["The circle has the parameter representation", "Text"],

Cell[BoxData[
    \(Declare[t, Real]\)], "Input",
  CellLabel->"In[75]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(cz[t_] := \ 2 + I\  + \ 2*Exp[I*t]\)], "Input",
  CellLabel->"In[76]:=",
  FontFamily->"Times New Roman"],

Cell["\<\
The isotropic 1-spaces corresponding to the points of the circle \
are orthogonal to rscirclevector[2+I, 2]:\
\>", "Text"],

Cell["pssp[isotrop[cz[t]], vn]", "Input",
  CellLabel->"In[77]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(FullSimplify[%]\)], "Input",
  CellLabel->"In[78]:=",
  FontFamily->"Times New Roman"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
5.3 The M\[ODoubleDot]bius invariant of circle pairs  (Coxeter \
invariant)\
\>", "Subsection",
  FontFamily->"Times New Roman"],

Cell[CellGroupData[{

Cell["5.3.1 The derivation of the Coxeter invariant", "Subsubsection"],

Cell[TextData[{
  "The M\[ODoubleDot]bius invariant of two (non oriented) hyperspheres is \
simply the absolute value of the generalized cosinus of the corresponding \
vectors, see for Details section 2.7 in ",
  ButtonBox["[0.-S.]",
    ButtonData:>"O.-S.",
    ButtonStyle->"Hyperlink"],
  " . We set"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"rscirclevector1", "[", 
        RowBox[{"m_", ",", "r_"}], "]"}], " ", ":=", " ", 
      RowBox[{"normalize", "[", 
        RowBox[{"rscirclevector", "[", 
          RowBox[{"m", ",", "r"}], "]"}], "]"}]}]], "Input",
  CellLabel->"In[22]:=",
  InitializationCell->True],

Cell["\<\
The next definition yields the invariant as function of the \
euclidean parameters, the centers and the radii:\
\>", "Text"],

Cell[BoxData[
    \(inv[m_, m1_, r_, r1_]\  := \ 
      pssp[rscirclevector1[m, r], rscirclevector1[m1, r1]]\)], "Input",
  CellLabel->"In[62]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(inv[m, m1, r, r1]\)], "Input",
  CellLabel->"In[63]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(FullSimplify[Together[%]]\)], "Input",
  CellLabel->"In[64]:=",
  FontFamily->"Times New Roman"],

Cell["This is a classical formula; the expression", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(?rsCoxeter\)\)], "Input",
  CellLabel->"In[65]:="],

Cell[BoxData[
    \(rsCoxeter[m, m1, r, r1]\)], "Input",
  CellLabel->"In[66]:="],

Cell["\<\
is called the Coxeter invariant of the circles. Remember that \
Abs[m-m1] is the distance of their centers. If the circles intersect, it \
equals the cosinus of the intersection angle. Clearly it is a \
M\[ODoubleDot]bius invariant for oriented circles; its absolute value is the \
M\[ODoubleDot]bius invariant in the non oriented case..\
\>", "Text",
  FontFamily->"Times New Roman"]
}, Closed]],

Cell[CellGroupData[{

Cell["5.3.2 Example", "Subsubsection"],

Cell["\<\
Since the M\[ODoubleDot]bius group acts transitively on the set of \
circles we may assume that one of he circle of a pair is the unit circle with \
center at the origin m1 = 0. Furthermore, since Abs[m-m1] = Abs[m] is the \
distance of the centers, and rsCoxeter does not depend on the direction of \
the line joining the centers we may assume that m is real.  If the circles \
coincide, we have \
\>", "Text"],

Cell[BoxData[
    \(rsCoxeter[0, 0, 1, 1]\)], "Input",
  CellLabel->"In[67]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(rsCoxeter[0, m, \ 1, r]\)], "Input",
  CellLabel->"In[68]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Plot3D[\((1 + r^2 - m^2)\)/\((2*r)\), \ {m, \ \(-3\), 3}, \ {r, 0.1, 
        2}, PlotPoints\  \[Rule] 90]\)], "Input",
  CellLabel->"In[71]:=",
  FontFamily->"Times New Roman"],

Cell["\<\
If the radius r is fixed, too, e.g. r = 2, we obtain  the \
parabola\
\>", "Text"],

Cell[BoxData[
    \(Plot[\((5\  - m^2)\)/4, \ {m, \(-3\), 3}]\)], "Input",
  CellLabel->"In[73]:=",
  FontFamily->"Times New Roman"],

Cell["r=5:", "Text"],

Cell[BoxData[
    \(Plot[\((26\  - m^2)\)/10, \ {m, \(-7\), 7}]\)], "Input",
  CellLabel->"In[72]:="],

Cell[TextData[{
  "For m = 1 and m = 3 the circles are tangent to each other, and we get the \
value +1, -1 for the Coxeter invariant. An elementary proof (the \
cosinus-theorem) shows that the Coxeter invariant coincides with the cosinus \
of the intersection angle of the circles in case 1<m<3, and analogeously \
-3<m<-1. The Coxeter invariant depends on the ",
  ButtonBox["orientation",
    ButtonData:>"Orient",
    ButtonStyle->"Hyperlink"],
  " of  the circles. In the euclidean form the orientation does not appear \
explicitely; it is silently assumed that both circles are positively oriented \
with respect to the orientation of the plane containing the circles."
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["5.4 The M\[ODoubleDot]bius invariant of a circle and a 0-sphere", \
"Subsection",
  FontFamily->"Times New Roman"],

Cell[CellGroupData[{

Cell["5.4.1 Definition of the circle, 0-sphere invariant", "Subsubsection",
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "From the general theory, see [O.-S.] or ",
  ButtonBox["[S1]",
    ButtonData:>"S1",
    ButtonStyle->"Hyperlink"],
  ", see also the notebook [S3] for the 3-dimensional sphere,  it follows \
that a pair consisting of a hypersphere and a 0-sphere in general position \
has  only a single  invariant, namely (in case of the Riemannian sphere) for"
}], "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[{
    \(\(n\  = \ rscirclevector[m, r];\)\), "\[IndentingNewLine]", 
    \(\(msph\  = \ rsvspacepp[z1, z2];\)\)}], "Input",
  Evaluatable->False,
  FontFamily->"Times New Roman"],

Cell["the invariant is", "Text"],

Cell[BoxData[
    \(rsinv01 := 
      pssp[n, \ msph[\([1]\)]]^2 + \ pssp[n, \ msph[\([2]\)]]^2\)], "Input",
  Evaluatable->False,
  FontFamily->"Times New Roman"],

Cell["Remember:", "Text"],

Cell[BoxData[
    \(\(?rscirclevector\)\)], "Input",
  CellLabel->"In[72]:="],

Cell[BoxData[
    \(\(?\ rsvspacepp\)\)], "Input",
  CellLabel->"In[75]:="],

Cell["This leads to the definition:", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"rsinv01", "::", "usage"}], " ", "=", " ", 
        "\"\<rsinv01[z1,z2,m,r] is the Moebius invariant of  the 0-sphere \
{z1,z2} and the circle with center m and radius r in the Riemannian sphere.\>\
\""}], ";"}]], "Input",
  CellLabel->"In[23]:=",
  InitializationCell->True],

Cell[BoxData[
    RowBox[{
      RowBox[{"rsinv01", "[", 
        RowBox[{"z1_", ",", "z2_", ",", "m_", ",", "r_"}], "]"}], ":=", " ", 
      RowBox[{"Module", "[", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{"vn", ",", "msph"}], "}"}], ",", "\[IndentingNewLine]", 
          RowBox[{
            RowBox[{"vn", " ", "=", "  ", 
              RowBox[{"rscirclevector", "[", 
                RowBox[{"m", ",", "r"}], "]"}]}], ";", "\[IndentingNewLine]", 
            
            RowBox[{"msph", " ", "=", "  ", 
              RowBox[{"rsvspacepp", "[", 
                RowBox[{"z1", ",", "z2"}], "]"}]}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{
              RowBox[{
                RowBox[{"pssp", "[", 
                  RowBox[{"vn", ",", " ", 
                    RowBox[{"msph", "[", 
                      RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "^", "2"}], 
              "+", " ", 
              RowBox[{
                RowBox[{"pssp", "[", 
                  RowBox[{"vn", ",", " ", 
                    RowBox[{"msph", "[", 
                      RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "^", 
                "2"}]}]}]}], "]"}]}]], "Input",
  CellLabel->"In[24]:=",
  InitializationCell->True],

Cell[BoxData[
    \(rsinv01[\(-1\), 1, I, r]\)], "Input",
  CellLabel->"In[63]:="],

Cell["For  r =0 the Module returns warnings and Indeterminate:", "Text"],

Cell[BoxData[
    \(rsinv01[\(-1\), 1, I, 0]\)], "Input",
  CellLabel->"In[84]:="],

Cell["since", "Text"],

Cell[BoxData[
    \(rscirclevector[I, 0]\)], "Input",
  CellLabel->"In[64]:="],

Cell[TextData[{
  StyleBox["Warning:",
    FontColor->RGBColor[1, 0, 0]],
  " For arbitrary, also complex values of r\[NotEqual]0 the Module returns a \
number which makes no sense for non real r!"
}], "Text"],

Cell[BoxData[
    \(rsinv01[\(-1\), 1, I, I]\)], "Input",
  CellLabel->"In[81]:="],

Cell[BoxData[
    \(rsinv01[\(-1\), 1, I, 1 + I]\)], "Input",
  CellLabel->"In[82]:="],

Cell[BoxData[
    \(rsinv01[\(-1\), 1, I, 2 + I]\)], "Input",
  CellLabel->"In[85]:="],

Cell["\<\
Always it is possible to find a M\[ODoubleDot]bius transform such \
that the circle is ttransformed into the unit circle with center 0, and one \
of the points, say z2, is transformed into 0, assumied that 0-sphere and \
circle are in general position. We then consider the circle, 0-sphere \
invariant as a function of one point z. This gives a general picture of the \
behavior of this invariant: For  arbitratry circles and points z2 and \
variable z we obtain a conformal picture of the special situation, which is \
very simple:\
\>", "Text"],

Cell[BoxData[
    \(fct01[z_]\  := \ rsinv01[z, 0, 0, 1]\)], "Input",
  CellLabel->"In[66]:="],

Cell[BoxData[
    \(fct01[z]\)], "Input",
  CellLabel->"In[67]:="],

Cell[BoxData[
    \(% \[Equal] \ 1/Abs[z]^2\)], "Input",
  CellLabel->"In[68]:="],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[69]:="],

Cell["Thus, we may express the function simply by", "Text"],

Cell[BoxData[
    \(fct01[z_]\  := \ 1/Abs[z]^2\)], "Input",
  CellLabel->"In[71]:="],

Cell[TextData[{
  "and we conclude:\n",
  StyleBox["Lemma.",
    FontColor->RGBColor[0, 0, 1]],
  "  Assume thet the point z2 does not belong to the circle with center m and \
radius r. Then the curves of constant value of the M\[ODoubleDot]bius \
invariant  f[z] = rsinv01[z,z2,m,r], z2, m, r constant, are circles or lines. \
\nThe case that z2 belongs to the circle will beterated in subsection 5.4.3 \
below."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["5.4.2 The circle, 0-sphere invariant in euclidean terms", \
"Subsubsection",
  FontFamily->"Times New Roman"],

Cell["\<\
Since the M\[ODoubleDot]bius group acts transitively on the set of \
0-spheres we can assume that z1 = d, z2 = -d, d real: \
\>", "Text"],

Cell[BoxData[
    \(Clear[d, m, r, z1, z2, r0]\)], "Input",
  CellLabel->"In[69]:="],

Cell[BoxData[
    \(\(\(Declare[{r0, r}, Real]\)\(\ \)\)\)], "Input",
  CellLabel->"In[70]:="],

Cell[BoxData[
    \(rsinv01[\(-r0\), r0, m, r]\)], "Input",
  CellLabel->"In[71]:="],

Cell[BoxData[
    \(Simplify[%, \ r \[Element] Reals && \ r0 > 0]\)], "Input",
  CellLabel->"In[72]:="],

Cell["\<\
This gives the following formula for the M\[ODoubleDot]bius \
invariant in euclidean terms:\
\>", "Text"],

Cell[TextData[{
  StyleBox["Proposition 1",
    FontColor->RGBColor[0, 0, 1]],
  ". Let ",
  Cell[BoxData[
      \(TraditionalForm\`S\^\(\(0\)\(\ \ \)\)\)]],
  "be the 0-sphere with center c and radius r0, and ",
  Cell[BoxData[
      \(TraditionalForm\`S\^\(\(1\)\(\ \ \)\)\)]],
  "the circle with center m and Radius r in the euclidean plane. Denote by d \
the distance of the centers, and by a the angle between the line containing \
the 0-sphere and the line joining the centers. Then "
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"euinv01", "[", 
        RowBox[{"r0_", ",", "r_", ",", " ", "d_", ",", "a_"}], "]"}], " ", ":=",
       " ", 
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"r", "^", "2"}], "+", 
                  RowBox[{"r0", "^", "2"}], " ", "-", 
                  RowBox[{"d", "^", "2"}]}], ")"}], "/", 
              RowBox[{"(", 
                RowBox[{"2", "*", "r0", "*", "r"}], ")"}]}], ")"}], "^", 
          "2"}], " ", "+", " ", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{"d", "*", 
              RowBox[{
                RowBox[{"Sin", "[", "a", "]"}], "/", "r"}]}], ")"}], "^", 
          "2"}]}]}]], "Input",
  CellLabel->"In[25]:=",
  InitializationCell->True],

Cell[TextData[{
  "is a M\[ODoubleDot]bius invariant; it is the square of the generalized \
stationary cosinus between circles containing ",
  Cell[BoxData[
      \(TraditionalForm\`S\^\(\(0\)\(\ \ \)\)\)]],
  "and the given circle ",
  Cell[BoxData[
      \(TraditionalForm\`S\^1\)]],
  "."
}], "Text"],

Cell["\<\
Proof. We identify the Gaussian plane of the complex numbers with \
the euclidean plane. In the last formula for 
rsinv01[-r0,r0,m,r] we recognize d = Abs[m] and Im[m] = d* Sin[a]. Inserting \
these we obtain the stated formula which, of course, is valid in any \
euclidean plane, not only in the Gaussian plane.\
\>", "Text"],

Cell[TextData[{
  StyleBox["Remark 1",
    FontColor->RGBColor[0, 0, 1]],
  ". For a = 0, i.e. the center m of the circle belongs to the line \
containing the 0-sphere, or d = 0, there remains only the first term which \
coincides with the Coxeter invariant of the circle   ",
  Cell[BoxData[
      \(TraditionalForm\`S\^\(\(1\)\(\ \ \)\)\)]],
  "and the circle with radius r0 and center c  of the 0-sphere."
}], "Text"],

Cell[TextData[{
  StyleBox["Remark 2",
    FontColor->RGBColor[0, 0, 1]],
  ". One confirms easely the formula for fct01 obtained at the end of \
subsection 5.4.1 using the expression euinv01 above."
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["5.4.3 Some special positions", "Subsection",
  FontFamily->"Times New Roman"],

Cell["\<\
In the following examples we assume without restriction of \
generality that the circle is the unit circle C with center 0.\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["The case (z1,z2)\[Subset] C",
    FontColor->RGBColor[0, 0, 1]],
  ":"
}], "Subsubsection",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Declare[{s, t}, \ Real]\)], "Input",
  CellLabel->"In[65]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(rsinv01[\ Exp[I*t], Exp[I*s], 0, 1]\)], "Input",
  CellLabel->"In[75]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(FullSimplify[%, \ s > 0 && t > 0]\)], "Input",
  CellLabel->"In[76]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(rank[
      Join[rsvspacepp[\ Exp[I*t], 
          Exp[I*s]], {rscirclevector[0, 1]}]]\)], "Input",
  CellLabel->"In[77]:=",
  FontFamily->"Times New Roman"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Case z1\[Element] C,  z2 \[NotElement] C",
    FontColor->RGBColor[0, 0, 1]],
  " "
}], "Subsubsection",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Consider, \ e . g . \ z2\  = \ 2 + \(\(I\)\(:\)\)\)], "Text"],

Cell[BoxData[
    \(rsinv01[Exp[I*t], 2\  + \ I, 0, 1]\)], "Input",
  CellLabel->"In[67]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(FullSimplify[Together[%], t \[Element] Reals]\)], "Input",
  CellLabel->"In[68]:="],

Cell["\<\
The evaluation of  this  expression yields the constnt 1, as \
expected:\
\>", "Text"],

Cell[BoxData[
    \(Plot[Chop[%\  - 1]\  + 1, \ {t, 0, 2*Pi}]\)], "Input",
  CellLabel->"In[69]:="],

Cell[BoxData[
    \(rank[
      Join[rsvspacepp[\ Exp[I*t], 
          2\  + \ I], {rscirclevector[0, 1]}]]\)], "Input",
  CellLabel->"In[88]:=",
  FontFamily->"Times New Roman"],

Cell[TextData[{
  StyleBox["In the case rsinv01 = 1 the rank is essential! ",
    FontColor->RGBColor[0, 0, 1]],
  "We conclude:\n1. Both points z1,z2 belong to the circle C(m,r) iff \
rsinvcpp[m,r,z1,z2] =1, and rank(m,r,z1,z2) = 2.\n2.Only one of the points \
z1,z2 belongs to the circle C(m,r) iff rsinvcpp[m,r,z1,z2] =1, and \
rank(m,r,z1,z2) = 3."
}], "Text",
  FontFamily->"Times New Roman"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Case z1,z2 in involution with respect to C:",
  FontColor->RGBColor[0, 0, 1]]], "Subsubsection",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(?sphf\)\)], "Input",
  CellLabel->"In[72]:="],

Cell[BoxData[
    \(Declare[{x1, y1, x2, y2, r}, \ Real]\)], "Input",
  CellLabel->"In[73]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(rsinv01[\ \(sphf[x2, y2]\)[\([1]\)]\  + \ 
        I*\ \(sphf[x2, y2]\)[\([2]\)], x2\  + \ I*y2, 0, 1]\)], "Input",
  CellLabel->"In[74]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(FullSimplify[%]\)], "Input",
  CellLabel->"In[75]:=",
  FontFamily->"Times New Roman"],

Cell[TextData[{
  StyleBox["Corollary.",
    FontColor->RGBColor[0, 0, 1]],
  " The two points of ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(S\)\(\ \)\)\^0\)]],
  "={ z1,z2} are in inversion with respect to the circle ",
  Cell[BoxData[
      \(TraditionalForm\`S\^1\)]],
  " iff rsinv01[",
  Cell[BoxData[
      \(TraditionalForm\`\(\(S\)\(\ \)\)\^0\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`S\^1\)]],
  "] = 0. In this case any circle through z1,z2 intersects the given circle \
",
  Cell[BoxData[
      \(TraditionalForm\`S\^1\)]],
  "orthogonally."
}], "Text"],

Cell[TextData[{
  StyleBox["Exercise.",
    FontColor->RGBColor[0, 0, 1]],
  " Consider lines intersecting the unit circle, visualize, and discuss the \
invariant rsinv01 for points z1 ,z2 on the line, and the unit circle, e.g."
}], "Text"],

Cell[BoxData[
    \(\(\(a\  = 2*Pi*Random[]; 
    Plot[rsinv01[0.8, Exp[I*a]*t, \ 0, 1], {t, \(-2\), 
        2}]\)\(\[IndentingNewLine]\)
    \)\)], "Input",
  CellLabel->"In[75]:="],

Cell[BoxData[
    \(a\)], "Input",
  CellLabel->"In[76]:="],

Cell[BoxData[
    \(\(\(a\  = 2*Pi*Random[]; 
    Plot[rsinv01[1.8, Exp[I*a]*t, \ 0, 1], {t, \(-2\), 
        2}]\)\(\[IndentingNewLine]\)
    \)\)], "Input",
  CellLabel->"In[77]:="]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["6 Circle bundles", "Section",
  FontFamily->"Times New Roman"],

Cell[CellGroupData[{

Cell["6.1 The circle bundle through two points", "Subsection",
  FontFamily->"Times New Roman"],

Cell["\<\
In this section we consider the bundle of all circles through two \
given points, say (z1, z2) = (-1, 1), and study the position of these circles \
to an arbitrarily fixed circle S(m, r).  The circles bc[t_] of the bundle \
depend on a single parameter t = center[bc[t]], where t must be a point of \
the bundle axis, here it is the imaginary axis. Then the radius of bc[t] \
equals Sqrt[1 + t^2].  We calculate the corresponding spacelike unit \
vector:\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Clear[r, t]; \ Declare[{t, \ r}, \ Real]\)], "Input",
  CellLabel->"In[107]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(bc[t_]\  := \ rscirclevector[I*t, \ Sqrt[1 + \ t^2]]\)], "Input",
  CellLabel->"In[108]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(bc[t]\)], "Input",
  CellLabel->"In[109]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(FullSimplify[%]\)], "Input",
  CellLabel->"In[110]:=",
  FontFamily->"Times New Roman"],

Cell["\<\
Thus, the circle vector of the bundle circle directedly defined \
is\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell["bdlvec[t_] := {0, t/Sqrt[1 + t^2], -1/Sqrt[1 + t^2], 0}", "Input",
  CellLabel->"In[26]:=",
  InitializationCell->True,
  FontFamily->"Times New Roman"],

Cell["\<\
The limit for t -> \[Infinity] is the real axis:\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Limit[bdlvec[t], \ t \[Rule] \ Infinity]\)], "Input",
  CellLabel->"In[112]:=",
  FontFamily->"Times New Roman"],

Cell[" With", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Cos[u]\  := t\/\@\(1 + t\^2\); \ 
    Sin[u]\  := 1\/\@\(1 + t\^2\)\)], "Input",
  Evaluatable->False,
  FontFamily->"Times New Roman"],

Cell["\<\
we see, that the circle bundle corresponds to the circle in the \
2,3-Coordinate plane of the pseudo-euclidean 4-space:\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(rsvspacepp[\(-1\), 1]\)], "Input",
  CellLabel->"In[113]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Clear[a, b, c, d, t]; \ Declare[{a, b, c, d, t}, \ Real]\)], "Input",
  CellLabel->"In[114]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(bdlgraphics[a_, b_, d_]\  := \ 
      Table[Graphics[Circle[{0, \ t}, Sqrt[1 + t^2]]], \ {t, a, b, 
          d}]\)], "Input",
  CellLabel->"In[115]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(bdlgraphics[\(-3\), 3, \  .5]\)], "Input",
  CellLabel->"In[116]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(grbdl\  = \ %\)], "Input",
  CellLabel->"In[117]:=",
  FontFamily->"Times New Roman"],

Cell["\<\
 We add the real axis, which is to be considered as a circle, \
too:\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(reax[a_, b_]\  := \ Graphics[Line[{{a, 0}, \ {b, 0}}]]\)], "Input",
  CellLabel->"In[118]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Show[{grbdl, \ reax[\(-5\), 5]}, \ 
      AspectRatio\  \[Rule] \ Automatic]\)], "Input",
  CellLabel->"In[119]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(bdlpict\  = \ %\)], "Input",
  CellLabel->"In[120]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(pictcirclebdl[a_, b_, c_, \ opts___]\  := \ 
      Show[bdlgraphics[a, b, c], \ opts]\)], "Input",
  CellLabel->"In[121]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(pictcirclebdl[\(-2\), \ 2, \  .5, \ 
      AspectRatio\  \[Rule] \ Automatic]\)], "Input",
  CellLabel->"In[122]:=",
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "The stationary invariant of the circle through the  0-sphere ",
  Cell[BoxData[
      \(TraditionalForm\`S\^0\)]],
  "=(-1,1) corresponding to t  with an arbitrary circle is the square of"
}], "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Clear[x, y, r, t]; \ 
    Declare[{x, y, r, t}, Real]; \(stationary[x_, y_, r_]\)[t_]\  := \ 
      pssp[bdlvec[t], \ rscirclevector[x + I*y, r]]\)], "Input",
  CellLabel->"In[123]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(stationary[x, y, r]\)[t]\)], "Input",
  CellLabel->"In[124]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(FullSimplify[Together[%]]\)], "Input",
  CellLabel->"In[125]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(pssp[bdlvec[t], bdlvec[s]]\)], "Input",
  CellLabel->"In[126]:="],

Cell[BoxData[
    \(Simplify\ [Together[%]]\)], "Input",
  CellLabel->"In[127]:="],

Cell[TextData[{
  "\nClearly, the invariant rsinvcpp of a bundle circle with ",
  Cell[BoxData[
      \(TraditionalForm\`S\^0\)]],
  "=(-1,1) equals 1:"
}], "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(rsinv01[\(-1\), 1, I*t, Sqrt[1 + t^2]]\)], "Input",
  CellLabel->"In[88]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(FullSimplify\ [Together[%]]\)], "Input",
  CellLabel->"In[89]:="],

Cell[BoxData[
    \(% /. \ Abs[t]^4\  \[Rule] \ t^4\)], "Input",
  CellLabel->"In[91]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
6.2 The uniquely defined circle of the bundle through a given point \
z \[NotEqual] \[PlusMinus]1\
\>", "Subsection",
  FontFamily->"Times New Roman"],

Cell["\<\
Let  z = x + I*y be a given point of the Riemannian sphere, z \
\[NotEqual]  \[PlusMinus]1. Then the circle  of the bundle through z is \
defined by\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(rsvector3pts[1, \(-1\), z]\)], "Input",
  CellLabel->"In[65]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(FullSimplify[%]\)], "Input",
  CellLabel->"In[66]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(% \[Equal] \ \(-4\)*{0, 1\  - Abs[z]^2, 2*Im[z], 0}\)], "Input",
  CellLabel->"In[67]:="],

Cell[BoxData[
    \(FullSimplify[%]\)], "Input",
  CellLabel->"In[68]:="],

Cell["\<\
Thus we may define bdlvec[z] as a spacelike vector definimg the \
circle of the bundle through z: \
\>", "Text"],

Cell[BoxData[
    \(bdlvec[z_]\  := \ \(-{0, 1\  - Abs[z]^2, 2*Im[z], 0}\)\)], "Input",
  CellLabel->"In[97]:="],

Cell[BoxData[
    \(Declare[{x, y}, \ Real]\)], "Input",
  CellLabel->"In[70]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(zz = \ x\  + \ I*y\)], "Input",
  CellLabel->"In[71]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(normalize[bdlvec[zz]]\)], "Input",
  CellLabel->"In[98]:="],

Cell[BoxData[
    \(FullSimplify[%]\)], "Input",
  CellLabel->"In[99]:="],

Cell[BoxData[
    \(% //. Abs[A_]\  \[Rule] \ A\)], "Input",
  CellLabel->"In[100]:="],

Cell["\<\
The denominator is always non negative; it vanishes for the exluded \
points z =  \[PlusMinus]1 only.  Thus we define\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell["\<\
nvecbdt[x_, y_] := {0, -1 + x^2 + y^2, -2*y, 0}/
   Sqrt[4*y^2 + (-1 + x^2 + y^2)^2]\
\>", "Input",
  CellLabel->"In[76]:=",
  FontFamily->"Times New Roman"],

Cell["\<\
 The parameter t of the corresponding circle can be found \
calculating\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(rscenter3pts[1, \(-1\), \ x + I*y]\)], "Input",
  CellLabel->"In[77]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(FullSimplify[%]\)], "Input",
  CellLabel->"In[79]:=",
  FontFamily->"Times New Roman"],

Cell["bdlcirclt[x_, y_] := (-1 + x^2 + y^2)/(2*y)", "Input",
  CellLabel->"In[82]:=",
  FontFamily->"Times New Roman"],

Cell["\<\
The radius of this circle as a function of x,y is given by r^2 = 1 \
+ t^2\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(radiust[x_, y_] := \ Sqrt[1\  + \ bdlcirclt[x, y]^2]\)], "Input",
  CellLabel->"In[83]:="],

Cell[BoxData[
    \(radiust[x, y]\)], "Input",
  CellLabel->"In[84]:="],

Cell[BoxData[
    \(Simplify[Together[%^2]]\)], "Input",
  CellLabel->"In[85]:="],

Cell[BoxData[
    \(Factor[
      x\^4 + 2\ x\^2\ \((\(-1\) + y\^2)\) + \((1 + y\^2)\)\^2]\)], "Input",
  CellLabel->"In[88]:="],

Cell["Thus we may set", "Text"],

Cell[BoxData[
    \(Clear[radiust]; \ 
    radiust[x_, y_] := \ 
      Sqrt[\((1 - 2\ x + x\^2 + y\^2)\)\ \((1 + 2\ x + x\^2 + y\^2)\)]/\((2*
            Abs[y])\)\)], "Input",
  CellLabel->"In[89]:=",
  FontFamily->"Times New Roman"],

Cell[TextData[{
  StyleBox["Control:",
    FontColor->RGBColor[0, 0, 1]],
  " We apply the functions (defined in mspher.m)"
}], "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(?vcenter\)\)], "Input",
  CellLabel->"In[92]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(?vradius\)\)], "Input",
  CellLabel->"In[93]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(vradius[bdlvec[x + \ I*y]]\)], "Input",
  CellLabel->"In[101]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(FullSimplify[%]\)], "Input",
  CellLabel->"In[102]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(vcenter[nvecbdt[x, y]]\)], "Input",
  CellLabel->"In[96]:=",
  FontFamily->"Times New Roman"]
}, Closed]],

Cell[CellGroupData[{

Cell["6.3 Circle of the bundle orthogonal to a given test circle", \
"Subsection",
  FontFamily->"Times New Roman"],

Cell["\<\
We consider the test circle with  center m = mx + I*my and radius \
r; its circlevector is:\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Declare[{mx, my, r}, Real]; \ rscirclevector[mx + \ I*my, r]\)], "Input",\

  CellLabel->"In[128]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(FullSimplify[%]\)], "Input",
  CellLabel->"In[129]:=",
  FontFamily->"Times New Roman"],

Cell["\<\
rscv[mx_, my_, r_] := {2 mx, 2 my,  -1 + mx^2 + my^2 - r^2, 
   1 + mx^2 + my^2 - r^2}/(2*r)\
\>", "Input",
  CellLabel->"In[27]:=",
  InitializationCell->True,
  FontFamily->"Times New Roman"],

Cell["\<\
The condition for orthogonality with a circle of the bundle \
is\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(stationary[x, y, r]\)[t]\  \[Equal] \ 0\)], "Input",
  CellLabel->"In[131]:="],

Cell[" or", "Text"],

Cell[BoxData[
    \(pssp[rscv[mx, my, r], bdlvec[t]] \[Equal] \ 0\)], "Input",
  CellLabel->"In[132]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Solve[%, \ t]\)], "Input",
  CellLabel->"In[133]:=",
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "We conclude:\n",
  StyleBox["Proposition 2",
    FontColor->RGBColor[0, 0, 1]],
  ".  For a given pair (",
  Cell[BoxData[
      \(TraditionalForm\`S\^1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`S\^0\)]],
  ") of a circle and a 0-sphere ",
  Cell[BoxData[
      \(TraditionalForm\`S\^0\)]],
  " = (z1, z2) always exists a circle of the circle bundle through  ",
  Cell[BoxData[
      \(TraditionalForm\`S\^0\)]],
  " intersecting ",
  Cell[BoxData[
      \(TraditionalForm\`S\^1\)]],
  " orthogonally.\nProof: By a M\[ODoubleDot]bius transform we can reach that \
 ",
  Cell[BoxData[
      \(TraditionalForm\`S\^0\)]],
  "=(1, -1). If the center of  ",
  Cell[BoxData[
      \(TraditionalForm\`S\^1\)]],
  " belongs to the real axis obviously this axis is the circle of the bundle \
solving the problem. Otherwise we have my \[NotEqual] 0, and the solution"
}], "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    RowBox[{
      RowBox[{"orthot", "[", 
        RowBox[{"m_", ",", " ", "r_"}], "]"}], " ", ":=", " ", 
      RowBox[{
        RowBox[{"-", 
          RowBox[{"(", " ", 
            RowBox[{
              RowBox[{"r", "^", "2"}], " ", "+", "1", "-", 
              RowBox[{
                RowBox[{"Abs", "[", "m", "]"}], "^", "2"}]}], " ", ")"}]}], 
        "/", 
        RowBox[{"(", 
          RowBox[{"2", "*", 
            RowBox[{"Im", "[", "m", "]"}]}], ")"}]}]}]], "Input",
  CellLabel->"In[28]:=",
  InitializationCell->True,
  FontFamily->"Times New Roman"],

Cell["gives the bundle parameter of the circle to find.", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(orthot[1 + 2*I,  .5]\)], "Input",
  CellLabel->"In[135]:=",
  FontFamily->"Times New Roman"],

Cell[CellGroupData[{

Cell["6.3.1 Examples", "Subsubsection",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(mmx\  = \ \(-1\); mmy\  = 2; \ mmr\  = 0.5; \ 
    gcirc\  = Graphics[\ Circle[{mmx, mmy}, mmr]]; 
    mmt\  = \ orthot[mmx + I*mmy, mmr]; \ mrt\  = \ Sqrt[1 + mmt^2]; 
    tcirc\  = \ Graphics[Circle[{0, mmt}, mrt]]; \ 
    Show[{tcirc, gcirc}, \ AspectRatio\  \[Rule] \ Automatic, \ 
      Axes\  \[Rule] Automatic]\)], "Input",
  CellLabel->"In[58]:=",
  FontFamily->"Times New Roman"],

Cell["The circle invariant is numerically very small:", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(pssp[bdlvec[mmt], \ rscirclevector[mmx + I*mmy, mmr]]\)], "Input",
  CellLabel->"In[137]:=",
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "The invariant of the pair ",
  "(",
  Cell[BoxData[
      \(TraditionalForm\`S\^1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`S\^0\)]],
  ") is greater than 1; the circle does not separate the points:"
}], "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(rsinvcpp[mmx + I*mmy, mmr, \ 1, \ \(-1\)]\)], "Input",
  CellLabel->"In[138]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(mmx\  = \ \(- .5\); mmy\  =  .5; \ mmr\  = 1.2; \ 
    gcirc\  = Graphics[\ Circle[{mmx, mmy}, mmr]]; 
    mmt\  = \ orthot[mmx + I*mmy, mmr]; \ mrt\  = \ Sqrt[1 + mmt^2]; 
    tcirc\  = \ Graphics[Circle[{0, mmt}, mrt]]; \ 
    Show[{tcirc, gcirc}, \ AspectRatio\  \[Rule] \ Automatic, \ 
      Axes\  \[Rule] Automatic]\)], "Input",
  CellLabel->"In[142]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(pssp[bdlvec[mmt], \ rscirclevector[mmx + I*mmy, mmr]]\)], "Input",
  CellLabel->"In[143]:=",
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "The invariant of the pair (",
  Cell[BoxData[
      \(TraditionalForm\`S\^1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`S\^0\)]],
  ") is less than 1; the circle separates the points:"
}], "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(rsinvcpp[mmx + I*mmy, mmr, \ 1, \ \(-1\)]\)], "Input",
  CellLabel->"In[144]:=",
  FontFamily->"Times New Roman"],

Cell["The testcircle belongs to the bundle:", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(mmx\  = \ 0; T\  = \ 3*Random[]; mmy\  = T; \ mmr\  = Sqrt[1 + T^2]; \ 
    gcirc\  = Graphics[\ Circle[{mmx, mmy}, mmr]]; 
    mmt\  = \ orthot[mmx + I*mmy, mmr]; \ mrt\  = \ Sqrt[1 + mmt^2]; 
    tcirc\  = \ Graphics[Circle[{0, mmt}, mrt]]; \ 
    Show[{tcirc, gcirc}, \ AspectRatio\  \[Rule] \ Automatic, \ 
      Axes\  \[Rule] Automatic]\)], "Input",
  CellLabel->"In[145]:=",
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "Clearly, since the orthogonal circle of the testcircle belongs to the \
bundle, the intersection points must be  ",
  Cell[BoxData[
      \(TraditionalForm\`S\^0\)]],
  " = (-1, 1) . We calculate the correspondence of the parameter values:"
}], "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(corr[t_]\  := \ orthot[t*I, \ Sqrt[1 + t^2]]\)], "Input",
  CellLabel->"In[146]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(corr[t]\)], "Input",
  CellLabel->"In[147]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Declare[t, \ Real]; \ FullSimplify[%]\)], "Input",
  CellLabel->"In[148]:=",
  FontFamily->"Times New Roman"],

Cell["\<\
We obtained an involution without fixed points on the imaginary \
axis, completed with the infinite point.\
\>", "Text",
  FontFamily->"Times New Roman"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
6.3.2 Circles, intersecting all circles of the bundle \
orthogonally\
\>", "Subsubsection",
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "In this subsection we show\n",
  StyleBox["Proposition 3",
    FontColor->RGBColor[0, 0, 1]],
  ". The orthogonal trajectories of a circle bundle form a family of circles.\
\nFor the proof we find all the circles which meet all circles of the bundle \
orthogonally; such circle exist: the imaginary axis is such a circle.  "
}], "Text"],

Cell["\<\
Clear[mx,my,r]; Declare[{mx,my,r},Real]; pssp[{mx/r, my/r, -((-1 + \
mx^2 + my^2 - r^2)/(2*r)), (1 + mx^2 + my^2 - r^2)/(2*r)}, bdlvec[t]]\
\>", \
"Input",
  CellLabel->"In[149]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Together[%]\)], "Input",
  CellLabel->"In[150]:=",
  FontFamily->"Times New Roman"],

Cell["\<\
If the imaginary part my of the center of the orthogonal circle is \
not 0, the value t is uniquely defined, end it exists only one orthogonal \
bundle circle. In case my = 0  all circles\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(bortho[s_]\  := \ 
      Graphics[Circle[{s, \ 0}, \ Sqrt[s^2\  - \ 1]]]\)], "Input",
  CellLabel->"In[151]:=",
  FontFamily->"Times New Roman"],

Cell["with Abs[s] > 1 intersect all bundle circles orthogonally.", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Show[Table[bortho[s], \ {s, \ 1.4, \ 5,  .4}], \ 
      AspectRatio\  \[Rule] \ Automatic]\)], "Input",
  CellLabel->"In[152]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(grortho\  = \ %\)], "Input",
  CellLabel->"In[153]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Show[Table[bortho[s], \ {s, \ \(-1.4\), \ \(-5\), \(- .4\)}], \ 
      AspectRatio\  \[Rule] \ Automatic]\)], "Input",
  CellLabel->"In[154]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(grortho2\  = \ %\)], "Input",
  CellLabel->"In[155]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Show[{grortho, grortho2, bdlgraphics[\(-5\), 5,  .5]}, \ 
      AspectRatio\  \[Rule] \ Automatic]\)], "Input",
  CellLabel->"In[156]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(cirortho\  = \ %\)], "Input",
  FontFamily->"Times New Roman"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Export["\<cirortho.eps\>", \ cirortho]\)], "Input",
  Evaluatable->False,
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \("cirortho.eps"\)], "Output",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  FontFamily->"Times New Roman"]
}, Closed]],

Cell[TextData[{
  StyleBox["Remark.",
    FontColor->RGBColor[0, 0, 1]],
  " Proposiion 3 may be proved much simpler: Consider the bundle of the lines \
through the origin, i.e. the bundle of circles through 0 and infy. "
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["6.4 Circle of the bundle tangential to a given circle", "Subsection",
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "We start again with the spacevector of an arbitrarily given circle ",
  Cell[BoxData[
      \(TraditionalForm\`S\^1\)]],
  ":"
}], "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(rscv[mx, my, r]\)], "Input",
  CellLabel->"In[61]:=",
  FontFamily->"Times New Roman"],

Cell["\<\
The condition that a circle of the bundle is tangential to this \
circle is\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(pssp[rscv[mx, my, r], bdlvec[t]]\  \[Equal] \ 1\)], "Input",
  CellLabel->"In[66]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Solve[%, t]\)], "Input",
  CellLabel->"In[67]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(FullSimplify[%]\)], "Input",
  CellLabel->"In[68]:=",
  FontFamily->"Times New Roman"],

Cell["\<\
Deciding for the existence of one or two solutions is the value of \
the radicand; Factor yields\
\>", "Text"],

Cell[BoxData[
    \(Factor[
      r\^2\ \((mx\^4 + 
            2\ mx\^2\ \((\(-1\) + my\^2 - 
                  r\^2)\) + \((1 + my\^2 - r\^2)\)\^2)\)]\)], "Input",
  CellLabel->"In[161]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(% \[Equal] \ 
      r^2*\((r^2\  - \((1 + mx)\)^2\  - \ 
            my^2)\)*\((r^2\ \  - \((1 - mx)\)^2\ \  - my^2)\)\)], "Input",
  CellLabel->"In[162]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(FullSimplify[%]\)], "Input",
  CellLabel->"In[163]:=",
  FontFamily->"Times New Roman"],

Cell["We define ", "Text"],

Cell[BoxData[
    \(radicand[mx_, my_, 
        r_]\  := \ \ r^2*\((r^2\  - \((1 + mx)\)^2\  - \ 
            my^2)\)*\((r^2\ \  - \((1 - mx)\)^2\ \  - my^2)\)\)], "Input",
  CellLabel->"In[169]:="],

Cell["\<\
Now we calculate the M\[ODoubleDot]bius invariant rsinv01 (cf. \
Corollary 1) of the given circle and the 0-sphere. \
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(?rsinv01\)\)], "Input",
  CellLabel->"In[168]:="],

Cell[BoxData[
    \(rsinv01[\(-1\), 1, \ mx\  + \ I*my, \ r]\)], "Input",
  CellLabel->"In[180]:="],

Cell[BoxData[
    \(FullSimplify[Together[%]]\)], "Input",
  CellLabel->"In[181]:="],

Cell[BoxData[
    \(Factor[%]\)], "Input",
  CellLabel->"In[178]:="],

Cell[BoxData[
    \(Simplify[
      Together[radicand[mx, my, r]/\((r^2)\) - %*4*Abs[r]^2]]\)], "Input",
  CellLabel->"In[182]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Simplify[%, \ r > 0]\)], "Input",
  CellLabel->"In[183]:="],

Cell["\<\
Defining statinvcpp[mx,my,r] := rsinv01[-1,1,mx+I*my,r] the last \
result leads to\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell["\<\
statinvcpp[mx_, my_, r_] := 1 + ((-(1 - mx)^2 - my^2 + r^2)*(-(1 + \
mx)^2 - my^2 + r^2))/
    (4*Abs[r]^2)\
\>", "Input",
  CellLabel->"In[184]:=",
  FontFamily->"Times New Roman"],

Cell["for the stationary M\[ODoubleDot]bius invariant. ", "Text",
  FontFamily->"Times New Roman"],

Cell[TextData[StyleBox["Test:",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[BoxData[
    \(statinvcpp[mx, my, r] - rsinv01[\(-1\), 1, mx + I*my, r]\)], "Input",
  CellLabel->"In[192]:="],

Cell[BoxData[
    \(FullSimplify[Together[%], \ 
      r > 0 && \ mx^2 \[Element] \ Reals && \ 
        my^2 \[Element] \ Reals]\)], "Input",
  CellLabel->"In[193]:="],

Cell[BoxData[
    \(% //. Conjugate[A_]\  \[Rule] \ A\)], "Input",
  CellLabel->"In[195]:="],

Cell[TextData[{
  "We conclude:\n1. There exist two tangent circles of the circle bundle \
through ",
  Cell[BoxData[
      \(TraditionalForm\`S\^0\)]],
  "iff the radicand is positiv, and this is the case iff the circle ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(S\)\(\ \)\)\^1\)]],
  "does not separate the points of ",
  Cell[BoxData[
      \(TraditionalForm\`S\^0\)]],
  ".\n2. Iff  the radicand is negative, then any circle of the bundle through \
",
  Cell[BoxData[
      \(TraditionalForm\`S\^0\)]],
  "intersects the circle ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(S\)\(\ \)\)\^1\)]],
  ", and this is the case iff  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(S\)\(\ \)\)\^1\)]],
  "separates the points of ",
  Cell[BoxData[
      \(TraditionalForm\`S\^0\)]],
  ".\n3. In case the radicand = 0 there exists exactly one circle of the \
bundle tangent to the circle ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(S\)\(\ \)\)\^1\)]],
  ",  and this is the case iff  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(S\)\(\ \)\)\^1\)]],
  "\[Intersection]",
  Cell[BoxData[
      \(TraditionalForm\`S\^0\)]],
  "is not empty.\nIn the next three subsections we construct pictures \
coresponding to these cases."
}], "Text",
  FontFamily->"Times New Roman"],

Cell[CellGroupData[{

Cell["6.4.1 Case 1: Test circle not  separating the points", "Subsubsection",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(mx\  = \ 1.2; \ \ my\  = \ 1.5; \ r\  = \  .9; \ 
    statinvcpp[mx, my, r]\)], "Input",
  CellLabel->"In[196]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(so\  = \ 
      Graphics[{PointSize[0.05], 
          RGBColor[1, 0, 0], {Point[{\(-1\), 0}], Point[{1, 0}]}}]\)], "Input",\

  CellLabel->"In[197]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Show[so, \ AspectRatio\  \[Rule] \ Automatic]\)], "Input",
  CellLabel->"In[198]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(sc1\  = \ 
      Graphics[{Thickness[0.01], RGBColor[0, 0, 1], 
          Circle[{mx, \ my}, \ r]}]\)], "Input",
  CellLabel->"In[199]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Show[{so, sc1}, AspectRatio\  \[Rule] \ Automatic]\)], "Input",
  CellLabel->"In[200]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(pictcirclebdl[\(-2\), 2,  .5]\)], "Input",
  CellLabel->"In[201]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(bdlpict\  = \ %\)], "Input",
  CellLabel->"In[202]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Show[{so, sc1, \ bdlpict}, 
      AspectRatio\  \[Rule] \ Automatic]\)], "Input",
  CellLabel->"In[203]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(ft[t_]\  := \(stationary[mx, my, r]\)[t]\)], "Input",
  CellLabel->"In[204]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(ft[t]\)], "Input",
  CellLabel->"In[205]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Plot[ft[t], {t, \ \(-10\), \ 10}]\)], "Input",
  CellLabel->"In[206]:=",
  FontFamily->"Times New Roman"],

Cell["\<\
The oriented angle is defined only if the bundle circle intersects \
the test circle\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Plot[ArcCos[ft[t]], {t, \ \(-10\), \ 10}]\)], "Input",
  CellLabel->"In[207]:=",
  FontFamily->"Times New Roman"],

Cell["\<\
For the limit t -> \[PlusMinus]\[Infinity] we obtain complex angles \
the sum of which equals  \[Pi]: Passing Infinity we get the real axis with \
changing its orientation:\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Limit[ArcCos[ft[t]], t\  \[Rule] \ Infinity]\)], "Input",
  CellLabel->"In[208]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Limit[ArcCos[ft[t]], t\  \[Rule] \ \(-Infinity\)]\)], "Input",
  CellLabel->"In[209]:=",
  FontFamily->"Times New Roman"],

Cell["\<\
The Coxeter invariant of the test circle with the bundle circles is\
\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Plot[ft[t]^2, \ {t, \(-6\), 6}]\)], "Input",
  CellLabel->"In[210]:=",
  FontFamily->"Times New Roman"],

Cell["We find the maximimum of ft[t]:", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(D[ft[t], \ t]\)], "Input",
  CellLabel->"In[211]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Solve[%\  \[Equal] \ 0, \ t]\)], "Input",
  CellLabel->"In[212]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(tmax\  = \ t /. %[\([1]\)]\)], "Input",
  CellLabel->"In[213]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(ft[tmax]^2\)], "Input",
  CellLabel->"In[214]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Plot[ft[t], \ {t, \ \(-2\), 0}]\)], "Input",
  FontFamily->"Times New Roman"],

Cell["\<\
This number coincides with the stationary invariant, as expected.  \
The corresponding circle of the bundle is\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Graphics[Circle[{0, \ tmax}, Sqrt[1 + tmax^2]]]\)], "Input",
  CellLabel->"In[215]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Show[
      Graphics[{Thickness[0.01], \ RGBColor[0, 1, 0], 
          Circle[{0, \ tmax}, Sqrt[1 + tmax^2]]}]]\)], "Input",
  CellLabel->"In[216]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(scmax\  = \ %\)], "Input",
  CellLabel->"In[217]:=",
  FontFamily->"Times New Roman"],

Cell["\<\
Of course, the bundel circle corresponding to tmax does not \
intersect the testcircle:\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Show[{so, sc1, \ bdlpict, \ scmax}, 
      AspectRatio\  \[Rule] \ Automatic]\)], "Input",
  CellLabel->"In[218]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Solve[ft[t] \[Equal] \ 0, \ t]\)], "Input",
  CellLabel->"In[219]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(to\  = orthot[mx + I*my, r]\)], "Input",
  CellLabel->"In[220]:=",
  FontFamily->"Times New Roman"],

Cell["\<\
The circle of the bundle intersecting the given circle \
Circle[{mx,my},r] orthogonally is\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Show[
      Graphics[{Thickness[0.01], \ RGBColor[1, 0, 0], 
          Circle[{0, \ to}, Sqrt[1 + to^2]]}]]\)], "Input",
  CellLabel->"In[221]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(sco\  = \ %\)], "Input",
  CellLabel->"In[222]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Show[{so, sc1, \ bdlpict, \ scmax, sco}, 
      AspectRatio\  \[Rule] \ Automatic]\)], "Input",
  CellLabel->"In[223]:=",
  FontFamily->"Times New Roman"],

Cell["\<\
Now we are going to find the bundle circles tangent to the test \
circle.\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Solve[ft[t] \[Equal] \ 1, \ t]\)], "Input",
  CellLabel->"In[224]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(t1\  = \ t /. %[\([1]\)]\)], "Input",
  CellLabel->"In[225]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Solve[ft[t] \[Equal] \ \(-1\), \ t]\)], "Input",
  CellLabel->"In[226]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(t2\  = \ t /. %[\([1]\)]\)], "Input",
  CellLabel->"In[227]:=",
  FontFamily->"Times New Roman"],

Cell["The corresponding bundle circles are", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Show[
      Graphics[{Thickness[0.01], \ RGBColor[1, 0, 1], 
          Circle[{0, \ t1}, Sqrt[1 + t1^2]], 
          Circle[{0, \ t2}, Sqrt[1 + t2^2]]}]]\)], "Input",
  CellLabel->"In[228]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(ctangent\  = \ %\)], "Input",
  CellLabel->"In[229]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Show[{so, sc1, \ bdlpict, \ scmax, sco, ctangent}, 
      AspectRatio\  \[Rule] \ Automatic]\)], "Input",
  CellLabel->"In[230]:=",
  FontFamily->"Times New Roman"],

Cell["The tangent points on the test circle: Put", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(cvec = rscirclevector[mx + I*my, r]\)], "Input",
  CellLabel->"In[231]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Solve[{pssp[cvec, \ vec[x]] \[Equal] \ 0, \ 
        pssp[bdlvec[t1], \ vec[x]] \[Equal] \ 0, 
        pssp[vec[x], \ vec[x]] \[Equal] \ 0}, vec[x]]\)], "Input",
  CellLabel->"In[232]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(vt1\  = \ vec[x] /. %\)], "Input",
  CellLabel->"In[233]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(vt1\  = \ vt1 /. x[3]\  \[Rule] \ 1\)], "Input",
  CellLabel->"In[234]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(vt1\  = \ Re[vt1[\([1]\)]]\)], "Input",
  CellLabel->"In[235]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(pssp[%, %]\)], "Input",
  CellLabel->"In[236]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(ch[%%]\)], "Input",
  CellLabel->"In[237]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(invisotrop[vt1]\)], "Input",
  CellLabel->"In[238]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(tangpt1\  = \ Point[{Re[%], \ Im[%]}]\)], "Input",
  CellLabel->"In[239]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Solve[{pssp[cvec, \ vec[x]] \[Equal] \ 0, \ 
        pssp[bdlvec[t2], \ vec[x]] \[Equal] \ 0, 
        pssp[vec[x], \ vec[x]] \[Equal] \ 0}, vec[x]]\)], "Input",
  CellLabel->"In[240]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(vt2\  = \ vec[x] /. %\)], "Input",
  CellLabel->"In[241]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(vt2\  = \ vt2 /. \ x[3]\  \[Rule] \ 1\)], "Input",
  CellLabel->"In[242]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(vt2\  = \ Re[vt2[\([1]\)]]\)], "Input",
  CellLabel->"In[243]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(pssp[vt2, vt2]\)], "Input",
  CellLabel->"In[244]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(invisotrop[vt2]\)], "Input",
  CellLabel->"In[245]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(tangpt2\  = \ Point[{Re[%], \ Im[%]}]\)], "Input",
  CellLabel->"In[246]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(tangpts\  = \ Graphics[{PointSize[0.05], tangpt1, tangpt2}]\)], "Input",\

  CellLabel->"In[247]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Show[{so, sc1, \ bdlpict, \ scmax, sco, ctangent, \ tangpts}, 
      AspectRatio\  \[Rule] \ Automatic]\)], "Input",
  CellLabel->"In[248]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(twotang\  = \ %\)], "Input",
  CellLabel->"In[249]:=",
  FontFamily->"Times New Roman"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Export["\<twotang.eps\>", twotang]\)], "Input",
  Evaluatable->False,
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \("twotang.eps"\)], "Output",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  FontFamily->"Times New Roman"]
}, Closed]],

Cell[BoxData[
    \(Clear[mx, my, r]\)], "Input",
  CellLabel->"In[282]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["6.4.2 Case 2: Test circle separating the points", "Subsubsection",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(mx\  = \ 1.2; \ \ my\  = \ 0.5; \ r\  = \ 1.5; \ 
    statinvcpp[mx, my, r]\)], "Input",
  CellLabel->"In[250]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(sc1\  = \ 
      Graphics[{Thickness[0.01], RGBColor[0, 0, 1], 
          Circle[{mx, \ my}, \ r]}]\)], "Input",
  CellLabel->"In[251]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Show[{so, sc1}, AspectRatio\  \[Rule] \ Automatic]\)], "Input",
  CellLabel->"In[252]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(pictcirclebdl[\(-2\), 2,  .5]\)], "Input",
  CellLabel->"In[253]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(bdlpict1\  = \ %\)], "Input",
  CellLabel->"In[255]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Show[{so, sc1, \ bdlpict1}, 
      AspectRatio\  \[Rule] \ Automatic]\)], "Input",
  CellLabel->"In[256]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(ft[t_]\  := \(stationary[mx, my, r]\)[t]\)], "Input",
  CellLabel->"In[257]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(ft[t]\)], "Input",
  CellLabel->"In[258]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Plot[ft[t], {t, \ \(-10\), \ 10}]\)], "Input",
  CellLabel->"In[259]:=",
  FontFamily->"Times New Roman"],

Cell["The oriented angle is", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Plot[ArcCos[ft[t]], {t, \ \(-10\), \ 10}]\)], "Input",
  CellLabel->"In[260]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Limit[ArcCos[ft[t]], t\  \[Rule] \ Infinity]\)], "Input",
  CellLabel->"In[261]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Limit[ArcCos[ft[t]], t\  \[Rule] \ \(-Infinity\)]\)], "Input",
  CellLabel->"In[262]:=",
  FontFamily->"Times New Roman"],

Cell["\<\
Passing t ->Infinity  the orientation  of the real axis is \
changing; the sum of the two corresponding angles equals \[Pi]:\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(\(1.2309594173407747`\)\(\[InvisibleSpace]\)\(+\)\(1.9106332362490184`\
\)\(\[InvisibleSpace]\)\)\)], "Input",
  CellLabel->"In[263]:=",
  FontFamily->"Times New Roman"],

Cell["We find the maximimum of ft[t]:", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(D[ft[t], \ t]\)], "Input",
  CellLabel->"In[264]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Solve[%\  \[Equal] \ 0, \ t]\)], "Input",
  CellLabel->"In[265]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(tmax\  = \ t /. %[\([1]\)]\)], "Input",
  CellLabel->"In[266]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(ft[tmax]^2\)], "Input",
  CellLabel->"In[267]:=",
  FontFamily->"Times New Roman"],

Cell["\<\
This number coincides with the stationary invariant, as expected.  \
The corresponding circle of the bundle is\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Graphics[Circle[{0, \ tmax}, Sqrt[1 + tmax^2]]]\)], "Input",
  CellLabel->"In[268]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Show[
      Graphics[{Thickness[0.01], \ RGBColor[0, 1, 0], 
          Circle[{0, \ tmax}, Sqrt[1 + tmax^2]]}]]\)], "Input",
  CellLabel->"In[269]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(scmax\  = \ %\)], "Input",
  CellLabel->"In[270]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Show[{so, sc1, \ bdlpict1, \ scmax}, 
      AspectRatio\  \[Rule] \ Automatic]\)], "Input",
  CellLabel->"In[271]:=",
  FontFamily->"Times New Roman"],

Cell["\<\
For the green circle, corresponding to tmax, the stationary \
invariant, being the square of the cosinus of the intersection angle, is \
maximal; therefore the intersection angle is minimal.  Its value is\
\>", \
"Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(ArcCos[ft[tmax]]\)], "Input",
  CellLabel->"In[272]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Plot[ArcCos[ft[t]], \ {t, \  .45,  .9}]\)], "Input",
  CellLabel->"In[273]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Plot[ft[t]^2, \ {t, \ \(-10\), \ 10}]\)], "Input",
  CellLabel->"In[274]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Solve[ft[t] \[Equal] \ 0, \ t]\)], "Input",
  CellLabel->"In[275]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(to\  = orthot[mx + I*my, r]\)], "Input",
  CellLabel->"In[276]:=",
  FontFamily->"Times New Roman"],

Cell["\<\
The circle of the bundle intersecting the given circle \
Circle[{mx,my},r] orthogonally is\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Show[
      Graphics[{Thickness[0.01], \ RGBColor[1, 0, 0], 
          Circle[{0, \ to}, Sqrt[1 + to^2]]}]]\)], "Input",
  CellLabel->"In[277]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(sco\  = \ %\)], "Input",
  CellLabel->"In[278]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Show[{so, sc1, \ bdlpict1, \ scmax, sco}, 
      AspectRatio\  \[Rule] \ Automatic]\)], "Input",
  CellLabel->"In[279]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(notang\  = \ %\)], "Input",
  CellLabel->"In[280]:=",
  FontFamily->"Times New Roman"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Export["\<notang.eps\>", notang]\)], "Input",
  Evaluatable->False,
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \("notang.eps"\)], "Output",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  FontFamily->"Times New Roman"]
}, Closed]],

Cell[TextData[{
  "Red points: The 0-sphere ",
  Cell[BoxData[
      \(TraditionalForm\`S\^0\)]],
  " =(-1,1)\nBlue circle: ",
  Cell[BoxData[
      \(TraditionalForm\`S\^1\)]],
  "= Circle[{mx,my},r] separating the points -1,1.\nRed circle: The bundle \
circle orthogonal to ",
  Cell[BoxData[
      \(TraditionalForm\`S\^1\)]],
  ".\nGreen circle: The bundle circle intersecting  ",
  Cell[BoxData[
      \(TraditionalForm\`S\^1\)]],
  " with minimal angle."
}], "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Clear[mx, my, r, \ ft]\)], "Input",
  CellLabel->"In[281]:=",
  FontFamily->"Times New Roman"]
}, Closed]],

Cell[CellGroupData[{

Cell["6.4.3 Case 3: Test circle containing one of the points", "Subsubsection",
  FontFamily->"Times New Roman"],

Cell["\<\
In the following example the test circle is a random circle of \
radius 1 containing the Point (1,0):\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Clear[phi, mx, my, r]\)], "Input",
  CellLabel->"In[322]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(phi\  = 2*Pi*Random[]; Print[phi]; \ mx\  = \ 1. \  + \ Cos[phi]; \ 
    my\  = \ Sin[phi]; Print[{mx, my}]; \ r\  = \ 1;\)], "Input",
  CellLabel->"In[323]:=",
  FontFamily->"Times New Roman"],

Cell["\<\
Of course, the stationary invariant of (-1, 1) and the testcircle \
always equals 1:\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(rsinvcpp[mx + I*my, r, \ 1, \ \(-1\)]\)], "Input",
  CellLabel->"In[324]:=",
  FontFamily->"Times New Roman"],

Cell["\<\
Evaluate this subsection repeatedly, and and observe the last \
picture; the blue circle is the test circle. You may change the defining data \
in the second cell of this subsection in an appropriate way. \
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(sc3\  = \ 
      Graphics[{Thickness[0.01], RGBColor[0, 0, 1], 
          Circle[{mx, \ my}, \ r]}]\)], "Input",
  CellLabel->"In[325]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Show[{so, sc3}, AspectRatio\  \[Rule] \ Automatic]\)], "Input",
  CellLabel->"In[326]:=",
  FontFamily->"Times New Roman"],

Cell["\<\
Now we find the uniquely defined tangent circle of the bundle; its \
color will be magenta:\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(ft[t_]\  := \(stationary[mx, my, r]\)[t]\)], "Input",
  CellLabel->"In[327]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Plot[ft[t], \ {t, \ \(-15\), 15}]\)], "Input",
  CellLabel->"In[328]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Limit[ft[t], \ t\  \[Rule] \ Infinity]\)], "Input",
  CellLabel->"In[329]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Limit[ft[t], \ t\  \[Rule] \ \(-Infinity\)]\)], "Input",
  CellLabel->"In[330]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Solve[ft[t]^2 \[Equal] \ 1, \ t]\)], "Input",
  CellLabel->"In[331]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(tstat = \ Chop[Re[t /. %[\([1]\)]]]\)], "Input",
  CellLabel->"In[332]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Show[
      Graphics[{Thickness[0.01], \ RGBColor[1, 0, 1], 
          Circle[{0, tstat}, Sqrt[1 + tstat^2]]}], \ 
      AspectRatio\  \[Rule] \ Automatic]\)], "Input",
  CellLabel->"In[333]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(ctang1\  = \ %\)], "Input",
  CellLabel->"In[334]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(to\  = orthot[mx + I*my, 1]\)], "Input",
  CellLabel->"In[335]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Show[
      Graphics[{Thickness[0.01], \ RGBColor[1, 0, 0], 
          Circle[{0, to}, Sqrt[1 + to^2]]}], \ 
      AspectRatio\  \[Rule] \ Automatic]\)], "Input",
  CellLabel->"In[336]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(cto\  = \ %\)], "Input",
  CellLabel->"In[337]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Show[{so, sc3, bdlpict1, \ ctang1, \ cto}, 
      AspectRatio\  \[Rule] \ Automatic]\)], "Input",
  CellLabel->"In[338]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(onetang\  = \ %\)], "Input",
  CellLabel->"In[339]:=",
  FontFamily->"Times New Roman"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Export["\<onetang.eps\>", \ onetang]\)], "Input",
  Evaluatable->False,
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \("onetang.eps"\)], "Output",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  FontFamily->"Times New Roman"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["6.5 If the test circle is a line...", "Subsection",
  FontFamily->"Times New Roman"],

Cell["\<\
In this subsection we shall replace the test circle by a test line. \
Of course, only formal changes are to expect. We recommend the user to \
complete further details. 
The rscirclevector must be replaced by a spacelike unit vector corresponding \
to the line through two points u1, u2 of the complex plane; such a vector is \
obtained by normalizing\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(psCross[isotrop[u1], isotrop[u2], \ isotrop[infy]]\)], "Input",
  CellLabel->"In[100]:="],

Cell[BoxData[
    \(normalize[%]\)], "Input",
  CellLabel->"In[101]:="],

Cell[BoxData[
    \(% //. \ 
      1/\@Abs[Im[u1]\^2 - 2\ Im[u1]\ Im[u2] + Im[u2]\^2 + \((Re[u1] - Re[u2])\
\)\^2]\ \  \[Rule] \ 1/Abs[u2 - u1]\)], "Input",
  CellLabel->"In[102]:="],

Cell[BoxData[
    \(FullSimplify[%]\)], "Input",
  CellLabel->"In[103]:="],

Cell["Thus, we may define the Module", "Text"],

Cell["Clear[w, u1, u2, t]; Declare[t, Real];", "Input",
  CellLabel->"In[29]:=",
  InitializationCell->True,
  FontFamily->"Times New Roman"],

Cell["\<\
 rslinevector[u1_, u2_] := 
   Module[{tang, tt}, tang = u2 - u1; tt = Abs[tang]; 
     If[Chop[tt] == 0, Print[\"The points are equal!\"]; Return[]]; 
     Return[{(-Im[u1] + Im[u2])/Abs[u1 - u2], (Re[u1] - Re[u2])/
        Abs[u1 - u2], (Im[u2]*Re[u1] - Im[u1]*Re[u2])/Abs[u1 - u2], 
       (Im[u2]*Re[u1] - Im[u1]*Re[u2])/Abs[u1 - u2]}]]\
\>", "Input",
  CellLabel->"In[30]:=",
  InitializationCell->True,
  FontFamily->"Times New Roman"],

Cell[CellGroupData[{

Cell["6.5.1 Test. Exampless", "Subsubsection",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(rslinevector[u, u]\)], "Input",
  CellLabel->"In[105]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Clear[u1, u2]; \ rslinevector[u1, u2]\)], "Input",
  CellLabel->"In[106]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(FullSimplify[
      pssp[rslinevector[u1, u2], rslinevector[u1, u2]]]\)], "Input",
  CellLabel->"In[107]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(pssp[rslinevector[u1, u2], \ isotrop[u1]]\)], "Input",
  CellLabel->"In[108]:="],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[109]:="],

Cell[BoxData[
    \(pssp[rslinevector[u1, u2], \ isotrop[u2]]\)], "Input",
  CellLabel->"In[111]:="],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[112]:="],

Cell[BoxData[
    \(pssp[rslinevector[u1, u2], \ isotrop[infy]]\)], "Input",
  CellLabel->"In[110]:="],

Cell["OK!", "Text"],

Cell["\<\
The direction of  rslinevector depends on the orientation of the \
line:\
\>", "Text"],

Cell[BoxData[
    \(rslinevector[0, 1]\)], "Input",
  CellLabel->"In[113]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(rslinevector[1, 0]\)], "Input",
  CellLabel->"In[114]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(rslinevector[I, 1]\)], "Input",
  CellLabel->"In[116]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(tv = \ %\)], "Input",
  CellLabel->"In[117]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(pssp[isotrop1[I], \ tv]\)], "Input",
  CellLabel->"In[118]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(pssp[isotrop1[1], \ tv]\)], "Input",
  CellLabel->"In[119]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(pssp[isotrop1[1\  + \ t*\((I - 1)\)], \ tv]\)], "Input",
  CellLabel->"In[120]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(FullSimplify[%]\)], "Input",
  CellLabel->"In[121]:=",
  FontFamily->"Times New Roman"]
}, Closed]],

Cell[CellGroupData[{

Cell["6.5.2 The testfunction", "Subsubsection",
  FontFamily->"Times New Roman"],

Cell["For the vector of the bundle circle bc[t] we have again", "Text",
  FontFamily->"Times New Roman"],

Cell["bdlvec[t_] := {0, t/Sqrt[1 + t^2], 1/Sqrt[1 + t^2], 0}", "Input",
  CellLabel->"In[352]:=",
  FontFamily->"Times New Roman"],

Cell["\<\
The pseudo-euclidean  scalar product defines the testfunction   \
\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(ftest[u1_, u2_]\)[t_]\  := \ 
      pssp[rslinevector[u1, u2], \ bdlvec[t]]\)], "Input",
  CellLabel->"In[138]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(FullSimplify[\(ftest[u1, u2]\)[t], \ t > 0]\)], "Input",
  CellLabel->"In[123]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Plot[\(ftest[2*I, \ 1]\)[t], \ {t, \ \(-3\), 3}]\)], "Input",
  CellLabel->"In[124]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Plot[\(ftest[2*I, \ 1]\)[t]^2, \ {t, \ \(-3\), 3}]\)], "Input",
  CellLabel->"In[125]:=",
  FontFamily->"Times New Roman"]
}, Closed]],

Cell[CellGroupData[{

Cell["6.5.3 The orthogonal bundle circle", "Subsubsection",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Solve[\(ftest[u1, u2]\)[t]\  \[Equal] \ 0, \ t]\)], "Input",
  CellLabel->"In[139]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(otcir\  = \ t /. %[\([1]\)]\)], "Input",
  CellLabel->"In[128]:=",
  FontFamily->"Times New Roman"],

Cell["\<\
 Thus the parameter t of the bundle circle orthogonal to the line \
joining u1,u2, in case Re[u1]\[NotEqual]Re[u2], is\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(tortholine[u1_, 
        u2_] := \ \(Im[u2]\ Re[u1] - Im[u1]\ Re[u2]\)\/\(Re[u1] - \
Re[u2]\)\)], "Input",
  CellLabel->"In[135]:=",
  FontFamily->"Times New Roman"],

Cell["\<\
What happens in case Re[u1] = Re[u2]? Clear: The real axis is the \
orthogonal circle:\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Declare[{x1, y1, x2, y2}, \ Real]\)], "Input",
  CellLabel->"In[140]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Solve[\(ftest[x1\  + \ I*y1, x1 + \ I*y2]\)[t]\  \[Equal] \ 0, \ 
      t]\)], "Input",
  CellLabel->"In[141]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(tortholine[x1\  + \ I*y1, x1 + \ I*y2]\)], "Input",
  CellLabel->"In[142]:=",
  FontFamily->"Times New Roman"],

Cell["Here is an example where Solve yields no solution:", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Solve[\(ftest[\ I, I*2]\)[t]\  \[Equal] \ 0, \ t]\)], "Input",
  CellLabel->"In[149]:=",
  FontFamily->"Times New Roman"],

Cell["\<\
besides of the fact that all circle of the bundle intersect the \
imaginary axis orthogonally:\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Plot[\(ftest[2*I, \ I]\)[t] + 1, \ {t, \ \(-3\), 3}]\)], "Input",
  CellLabel->"In[147]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Table[\(ftest[2*I, \ I]\)[t], \ {t, \ \(-3\), 3, \  .5}]\)], "Input",
  CellLabel->"In[148]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(rslinevector[3*I, \ 2\  - \ 3*I]\)], "Input",
  CellLabel->"In[154]:="],

Cell[BoxData[
    \(vradius[%]\)], "Input",
  CellLabel->"In[155]:="],

Cell[BoxData[
    \(rsvcenter[%%]\)], "Input",
  CellLabel->"In[156]:="],

Cell[BoxData[
    \(Show[Graphics[Line[{{0, 3}, {2, \(-3\)}}]]]\)], "Input",
  CellLabel->"In[159]:="],

Cell[BoxData[
    \(gline\  = \ %\)], "Input",
  CellLabel->"In[160]:="],

Cell[BoxData[
    \(gort\  = \ tortholine[3*I, \ 2 - 3*I]\)], "Input",
  CellLabel->"In[161]:="],

Cell[BoxData[
    \(Show[Graphics[Circle[{0, \ 3}, Sqrt[10]]]]\)], "Input",
  CellLabel->"In[162]:="],

Cell[BoxData[
    \(glinecirc\  = \ %\)], "Input",
  CellLabel->"In[163]:="],

Cell[BoxData[
    \(Show[{glinecirc, \ gline}, 
      AspectRatio\  \[Rule] \ Automatic]\)], "Input",
  CellLabel->"In[164]:="]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
7 The homomorphism SL[2,C] \[LongRightArrow] SO[3,1]+ \
\>", \
"Section",
  FontFamily->"Times New Roman"],

Cell[CellGroupData[{

Cell["7.1 Equivariance. Examples", "Subsection",
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "From the general theory, see e.g. [",
  ButtonBox["O.-S.",
    ButtonData:>"O.-S.",
    ButtonStyle->"Hyperlink"],
  "], section 2.7, it is clear that the classical special M\[ODoubleDot]bius \
group as defined above as the projective group of the complex projective line \
(i.e. the Riemannian sphere) coincides with the special M\[ODoubleDot]bius \
group SO(3,1)+  the group of the pseudo-orthogonal, space- and \
time-orientation preserving transformations of the generators of the \
isotropic cone. Thus, there exists a 2-1-homomorphism of the complex special \
linear group SL(2,C) to SO(3,1)+.  A matrix describing the homomorphismus can \
be found in the paper ",
  ButtonBox["[W]",
    ButtonData:>"W.",
    ButtonStyle->"Hyperlink"],
  " of J. B. Wilker, see ",
  ButtonBox["below",
    ButtonData:>"W.matrix",
    ButtonStyle->"Hyperlink"],
  " . Another description of this homomorphism I learnt from my colleague H. \
Gollek. \nWe are going to derive Wilker's homomorphism using the equivariance \
of the transformation groups by means of the map isotrop defined in \
subsection 2.3.1.\nGenerally, the following function transfers the action of \
g0[a,b,c,d] into an action on the isotropic cone:"
}], "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"mg1", "[", 
          RowBox[{"a_", ",", "b_", ",", "c_", ",", "d_"}], "]"}], "[", 
        "h_List", "]"}], " ", ":=", " ", 
      RowBox[{"isotrop1", "[", 
        RowBox[{
          RowBox[{"g0", "[", 
            RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "]"}], "[", 
          RowBox[{"invisotrop", "[", "h", "]"}], "]"}], "]"}]}]], "Input",
  CellLabel->"In[31]:=",
  InitializationCell->True,
  FontFamily->"Times New Roman"],

Cell["\<\
 We may consider this action also with the unnormed function \
isotrop:\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"mg", "[", 
          RowBox[{"a_", ",", "b_", ",", "c_", ",", "d_"}], "]"}], "[", 
        "h_List", "]"}], " ", ":=", " ", 
      RowBox[{"isotrop", "[", 
        RowBox[{
          RowBox[{"g0", "[", 
            RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "]"}], "[", 
          RowBox[{"invisotrop", "[", "h", "]"}], "]"}], "]"}]}]], "Input",
  CellLabel->"In[32]:=",
  InitializationCell->True,
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(?isotrop\)\)], "Input",
  CellLabel->"In[68]:="],

Cell[BoxData[
    \(\(?invisotrop\)\)], "Input",
  CellLabel->"In[69]:="],

Cell[CellGroupData[{

Cell["General evaluation", "Subsubsection"],

Cell["\<\
Before considering these functions in details we declare some \
needed variables as real: \
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Declare[{t, x, y, r, \ u, v}, Real]\)], "Input",
  CellLabel->"In[165]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(RealQ[t]\)], "Input",
  CellLabel->"In[166]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(isotrop1[x + I*y]\)], "Input",
  CellLabel->"In[167]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(isotrop[x + I*y]\)], "Input",
  CellLabel->"In[168]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(mg1[a, b, c, d]\)[{2*x, 2*y, 1 - \((x^2 + y^2)\), 
        1 + x^2 + y^2}]\)], "Input",
  CellLabel->"In[169]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(mg[a, b, c, d]\)[{2*x, 2*y, 1 - \((x^2 + y^2)\), 
        1 + x^2 + y^2}]\)], "Input",
  CellLabel->"In[170]:=",
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "Examples of special transformations see ",
  ButtonBox["below",
    ButtonData:>"spectrans",
    ButtonStyle->"Hyperlink"],
  " ."
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["7.2 The geometric background", "Subsection"],

Cell["The imaginary axis yields stb[1]:", "Text"],

Cell[BoxData[
    \(\(?rsvector3pts\)\)], "Input",
  CellLabel->"In[171]:="],

Cell[BoxData[
    \(rsvector3pts[0, I, infy]\)], "Input",
  CellLabel->"In[172]:="],

Cell["The real axis yields stb[2]", "Text"],

Cell[BoxData[
    \(rsvector3pts[1, 0, infy]\)], "Input",
  CellLabel->"In[173]:="],

Cell["The unit circle yields stb[3]:", "Text"],

Cell[BoxData[
    \(rsvector3pts[1, I, \(-1\)]\)], "Input",
  CellLabel->"In[174]:="],

Cell["The images of 1, -1, 0, I, infy:", "Text"],

Cell[BoxData[
    \(mv1\  = \ \(g0[a, b, c, d]\)[1]\)], "Input",
  CellLabel->"In[175]:="],

Cell[BoxData[
    \(mvm1\  = \ \(g0[a, b, c, d]\)[\(-1\)]\)], "Input",
  CellLabel->"In[176]:="],

Cell[BoxData[
    \(mv0\  = \ \(g0[a, b, c, d]\)[0]\)], "Input",
  CellLabel->"In[177]:="],

Cell[BoxData[
    \(mvI\  = \ \(g0[a, b, c, d]\)[I]\)], "Input",
  CellLabel->"In[178]:="],

Cell[BoxData[
    \(mvinfy\  = \ \(g0[a, b, c, d]\)[infy]\)], "Input",
  CellLabel->"In[179]:="],

Cell["\<\
We use these images or similar images for the calculation of the \
images of the basis vectors; e.g.
stb[1]\[RightTeeArrow]imaginary axis = circle[0, I, infy] \[RightTeeArrow]g( \
circle[0, I, \
infy])=circle[g(0),g(I),g(infy)]\[RightTeeArrow]rsvector3pts[g(0),g(I),g(infy)\
];
we first calculate rsvector3pts, and then normalizing the result obtain the \
image of stb[1], the first column mv4v[1] of the corresponding \
pseudo-orthogonal matrix. Analogeously we calculate the second and the third \
column, and then we finde the fourth column by the cross product
mv4v[4] = psCross[mv4v[1],mv4v[2],mv4v[3]]\
\>", "Text"],

Cell["\<\
For future simplification it will be usefull enlarging \
$RecursionLimit and $IterationLimit done with the initialization \
already:\
\>", "Text"],

Cell[BoxData["$RecursionLimit"], "Input",
  CellLabel->"In[33]:=",
  InitializationCell->True],

Cell[BoxData[
    RowBox[{"$RecursionLimit", "=", 
      RowBox[{"4", "*", "%"}]}]], "Input",
  CellLabel->"In[34]:=",
  InitializationCell->True],

Cell[BoxData["$IterationLimit"], "Input",
  CellLabel->"In[35]:=",
  InitializationCell->True],

Cell[BoxData[
    RowBox[{"$IterationLimit", "=", 
      RowBox[{"2", "*", "%"}]}]], "Input",
  CellLabel->"In[36]:=",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["7.3 The calculation of Wilker's matrix", "Subsection"],

Cell[CellGroupData[{

Cell["The Parameter", "Subsubsection"],

Cell["\<\
The parameters of the transformation under the assumption a*d - b*c \
\[NotEqual] 0\
\>", "Text"],

Cell[BoxData[
    \(Declare[{a1, a2, b1, b2, c1, c2, d1, d2}, Real]\)], "Input",
  CellLabel->"In[180]:="],

Cell[BoxData[
    \(a = a1 + I*a2; b = b1 + I*b2; c = c1 + \ I*c2; 
    d = d1 + I*d2;\)], "Input",
  CellLabel->"In[181]:="],

Cell["\<\
Now we express the images of 1,-1 ,0,I, infy once more using the \
decomposition of the parameters:\
\>", "Text"],

Cell[BoxData[
    \(mv1\  = \ \(g0[a, b, c, d]\)[1]\)], "Input",
  CellLabel->"In[182]:="],

Cell[BoxData[
    \(mvm1\  = \ \(g0[a, b, c, d]\)[\(-1\)]\)], "Input",
  CellLabel->"In[183]:="],

Cell[BoxData[
    \(mvinfy\  = \ \(g0[a, b, c, d]\)[infy]\)], "Input",
  CellLabel->"In[184]:="],

Cell[BoxData[
    \(mv0\  = \ \(g0[a, b, c, d]\)[0]\)], "Input",
  CellLabel->"In[185]:="],

Cell[BoxData[
    \(mvI\  = \ \(g0[a, b, c, d]\)[I]\)], "Input",
  CellLabel->"In[186]:="],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[187]:="],

Cell[BoxData[
    \(mvI\  = %\)], "Input",
  CellLabel->"In[188]:="],

Cell["\<\
We use these images for the calculation of the images of the basis \
vectors as described above.\
\>", "Text"],

Cell["\<\
We want to consider the broken linear transformations under the \
assumption  a*d-c*b =1. For the real and imaginary parts we have\
\>", "Text"],

Cell[BoxData[
    \(Re[a*d - c*b]\)], "Input",
  CellLabel->"In[189]:="],

Cell[BoxData[
    \(% //. crRules\)], "Input",
  CellLabel->"In[190]:="],

Cell[BoxData[
    \(Im[a*d - c*b]\)], "Input",
  CellLabel->"In[191]:="],

Cell[BoxData[
    \(% //. crRules\)], "Input",
  CellLabel->"In[192]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["The image of stb[1]", "Subsubsection"],

Cell[BoxData[
    \(rsvector3pts[0, I, infy]\)], "Input",
  CellLabel->"In[105]:="],

Cell[BoxData[
    \(rsvector3pts[mv0, mvI, mvinfy]\)], "Input",
  CellLabel->"In[106]:="],

Cell[BoxData[
    \(% //. crRules\)], "Input",
  CellLabel->"In[107]:="],

Cell[BoxData[
    \(ComplexExpand[%]\)], "Input",
  CellLabel->"In[108]:="],

Cell[BoxData[
    \(Simplify[%, \(-b1\)\ c1 + b2\ c2 + a1\ d1 - a2\ d2 \[Equal] \ 
          1 && \(-b2\)\ c1 - b1\ c2 + a2\ d1 + a1\ d2 \[Equal] \ 
          0]\)], "Input",
  CellLabel->"In[109]:="],

Cell["\<\
%*(c1^2 + c2^2)*(d1^2 + d2^2)*(c1^2 + c2^2 - 2*c2*d1 + d1^2 + 
   2*c1*d2 + d2^2)\
\>", "Input",
  CellLabel->"In[110]:="],

Cell[BoxData[
    \(normalize[%]\)], "Input",
  CellLabel->"In[111]:="],

Cell[BoxData[
    \(% //. Abs[A_]\  \[Rule] \ A\)], "Input",
  CellLabel->"In[112]:="],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[113]:="],

Cell[BoxData[
    \(inter2\  = \ %\)], "Input",
  CellLabel->"In[114]:="],

Cell["\<\
Factor[(-4 + 8*b2*c2 + 8*a1*d1)^2 + (8*b1*c2 - 8*a2*d1)^2 + 
   16*(a1*b1 + a2*b2 - c1*d1 - c2*d2)^2 - 
   16*(a1*b1 + a2*b2 + c1*d1 + c2*d2)^2]\
\>", "Input",
  CellLabel->"In[115]:="],

Cell[BoxData[
    \(Simplify[%, \(-b1\)\ c1 + b2\ c2 + a1\ d1 - a2\ d2 \[Equal] \ 
          1 && \(-b2\)\ c1 - b1\ c2 + a2\ d1 + a1\ d2 \[Equal] \ 
          0]\)], "Input",
  CellLabel->"In[116]:="],

Cell[BoxData[
    \(inter2*
      Sqrt[\((\(-4\) + 8*b2*c2 + 8*a1*d1)\)^2 + \((8*b1*c2 - 8*a2*d1)\)^2 + 
            16*\((a1*b1 + a2*b2 - c1*d1 - c2*d2)\)^2 - 
            16*\((a1*b1 + a2*b2 + c1*d1 + c2*d2)\)^2]/4\)], "Input",
  CellLabel->"In[117]:="],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[118]:="],

Cell[BoxData[
    \(\(mat[
          1]\  = {\(-1\) + 2\ b2\ c2 + 2\ a1\ d1, \(-2\)\ b1\ c2 + 2\ a2\ d1, 
          a1\ b1 + a2\ b2 - c1\ d1 - c2\ d2, 
          a1\ b1 + a2\ b2 + c1\ d1 + c2\ d2};\)\)], "Input",
  CellLabel->"In[119]:="],

Cell[BoxData[
    \(pssp[mat[1], mat[1]]\)], "Input",
  CellLabel->"In[120]:="],

Cell[BoxData[
    \(Simplify[%, \(-b1\)\ c1 + b2\ c2 + a1\ d1 - a2\ d2 \[Equal] \ 
          1 && \(-b2\)\ c1 - b1\ c2 + a2\ d1 + a1\ d2 \[Equal] \ 
          0]\)], "Input",
  CellLabel->"In[121]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["The image of stb[2]", "Subsubsection"],

Cell[BoxData[
    \(rsvector3pts[1, 0, infy]\)], "Input",
  CellLabel->"In[123]:="],

Cell[BoxData[
    \(rsvector3pts[mv1, mv0, mvinfy]\)], "Input",
  CellLabel->"In[124]:="],

Cell[BoxData[
    \(ComplexExpand[%]\)], "Input",
  CellLabel->"In[125]:="],

Cell[BoxData[
    \(% //. crRules\)], "Input",
  CellLabel->"In[126]:="],

Cell[BoxData[
    \(% //. {Abs[A_*B_]\  \[Rule] \ Abs[A]*Abs[B], 
        Abs[A_/B_]\  \[Rule] \ Abs[A]/Abs[B], \ 
        Abs[Abs[C_]]\  \[Rule] \ Abs[C]}\)], "Input",
  CellLabel->"In[128]:="],

Cell["% //. Abs[A_]^2 -> Re[A]^2 + Im[A]^2", "Input",
  CellLabel->"In[127]:="],

Cell["\<\
% //. 1/Abs[A_]^2 \[Rule] 1/(Re[A]^2 + Im[A]^2)\
\>", "Input",
  CellLabel->"In[128]:="],

Cell[BoxData[
    \(% //. Abs[A_]\  \[Rule] \ A\)], "Input",
  CellLabel->"In[129]:="],

Cell[BoxData[
    \(\(inter3\  = \ %;\)\)], "Input",
  CellLabel->"In[130]:="],

Cell[BoxData[
    \(Simplify[
      inter3, \(-b1\)\ c1 + b2\ c2 + a1\ d1 - a2\ d2 \[Equal] \ 
          1 && \(-b2\)\ c1 - b1\ c2 + a2\ d1 + a1\ d2 \[Equal] \ 
          0]\)], "Input",
  CellLabel->"In[131]:="],

Cell["\<\
%*((c1^2 + c2^2)*(d1^2 + d2^2)*(c1^2 + c2^2 + 2*c1*d1 + d1^2 + 
    2*c2*d2 + d2^2))\
\>", "Input",
  CellLabel->"In[132]:="],

Cell[BoxData[
    \(normalize[%]\)], "Input",
  CellLabel->"In[133]:="],

Cell[BoxData[
    \(\(inter4\  = \ %;\)\)], "Input",
  CellLabel->"In[134]:="],

Cell[BoxData[
    \(Factor[\((8\ b1\ c2 - 8\ a1\ d2)\)\^2 + \((4 - 8\ b2\ c2 + 8\ a2\ d2)\)\
\^2 - 16\ \((a2\ b1 - a1\ b2 + c2\ d1 - c1\ d2)\)\^2 + 
        16\ \((a2\ b1 - a1\ b2 - c2\ d1 + c1\ d2)\)\^2]\)], "Input",
  CellLabel->"In[135]:="],

Cell[BoxData[
    \(Simplify[%, \(-b1\)\ c1 + b2\ c2 + a1\ d1 - a2\ d2 \[Equal] \ 
          1 && \(-b2\)\ c1 - b1\ c2 + a2\ d1 + a1\ d2 \[Equal] \ 
          0]\)], "Input",
  CellLabel->"In[136]:="],

Cell[BoxData[
    \(inter4 //. 
      1/\((\[Sqrt]Abs[\((8\ b1\ c2 - 8\ a1\ d2)\)\^2 + \((4 - 8\ b2\ c2 + 8\ \
a2\ d2)\)\^2 - 16\ \((a2\ b1 - a1\ b2 + c2\ d1 - c1\ d2)\)\^2 + 
                  16\ \((a2\ b1 - a1\ b2 - c2\ d1 + c1\ d2)\)\^2])\) \[Rule] \
\ 1/4\)], "Input",
  CellLabel->"In[138]:="],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[139]:="],

Cell["\<\
mat[2] = {-2*b1*c2 + 2*a1*d2, 1 - 2*b2*c2 + 2*a2*d2, 
    -a2*b1 + a1*b2 + c2*d1 - c1*d2, -a2*b1 + a1*b2 - c2*d1 + 
     c1*d2}; \
\>", "Input",
  CellLabel->"In[140]:="],

Cell[BoxData[
    \(pssp[mat[1], mat[2]]\)], "Input",
  CellLabel->"In[141]:="],

Cell[BoxData[
    \(Simplify[%, \(-b1\)\ c1 + b2\ c2 + a1\ d1 - a2\ d2 \[Equal] \ 
          1 && \(-b2\)\ c1 - b1\ c2 + a2\ d1 + a1\ d2 \[Equal] \ 
          0]\)], "Input",
  CellLabel->"In[142]:="],

Cell[BoxData[
    \(pssp[mat[2], mat[2]]\)], "Input",
  CellLabel->"In[143]:="],

Cell[BoxData[
    \(Simplify[%, \(-b1\)\ c1 + b2\ c2 + a1\ d1 - a2\ d2 \[Equal] \ 
          1 && \(-b2\)\ c1 - b1\ c2 + a2\ d1 + a1\ d2 \[Equal] \ 
          0]\)], "Input",
  CellLabel->"In[144]:="],

Cell["OK!", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["The image of stb[3]", "Subsubsection"],

Cell[BoxData[
    \(rsvector3pts[1, I, \(-1\)]\)], "Input",
  CellLabel->"In[145]:="],

Cell[BoxData[
    \(rsvector3pts[mv1, mvI, mvm1]\)], "Input",
  CellLabel->"In[146]:="],

Cell[BoxData[
    \(% //. crRules\)], "Input",
  CellLabel->"In[147]:="],

Cell[BoxData[
    \(ComplexExpand[%]\)], "Input",
  CellLabel->"In[148]:="],

Cell[BoxData[
    \(Simplify[%, \(-b1\)\ c1 + b2\ c2 + a1\ d1 - a2\ d2 \[Equal] \ 
          1 && \(-b2\)\ c1 - b1\ c2 + a2\ d1 + a1\ d2 \[Equal] \ 
          0]\)], "Input",
  CellLabel->"In[149]:="],

Cell[BoxData[
    \(\(inter5\  = \ %;\)\)], "Input",
  CellLabel->"In[150]:="],

Cell["\<\
inter5*((c1^2 + c2^2 - 2*c2*d1 + d1^2 + 2*c1*d2 + d2^2)*
   (c1^2 + c2^2 - 2*c1*d1 + d1^2 - 2*c2*d2 + d2^2)*
   (c1^2 + c2^2 + 2*c1*d1 + d1^2 + 2*c2*d2 + d2^2))\
\>", "Input",
  CellLabel->"In[151]:="],

Cell[BoxData[
    \(normalize[%]\)], "Input",
  CellLabel->"In[152]:="],

Cell[BoxData[
    \(\(inter6\  = \ %;\)\)], "Input",
  CellLabel->"In[153]:="],

Cell[BoxData[
    \(Simplify[
      inter6, \(-b1\)\ c1 + b2\ c2 + a1\ d1 - a2\ d2 \[Equal] \ 
          1 && \(-b2\)\ c1 - b1\ c2 + a2\ d1 + a1\ d2 \[Equal] \ 
          0]\)], "Input",
  CellLabel->"In[154]:="],

Cell["\<\
mat[3] = {a1*c1 + a2*c2 - b1*d1 - b2*d2, a2*c1 - a1*c2 - b2*d1 + 
     b1*d2, (1/2)*(a1^2 + a2^2 - b1^2 - b2^2 - c1^2 - c2^2 + d1^2 + 
      d2^2), (1/2)*(a1^2 + a2^2 - b1^2 - b2^2 + c1^2 + c2^2 - d1^2 - 
      d2^2)}; \
\>", "Input",
  CellLabel->"In[155]:="],

Cell[BoxData[
    \(pssp[mat[1], mat[3]]\)], "Input",
  CellLabel->"In[156]:="],

Cell[BoxData[
    \(Simplify[%, \(-b1\)\ c1 + b2\ c2 + a1\ d1 - a2\ d2 \[Equal] \ 
          1 && \(-b2\)\ c1 - b1\ c2 + a2\ d1 + a1\ d2 \[Equal] \ 
          0]\)], "Input",
  CellLabel->"In[157]:="],

Cell[BoxData[
    \(pssp[mat[2], mat[3]]\)], "Input",
  CellLabel->"In[158]:="],

Cell[BoxData[
    \(Simplify[%, \(-b1\)\ c1 + b2\ c2 + a1\ d1 - a2\ d2 \[Equal] \ 
          1 && \(-b2\)\ c1 - b1\ c2 + a2\ d1 + a1\ d2 \[Equal] \ 
          0]\)], "Input",
  CellLabel->"In[159]:="],

Cell[BoxData[
    \(pssp[mat[3], mat[3]]\)], "Input",
  CellLabel->"In[160]:="],

Cell[BoxData[
    \(Simplify[%, \(-b1\)\ c1 + b2\ c2 + a1\ d1 - a2\ d2 \[Equal] \ 
          1 && \(-b2\)\ c1 - b1\ c2 + a2\ d1 + a1\ d2 \[Equal] \ 
          0]\)], "Input",
  CellLabel->"In[161]:="],

Cell["OK!", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["The image of stb[4]", "Subsubsection"],

Cell["\<\
By the equivariance of the cross product the image of stb[4] equals\
\
\>", "Text"],

Cell[BoxData[
    \(mat[4]\  = psCross[mat[1], mat[2], mat[3]]\)], "Input",
  CellLabel->"In[162]:="],

Cell[BoxData[
    \(Simplify[%, \(-b1\)\ c1 + b2\ c2 + a1\ d1 - a2\ d2 \[Equal] \ 
          1 && \(-b2\)\ c1 - b1\ c2 + a2\ d1 + a1\ d2 \[Equal] \ 
          0]\)], "Input",
  CellLabel->"In[163]:="],

Cell["\<\
mat[4] = {a1*c1 + a2*c2 + b1*d1 + b2*d2, a2*c1 - a1*c2 + b2*d1 - 
     b1*d2, (1/2)*(a1^2 + a2^2 + b1^2 + b2^2 - c1^2 - c2^2 - d1^2 - 
      d2^2), (1/2)*(a1^2 + a2^2 + b1^2 + b2^2 + c1^2 + c2^2 + d1^2 + 
      d2^2)}; \
\>", "Input",
  CellLabel->"In[165]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["The homomorphismus SL(2,C) to SO(3,1)", "Subsubsection"],

Cell[BoxData[
    \(matrix\  = \ vec[mat]\)], "Input",
  CellLabel->"In[175]:="],

Cell[BoxData[
    \(Det[matrix]\)], "Input",
  CellLabel->"In[176]:="],

Cell[BoxData[
    \(Simplify[%, \(-b1\)\ c1 + b2\ c2 + a1\ d1 - a2\ d2 \[Equal] \ 
          1 && \(-b2\)\ c1 - b1\ c2 + a2\ d1 + a1\ d2 \[Equal] \ 
          0]\)], "Input",
  CellLabel->"In[177]:="],

Cell[BoxData[
    \(\(Table[
        pssp[matrix[\([i]\)], matrix[\([j]\)]], {i, 4}, {j, 4}];\)\)], "Input",\

  CellLabel->"In[178]:="],

Cell[BoxData[
    \(Simplify[%, \(-b1\)\ c1 + b2\ c2 + a1\ d1 - a2\ d2 \[Equal] \ 
          1 && \(-b2\)\ c1 - b1\ c2 + a2\ d1 + a1\ d2 \[Equal] \ 
          0]\)], "Input",
  CellLabel->"In[179]:="],

Cell["\<\
OK!!! Thus, we are in the position to define (done in the package \
riemann.m) the matrix function realizing the homomorphism:\
\>", "Text"],

Cell[BoxData[
    \(\(sl2Ctoso31::usage\  = \ "\<sl2Ctoso31[a,b,c,d] yields a \
pseudo-orthonormal matrix function with values in SO(3,1)+, describing a \
homomorphism SL(2,C) -> SO(3,1)+. Warning: This is true for arguments a,b,c,d \
with Det[{{a,b},{c,d}}] = 1 only!\>";\)\)], "Input",
  CellLabel->"In[33]:=",
  Evaluatable->False],

Cell["\<\
sl2Ctoso31[a_, b_, c_, d_] := {{-1 + 2*Im[b]*Im[c] + 2*Re[a]*Re[d], \

    -2*Im[c]*Re[b] + 2*Im[a]*Re[d], Im[a]*Im[b] - Im[c]*Im[d] + 
     Re[a]*Re[b] - Re[c]*Re[d], Im[a]*Im[b] + Im[c]*Im[d] + 
     Re[a]*Re[b] + Re[c]*Re[d]}, {2*Im[d]*Re[a] - 2*Im[c]*Re[b], 
    1 - 2*Im[b]*Im[c] + 2*Im[a]*Im[d], Im[b]*Re[a] - Im[a]*Re[b] - 
     Im[d]*Re[c] + Im[c]*Re[d], Im[b]*Re[a] - Im[a]*Re[b] + 
     Im[d]*Re[c] - Im[c]*Re[d]}, {Im[a]*Im[c] - Im[b]*Im[d] + 
     Re[a]*Re[c] - Re[b]*Re[d], (-Im[c])*Re[a] + Im[d]*Re[b] + 
     Im[a]*Re[c] - Im[b]*Re[d], (1/2)*(Abs[a]^2 + Abs[d]^2 - Im[b]^2 - \
Im[c]^2 - Re[b]^2 - Re[c]^2), 
    (1/2)*(Abs[a]^2 + Abs[c]^2 - Im[b]^2 - Im[d]^2 - Re[b]^2 - 
      Re[d]^2)}, {Im[a]*Im[c] + Im[b]*Im[d] + Re[a]*Re[c] + 
     Re[b]*Re[d], (-Im[c])*Re[a] - Im[d]*Re[b] + Im[a]*Re[c] + 
     Im[b]*Re[d], (1/2)*(Abs[a]^2 + Abs[b]^2 - Im[c]^2 - Im[d]^2 - 
      Re[c]^2 - Re[d]^2), (1/2)*(Abs[a]^2 + Abs[b]^2 + Abs[c]^2 + 
      Abs[d]^2)}}\
\>", "Input",
  CellLabel->"In[109]:="]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["7.4 Comparison with Wilker's matrix", "Subsection"],

Cell[TextData[{
  "Wilker's matrixhas been defined in his paper ",
  ButtonBox["[W]",
    ButtonData:>"W.",
    ButtonStyle->"Hyperlink"],
  "; we introduced it in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " terms in the Appendix ",
  ButtonBox["A6",
    ButtonData:>"W.matrix",
    ButtonStyle->"Hyperlink"],
  ". \n",
  StyleBox["Proposition 4",
    FontColor->RGBColor[0, 0, 1]],
  ". The matrix  sl2Ctoso31 coincides  with    Wilker's matrix."
}], "Text"],

Cell[BoxData[
    \(Clear[a, b, c, d, a1, a2, b1, b2, c1, c2, d1, d2]\)], "Input",
  CellLabel->"In[110]:="],

Cell[" Once more we set", "Text"],

Cell[BoxData[
    \(Declare[{a1, a2, b1, b2, c1, c2, d1, d2}, Real]\)], "Input",
  CellLabel->"In[111]:="],

Cell[BoxData[
    \(a = a1 + I*a2; b = b1 + I*b2; c = c1 + \ I*c2; 
    d = d1 + I*d2;\)], "Input",
  CellLabel->"In[112]:="],

Cell[BoxData[
    \(sl2Ctoso31[a, b, c, d] - wilker[a, b, c, d]\)], "Input",
  CellLabel->"In[113]:="],

Cell[BoxData[
    \(% //. crRules\)], "Input",
  CellLabel->"In[114]:="],

Cell[BoxData[
    \(Simplify[%, \(-b1\)\ c1 + b2\ c2 + a1\ d1 - a2\ d2 \[Equal] \ 
          1 && \(-b2\)\ c1 - b1\ c2 + a2\ d1 + a1\ d2 \[Equal] \ 
          0]\)], "Input",
  CellLabel->"In[115]:="],

Cell["\<\
OK! By the identification we conclude from the properties of \
Wilker's matrix function the peudo-orthogonality and the Homomorphism \
property, see Appendix A.6\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["7.5 Test of the equivariance", "Subsection"],

Cell[BoxData[
    \(Clear[a, b, c, d, a1, a2, b1, b2, c1, c2, d1, d2]\)], "Input",
  CellLabel->"In[47]:="],

Cell[" Once more we set", "Text"],

Cell[BoxData[
    \(Declare[{a1, a2, b1, b2, c1, c2, d1, d2}, Real]\)], "Input",
  CellLabel->"In[51]:="],

Cell[BoxData[
    \(a = a1 + I*a2; b = b1 + I*b2; c = c1 + \ I*c2; 
    d = d1 + I*d2;\)], "Input",
  CellLabel->"In[52]:="],

Cell["\<\
The direct image of z under the M\[ODoubleDot]bius transformation \
g0[a,b,c,d] is\
\>", "Text"],

Cell[BoxData[
    \(w1 = \(g0[a, b, c, d]\)[z]\)], "Input",
  CellLabel->"In[53]:="],

Cell["\<\
Now we first go to the isotropic cone (the M\[ODoubleDot]bius \
sphere), transform with the image of g0[a,b,c,d] under sl2Ctoso31, and return \
to the Riemann sphere:\
\>", "Text"],

Cell[BoxData[
    \(w2\  = \ invisotrop[sl2Ctoso31[a, b, c, d] . isotrop[z]]\)], "Input",
  CellLabel->"In[54]:="],

Cell["The differenz w2 -w1 is 0, we check it:", "Text"],

Cell[BoxData[
    \(w2\  - w1 //. crRules\)], "Input",
  CellLabel->"In[55]:="],

Cell[BoxData[
    \(FullSimplify[%, \(-b1\)\ c1 + b2\ c2 + a1\ d1 - a2\ d2 \[Equal] \ 
          1 && \(-b2\)\ c1 - b1\ c2 + a2\ d1 + a1\ d2 \[Equal] \ 
          0]\)], "Input",
  CellLabel->"In[56]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["7.6 Proof of the homomorphism property", "Subsection"],

Cell["\<\
We have shown the homomorphism property of F= sl2Ctoso31 by the \
identification with Wilker's matrix and the random test in appendix A6. Now \
we give a direct proof applying the result of the foregoing subsection. For \
shortness denote f = isotrop. What we calculated is\
\>", "Text"],

Cell[BoxData[
    \(g0\  = f\^\(-1\)\[SmallCircle]\ F \((g0)\)\[SmallCircle]f, \ 
    or\ F \((g0)\)\  = \ f\[SmallCircle]g0\[SmallCircle]f\^\(-1\)\)], "Input",\

  Evaluatable->False],

Cell["\<\
Here g0 denotes an arbnitrary orientation preserving \
M\[ODoubleDot]bius transformation. If h0 denotes another such transformation, \
we conclude\
\>", "Text"],

Cell[BoxData[
    \(F \((g0\[SmallCircle]h0)\) = \ \(f\[SmallCircle]g0\[SmallCircle]
          h0\[SmallCircle]f\^\(-1\)\  = \(f\[SmallCircle]g0\[SmallCircle]
            f\^\(-1\)\[SmallCircle]f\[SmallCircle]h0\[SmallCircle]
            f\^\(-1\) = \ F \((g0)\) . F \((h0)\)\)\)\)], "Input",
  Evaluatable->False],

Cell["\<\
and this is the stated homomorphism property.In addition, we \
check\
\>", "Text"],

Cell[BoxData[
    \(sl2Ctoso31[1, 0, 0, 1]\)], "Input",
  CellLabel->"In[57]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["7.7 The kernel of the homomorphism sl2Ctoso31", "Subsection"],

Cell[BoxData[
    \(Clear[a, b, c, d, a1, a2, b1, b2, c1, c2, d1, d2]\)], "Input",
  CellLabel->"In[58]:="],

Cell[" Once more we set", "Text"],

Cell[BoxData[
    \(Declare[{a1, a2, b1, b2, c1, c2, d1, d2}, Real]\)], "Input",
  CellLabel->"In[59]:="],

Cell[BoxData[
    \(a = a1 + I*a2; b = b1 + I*b2; c = c1 + \ I*c2; 
    d = d1 + I*d2;\)], "Input",
  CellLabel->"In[60]:="],

Cell[TextData[{
  "The direct equation has not been solved by ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ":"
}], "Text"],

Cell[BoxData[
    \(Clear[a, b, c, d]\)], "Input",
  CellLabel->"In[61]:="],

Cell[BoxData[
    \(Solve[
      sl2Ctoso31[a, b, c, d] \[Equal] \ IdentityMatrix[4], \ {a, b, c, 
        d}]\)], "Input",
  CellLabel->"In[62]:="],

Cell[BoxData[
    \(Clear[a, b, c, d, a1, a2, b1, b2, c1, c2, d1, d2]\)], "Input",
  CellLabel->"In[63]:="],

Cell[" Once more we set", "Text"],

Cell[BoxData[
    \(Declare[{a1, a2, b1, b2, c1, c2, d1, d2}, Real]\)], "Input",
  CellLabel->"In[64]:="],

Cell[BoxData[
    \(a = a1 + I*a2; b = b1 + I*b2; c = c1 + \ I*c2; 
    d = d1 + I*d2;\)], "Input",
  CellLabel->"In[65]:="],

Cell[BoxData[
    \(Solve[{sl2Ctoso31[a, b, c, d] \[Equal] \ 
          IdentityMatrix[4], \(-b1\)\ c1 + b2\ c2 + a1\ d1 - 
            a2\ d2 \[Equal] \ 
          1, \(-b2\)\ c1 - b1\ c2 + a2\ d1 + a1\ d2 \[Equal] \ 0}, \ {a1, a2, 
        b1, b2, c1, c2, d1, d2}]\)], "Input",
  CellLabel->"In[66]:="],

Cell["\<\
If one neglects the warning Solve::ifun, one has the expected \
result: the solutions are \[PlusMinus]IdentityMatrix[2]\
\>", "Text"],

Cell[BoxData[
    \({IdentityMatrix[2], \(-IdentityMatrix[2]\)}\)], "Input",
  CellLabel->"In[71]:="],

Cell["\<\
Again using the denotations of the foregoing subsection, we may \
give a direct proof of this result. The equation\
\>", "Text"],

Cell[BoxData[
    \(F \((g0)\)\  = \ \(f\[SmallCircle]g0\[SmallCircle]f\^\(-1\) = \ 
        IdentityMatrix[4]\)\)], "Input",
  Evaluatable->False],

Cell["leads to", "Text"],

Cell[BoxData[
    \(g0 = \ \(f\^\(-1\)\[SmallCircle]
          f\  = \ \(\(Identity\)\(.\)\(\ \)\)\)\)], "Input",
  Evaluatable->False],

Cell["\<\
Thus, g0[a,b,c,d] must be the identity, what immediately leeds to\
\
\>", "Text"],

Cell[BoxData[
    \(c*z^2\  + \ z*\((d - a)\)\  - b\  \[Equal] \ 0\)], "Input"],

Cell["This equation must be fullfilled for all z, and this gives ", "Text"],

Cell[BoxData[
    \(c \[Equal] \ b \[Equal] 0, \ d \[Equal] \(\(a\)\(.\)\)\)], "Input"],

Cell["\<\
 Since we consider only matrices with Det = 1, we get again a 0 d = \
1 or a = d = -1.\
\>", "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Appendix", "Subtitle"],

Cell[CellGroupData[{

Cell["A1 ThreeScript, MathGL3d", "Section",
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "If you want to generate *.ts files for animations outside of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", activate the next section. To use the animation program MathGL3d in this \
notebook, read and  activate section 7.2."
}], "Text",
  FontFamily->"Times New Roman"],

Cell[CellGroupData[{

Cell["7.1 Threescript ", "Subsection",
  FontFamily->"Times New Roman"],

Cell["\<\
 The ThreeScript commands generate *.ts files appropriate  for \
certain animation programs. The freeware program  MathGL3d  created by \
Jens-Peer Kuska (for Windows95, Linux and other platforms) can be downloaded \
from [K].\
\>", "Text",
  Evaluatable->False,
  FontFamily->"Times New Roman"],

Cell["\<\
Under Windows the commercial 3D-Animation programs MathLive and \
DynamicVisualizer are available. To produce .ts-files one \
\>", "Text",
  Evaluatable->False,
  FontFamily->"Times New Roman"],

Cell[BoxData[
    RowBox[{"Needs", "[", "\"\<Graphics`ThreeScript`\>\"", "]"}]], "Input",
  CellLabel->"In[37]:=",
  InitializationCell->True,
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(?ThreeScript\)\)], "Input",
  FontFamily->"Times New Roman"],

Cell["\<\
The standard extension of these files is ts: \"filename.ts\" or \
\"Path/filename.ts\", e.g.\
\>", "Text",
  Evaluatable->False,
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(ThreeScript["\<isofam.ts\>", \ isofam]\)], "Input",
  Evaluatable->False,
  FontFamily->"Times New Roman"]
}, Closed]],

Cell[CellGroupData[{

Cell["7.2 MathGL3d", "Subsection",
  FontFamily->"Times New Roman",
  CellTags->"MathGL"],

Cell[TextData[{
  "The free animation program MathGL3d by Jens-Peer Kuska",
  " [K]",
  " can be used from a command line and within a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " session. A new version of this program is in preparation. Jens-Peer Kuska \
has sent me a new startup file OpenGLViewer.m, and friendly permitted to add \
it to the item \"Spheres\". Replace the old file OpenGLViewer.m by this new \
OpenGLViewer.m. If you did this, changes of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s ParametricPlot3D, especially the sometimes disturbing generating of \
MeshGraphics3D objects, will not take place.\nEIf not yet done, establish now \
the link to the current ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " session with the command:"
}], "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Get["\<MathGL3d`OpenGLViewer`\>"]\)], "Input",
  CellLabel->"In[137]:=",
  FontFamily->"Times New Roman",
  CellTags->"getMGL3D"],

Cell["\<\
If you called anything of MathGL3D in absence of the link you must \
remove the called functions from the global context before establishing the \
link correctly:\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Remove[MVShow3D, MVPointSphereSize, MVLineTubeSize]\)], "Input",
  CellLabel->"In[245]:=",
  FontFamily->"Times New Roman"],

Cell["If you want to close the link, enter", "Text",
  FontFamily->"Times New Roman"],

Cell["MVClose[]", "Text",
  FontFamily->"Times New Roman"],

Cell["\<\
The following command clears the Viewer window; this and other \
MathGL3d commands you may enter also with  palettes.\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[{
    \(\(\(MVClear[];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(MVShow3D[\[Placeholder], MVPolygonShading \[Rule] MVSmooth, 
      MVGrayBackground \[Rule] False, MVTexture \[Rule] None, 
      MVTextureMapType \[Rule] MVMeshUVMapping, 
      MVScaleTexture \[Rule] {1, 1}, 
      MVTranslateTextureTarget \[Rule] Automatic, 
      MVRotateTextureTarget \[Rule] Automatic, 
      MVScaleTextureTarget \[Rule] Automatic]\)}], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(MVShow3D[circles1, \ MVLineTubeSize\  -> \ 0.005]\)], "Input",
  CellLabel->"In[139]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(MVShow3D[tgr1, \ MVLineTubeSize\  -> \ 0.03]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(MVShow3D[tgr3, MVPointSphereSize \[Rule] 2.8]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(MVShow3D[spsf6]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Options[MVShow3D]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(MVClose[]\)], "Input",
  CellLabel->"In[168]:=",
  FontFamily->"Times New Roman"],

Cell["\<\
Attention! MVClose[] closes the link to MathVGl3d and therefore the \
viewer window, too,  but the  MathVGl3d commands are preserved:\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(?? MVShow3D\)], "Input",
  CellLabel->"In[292]:=",
  FontFamily->"Times New Roman"],

Cell["They may not be removed:", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Remove[MVShow3D, MVPointSphereSize, MVLineTubeSize]\)], "Input",
  CellLabel->"In[293]:=",
  FontFamily->"Times New Roman"],

Cell["\<\
Solution: Quit the kernel and start again with evaluating the \
initialization cells. In general that must not be done; you may establish the \
link again by the Get command above without trouble.\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[CellGroupData[{

Cell["7.2.1 An application of rs2pointplot  and MathGL3D", "Subsubsection",
  CellTags->"equipict"],

Cell["\<\
The next cell requires thr initialization of MathGL3d, see section \
Initialization, or the last section!\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(MVShow3D[equipict, MVPointSphereSize \[Rule] 0.8]\)], "Input",
  CellLabel->"In[282]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Sin[Pi/3]\)], "Input",
  CellLabel->"In[235]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(N[Sin[Pi/3]]\)], "Input",
  CellLabel->"In[236]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(reallist\  = \ Table[j/20, {j, 0, 10}]\)], "Input",
  CellLabel->"In[283]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(blist = \ Table[\((1 + I*Sqrt[3])\)*j/20, {j, 0, 10}]\)], "Input",
  CellLabel->"In[284]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(alist = \ 
      Table[\((10 - j)\)/20 + \((1 + I*Sqrt[3])\)*j/20, {j, 0, 
          10}]\)], "Input",
  CellLabel->"In[285]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(rs2pointplot[Join[reallist, alist, blist], \ 0.03];\)\)], "Input",
  CellLabel->"In[286]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(equitri = %\)], "Input",
  CellLabel->"In[287]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Show[{equipict, equitri}]\)], "Input",
  CellLabel->"In[288]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(equitriangle\  = \ %\)], "Input",
  CellLabel->"In[289]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(MVShow3D[equitriangle, MVPointSphereSize \[Rule] 0.6]\)], "Input",
  CellLabel->"In[290]:=",
  FontFamily->"Times New Roman"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["A2 The usages", "Section"],

Cell["\<\
After a package has been loaded you can get information about the  \
listed concepts in the usual way, e.g.\
\>", "Text",
  Evaluatable->False,
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(?orthonorm\)\)], "Input",
  CellLabel->"In[110]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Context[orthonorm]\)], "Input",
  CellLabel->"In[111]:=",
  FontFamily->"Times New Roman"],

Cell["\<\
For getting the usage and the complete definition, enter e.g.\
\>", \
"Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(?? null\)], "Input",
  CellLabel->"In[116]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(null[]\)], "Input",
  CellLabel->"In[117]:="],

Cell["\<\
Since the names are prepended by the ContextNames the definition \
obtained in this way are sometimes  hard to read. Therefore you will find \
some of them in the notebook in the original form in unevaluable cells.  It \
is recommended to look in the packages. An ugly example:\
\>", "Text",
  Evaluatable->False,
  FontFamily->"Times New Roman"],

Cell[BoxData[
    RowBox[{"??", "orthonorm"}]], "Input",
  CellLabel->"In[47]:="],

Cell[BoxData[
    RowBox[{"Context", "[", "orthonorm", "]"}]], "Input",
  CellLabel->"In[48]:="],

Cell[TextData[{
  "Look into the package pseuvec.m. There you will find the definition in an \
easier readable shape. Furthermore, you will find a hint to the notebook \
pseuklid.nb, in which orthonorm is tested and applied. To each of the \
packages, with exception of Declare.m,  there is written a notebook in which \
the concepts of the package are developed and demonstrated. The \
correspondence is described in the ",
  ButtonBox["References",
    ButtonData:>"pack",
    ButtonStyle->"Hyperlink"],
  " ."
}], "Text"],

Cell[CellGroupData[{

Cell["Euclidean Geometry. Symbols in euvec.m", "Subsubsection",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    RowBox[{"TableForm", "[", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{
            "\"\<cross\>\"", ",", "\"\<hyperplane\>\"", ",", 
              "\"\<invsterproj\>\"", ",", "\"\<dotnorme\>\""}], "}"}], ",", 
          RowBox[{"{", 
            RowBox[{
            "\"\<esorthonorm\>\"", ",", "\"\<innerprod\>\"", ",", 
              "\"\<normed\>\"", ",", "\"\<print\>\""}], "}"}], ",", 
          RowBox[{"{", 
            RowBox[{
            "\"\<neglect\>\"", ",", "\"\<null\>\"", ",", 
              "\"\<orthocomplement\>\"", ",", "\"\<outzero\>\""}], "}"}], ",",
           
          RowBox[{"{", 
            RowBox[{
            "\"\<randomv\>\"", ",", "\"\<rank\>\"", ",", "\"\<renorm\>\"", 
              ",", "\"\<smoothing\>\""}], "}"}], ",", 
          RowBox[{"{", 
            RowBox[{
            "\"\<sphere\>\"", ",", "\"\<sphereplot3D\>\"", ",", " ", 
              "\"\<subsphere\>\"", ",", "\"\<subspheremf\>\""}], "}"}], ",", 
          RowBox[{"{", 
            RowBox[{
            "\"\<sphericalreflection\>\"", ",", "\"\<stb\>\"", ",", 
              "\"\<sterproj\>\"", ",", "\"\<tg4frame\>\""}], "}"}], ",", 
          RowBox[{"{", 
            RowBox[{
            "\"\<unit\>\"", ",", "\"\<vec\>\"", ",", " ", "\"\<basis\>\""}], 
            "}"}]}], "}"}], "]"}]], "Input",
  CellLabel->"In[49]:=",
  FontFamily->"Times New Roman"],

Cell["To get the usages activate the next cell!", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    RowBox[{
      RowBox[{"{", 
        RowBox[{
          RowBox[{"?", "\"\<cross\>\""}], ",", 
          RowBox[{"?", "\"\<hyperplane\>\""}], ",", 
          RowBox[{"?", "\"\<invsterproj\>\""}], ",", 
          RowBox[{"?", "\"\<dotnorme\>\""}], ",", 
          RowBox[{"?", "\"\<esorthonorm\>\""}], ",", 
          RowBox[{"?", "\"\<innerprod\>\""}], ",", 
          RowBox[{"?", "\"\<normed\>\""}], ",", 
          RowBox[{"?", "\"\<print\>\""}], ",", 
          RowBox[{"?", "\"\<neglect\>\""}], ",", 
          RowBox[{"?", "\"\<null\>\""}], ",", " ", 
          RowBox[{"?", "\"\<orthocomplement\>\""}], ",", 
          RowBox[{"?", "\"\<outzero\>\""}], ",", 
          RowBox[{"?", "\"\<randomv\>\""}], ",", 
          RowBox[{"?", "\"\<rank\>\""}], ",", 
          RowBox[{"?", "\"\<renorm\>\""}], ",", 
          RowBox[{"?", "\"\<smoothing\>\""}], ",", 
          RowBox[{"?", "\"\<sphere\>\""}], ",", 
          RowBox[{"?", "\"\<subsphere\>\""}], ",", 
          RowBox[{"?", "\"\<subspheremf\>\""}], ",", 
          RowBox[{"?", "\"\<sphereplot3D\>\""}], ",", 
          RowBox[{"?", "\"\<sphericalreflection\>\""}], ",", 
          RowBox[{"?", "\"\<stb\>\""}], ",", 
          RowBox[{"?", "\"\<sterproj\>\""}], ",", 
          RowBox[{"?", "\"\<tg4frame\>\""}], ",", 
          RowBox[{"?", "\"\<unit\>\""}], ",", 
          RowBox[{"?", "\"\<vec\>\""}], ",", " ", 
          RowBox[{"?", "\"\<basis\>\""}]}], "}"}], ";"}]], "Input",
  CellLabel->"In[47]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    RowBox[{"Length", "[", "%", "]"}]], "Input",
  CellLabel->"In[48]:="],

Cell[BoxData[
    \(sphericalreflection[{x, y}, {0, 0}, r]\)], "Input",
  CellLabel->"In[120]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(vec[x]\)], "Input",
  CellLabel->"In[121]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(orthocomplement[{stb[1]}]\)], "Input",
  CellLabel->"In[123]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(orthocomplement[{stb[1], stb[2]}]\)], "Input",
  CellLabel->"In[125]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(orthocomplement[{stb[4], stb[1]*Cos[t]\  + \ stb[3]*Sin[t]}]\)], "Input",\

  CellLabel->"In[128]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Simplify[%, \ t > 0]\)], "Input",
  CellLabel->"In[129]:="],

Cell[BoxData[
    \(FullSimplify[%, \ t > 0]\)], "Input",
  CellLabel->"In[130]:="],

Cell[BoxData[
    \(orthocomplement[stb[1]*Cos[t]\  + \ stb[3]*Sin[t]]\)], "Input",
  CellLabel->"In[131]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(sphere[{0, 0, 0}, r]\)[u, v]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(subsphere[stb[4],  .5]\)[u, v]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(sterproj[{x, \ y, \ Sqrt[1 - x^2 - y^2]}]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(?? orthocomplement\)], "Input",
  CellLabel->"In[134]:="],

Cell[BoxData[
    \(Context[orthocomplement]\)], "Input",
  CellLabel->"In[133]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Pseudo-euclidean Geometry. Symbols in pseuvec.m", "Subsubsection",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(\(TableForm[{{"\<ch\>", "\<dual\>", "\<ide\>", "\<normalize\>"}, \
{"\<orthonorm\>", "\<orthopair\>", "\<pr\>", "\<psCross\>"}, {"\<pscross\>", \
"\<psfilter\>", "\<pssp\>"}}]\)\(\ \)\)\)], "Input",
  CellLabel->"In[101]:=",
  FontFamily->"Times New Roman"],

Cell["To get the usages activate the next cell!", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\({\(?"\<ch\>"\), \(?"\<dual\>"\), \(?"\<ide\>"\), \
\(?"\<normalize\>"\), \(?"\<orthonorm\>"\), \(?"\<orthopair\>"\), \(?"\<pr\>"\
\), \(?"\<psCross\>"\), \(?"\<pscross\>"\), \(?"\<psfilter\>"\), \
\(?"\<pssp\>"\)};\)\)], "Input",
  CellLabel->"In[140]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(orthopair[stb[1]*Cos[t] + stb[4]*Sin[t]]\)], "Input",
  CellLabel->"In[141]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(orthopair[stb[1]*Cosh[t] + stb[4]*Sinh[t]]\)], "Input",
  CellLabel->"In[142]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(pr[stb[4], \ stb[4]*32\  + stb[1]*4]\)], "Input",
  CellLabel->"In[138]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(pscross[{4*stb[1], \ stb[2] + \ 3*stb[3], \ 
        stb[2] - 3*stb[1]}]\)], "Input",
  CellLabel->"In[139]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(dual[stb[3]]\)], "Input",
  CellLabel->"In[140]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(dual[stb[4]]\)], "Input",
  CellLabel->"In[141]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(?psfilter\)\)], "Input",
  CellLabel->"In[142]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(?? pscross\)], "Input",
  CellLabel->"In[147]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(?? psCross\)], "Input",
  CellLabel->"In[146]:=",
  FontFamily->"Times New Roman"]
}, Closed]],

Cell[CellGroupData[{

Cell["Symbols in mspher.m", "Subsubsection",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    RowBox[{
      RowBox[{"TableForm", "[", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
              "\"\<coxeterinv\>\"", ",", " ", "\"\<gencos\>\"", ",", " ", 
                "\"\<invstepro\>\"", ",", " ", "\"\<planevec\>\""}], "}"}], 
            ",", 
            RowBox[{"{", " ", 
              RowBox[{
              "\"\<hspherevector\>\"", ",", "\n", "\"\<euklidsphere\>\"", ",",
                 " ", "\"\<pstg5frame\>\"", ",", " ", 
                "\"\<euklidsphereplot3D\>\""}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{
              "\"\<sph4ptsvec\>\"", ",", " ", "\"\<vradius\>\"", ",", " ", 
                "\"\<vcenter\>\"", ",", "\"\<spherevec\>\""}], "}"}], ",", 
            "\n", 
            RowBox[{"{", " ", 
              RowBox[{
              "\"\<spt\>\"", ",", "\"\<spunit\>\"", ",", " ", 
                "\"\<stepro\>\""}], "}"}]}], "}"}], "]"}], " "}]], "Input",
  CellLabel->"In[174]:=",
  FontFamily->"Times New Roman"],

Cell["To get the usages activate the next cell!", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    RowBox[{
      RowBox[{"{", 
        RowBox[{
          RowBox[{"?", "\"\<coxeterinv\>\""}], ",", " ", 
          RowBox[{"?", "\"\<gencos\>\""}], ",", " ", 
          RowBox[{"?", "\"\<invstepro\>\""}], ",", " ", 
          RowBox[{"?", "\"\<planevec\>\""}], ",", " ", 
          RowBox[{"?", "\"\<hspherevector\>\""}], ",", "\n", 
          RowBox[{"?", "\"\<euklidsphere\>\""}], ",", " ", 
          RowBox[{"?", "\"\<pstg5frame\>\""}], ",", " ", 
          RowBox[{"?", "\"\<euklidsphereplot3D\>\""}], ",", " ", 
          RowBox[{"?", "\"\<sph4ptsvec\>\""}], ",", 
          RowBox[{"?", "\"\<vradius\>\""}], ",", " ", 
          RowBox[{"?", "\"\<vcenter\>\""}], ",", " ", 
          RowBox[{"?", "\"\<spherevec\>\""}], ",", "\n", " ", 
          RowBox[{"?", "\"\<spt\>\""}], ",", 
          RowBox[{"?", "\"\<spunit\>\""}], ",", " ", 
          RowBox[{"?", "\"\<stepro\>\""}]}], "}"}], ";"}]], "Input",
  CellLabel->"In[175]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    RowBox[{"??", "confinv"}]], "Input",
  CellLabel->"In[102]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    RowBox[{"confinv", "[", 
      RowBox[{"r", ",", "R", ",", "dis"}], "]"}]], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    RowBox[{"planev", "[", 
      RowBox[{"0", ",", "1", ",", "5", ",", " ", "2"}], "]"}]], "Input",
  CellLabel->"In[103]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    RowBox[{"gencos", "[", 
      RowBox[{
        RowBox[{"stb", "[", "1", "]"}], ",", 
        RowBox[{
          RowBox[{
            RowBox[{"stb", "[", "1", "]"}], "*", 
            RowBox[{"Cos", "[", "t", "]"}]}], "+", 
          RowBox[{
            RowBox[{"Sin", "[", "t", "]"}], "*", 
            RowBox[{"stb", "[", "4", "]"}]}]}]}], "]"}]], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    RowBox[{"pssp", "[", 
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{"stb", "[", "1", "]"}], "*", 
            RowBox[{"Cos", "[", "t", "]"}]}], "+", 
          RowBox[{
            RowBox[{"Sin", "[", "t", "]"}], "*", 
            RowBox[{"stb", "[", "4", "]"}]}]}], ",", 
        RowBox[{
          RowBox[{
            RowBox[{"stb", "[", "1", "]"}], "*", 
            RowBox[{"Cos", "[", "t", "]"}]}], "+", 
          RowBox[{
            RowBox[{"Sin", "[", "t", "]"}], "*", 
            RowBox[{"stb", "[", "4", "]"}]}]}]}], "]"}]], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    RowBox[{"??", "spunit"}]], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    RowBox[{"plotsphere", "[", 
      RowBox[{"stb", "[", "4", "]"}], "]"}]], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    RowBox[{"euklidsphereplot3D", "[", 
      RowBox[{"stb", "[", "4", "]"}], "]"}]], "Input",
  CellLabel->"In[104]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    RowBox[{"sph1", " ", "=", " ", "%"}]], "Input",
  FontFamily->"Times New Roman"]
}, Closed]],

Cell[CellGroupData[{

Cell["Symbols in mcirc.m", "Subsubsection",
  FontFamily->"Times New Roman"],

Cell["\<\
Here you can get information about the commands which are defined \
in mcirc.m:\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    RowBox[{"TableForm", "[", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{
            "\"\<adaptsplframe\>\"", ",", "\"\<center\>\"", ",", 
              "\"\<posvec\>\"", ",", "\"\<radius\>\""}], "}"}], ",", 
          RowBox[{"{", 
            RowBox[{
            "\"\<center3pts\>\"", ",", "\"\<circle2spv\>\"", ",", 
              "\"\<circle3D\>\"", ",", "\"\<circle3pts\>\""}], "}"}], ",", 
          RowBox[{"{", 
            RowBox[{
            "\"\<circlefamily\>\"", ",", "\"\<circleplane\>\"", ",", 
              "\"\<circlespacevectors\>\"", ",", "\"\<control\>\""}], "}"}], 
          ",", 
          RowBox[{"{", 
            RowBox[{
            "\"\<gencircle\>\"", ",", "\"\<plotcircle2spv\>\"", ",", 
              "\"\<plotcircle3D\>\"", ",", "\"\<plotcircle3pts\>\""}], "}"}], 
          ",", 
          RowBox[{"{", 
            RowBox[{
            "\"\<plotgencircle\>\"", ",", "\"\<posvec3pts\>\"", ",", 
              "\"\<pp\>\"", ",", "\"\<ppdet\>\""}], "}"}], ",", 
          RowBox[{"{", 
            RowBox[{
            "\"\<pptr\>\"", ",", "\"\<pscomplement\>\"", ",", 
              "\"\<radius3pts\>\"", ",", "\"\<threepoints\>\""}], "}"}], ",", 
          
          RowBox[{"{", 
            RowBox[{
            "\"\<tube\>\"", ",", "\"\<unitvec\>\"", ",", "\"\<vspace\>\""}], 
            "}"}]}], "}"}], "]"}]], "Input",
  CellLabel->"In[185]:=",
  FontFamily->"Times New Roman"],

Cell["To get the usages activate the next cell!", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    RowBox[{
      RowBox[{"{", 
        RowBox[{
          RowBox[{"?", "\"\<adaptsplframe\>\""}], ",", 
          RowBox[{"?", "\"\<center\>\""}], ",", 
          RowBox[{"?", "\"\<posvec\>\""}], ",", 
          RowBox[{"?", "\"\<radius\>\""}], ",", 
          RowBox[{"?", "\"\<center3pts\>\""}], ",", " ", 
          RowBox[{"?", "\"\<circle2spv\>\""}], ",", " ", 
          RowBox[{"?", "\"\<circle3D\>\""}], ",", 
          RowBox[{"?", "\"\<circle3pts\>\""}], ",", 
          RowBox[{"?", "\"\<circlefamily\>\""}], ",", 
          RowBox[{"?", "\"\<circleplane\>\""}], ",", 
          RowBox[{"?", "\"\<circlespacevectors\>\""}], ",", " ", 
          RowBox[{"?", "\"\<control\>\""}], ",", " ", 
          RowBox[{"?", "\"\<gencircle\>\""}], ",", "   ", 
          RowBox[{"?", "\"\<plotcircle2spv\>\""}], ",", 
          RowBox[{"?", "\"\<plotcircle3D\>\""}], ",", " ", 
          RowBox[{"?", "\"\<plotgencircle\>\""}], ",", 
          RowBox[{"?", "\"\<plotcircle3pts\>\""}], ",", 
          RowBox[{"?", "\"\<posvec3pts\>\""}], ",", " ", 
          RowBox[{"?", "\"\<pp\>\""}], ",", 
          RowBox[{"?", "\"\<ppdet\>\""}], ",", " ", 
          RowBox[{"?", "\"\<pptr\>\""}], ",", 
          RowBox[{"?", "\"\<pscomplement\>\""}], ",", 
          RowBox[{"?", "\"\<radius3pts\>\""}], ",", 
          RowBox[{"?", "\"\<threepoints\>\""}], ",", " ", "\n", " ", 
          RowBox[{"?", "\"\<tube\>\""}], ",", " ", 
          RowBox[{"?", "\"\<unitvec\>\""}], ",", " ", 
          RowBox[{"?", "\"\<vspace\>\""}]}], "}"}], ";"}]], "Input",
  CellLabel->"In[50]:=",
  FontFamily->"Times"]
}, Closed]],

Cell[CellGroupData[{

Cell["Symbols in riemann.m", "Subsubsection"],

Cell["\<\
The functions and Modules defined and protected in riemann.m have \
the symbols\
\>", "Text"],

Cell[BoxData[
    RowBox[{"Names", "[", "\"\<riemann`*\>\"", "]"}]], "Input",
  CellLabel->"In[47]:="],

Cell["To get the usages activate the next cell!", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    RowBox[{
      RowBox[{"{", 
        RowBox[{
          RowBox[{"?", "\"\<crossratio\>\""}], ",", 
          RowBox[{"?", "\"\<crvalues\>\""}], ",", 
          RowBox[{"?", "\"\<g0\>\""}], ",", 
          RowBox[{"?", "\"\<g1\>\""}], ",", 
          RowBox[{"?", "\"\<infy\>\""}], ",", 
          RowBox[{"?", "\"\<invisotrop\>\""}], ",", 
          RowBox[{"?", "\"\<isotrop\>\""}], ",", 
          RowBox[{"?", "\"\<isotrop1\>\""}], ",", 
          RowBox[{"?", "\"\<rs2\>\""}], ",", 
          RowBox[{"?", "\"\<rs2point\>\""}], ",", 
          RowBox[{"?", "\"\<rs2pointplot\>\""}], ",", 
          RowBox[{"?", "\"\<rscenter3pts\>\""}], ",", 
          RowBox[{"?", "\"\<rscircle3pts\>\""}], ",", 
          RowBox[{"?", "\"\<rscirclevector\>\""}], ",", 
          RowBox[{"?", "\"\<rsCoxeter\>\""}], ",", 
          RowBox[{"?", "\"\<rsoperatorpp\>\""}], ",", 
          RowBox[{"?", "\"\<rsplotcircle3pts\>\""}], ",", 
          RowBox[{"?", "\"\<rspsframepp\>\""}], ",", 
          RowBox[{"?", "\"\<rsradius3pts\>\""}], ",", 
          RowBox[{"?", "\"\<rsvcenter\>\""}], ",", 
          RowBox[{"?", "\"\<rsvector3pts\>\""}], ",", 
          RowBox[{"?", "\"\<rsvspacepp\>\""}], ",", 
          RowBox[{"?", "\"\<scale\>\""}], ",", 
          RowBox[{"?", "\"\<sl2Ctoso31\>\""}]}], "}"}], ";"}]], "Input",
  CellLabel->"In[55]:="]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["A3 Some tools", "Section",
  FontFamily->"Times New Roman"],

Cell[CellGroupData[{

Cell["A general vector, random vectors", "Subsubsection",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(vec[x_, \ n_:  dim]\  := \ Table[x[i], \ {i, \ n}]\)], "Input",
  Evaluatable->False,
  FontFamily->"Times New Roman",
  FontSize->15],

Cell[BoxData[
    \(vec[Sin]\)], "Input",
  CellLabel->"In[148]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(N[%]\)], "Input",
  CellLabel->"In[149]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(randomv[n_:  dim]\  := \ Table[Random[], {i, \ n}]\)], "Input",
  Evaluatable->False,
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(randomv[]\)], "Input",
  CellLabel->"In[150]:=",
  FontFamily->"Times New Roman"]
}, Closed]],

Cell[CellGroupData[{

Cell["Rank of a matrix, random matrices", "Subsubsection",
  FontFamily->"Times New Roman"],

Cell["\<\
The rank of matrix can be calculated by the following module, if \
the matrix is not too large:\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(?rank\)\)], "Input",
  CellLabel->"In[151]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Context[rank]\)], "Input",
  CellLabel->"In[152]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(rank[m_]\  := \ 
      Module[{\ di\  = \ Length[m[\([1]\)]], \ nsp}, \n\t\tnsp\  = \ 
            NullSpace[m]; \n\t\tdi\  - \ Length[nsp]] /; 
        MatrixQ[m]\)], "Input",
  Evaluatable->False,
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(rank[{stb[1], \ stb[3], \ stb[4]}]\)], "Input",
  CellLabel->"In[153]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(rank[{stb[1], \ stb[1], \ stb[4]}]\)], "Input",
  CellLabel->"In[154]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(rank[{{Cos[t], Sin[t]}, {\(-Sin[t]\), Cos[t]}}]\)], "Input",
  CellLabel->"In[155]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Timing[rank[IdentityMatrix[10^3]]]\)], "Input",
  CellLabel->"In[156]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    RowBox[{
      RowBox[{"randommatrix", "[", 
        RowBox[{"k_", ",", "l_"}], "]"}], " ", ":=", " ", 
      RowBox[{"Table", "[", 
        RowBox[{
          RowBox[{"randomv", "[", "l", "]"}], ",", " ", 
          RowBox[{"{", "k", "}"}]}], "]"}]}]], "Input",
  CellLabel->"In[38]:=",
  InitializationCell->True,
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(randommatrix[2, 3] // MatrixForm\)], "Input",
  CellLabel->"In[158]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Timing[rank[randommatrix[100, 200]]]\)], "Input",
  CellLabel->"In[159]:=",
  FontFamily->"Times New Roman"]
}, Closed]],

Cell[CellGroupData[{

Cell["Finding orthogonal pairs", "Subsubsection",
  FontFamily->"Times New Roman"],

Cell["The following definition is given in pseuklid.m:", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(?orthopair\)\)], "Input",
  CellLabel->"In[160]:=",
  FontFamily->"Times New Roman"],

Cell["Examples:", "Text",
  FontFamily->"Times New Roman",
  FontSize->16,
  FontVariations->{"Underline"->True}],

Cell[BoxData[
    \(orthopair[{0.5, 0.5, 1, 0}]\)], "Input",
  CellLabel->"In[169]:=",
  FontFamily->"Times New Roman"],

Cell["\<\
Working with floating point numbers  gives approximate results \
only:\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(orthopair[{0.5, 0.5, 1. , 1. }]\)], "Input",
  CellLabel->"In[171]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Table[N[pssp[%[\([i]\)], %[\([j]\)]], 20], {i, 2}, {j, 2}]\)], "Input",
  CellLabel->"In[172]:=",
  FontFamily->"Times New Roman"],

Cell["Here is an exact solution:", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(orthopair[{1/2, 1/2, 1, 1}]\)], "Input",
  CellLabel->"In[173]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Table[pssp[%[\([i]\)], %[\([j]\)]], {i, 2}, {j, 2}]\)], "Input",
  CellLabel->"In[174]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(orthopair[stb[1]]\)], "Input",
  CellLabel->"In[175]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(orthopair[{Cos[t], Sin[t], \ 0, 1}]\)], "Input",
  CellLabel->"In[176]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(orthopair[{2*Cos[t], 2*Sin[t], \ 0, 1}]\)], "Input",
  CellLabel->"In[177]:=",
  FontFamily->"Times New Roman"]
}, Closed]],

Cell[CellGroupData[{

Cell["Control of orthonormality", "Subsubsection",
  FontFamily->"Times New Roman"],

Cell["\<\
If necessary,  one can apply the following control of \
orthonormality of two vectors:\
\>", "Text",
  Evaluatable->False,
  FontFamily->"Times New Roman"],

Cell[BoxData[
    RowBox[{
      RowBox[{"control", "[", 
        RowBox[{"v_List", ",", "w_List", ",", " ", 
          RowBox[{"prod_:", "pssp"}]}], "]"}], ":=", 
      RowBox[{"Simplify", "[", 
        RowBox[{
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{
                RowBox[{"prod", "[", 
                  RowBox[{"v", ",", "v"}], "]"}], "-", 
                RowBox[{"Sign", "[", 
                  RowBox[{"prod", "[", 
                    RowBox[{"v", ",", "v"}], "]"}], "]"}]}], ")"}], "2"], "+",
           
          SuperscriptBox[
            RowBox[{"prod", "[", 
              RowBox[{"v", ",", "w"}], "]"}], "2"], "+", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{
                RowBox[{"prod", "[", 
                  RowBox[{"w", ",", "w"}], "]"}], "-", 
                RowBox[{"Sign", "[", 
                  RowBox[{"prod", "[", 
                    RowBox[{"w", ",", "w"}], "]"}], "]"}]}], ")"}], "2"]}], 
        "]"}]}]], "Input",
  CellLabel->"In[39]:=",
  InitializationCell->True,
  FontFamily->"Times New Roman"],

Cell["\<\
If all is correct the result must be 0, or numerically very small. \
If the result depends on a parameter, integrate!\
\>", "Text",
  Evaluatable->False,
  FontFamily->"Times New Roman"],

Cell["EXAMPLE:", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(orthopair[{Cos[t], Sin[t], \ 0, 1/2}]\)], "Input",
  CellLabel->"In[186]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(control[%[\([1]\)], %[\([2]\)]]\)], "Input",
  CellLabel->"In[187]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(control[stb[1], \ stb[4]]\)], "Input",
  CellLabel->"In[188]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\((va\  = \ randomv[]; \ Print[va, "\<, \>", \ ch[va]]; 
      vb\  = orthopair[va]; 
      Print[vb]; \[IndentingNewLine]control[vb[\([1]\)], \ 
        vb[\([2]\)]])\)\)], "Input",
  CellLabel->"In[189]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Remove[va, \ vb]\)], "Input",
  CellLabel->"In[190]:=",
  FontFamily->"Times New Roman"],

Cell["\<\
The default scalar product is pssp; you may use another scalar \
product inserting it as second argument:\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \({{Cos[t], Sin[t], \ 0, 0}, \ stb[2, 4]}\)], "Input",
  CellLabel->"In[191]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(control[%[\([1]\)], %[\([2]\)], \ Dot]\)], "Input",
  CellLabel->"In[192]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \({{Cos[t], Sin[t], \ 0, 0}, \ stb[3, 4]}\)], "Input",
  CellLabel->"In[193]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(control[%[\([1]\)], %[\([2]\)], \ Dot]\)], "Input",
  CellLabel->"In[194]:=",
  FontFamily->"Times New Roman"]
}, Closed]],

Cell[CellGroupData[{

Cell["Smoothing", "Subsubsection",
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "The following function makes an almost zero  number to be zero; the \
sensibility can be regulated by the optional second argument, whose default \
value is ",
  Cell[BoxData[
      \(10\^\(-10\)\)]],
  "; for the difference to Chop see the notebook chopping.nb."
}], "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(smoothing[a_, b_:  10^\(-10\)] := 
        Module[{c = a}, If[b \[Equal] 1, Return[c], If[Abs[c] < b, c = 0]]; \ 
          c];\)\)], "Input",
  Evaluatable->False,
  FontFamily->"Times New Roman"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["A4 Tests ", "Section"],

Cell[CellGroupData[{

Cell["A4.1  Test of some new modules", "Subsection"],

Cell[CellGroupData[{

Cell["11.1.1 crRules and properties of Re, Im, Abs", "Subsubsection",
  FontFamily->"Times New Roman",
  CellTags->"crtest"],

Cell[BoxData[
    \(Re[A + B] == \ Re[A] + Re[B]\)], "Input",
  CellLabel->"In[173]:=",
  FontFamily->"Times New Roman"],

Cell["\<\
Often Simplify does not proceed successfully, but FullSimplify \
does:\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Simplify[Re[A + B] == \ Re[A] + Re[B]]\)], "Input",
  CellLabel->"In[174]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(FullSimplify[Re[A + B] == \ Re[A] + Re[B]]\)], "Input",
  CellLabel->"In[175]:=",
  FontFamily->"Times New Roman"],

Cell["Application of crRules gives the same result immediately", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Re[A + B] == \ Re[A] + Re[B] /. crRules\)], "Input",
  CellLabel->"In[239]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Re[Re[z]]\  \[Equal] \ Re[z]\)], "Input",
  CellLabel->"In[230]:="],

Cell[BoxData[
    \(Re[Im[z]]\  \[Equal] \ Im[z]\)], "Input",
  CellLabel->"In[231]:="],

Cell[BoxData[
    \(Re[I*Im[z]]\  \[Equal] \ 0\)], "Input",
  CellLabel->"In[232]:="],

Cell[BoxData[
    \(Re[1/z]\)], "Input",
  CellLabel->"In[241]:="],

Cell[BoxData[
    \(% //. \ crRules\)], "Input",
  CellLabel->"In[242]:="],

Cell[BoxData[
    \(\((Re[\((I*Im[z] + Re[z])\)/Abs[z]^2] \[Equal] \ 
        Re[z]/Abs[z]^2)\)\)], "Input",
  CellLabel->"In[243]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[244]:=",
  FontFamily->"Times New Roman"],

Cell["In this case FullSimplify works", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(FullSimplify[%]\)], "Input",
  CellLabel->"In[245]:=",
  FontFamily->"Times New Roman"],

Cell["and crRules, too", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\((Re[\((I*Im[z] + Re[z])\)/Abs[z]^2] \[Equal] \ Re[z]/Abs[z]^2)\) //. 
      crRules\)], "Input",
  CellLabel->"In[246]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(RealQ[x]\)], "Input",
  CellLabel->"In[183]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Re[I*Im[z] + Re[z]]\)], "Input",
  CellLabel->"In[184]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Re[I*x\  + \ y]\)], "Input",
  CellLabel->"In[185]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Re[\((I*Im[z] + Re[z])\)/Abs[z]^2]\)], "Input",
  CellLabel->"In[188]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(FullSimplify[%]\)], "Input",
  CellLabel->"In[189]:="],

Cell[BoxData[
    \(%% /. crRules\)], "Input",
  CellLabel->"In[190]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Re[\((I*Im[z] + Re[z])\)*Abs[z]^2]\)], "Input",
  CellLabel->"In[191]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Re[\((I*Im[z] + Re[z])\)*Abs[z]^2] /. crRules\)], "Input",
  CellLabel->"In[192]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Re[\((I*Im[z])\)*Abs[z]^2]\)], "Input",
  CellLabel->"In[195]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Im[\((Im[z])\)*Abs[z]^2]\)], "Input",
  CellLabel->"In[196]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Declare[{x1, x2}, Real]\)], "Input",
  CellLabel->"In[197]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Re[a*\((x1 + x2)\)]\  \[Equal] \ Re[a]*\((x1 + x2)\)\)], "Input",
  CellLabel->"In[201]:=",
  FontFamily->"Times New Roman"],

Cell["In this case FullSimplify doesn't work:", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(FullSimplify[%]\)], "Input",
  CellLabel->"In[202]:=",
  FontFamily->"Times New Roman"],

Cell["but crRules does:", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(% //. crRules\)], "Input",
  CellLabel->"In[203]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Clear[z, w]\)], "Input",
  CellLabel->"In[204]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Re[z*w]\  \[Equal] \ Re[z]*Re[w]\  - Im[z]*Im[w]\)], "Input",
  CellLabel->"In[205]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(FullSimplify[%]\)], "Input",
  CellLabel->"In[206]:=",
  FontFamily->"Times New Roman"],

Cell["FullSimplify recognizes this rule.", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Im[z*w]\  \[Equal] \ Re[z]*Im[w]\  + Im[z]*Re[w]\)], "Input",
  CellLabel->"In[207]:=",
  FontFamily->"Times New Roman"],

Cell["\<\
Strange: FullSimplify does not recognize this analogeous \
rule:\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(FullSimplify[%]\)], "Input",
  CellLabel->"In[208]:=",
  FontFamily->"Times New Roman"],

Cell["Of course, crRules works:", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(% /. crRules\)], "Input",
  CellLabel->"In[209]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(1/Abs[z] \[Element] \ Reals\)], "Input",
  CellLabel->"In[210]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(1/\((1 + Abs[z])\) \[Element] \ Reals\)], "Input",
  CellLabel->"In[211]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(1\  + 1/Abs[z] \[Element] \ Reals\)], "Input",
  CellLabel->"In[212]:=",
  FontFamily->"Times New Roman"],

Cell["Unfortunately, the basic rule", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(z\  \[Equal] \ Re[z]\  + \ I*\ Im[z]\)], "Input",
  CellLabel->"In[213]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[214]:=",
  FontFamily->"Times New Roman"],

Cell["is recognized only with", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(FullSimplify[%]\)], "Input",
  CellLabel->"In[215]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Re[1/z]\)], "Input",
  CellLabel->"In[216]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(% \[Equal] \ Re[z]/Abs[z^2]\)], "Input",
  CellLabel->"In[217]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(FullSimplify[%]\)], "Input",
  CellLabel->"In[218]:=",
  FontFamily->"Times New Roman"],

Cell["(Re[1/z] == Re[z]/Abs[z]^2)  //.crRules", "Input",
  CellLabel->"In[226]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[227]:="],

Cell["Further Examples:", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Abs[z]^2 \[Equal] Re[z]^2\  + \ Im[z]^2\)], "Input",
  CellLabel->"In[247]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Simplify[Abs[z]^2 \[Equal] Re[z]^2\  + \ Im[z]^2]\)], "Input",
  CellLabel->"In[248]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Re[I*Im[z] + Re[z]] \[Equal] \ Re[z]\)], "Input",
  CellLabel->"In[249]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Re[\(-I\)*Im[z] + Re[z]] \[Equal] \ Re[z]\)], "Input",
  CellLabel->"In[250]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Re[I*Im[z]]\)], "Input",
  CellLabel->"In[251]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Re[Re[z]] \[Equal] \ Re[z]\)], "Input",
  CellLabel->"In[252]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Re[Abs[z]^2]\  \[Equal] \ Abs[z]^2\)], "Input",
  CellLabel->"In[253]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Abs[z^2]\  \[Equal] \ Abs[z]^2\)], "Input",
  CellLabel->"In[254]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Abs[a*b]\  \[Equal] \ Abs[a]*Abs[b]\)], "Input",
  CellLabel->"In[255]:="],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[256]:="],

Cell[BoxData[
    \(FullSimplify[%]\)], "Input",
  CellLabel->"In[257]:="],

Cell[BoxData[
    \(Abs[z^\(-2\)]\  \[Equal] \ Abs[z]^\(-2\)\)], "Input",
  CellLabel->"In[148]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Re[\((I*Im[z] + Re[z])\)*Abs[z]^2]\)], "Input",
  CellLabel->"In[149]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[150]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(RealQ[t]\)], "Input",
  CellLabel->"In[151]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Declare[s, \ Real]\)], "Input",
  CellLabel->"In[224]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Abs[s + I\ *t]^2\  \[Equal] \ s^2 + t^2\)], "Input",
  CellLabel->"In[225]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(% /. crRules\)], "Input",
  CellLabel->"In[226]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Simplify[Abs[s + I\ t]^2\  \[Equal] \ s^2 + t^2]\)], "Input",
  CellLabel->"In[227]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(FullSimplify[%]\)], "Input",
  CellLabel->"In[228]:=",
  FontFamily->"Times New Roman"],

Cell["\<\
Really, the following identity is recognized with Simplify \
only:\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Abs[z]^2 \[Equal] Re[z]^2 + Im[z]^2\)], "Input",
  CellLabel->"In[223]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[224]:=",
  FontFamily->"Times New Roman"],

Cell["ATTENTION! :", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(TrueQ[Abs[z]^2 \[Equal] Re[z]^2 + Im[z]^2]\)], "Input",
  CellLabel->"In[222]:=",
  FontFamily->"Times New Roman"]
}, Closed]],

Cell[CellGroupData[{

Cell["11.1.2 riem, invisotrop", "Subsubsection",
  FontFamily->"Times New Roman",
  CellTags->"riemT"],

Cell[BoxData[
    \(isotrop1[1/z]\)], "Input",
  CellLabel->"In[114]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(FullSimplify[%]\)], "Input",
  CellLabel->"In[115]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(isotrop1[1/z] /. crRules\)], "Input",
  CellLabel->"In[116]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(FullSimplify[%]\)], "Input",
  CellLabel->"In[117]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(pssp[%, %]\)], "Input",
  CellLabel->"In[118]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(FullSimplify[%]\)], "Input",
  CellLabel->"In[119]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(RealQ[t]\)], "Input",
  CellLabel->"In[120]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Declare[t, Real]\)], "Input",
  CellLabel->"In[121]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(isotrop1[Cos[t]]\)], "Input",
  CellLabel->"In[122]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Simplify[pssp[%, %]]\)], "Input",
  CellLabel->"In[123]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(isotrop1[Cos[z]]\)], "Input",
  CellLabel->"In[124]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(pssp[%, \ %]\)], "Input",
  CellLabel->"In[125]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(FullSimplify[%]\)], "Input",
  CellLabel->"In[126]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(pssp[isotrop1[infy], \ isotrop1[infy]]\)], "Input",
  CellLabel->"In[127]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(pssp[isotrop1[1/z], \ isotrop1[1/z]]\)], "Input",
  CellLabel->"In[128]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(FullSimplify[%]\)], "Input",
  CellLabel->"In[129]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(isotrop1[I]\)], "Input",
  CellLabel->"In[130]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(invisotrop[%]\)], "Input",
  CellLabel->"In[131]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(invisotrop[{0, 0, 1, 1}]\)], "Input",
  CellLabel->"In[132]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(invisotrop[{1, 0, 0, 1}]\)], "Input",
  CellLabel->"In[133]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(isotrop1[invisotrop[{1, 0, 0, 1}]]\)], "Input",
  CellLabel->"In[134]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(invisotrop[{0, 0, 1, 1}]\)], "Input",
  CellLabel->"In[135]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(invisotrop[{0, 0, \(-1\), 1}]\)], "Input",
  CellLabel->"In[136]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(isotrop1[invisotrop[{0, 0, \(-1\), 1}]]\)], "Input",
  CellLabel->"In[137]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(isotrop1[invisotrop[{0, 0, \(-1\), 1}]]\)], "Input",
  CellLabel->"In[138]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(invisotrop[{1, 0, 0, 0}]\)], "Input",
  CellLabel->"In[139]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(isotrop1[invisotrop[{0, 0, 0, 0}]]\)], "Input",
  CellLabel->"In[140]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(invisotrop[{Cos[t], Sin[t], 0, 1}]\)], "Input",
  CellLabel->"In[141]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(isotrop1[invisotrop[{Cos[t], Sin[t], 0, 1}]]\)], "Input",
  CellLabel->"In[142]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(invisotrop[{Sinh[t], 1, 0, Cosh[t]}]\)], "Input",
  CellLabel->"In[143]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(isotrop1[invisotrop[{Sinh[t], 1, 0, Cosh[t]}]]\)], "Input",
  CellLabel->"In[144]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(pssp[%, %]\)], "Input",
  CellLabel->"In[145]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[146]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(invisotrop[isotrop1[Cos[w]]]\)], "Input",
  CellLabel->"In[147]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(% \[Equal] \ Cos[w]\)], "Input",
  CellLabel->"In[148]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[149]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(FullSimplify[%]\)], "Input",
  CellLabel->"In[150]:=",
  FontFamily->"Times New Roman"],

Cell["\<\
The last example shows: For simplifying complex expressions one \
should always use FullSimplify.\
\>", "Text",
  FontFamily->"Times New Roman"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["A4.2  Examples of special transformations (to section 7)", "Subsection",
  CellTags->"spectrans"],

Cell[TextData[{
  "We first consider the ",
  StyleBox["similarity",
    FontColor->RGBColor[0, 0, 1]]
}], "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(g0[r*Exp[I*t], \ u + I*v, \ 0, \ 1]\)[z]\)], "Input",
  CellLabel->"In[83]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(mg1[r*Exp[I*t], \ u + I*v, \ 0, 1]\)[{2*x, 2*y, 1 - \((x^2 + y^2)\), 
        1 + x^2 + y^2}]\)], "Input",
  CellLabel->"In[84]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(% //. crRules\)], "Input",
  CellLabel->"In[86]:="],

Cell[BoxData[
    \(% //. \ Abs[A_]\  \[Rule] \ A\)], "Input",
  CellLabel->"In[87]:="],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[88]:="],

Cell[TextData[StyleBox["Similarities:",
  FontColor->RGBColor[0, 0, 1]]], "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(mg1[Sqrt[r]*Exp[I*t/2], \((\ u + I*v)\)/\((Sqrt[r]*Exp[I*t/2])\), \ 
        0, 1/\((Sqrt[r]*Exp[I*t/2])\)]\)[{2*x, 2*y, 1 - \((x^2 + y^2)\), 
        1 + x^2 + y^2}]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(isotrop1[I]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(isotrop1[\(-I\)]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(isotrop1[0]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(isotrop1[infy]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(isotrop1[1]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(isotrop1[\(-1\)]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(mg1[Sqrt[r]*Exp[I*t/2], \((\ u + I*v)\)/\((Sqrt[r]*Exp[I*t/2])\), \ 
        0, 1/\((Sqrt[r]*Exp[I*t/2])\)]\)[{0, 1, 0, 1}]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(mg1[Sqrt[r]*Exp[I*t/2], \((\ u + I*v)\)/\((Sqrt[r]*Exp[I*t/2])\), \ 
        0, 1/\((Sqrt[r]*Exp[I*t/2])\)]\)[{0, \(-1\), 0, 1}]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(mg1[Sqrt[r]*Exp[I*t/2], \((\ u + I*v)\)/\((Sqrt[r]*Exp[I*t/2])\), \ 
        0, 1/\((Sqrt[r]*Exp[I*t/2])\)]\)[{0, 0, 1, 1}]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(mg1[Sqrt[r]*Exp[I*t/2], \((\ u + I*v)\)/\((Sqrt[r]*Exp[I*t/2])\), \ 
        0, 1/\((Sqrt[r]*Exp[I*t/2])\)]\)[{1, 0, 0, 1}]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(mg1[Sqrt[r]*Exp[I*t/2], \((\ u + I*v)\)/\((Sqrt[r]*Exp[I*t/2])\), \ 
        0, 1/\((Sqrt[r]*Exp[I*t/2])\)]\)[{\(-1\), 0, 0, 1}]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(mg1[Sqrt[r]*Exp[I*t/2], \((\ u + I*v)\)/\((Sqrt[r]*Exp[I*t/2])\), \ 
        0, 1/\((Sqrt[r]*Exp[I*t/2])\)]\)[{0, 0, \(-1\), 1}]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(FullSimplify[
      Re[\[ImaginaryI]\ \[ExponentialE]\^\(\[ImaginaryI]\ t\)\ r + 
          u + \[ImaginaryI]\ v]]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(FullSimplify[
      Im[\[ImaginaryI]\ \[ExponentialE]\^\(\[ImaginaryI]\ t\)\ r + 
          u + \[ImaginaryI]\ v]]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(FullSimplify[\((u - r*Sin[t])\)^2 + \((v + r*Cos[t])\)^2]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(% \[Equal] \ 
      u^2\  + v^2\  + 2*r*\((v*Cos[t] - u*Sin[t])\)\  + \ r^2\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(FullSimplify[%]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[TextData[StyleBox["Dilatation",
  FontColor->RGBColor[0, 0, 1]]], "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    RowBox[{
      RowBox[{"mg1", "[", 
        RowBox[{\(Sqrt[r]\), ",", "0", ",", " ", "0", ",", 
          RowBox[{"1", 
            StyleBox["/",
              "Text"], \(Sqrt[r]\)}]}], "]"}], 
      "[", \({\((2*x)\)/\((1 + x^2 + y^2)\), \((2*y)\)/\((1 + x^2 + 
              y^2)\), \(-1\) + 2/\((1 + x^2 + y^2)\), 1}\), "]"}]], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    RowBox[{
      RowBox[{"mg1", "[", 
        RowBox[{\(Sqrt[r]\), ",", "0", ",", " ", "0", ",", 
          RowBox[{"1", 
            StyleBox["/",
              "Text"], \(Sqrt[r]\)}]}], "]"}], "[", \({0, 0, \(-1\), 1}\), 
      "]"}]], "Input",
  FontFamily->"Times New Roman"],

Cell[TextData[StyleBox["Translation",
  FontColor->RGBColor[0, 0, 1]]], "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(mg1[1, \ u + I*v, \ 0, 
        1]\)[{\((2*x)\)/\((1 + x^2 + y^2)\), \((2*y)\)/\((1 + x^2 + 
              y^2)\), \(-1\) + 2/\((1 + x^2 + y^2)\), 1}]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(mg1[1, \ u + I*v, \ 0, 1]\)[{1, 0, 0, 1}]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[TextData[StyleBox["Rotation",
  FontColor->RGBColor[0, 0, 1]]], "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(mg1[Exp[I*t/2], 0, \ 0, 
        Exp[\(-I\)*
            t/2]]\)[{\((2*x)\)/\((1 + x^2 + y^2)\), \((2*y)\)/\((1 + x^2 + 
              y^2)\), \(-1\) + 2/\((1 + x^2 + y^2)\), 1}]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[TextData[StyleBox["Inversion",
  FontColor->RGBColor[0, 0, 1]]], "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(mg1[0, I, I, 
        0]\)[{\((2*x)\)/\((1 + x^2 + y^2)\), \((2*y)\)/\((1 + x^2 + 
              y^2)\), \(-1\) + 2/\((1 + x^2 + y^2)\), 1}]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Clear[t, x, y, r, u, v]\)], "Input",
  CellLabel->"In[89]:=",
  FontFamily->"Times New Roman"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["A5 The package Declare.m", "Section",
  FontFamily->"Times New Roman",
  CellTags->"Declare"],

Cell["\<\
The package Declare.m by Pekka Janhunen gives the possibility to \
declare variables and expression as real. This is very useful for our \
applications in which we often need transitions from the complex to the real  \
and vice versa. In this section we discuss and test some aspects of this \
package which we modified and adapted to our purposes.\
\>", "Text"],

Cell[CellGroupData[{

Cell["12.1 Changes, additions", "Subsection"],

Cell[TextData[{
  "Unfortunately, the package contains minor errors and needs some additions. \
In details, I changed the following points:\n1. RealQ is not a function in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " v.4.1 or higher. It is defined in the package only. Therefore it needs \
not to be unprotected before its definition.\n2. The Definitions of \
RealQ[a_+b_], RealQ[a_*b_] have been incorrect.\n3. A definition for real \
vectors RealQ[a_List] has been added.\n4. Some operations for the logical \
entities True, False and the new entity Uncertain are added.\n5. Not all real \
functions of real variables are recognized to be real, if they are, e.g. for \
Exp the answer was correct, but for Sin and Cos not! We completed the package \
Declare.m by the next commands:"
}], "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(ElementaryFunctions\  = {Cos, Sin, Tan, Csc, \ Sec, Cot, ArcTan, \ 
        ArcCot, Cosh, \ Sinh, Tanh, Csch, Sech, Coth, ArcSinh, ArcCsch, \ 
        Exp}\)], "Input",
  Evaluatable->False,
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(For[j = 1, \ j < 18, 
      RealQ[\(ElementaryFunctions[\([j]\)]\)[x_?RealQ]] := 
        True; \(j++\)]\)], "Input",
  Evaluatable->False,
  FontFamily->"Times New Roman"],

Cell["\<\
6. Since Declare[x,Real] did not imply Element[x,Reals] -> True, we \
introduced the following change of the Element relation:\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Element[el_, \ Reals]\  := \ RealQ[el]\)], "Input",
  Evaluatable->False,
  FontFamily->"Times New Roman"],

Cell["Thus now is valid", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Element[el, \ Reals]\  \[Equal] \ \ RealQ[el]\)], "Input",
  CellLabel->"In[102]:=",
  FontFamily->"Times New Roman"]
}, Closed]],

Cell[CellGroupData[{

Cell["12.2 Tests", "Subsection"],

Cell[CellGroupData[{

Cell["Tests: Declare, RealQ, algebraic operations", "Subsubsection",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(?Declare\)\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(?NewDeclare\)\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(?RealQ\)\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Context[RealQ]\)], "Input"],

Cell[BoxData[
    \(Attributes[RealQ]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(?Real\)\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Declare[{t, x, y}, \ Real, vec[x], Real]\)], "Input",
  FontFamily->"Times New Roman"],

Cell["The symbol t is not a real number:", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(t\)], "Input"],

Cell["In spite of this, by the declaration we have", "Text"],

Cell[BoxData[
    \(t \[Element] Reals\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Head[t]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Head[Pi]\)], "Input"],

Cell[BoxData[
    \(Pi \[Element] Reals\)], "Input"],

Cell[BoxData[
    \(Head[N[Pi]]\)], "Input"],

Cell[BoxData[
    \(x[1]\)], "Input"],

Cell[BoxData[
    \(RealQ[x[1]]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(RealQ[vec[x]]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(RealQ[\(vec[x]\)[\([1]\)]]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(RealQ[x + t]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(RealQ[x + z]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(RealQ[x*z]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(RealQ[t*x]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(RealQ[Sum[x[i], {i, 1, 5}]]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(RealQ[Sum[x[i], {i, 1, 4}]]\)], "Input",
  FontFamily->"Times New Roman"],

Cell["For x[5] the declaration is not explained:", "Text"],

Cell[BoxData[
    \(RealQ[x[5]]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(RealQ[x[4]]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(RealQ[I*x]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(RealQ[I^2*t]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(RealQ[I*0]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(RealQ[I*I]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(RealQ[Re[A_]*B_Real]\)], "Input",
  FontFamily->"Times New Roman"],

Cell["\<\
In spite of the fact that in the package RealQ[_Real] = True is \
defined, this does not work:\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(RealQ[B_Real]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(RealQ[_Real]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(RealQ[Re[A_]*Re[B_]]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(RealQ[z^2]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(RealQ[t]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(RealQ[t^2]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(RealQ[t^n]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(RealQ[t^10]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(RealQ[t^I]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(RealQ[Im[z]]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(RealQ[Re[z] + Im[z]]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(RealQ[z*Conjugate[z]]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(FullSimplify[z*Conjugate[z]]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(RealQ[Abs[z]^2]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(RealQ[infy]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Re[\((\((\(-I\))\)*Im[z] + Re[z])\)/Abs[z]^2] \[Equal] 
      Re[z^\((\(-1\))\)]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(FullSimplify[%]\)], "Input",
  FontFamily->"Times New Roman"]
}, Closed]],

Cell[CellGroupData[{

Cell["Tests: Logical Operations", "Subsubsection",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(False || True\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(False || False\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(False || Uncertain\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(False && True\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(False && \ False\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(False && Uncertain\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(True && Uncertain\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(False || Uncertain\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(True || Uncertain\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Uncertain || False\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Uncertain || True\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Uncertain && False\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Uncertain && True\)], "Input",
  FontFamily->"Times New Roman"]
}, Closed]],

Cell[CellGroupData[{

Cell["Tests: Lists", "Subsubsection",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Declare[{t, x, y}, \ Real, vec[x], Real]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(RealQ[vec[x]]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(RealQ[{x, z}]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(RealQ[{I*x, z}]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(RealQ[{x, I*z}]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(RealQ[{x, I*x}]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(RealQ[{}]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(RealQ[{z}]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(RealQ[{I}]\)], "Input",
  FontFamily->"Times New Roman"]
}, Closed]],

Cell[CellGroupData[{

Cell["Tests: Functions", "Subsubsection",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(RealQ[t]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(RealQ[Exp[t]]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(RealQ[Exp[z]]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(RealQ[Sin[t]]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(RealQ[Cos[t]]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(RealQ[Tanh[t]]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(RealQ[Re[A_]*t]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(RealQ[Abs[z]]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(RealQ[Abs[z]^2]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(RealQ[1/Abs[z]^2]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(RealQ[Re[z]/Abs[z]^2]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(RealQ[Im[z]/Abs[z]^2]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(RealQ[I*Im[z]/Abs[z]^2]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(RealQ[Re[I*Im[z]]/Abs[z]^2]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(RealQ[Re[Re[z] + I*Im[z]]/Abs[z]^2]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(ComplexExpand[Tanh[t]]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(RealQ[%]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(RealQ[ArcCos[t]]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(RealQ[Sqrt[Exp[t]]]\)], "Input",
  FontFamily->"Times New Roman"],

Cell["\<\
The answer of the next cell should be \"False\", since t is real:\
\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(RealQ[Sqrt[\(-Exp[t]\)]]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(RealQ[Sqrt[\(-Exp[t^2 + 1]\)]]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Re[Sqrt[\(-Exp[t^2 + 1]\)]]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Im[Sqrt[\(-Exp[t^2 + 1]\)]]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Positive[%]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(RealQ[A_] := \ 
      Module[{}, \[IndentingNewLine]If[Re[A] != \ 0 && Im[A] \[Equal] \ 0, \ 
          Return[True]]; \[IndentingNewLine]If[Im[A] != \ 0, \ 
          Return[False]]; \[IndentingNewLine]Uncertain]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(RealQ[Sqrt[\(-Exp[t^2 + 1]\)]]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(FullSimplify[RealQ[Sqrt[\(-Exp[t^2 + 1]\)]]]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Sqrt[\(-Exp[t^2 + 1]\)] \[NotEqual] \ 0\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Re[Sqrt[\(-Exp[t^2 + 1]\)]]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Im[Sqrt[\(-Exp[t^2 + 1]\)]]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(% \[NotEqual] 0\)], "Input",
  FontFamily->"Times New Roman"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " does not know that this function never vanishes!"
}], "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Positive[Sqrt[\(-Exp[t^2 + 1]\)]]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Positive[\(-Exp[t^2 + 1]\)]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Negative[\(-Exp[t^2 + 1]\)]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Positive[Exp[t^2 + 1]]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Positive[Sqrt[Exp[t^2 + 1]]]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Positive[Sqrt[t^2]]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Positive[Sqrt[t^2 + \ 1]]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Positive[Sqrt[Abs[t^2] + 1]]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(NonNegative[Sqrt[Abs[t^2]]]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(RealQ[x]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(RealQ[Cos[x] + Sin[x]]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(RealQ[Cos[x] + I*Sin[x]]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(RealQ[Exp[I*x]]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(RealQ[Cos[x]*Sin[x]]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(RealQ[Cos[x]*Sin[z]]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(RealQ[Sqrt[Cos[x]]]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Element[x, \ Reals]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Clear[y]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Element[y, \ Reals]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(x \[Element] Reals\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(y \[Element] Reals\)], "Input",
  FontFamily->"Times New Roman"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
12.3 Observation: Clear[x] does not remove correctly declared \
properties of x\
\>", "Subsection",
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "After declaring some symbols as real, and clearing it after use, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " continues to apply the property Realin certain cases; one has to remove \
the symbols for clearing the situation! "
}], "Text"],

Cell[BoxData[
    \(Remove[z, \ x, \ y]\)], "Input",
  CellLabel->"In[109]:="],

Cell[BoxData[
    \(z = \ x\  + \ I*y\)], "Input",
  CellLabel->"In[110]:="],

Cell[BoxData[
    \(Re[Sin[z]]\)], "Input",
  CellLabel->"In[111]:="],

Cell[BoxData[
    \(FullSimplify[%]\)], "Input",
  CellLabel->"In[112]:="],

Cell["Now we declare and repeat the last cells:", "Text"],

Cell[BoxData[
    \(Declare[{x, y}, \ Real]\)], "Input",
  CellLabel->"In[113]:="],

Cell[BoxData[
    \(RealQ[x]\)], "Input",
  CellLabel->"In[114]:="],

Cell[BoxData[
    \(z = \ x\  + \ I*y\)], "Input",
  CellLabel->"In[115]:="],

Cell[BoxData[
    \(Re[Sin[z]]\)], "Input",
  CellLabel->"In[116]:="],

Cell[BoxData[
    \(FullSimplify[%]\)], "Input",
  CellLabel->"In[117]:="],

Cell["We Clear x,y,z and repeat the last cells once more:", "Text"],

Cell[BoxData[
    \(Clear[z, \ x, \ y]\)], "Input",
  CellLabel->"In[118]:="],

Cell[BoxData[
    \(RealQ[x]\)], "Input",
  CellLabel->"In[119]:="],

Cell[BoxData[
    \(z = \ x\  + \ I*y\)], "Input",
  CellLabel->"In[120]:="],

Cell[BoxData[
    \(Re[Sin[z]]\)], "Input",
  CellLabel->"In[121]:="],

Cell[BoxData[
    \(FullSimplify[%]\)], "Input",
  CellLabel->"In[122]:="],

Cell["Formula (***):", "Text"],

Cell[BoxData[
    \(Re[Sin[z]]\  \[Equal] \ Cosh[y]*Sin[x]\)], "Input",
  CellLabel->"In[130]:="],

Cell[BoxData[
    \(FullSimplify[%]\)], "Input",
  CellLabel->"In[132]:="],

Cell[TextData[{
  StyleBox["WARNING!",
    FontWeight->"Bold"],
  StyleBox[" Formula (***) is false, in general:",
    FontColor->RGBColor[1, 0, 0]]
}], "Text"],

Cell["\<\
The last result has not been expected. Therefore, if  one wants  \
removing the declared property, one must remove the symbols !\
\>", "Text"],

Cell[BoxData[
    \(Re[Sin[z]]\)], "Input",
  CellLabel->"In[128]:="],

Cell[BoxData[
    \(% /. {x \[Rule] I, \ y \[Rule] 0}\)], "Input",
  CellLabel->"In[129]:="],

Cell[BoxData[
    \(Re[Sin[I]]\)], "Input",
  CellLabel->"In[125]:="],

Cell["\<\
On the other hand, using the formula (***) above, one gets the \
false result\
\>", "Text"],

Cell[BoxData[
    \(Cosh[y]*Sinh[x] /. {x \[Rule] I, \ y \[Rule] 0}\)], "Input",
  CellLabel->"In[126]:="]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["A6 J.B.Wilkers Matrix", "Section",
  FontFamily->"Times New Roman",
  CellTags->"W.matrix"],

Cell[CellGroupData[{

Cell["A6.1 Description", "Subsection",
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "See [",
  ButtonBox["W",
    ButtonData:>"W.",
    ButtonStyle->"Hyperlink"],
  "], p. 418, Theorem 10.  The first column of Wilkers matrix should have \
pseudo-length one. We try proving this statement by calculation.\n "
}], "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    RowBox[{
      RowBox[{"fc", "[", "z_", "]"}], " ", ":=", " ", 
      RowBox[{"Conjugate", "[", "z", "]"}]}]], "Input",
  CellLabel->"In[40]:=",
  InitializationCell->True,
  FontFamily->"Times New Roman"],

Cell[BoxData[
    RowBox[{
      RowBox[{"wilker1", "[", 
        RowBox[{"a_", ",", "b_", ",", "c_", ",", "d_"}], "]"}], " ", ":=", 
      " ", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{"Re", "[", 
            RowBox[{
              RowBox[{"a", "*", 
                RowBox[{"fc", "[", "d", "]"}]}], "+", 
              RowBox[{"b", "*", 
                RowBox[{"fc", "[", "c", "]"}]}]}], "]"}], ",", " ", 
          RowBox[{"Im", "[", 
            RowBox[{
              RowBox[{
                RowBox[{"-", "a"}], "*", 
                RowBox[{"fc", "[", "d", "]"}]}], "+", 
              RowBox[{"b", "*", 
                RowBox[{"fc", "[", "c", "]"}]}]}], "]"}], ",", " ", 
          RowBox[{"Re", "[", 
            RowBox[{
              RowBox[{"a", "*", 
                RowBox[{"fc", "[", "c", "]"}]}], "-", 
              RowBox[{"b", "*", 
                RowBox[{"fc", "[", "d", "]"}]}]}], "]"}], ",", 
          RowBox[{"Re", "[", 
            RowBox[{
              RowBox[{"a", "*", 
                RowBox[{"fc", "[", "c", "]"}]}], "+", 
              RowBox[{"b", "*", 
                RowBox[{"fc", "[", "d", "]"}]}]}], "]"}]}], "}"}]}]], "Input",\

  CellLabel->"In[41]:=",
  InitializationCell->True,
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(\(FullSimplify[
      pssp[wilker1[a, b, c, d], 
        wilker1[a, b, c, 
          d]], \((b*c\  - a*d)\)*\((Conjugate[b]*Conjugate[c\ ] - 
              Conjugate[a]*
                Conjugate[d])\) \[Equal] \ \ 1]\)\(\ \)\)\)], "Input",
  FontFamily->"Times New Roman"],

Cell["We want to check the other orthonormality relations.", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    RowBox[{
      RowBox[{"wilker2", "[", 
        RowBox[{"a_", ",", "b_", ",", "c_", ",", "d_"}], "]"}], " ", ":=", 
      " ", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{"Im", "[", 
            RowBox[{
              RowBox[{"a", "*", 
                RowBox[{"fc", "[", "d", "]"}]}], "+", 
              RowBox[{"b", "*", 
                RowBox[{"fc", "[", "c", "]"}]}]}], "]"}], ",", " ", 
          RowBox[{"Re", "[", 
            RowBox[{
              RowBox[{"a", "*", 
                RowBox[{"fc", "[", "d", "]"}]}], "-", 
              RowBox[{"b", "*", 
                RowBox[{"fc", "[", "c", "]"}]}]}], "]"}], ",", " ", 
          RowBox[{"Im", "[", 
            RowBox[{
              RowBox[{"a", "*", 
                RowBox[{"fc", "[", "c", "]"}]}], "-", 
              RowBox[{"b", "*", 
                RowBox[{"fc", "[", "d", "]"}]}]}], "]"}], ",", 
          RowBox[{"Im", "[", 
            RowBox[{
              RowBox[{"a", "*", 
                RowBox[{"fc", "[", "c", "]"}]}], "+", 
              RowBox[{"b", "*", 
                RowBox[{"fc", "[", "d", "]"}]}]}], "]"}]}], "}"}]}]], "Input",\

  CellLabel->"In[42]:=",
  InitializationCell->True,
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(\(FullSimplify[
      pssp[wilker2[a, b, c, d], 
        wilker2[a, b, c, 
          d]], \((b*c\  - a*d)\)*\((Conjugate[b]*Conjugate[c\ ] - 
              Conjugate[a]*
                Conjugate[d])\) \[Equal] \ \ 1]\)\(\ \)\)\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(\(FullSimplify[
      pssp[wilker1[a, b, c, d], 
        wilker2[a, b, c, 
          d]], \((b*c\  - a*d)\)*\((Conjugate[b]*Conjugate[c\ ] - 
              Conjugate[a]*
                Conjugate[d])\) \[Equal] \ \ 1]\)\(\ \)\)\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    RowBox[{
      RowBox[{"wilker3", "[", 
        RowBox[{"a_", ",", "b_", ",", "c_", ",", "d_"}], "]"}], " ", ":=", 
      " ", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{"Re", "[", 
            RowBox[{
              RowBox[{"a", "*", 
                RowBox[{"fc", "[", "b", "]"}]}], "-", 
              RowBox[{"c", "*", 
                RowBox[{"fc", "[", "d", "]"}]}]}], "]"}], ",", " ", 
          RowBox[{"Im", "[", 
            RowBox[{
              RowBox[{
                RowBox[{"-", "a"}], "*", 
                RowBox[{"fc", "[", "b", "]"}]}], "+", 
              RowBox[{"c", "*", 
                RowBox[{"fc", "[", "d", "]"}]}]}], "]"}], ",", " ", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"Abs", "[", "a", "]"}], "^", "2"}], " ", "-", 
                RowBox[{
                  RowBox[{"Abs", "[", "b", "]"}], "^", "2"}], " ", "-", 
                RowBox[{
                  RowBox[{"Abs", "[", "c", "]"}], "^", "2"}], "+", " ", 
                RowBox[{
                  RowBox[{"Abs", "[", "d", "]"}], "^", "2"}]}], ")"}], "/", 
            "2"}], ",", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"Abs", "[", "a", "]"}], "^", "2"}], " ", "+", 
                RowBox[{
                  RowBox[{"Abs", "[", "b", "]"}], "^", "2"}], " ", "-", 
                RowBox[{
                  RowBox[{"Abs", "[", "c", "]"}], "^", "2"}], "-", " ", 
                RowBox[{
                  RowBox[{"Abs", "[", "d", "]"}], "^", "2"}]}], ")"}], "/", 
            "2"}]}], "}"}]}]], "Input",
  CellLabel->"In[43]:=",
  InitializationCell->True,
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(\(FullSimplify[
      pssp[wilker3[a, b, c, d], 
        wilker3[a, b, c, 
          d]], \((b*c\  - a*d)\)*\((Conjugate[b]*Conjugate[c\ ] - 
              Conjugate[a]*
                Conjugate[d])\) \[Equal] \ \ 1]\)\(\ \)\)\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(\(FullSimplify[
      pssp[wilker1[a, b, c, d], 
        wilker3[a, b, c, 
          d]], \((b*c\  - a*d)\)*\((Conjugate[b]*Conjugate[c\ ] - 
              Conjugate[a]*
                Conjugate[d])\) \[Equal] \ \ 1]\)\(\ \)\)\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(\(FullSimplify[
      pssp[wilker2[a, b, c, d], 
        wilker3[a, b, c, 
          d]], \((b*c\  - a*d)\)*\((Conjugate[b]*Conjugate[c\ ] - 
              Conjugate[a]*
                Conjugate[d])\) \[Equal] \ \ 1]\)\(\ \)\)\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    RowBox[{
      RowBox[{"wilker4", "[", 
        RowBox[{"a_", ",", "b_", ",", "c_", ",", "d_"}], "]"}], " ", ":=", 
      " ", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{"Re", "[", 
            RowBox[{
              RowBox[{"a", "*", 
                RowBox[{"fc", "[", "b", "]"}]}], "+", 
              RowBox[{"c", "*", 
                RowBox[{"fc", "[", "d", "]"}]}]}], "]"}], ",", " ", 
          RowBox[{"Im", "[", 
            RowBox[{
              RowBox[{
                RowBox[{"-", "a"}], "*", 
                RowBox[{"fc", "[", "b", "]"}]}], "-", 
              RowBox[{"c", "*", 
                RowBox[{"fc", "[", "d", "]"}]}]}], "]"}], ",", " ", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"Abs", "[", "a", "]"}], "^", "2"}], " ", "-", 
                RowBox[{
                  RowBox[{"Abs", "[", "b", "]"}], "^", "2"}], " ", "+", 
                RowBox[{
                  RowBox[{"Abs", "[", "c", "]"}], "^", "2"}], "-", " ", 
                RowBox[{
                  RowBox[{"Abs", "[", "d", "]"}], "^", "2"}]}], ")"}], "/", 
            "2"}], ",", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"Abs", "[", "a", "]"}], "^", "2"}], " ", "+", 
                RowBox[{
                  RowBox[{"Abs", "[", "b", "]"}], "^", "2"}], " ", "+", 
                RowBox[{
                  RowBox[{"Abs", "[", "c", "]"}], "^", "2"}], "+", " ", 
                RowBox[{
                  RowBox[{"Abs", "[", "d", "]"}], "^", "2"}]}], ")"}], "/", 
            "2"}]}], "}"}]}]], "Input",
  CellLabel->"In[44]:=",
  InitializationCell->True,
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(\(FullSimplify[
      pssp[wilker4[a, b, c, d], 
        wilker4[a, b, c, 
          d]], \((b*c\  - a*d)\)*\((Conjugate[b]*Conjugate[c\ ] - 
              Conjugate[a]*
                Conjugate[d])\) \[Equal] \ \ 1]\)\(\ \)\)\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(\(FullSimplify[
      pssp[wilker1[a, b, c, d], 
        wilker4[a, b, c, 
          d]], \((b*c\  - a*d)\)*\((Conjugate[b]*Conjugate[c\ ] - 
              Conjugate[a]*
                Conjugate[d])\) \[Equal] \ \ 1]\)\(\ \)\)\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(\(FullSimplify[
      pssp[wilker2[a, b, c, d], 
        wilker4[a, b, c, 
          d]], \((b*c\  - a*d)\)*\((Conjugate[b]*Conjugate[c\ ] - 
              Conjugate[a]*
                Conjugate[d])\) \[Equal] \ \ 1]\)\(\ \)\)\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(\(FullSimplify[
      pssp[wilker3[a, b, c, d], 
        wilker4[a, b, c, 
          d]], \((b*c\  - a*d)\)*\((Conjugate[b]*Conjugate[c\ ] - 
              Conjugate[a]*
                Conjugate[d])\) \[Equal] \ \ 1]\)\(\ \)\)\)], "Input",
  FontFamily->"Times New Roman"],

Cell["\<\
Therefore all the orthonormality relations are valid, and we may \
express the 2-1 homomorphism SL(2,C) -> SO(4,1) as follows:\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"wilker", "::", "usage"}], " ", "=", " ", 
        "\"\<wilker[a,b,c,d] is the pseudo-orthogonal square matrix of order \
4 corresponding to the M\[ODoubleDot]bius transform g0[a,b,c,d] with a*d-c*d \
= 1.\>\""}], ";"}]], "Input",
  CellLabel->"In[45]:=",
  InitializationCell->True,
  FontFamily->"Times New Roman"],

Cell[BoxData[
    RowBox[{
      RowBox[{"wilker", "[", 
        RowBox[{"a_", ",", "b_", ",", "c_", ",", "d_"}], "]"}], " ", ":=", 
      " ", 
      RowBox[{"Transpose", "[", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"wilker1", "[", 
              RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "]"}], ",", 
            RowBox[{"wilker2", "[", 
              RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "]"}], ",", 
            RowBox[{"wilker3", "[", 
              RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "]"}], ",", 
            RowBox[{"wilker4", "[", 
              RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "]"}]}], "}"}], 
        "]"}]}]], "Input",
  CellLabel->"In[46]:=",
  InitializationCell->True,
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(wilker[a, b, c, d]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Transpose[wilker[a, b, c, d]]\)], "Input",
  CellLabel->"In[192]:=",
  FontFamily->"Times New Roman"],

Cell["REM: One always must have in mind the condition a*d-b*c = 1.", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Transpose[wilker[a, b, c, d]] // MatrixForm\)], "Input",
  CellLabel->"In[191]:=",
  FontFamily->"Times New Roman",
  FontSize->18],

Cell[BoxData[
    \(FullSimplify[
      Table[pssp[\(Transpose[wilker[a, b, c, d]]\)[\([i]\)], \(Transpose[
              wilker[a, b, c, d]]\)[\([j]\)]], {i, 4}, {j, 
          4}], \((b*c\  - a*d)\)*\((Conjugate[b]*Conjugate[c\ ] - 
              Conjugate[a]*Conjugate[d])\) \[Equal] \ \ 1]\)], "Input",
  CellLabel->"In[250]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(wilker[1, 0, 0, 1] // MatrixForm\)], "Input",
  CellLabel->"In[188]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(?? Declare\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Declare[{a1, b1, c1, d1}, \ Real]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Declare[{a2, b2, c2, d2}, \ Real]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(RealQ[a2]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Clear[ma]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(\(ma[a1_, a2_, b1_, b2_, c1_, c2_, d1_, 
        d2_]\)\(\ \)\(:=\)\(\ \)\({{a1 + I*a2, \ b1 + I*b2}, {c1 + I*c2, \ 
          d1\  + I*d2}}\)\(\ \)\)\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Det[ma[a1, a2, b1, b2, c1, c2, d1, d2]]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Im[%]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(dm[a1_, a2_, b1_, b2_, c1_, c2_, d1_, d2_] = \ %\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Re[%]\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(dr[a1_, a2_, b1_, b2_, c1_, c2_, d1_, d2_] = %\)], "Input",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(FullSimplify[
      wilker[a1 + I*a2, b1 + I*b2, c1 + I*c2, d1 + I*d2] . 
        wilker[d1 + I*d2, \(-b1\) - I*b2, \ \(-c1\) - I*c2, a1 + I*a2], \ 
      dr[a1, a2, b1, b2, c1, c2, d1, d2] \[Equal] \ \ 1 && 
        dm[a1, a2, b1, b2, c1, c2, d1, d2] \[Equal] \ \ 0]\)], "Input",
  CellLabel->"In[189]:=",
  FontFamily->"Times New Roman"],

Cell["Inverses are transformed into inverses.", "Text",
  FontFamily->"Times New Roman"]
}, Closed]],

Cell[CellGroupData[{

Cell["A6.2 Random test1 of the homomorphy property", "Subsection",
  FontFamily->"Times New Roman"],

Cell["\<\
 We evaluate the homomorphy for random matrices of a special \
kind:\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(rv\ \  = randomv[8]; \ b = \ rv[\([1]\)] + \ I*rv[\([5]\)]; \ 
    c = \ 2*rv[\([2]\)] + \ I*rv[\([6]\)]; 
    bb\  = \ rv[\([3]\)] + \ I*rv[\([7]\)]; \ 
    cc = \ 2*rv[\([4]\)] + \ I*rv[\([8]\)]; Print[{b, c, bb, cc}]\)], "Input",\

  CellLabel->"In[63]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(apro = 
      FullSimplify[
        wilker[1, b, c, \((1 + b*c)\)] . 
          wilker[1, bb, cc, \((1 + bb*cc)\)]]\)], "Input",
  CellLabel->"In[64]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Table[pssp[apro[\([i]\)], apro[\([j]\)]], {i, 4}, {j, 4}] // 
      MatrixForm\)], "Input",
  CellLabel->"In[65]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(uv\  = {{1, c}, {b, \((1 + c*b)\)}} . {{1, 
            cc}, {bb, \((1 + bb*cc)\)}}\)], "Input",
  CellLabel->"In[66]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Print[Det[uv]]\)], "Input",
  CellLabel->"In[67]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(unapro\  = \ 
      wilker[uv[\([1, 1]\)], uv[\([2, 1]\)], \ uv[\([1, 2]\)], 
        uv[\([2, 2]\)]]\)], "Input",
  CellLabel->"In[68]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Table[pssp[unapro[\([i]\)], unapro[\([j]\)]], {i, 4}, {j, 4}] // 
      MatrixForm\)], "Input",
  CellLabel->"In[69]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(dro\  = apro - unapro\)], "Input",
  CellLabel->"In[70]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Chop[dro] // MatrixForm\)], "Input",
  CellLabel->"In[71]:=",
  FontFamily->"Times New Roman"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
A6.3 Random test2 of the homomorphy property: The general \
case\
\>", "Subsection",
  FontFamily->"Times New Roman"],

Cell["\<\
 We evaluate the homomorphy for random matrices in the general case\
\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Clear[rv, a, b, c, d, aa, bb, cc, dd, uv1, uv2, uv]\)], "Input",
  CellLabel->"In[72]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[{
    \(rv\ \  = randomv[8]; \ a = \ rv[\([1]\)] + \ I*rv[\([5]\)]; \ 
    b = \ 2*rv[\([2]\)] + \ I*rv[\([6]\)]; 
    c\  = \ rv[\([3]\)] + \ I*rv[\([7]\)]; \ 
    d = \ 2*rv[\([4]\)] + \ I*rv[\([8]\)]; uv1\  = {{a, c}, {b, d}}; \ 
    uv1\  = \ uv1/Sqrt[Det[uv1]];\), "\[IndentingNewLine]", 
    \(Print[uv1]\)}], "Input",
  CellLabel->"In[73]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[{
    \(rv\ \  = randomv[8]; \ aa = \ rv[\([1]\)] + \ I*rv[\([5]\)]; \ 
    bb = \ 2*rv[\([2]\)] + \ I*rv[\([6]\)]; 
    cc\  = \ rv[\([3]\)] + \ I*rv[\([7]\)]; \ 
    dd = \ 2*rv[\([4]\)] + \ I*rv[\([8]\)]; uv2\  = {{aa, cc}, {bb, dd}}; \ 
    uv2\  = \ uv2/Sqrt[Det[uv2]];\), "\[IndentingNewLine]", 
    \(Print[uv2]\)}], "Input",
  CellLabel->"In[75]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Det[uv2]\)], "Input",
  CellLabel->"In[77]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(uv\  = \ uv1 . uv2\)], "Input",
  CellLabel->"In[78]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(uv // MatrixForm\)], "Input",
  CellLabel->"In[79]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Det[uv]\)], "Input",
  CellLabel->"In[80]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(apro = \ 
      wilker[uv1[\([1, 1]\)], uv1[\([2, 1]\)], uv1[\([1, 2]\)], \ 
          uv1[\([2, 2]\)]] . 
        wilker[uv2[\([1, 1]\)], uv2[\([2, 1]\)], uv2[\([1, 2]\)], \ 
          uv2[\([2, 2]\)]]\)], "Input",
  CellLabel->"In[81]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Table[pssp[apro[\([i]\)], apro[\([j]\)]], {i, 4}, {j, 4}] // 
      MatrixForm\)], "Input",
  CellLabel->"In[83]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(unapro\  = \ 
      wilker[uv[\([1, 1]\)], uv[\([2, 1]\)], \ uv[\([1, 2]\)], 
        uv[\([2, 2]\)]]\)], "Input",
  CellLabel->"In[84]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Table[pssp[unapro[\([i]\)], unapro[\([j]\)]], {i, 4}, {j, 4}] // 
      MatrixForm\)], "Input",
  CellLabel->"In[85]:=",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(dro\  = Chop[apro - unapro]\)], "Input",
  CellLabel->"In[86]:=",
  FontFamily->"Times New Roman"],

Cell["\<\
Here we always get the zero matrix null[5]. This means  - in the \
sense of experimental mathematics - that the map hom is an \
homomorphism.\
\>", "Text",
  FontFamily->"Times New Roman"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["References", "Subtitle"],

Cell["\<\
[G] Alfred Gray. Modern Differential Geometry of Curves and \
Surfaces. CRC PRESS, 1993 (German translation: Spektrum Akademischer Verlag \
1994)\
\>", "Text",
  FontFamily->"Times New Roman",
  CellTags->"Alfred"],

Cell["\<\
[K] Jens-Peer Kuska. http://phong.informatik.uni-leipzig.de/ \
~kuska/mview3d.html.\
\>", "Text",
  FontFamily->"Times New Roman",
  CellTags->"Kuska"],

Cell["\<\
[M] Uwe May. Der Raum der Kreise in der Sph\[ADoubleDot]re. \
Diplomarbeit, Humboldt-Universit\[ADoubleDot]t, Berlin, 1993\
\>", "Text",
  FontFamily->"Times New Roman",
  CellTags->"M."],

Cell["\<\
[O.-S.] A.L. Onishchik,  Sulanke, R. Projektive und \
Cayley-Kleinsche Geometrien, \
http://www-irm.mathematik.hu-berlin.de/~sulanke\
\>", "Text",
  FontFamily->"Times New Roman",
  CellTags->"O.-S."],

Cell[TextData[{
  "[S1] R. Sulanke. M\[ODoubleDot]bius invariants for pairs (",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["S", "1", "m"], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["S", "2", "l"], TraditionalForm]]],
  ") of spheres in the M\[ODoubleDot]bius space ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox["S", "n"], TraditionalForm]]],
  ". http://xxx.lanl.gov/abs/math.MG/9902131"
}], "Text",
  Evaluatable->False,
  FontFamily->"Times New Roman",
  CellTags->"S1"],

Cell[TextData[{
  "[S2] R. Sulanke. Lie Algebras. \
http://www.mathsource.com/cgi-bin/msitem?0210-845.\n(See also my ",
  ButtonBox["homepage",
    ButtonData:>"hopa",
    ButtonStyle->"Hyperlink"],
  " .)"
}], "Text",
  FontFamily->"Times New Roman",
  CellTags->"S2"],

Cell[TextData[{
  "[S3] R. Sulanke. Spheres. \
http://www.mathsource.com/content/Enhancements/Geometry/0210-092.\n(See also \
my ",
  ButtonBox["homepage",
    ButtonData:>"hopa",
    ButtonStyle->"Hyperlink"],
  " .)"
}], "Text",
  FontFamily->"Times New Roman",
  CellTags->"S3"],

Cell["\<\
[W] J. B. Wilker. Inversive Geometry. Coxeter Festschrift The \
Geometric Vein, Springer-Verlag 1981, 379-442\
\>", "Text",
  FontFamily->"Times New Roman",
  CellTags->"W."],

Cell["\<\
.[J] Pekka Janhunen. Declare.m. \
http://www.mathsource.com/Content22/Enhancements/Algebraic/0202-149, \
1223.\
\>", "Text",
  FontFamily->"Times New Roman",
  CellTags->"J."],

Cell[CellGroupData[{

Cell["Packages and corresponding notebooks", "Subsubsection",
  CellTags->"pack"],

Cell["\<\
1. euvec.m ==> Euklid.nb
2. pseuvec.m ==> pseuklid.nb
3. mspher.m ==> mspheres.nb
4. mcirc.m ==> mcircles.nb
5. mpairs.m ==> pairs.nb
6. spiralsf.m ==> Spirals.nb
7. riemann.m ==> riemsph.nb
8. liealg.m ==> liealgeb.nb\
\>", "Text"],

Cell[TextData[{
  " All this stuff can be downloaded from my ",
  ButtonBox["homepage",
    ButtonData:>"hopa",
    ButtonStyle->"Hyperlink"],
  ": The actual versions of the packages 1-8 are collected in mathpack.tgz, \
the items 1. - 6. in sphs4.tgz and items 8 in lie.tgz. "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Address", "Subsubtitle",
  FontFamily->"Times New Roman"],

Cell["sulanke@mathematik.hu-berlin.de", "Text",
  FontFamily->"Times New Roman"],

Cell["Homepage:http://www-irm.mathematik.hu-berlin.de/~sulanke", "Text",
  FontFamily->"Times New Roman",
  CellTags->"hopa"],

Cell["\<\
The author will be very thankful for \
hints,corrections,comments.\
\>", "Text",
  FontFamily->"Times New Roman"]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
AutoGeneratedPackage->None,
ScreenStyleEnvironment->"Presentation",
PrintingStyleEnvironment->"Working",
WindowSize->{763, 637},
WindowMargins->{{1, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PageHeaderLines->{Inherited, False},
PrintingOptions->{"PrintingMargins"->{{72, 72}, {54, 54}},
"PaperSize"->{597.563, 842.375},
"PaperOrientation"->"Landscape",
"PrintCellBrackets"->False,
"PrintRegistrationMarks"->False,
"PrintMultipleHorizontalPages"->False,
"FirstPageHeader"->False,
"FirstPageFooter"->False,
"PostScriptOutputFile":>FrontEnd`FileName[{"home", "rolf", "mymath", \
"spheres", "Riemannsph"}, "riemsph.nb.ps", CharacterEncoding -> \
"WindowsANSI"],
"Magnification"->1},
ShowCellTags->True,
StyleDefinitions -> "ArticleClassic.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "eq1"->{
    Cell[18763, 571, 287, 9, 70, "Input",
      InitializationCell->True,
      CellTags->"eq1"]},
  "CrRatio"->{
    Cell[59714, 2111, 94, 2, 70, "Subsection",
      CellTags->"CrRatio"]},
  "equith"->{
    Cell[67114, 2366, 163, 6, 70, "Text",
      CellTags->"equith"]},
  "Orient"->{
    Cell[116785, 4083, 897, 15, 70, "Text",
      CellTags->"Orient"]},
  "MathGL"->{
    Cell[219915, 7911, 89, 2, 70, "Subsection",
      CellTags->"MathGL"]},
  "getMGL3D"->{
    Cell[220846, 7936, 149, 4, 70, "Input",
      CellTags->"getMGL3D"]},
  "equipict"->{
    Cell[223642, 8032, 99, 1, 70, "Subsubsection",
      CellTags->"equipict"]},
  "crtest"->{
    Cell[251611, 8959, 124, 2, 70, "Subsubsection",
      CellTags->"crtest"]},
  "riemT"->{
    Cell[260862, 9343, 102, 2, 70, "Subsubsection",
      CellTags->"riemT"]},
  "spectrans"->{
    Cell[265518, 9542, 103, 1, 57, "Subsection",
      CellTags->"spectrans"]},
  "Declare"->{
    Cell[271182, 9733, 99, 2, 58, "Section",
      CellTags->"Declare"]},
  "W.matrix"->{
    Cell[287935, 10459, 97, 2, 58, "Section",
      CellTags->"W.matrix"]},
  "Alfred"->{
    Cell[306479, 11052, 224, 6, 87, "Text",
      CellTags->"Alfred"]},
  "Kuska"->{
    Cell[306706, 11060, 161, 5, 62, "Text",
      CellTags->"Kuska"]},
  "M."->{
    Cell[306870, 11067, 197, 5, 62, "Text",
      CellTags->"M."]},
  "O.-S."->{
    Cell[307070, 11074, 210, 6, 87, "Text",
      CellTags->"O.-S."]},
  "S1"->{
    Cell[307283, 11082, 540, 17, 87, "Text",
      Evaluatable->False,
      CellTags->"S1"]},
  "S2"->{
    Cell[307826, 11101, 269, 9, 87, "Text",
      CellTags->"S2"]},
  "S3"->{
    Cell[308098, 11112, 281, 10, 87, "Text",
      CellTags->"S3"]},
  "W."->{
    Cell[308382, 11124, 184, 5, 62, "Text",
      CellTags->"W."]},
  "J."->{
    Cell[308569, 11131, 185, 6, 87, "Text",
      CellTags->"J."]},
  "pack"->{
    Cell[308779, 11141, 81, 1, 74, "Subsubsection",
      CellTags->"pack"]},
  "hopa"->{
    Cell[309583, 11173, 125, 2, 62, "Text",
      CellTags->"hopa"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"eq1", 311177, 11221},
  {"CrRatio", 311291, 11225},
  {"equith", 311381, 11228},
  {"Orient", 311465, 11231},
  {"MathGL", 311551, 11234},
  {"getMGL3D", 311643, 11237},
  {"equipict", 311733, 11240},
  {"crtest", 311828, 11243},
  {"riemT", 311921, 11246},
  {"spectrans", 312017, 11249},
  {"Declare", 312112, 11252},
  {"W.matrix", 312202, 11255},
  {"Alfred", 312292, 11258},
  {"Kuska", 312377, 11261},
  {"M.", 312458, 11264},
  {"O.-S.", 312539, 11267},
  {"S1", 312620, 11270},
  {"S2", 312725, 11274},
  {"S3", 312803, 11277},
  {"W.", 312882, 11280},
  {"J.", 312960, 11283},
  {"pack", 313040, 11286},
  {"hopa", 313130, 11289}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 153, 4, 120, "Title",
  Evaluatable->False],
Cell[1932, 59, 232, 8, 57, "Subsubtitle",
  Evaluatable->False],
Cell[2167, 69, 158, 5, 53, "Text",
  Evaluatable->False],
Cell[2328, 76, 144, 4, 45, "Text",
  Evaluatable->False],
Cell[2475, 82, 238, 10, 41, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[2738, 96, 88, 2, 57, "Subsubsection"],
Cell[2829, 100, 1271, 24, 245, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[4137, 129, 33, 0, 35, "Subsubsection"],
Cell[4173, 131, 3732, 77, 645, "Text",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[7942, 213, 46, 0, 35, "Subsubsection"],
Cell[7991, 215, 806, 26, 120, "Text",
  Evaluatable->False],
Cell[8800, 243, 237, 8, 45, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[9074, 256, 68, 1, 35, "Subsubsection"],
Cell[9145, 259, 406, 7, 120, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[9588, 271, 73, 1, 41, "Section"],
Cell[9664, 274, 589, 14, 95, "Text"],

Cell[CellGroupData[{
Cell[10278, 292, 33, 0, 68, "Subsection"],

Cell[CellGroupData[{
Cell[10336, 296, 77, 1, 57, "Subsubsection"],
Cell[10416, 299, 781, 13, 70, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[11234, 317, 82, 1, 35, "Subsubsection"],
Cell[11319, 320, 456, 9, 70, "Text"],
Cell[11778, 331, 99, 2, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[11914, 338, 87, 1, 35, "Subsubsection"],
Cell[12004, 341, 349, 7, 70, "Text"],
Cell[12356, 350, 199, 4, 45, "Text"],
Cell[12558, 356, 88, 1, 45, "Text"],
Cell[12649, 359, 119, 3, 39, "Input"],
Cell[12771, 364, 435, 9, 95, "Text"],
Cell[13209, 375, 134, 3, 46, "Text"],
Cell[13346, 380, 255, 7, 39, "Input",
  InitializationCell->True],
Cell[13604, 389, 121, 4, 45, "Text"],
Cell[13728, 395, 130, 3, 46, "Text"],
Cell[13861, 400, 147, 4, 39, "Input"],
Cell[14011, 406, 178, 4, 45, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[14226, 415, 63, 1, 35, "Subsubsection"],
Cell[14292, 418, 184, 4, 46, "Text"],
Cell[14479, 424, 214, 5, 70, "Text"],
Cell[14696, 431, 160, 4, 39, "Input",
  InitializationCell->True],
Cell[14859, 437, 159, 4, 39, "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[15079, 448, 125, 4, 41, "Section"],
Cell[15207, 454, 340, 7, 70, "Text"],

Cell[CellGroupData[{
Cell[15572, 465, 62, 0, 70, "Subsection"],
Cell[15637, 467, 1404, 29, 70, "Text"],
Cell[17044, 498, 220, 6, 70, "Input",
  InitializationCell->True],
Cell[17267, 506, 122, 5, 70, "Text"],
Cell[17392, 513, 67, 2, 70, "Input"],
Cell[17462, 517, 79, 2, 70, "Input"],
Cell[17544, 521, 65, 2, 70, "Input"],
Cell[17612, 525, 23, 0, 70, "Text"],
Cell[17638, 527, 68, 2, 70, "Input"],
Cell[17709, 531, 81, 2, 70, "Input"],
Cell[17793, 535, 240, 7, 70, "Text",
  Evaluatable->False],
Cell[18036, 544, 34, 0, 70, "Text"],
Cell[18073, 546, 67, 2, 70, "Input"],
Cell[18143, 550, 96, 2, 70, "Input"],
Cell[18242, 554, 226, 5, 70, "Text"],
Cell[18471, 561, 149, 3, 70, "Input"],
Cell[18623, 566, 137, 3, 70, "Text"],
Cell[18763, 571, 287, 9, 70, "Input",
  InitializationCell->True,
  CellTags->"eq1"],
Cell[19053, 582, 43, 0, 70, "Text"],
Cell[19099, 584, 77, 2, 70, "Input"],
Cell[19179, 588, 74, 0, 70, "Text"],
Cell[19256, 590, 88, 2, 70, "Input"],
Cell[19347, 594, 68, 2, 70, "Input"],
Cell[19418, 598, 71, 0, 70, "Text"],
Cell[19492, 600, 68, 2, 70, "Input"],
Cell[19563, 604, 71, 2, 70, "Input"],
Cell[19637, 608, 105, 3, 70, "Text"],
Cell[19745, 613, 174, 5, 70, "Input"],
Cell[19922, 620, 67, 2, 70, "Input"],
Cell[19992, 624, 83, 2, 70, "Input"],
Cell[20078, 628, 70, 2, 70, "Input"],
Cell[20151, 632, 360, 9, 70, "Text"],
Cell[20514, 643, 135, 3, 70, "Input"],
Cell[20652, 648, 18, 0, 70, "Text"],
Cell[20673, 650, 98, 2, 70, "Input"],
Cell[20774, 654, 162, 4, 70, "Text"],
Cell[20939, 660, 257, 8, 70, "Input",
  InitializationCell->True],
Cell[21199, 670, 150, 4, 70, "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[21398, 680, 106, 1, 41, "Section"],
Cell[21507, 683, 818, 17, 70, "Text"],

Cell[CellGroupData[{
Cell[22350, 704, 102, 1, 70, "Subsection"],
Cell[22455, 707, 111, 3, 70, "Text"],

Cell[CellGroupData[{
Cell[22591, 714, 127, 5, 70, "Subsubsection"],
Cell[22721, 721, 236, 7, 70, "Text"],
Cell[22960, 730, 73, 2, 70, "Input"],
Cell[23036, 734, 130, 3, 70, "Text"],
Cell[23169, 739, 70, 2, 70, "Input"],
Cell[23242, 743, 92, 2, 70, "Input"],
Cell[23337, 747, 90, 2, 70, "Input"],
Cell[23430, 751, 117, 2, 70, "Input"],
Cell[23550, 755, 128, 3, 70, "Input"],
Cell[23681, 760, 86, 2, 70, "Input"],
Cell[23770, 764, 79, 2, 70, "Input"],
Cell[23852, 768, 411, 10, 70, "Text"],
Cell[24266, 780, 76, 2, 70, "Input"],
Cell[24345, 784, 90, 3, 70, "Text"],
Cell[24438, 789, 77, 2, 70, "Input"],
Cell[24518, 793, 118, 5, 70, "Text"],
Cell[24639, 800, 113, 2, 70, "Input"],
Cell[24755, 804, 59, 0, 70, "Text"],
Cell[24817, 806, 117, 2, 70, "Input"],
Cell[24937, 810, 137, 4, 70, "Text"],
Cell[25077, 816, 66, 2, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[25180, 823, 82, 1, 70, "Subsubsection"],
Cell[25265, 826, 179, 4, 70, "Text"],
Cell[25447, 832, 65, 2, 70, "Input"],
Cell[25515, 836, 78, 2, 70, "Input"],
Cell[25596, 840, 59, 0, 70, "Text"],
Cell[25658, 842, 83, 2, 70, "Input"],
Cell[25744, 846, 65, 2, 70, "Input"],
Cell[25812, 850, 147, 4, 70, "Text"],
Cell[25962, 856, 85, 2, 70, "Input"],
Cell[26050, 860, 88, 2, 70, "Input"],
Cell[26141, 864, 97, 2, 70, "Input"],
Cell[26241, 868, 105, 2, 70, "Input"],
Cell[26349, 872, 83, 2, 70, "Input"],
Cell[26435, 876, 76, 2, 70, "Input"],
Cell[26514, 880, 76, 2, 70, "Input"],
Cell[26593, 884, 69, 2, 70, "Input"],
Cell[26665, 888, 67, 2, 70, "Input"],
Cell[26735, 892, 107, 3, 70, "Input"],
Cell[26845, 897, 123, 3, 70, "Input"],
Cell[26971, 902, 101, 3, 70, "Input"],
Cell[27075, 907, 64, 2, 70, "Input"],
Cell[27142, 911, 112, 3, 70, "Input"],
Cell[27257, 916, 108, 3, 70, "Input"],
Cell[27368, 921, 113, 3, 70, "Input"],
Cell[27484, 926, 111, 3, 70, "Input"],
Cell[27598, 931, 119, 3, 70, "Input"],
Cell[27720, 936, 105, 3, 70, "Input"],
Cell[27828, 941, 98, 3, 70, "Input"],
Cell[27929, 946, 101, 3, 70, "Input"],
Cell[28033, 951, 72, 2, 70, "Input"],
Cell[28108, 955, 106, 3, 70, "Input"],
Cell[28217, 960, 182, 6, 70, "Text"],
Cell[28402, 968, 70, 2, 70, "Input"],
Cell[28475, 972, 82, 2, 70, "Input"],
Cell[28560, 976, 71, 2, 70, "Input"],
Cell[28634, 980, 90, 3, 70, "Text"],
Cell[28727, 985, 86, 2, 70, "Input"],
Cell[28816, 989, 148, 3, 70, "Text"],
Cell[28967, 994, 75, 2, 70, "Input"],
Cell[29045, 998, 82, 2, 70, "Input"],
Cell[29130, 1002, 83, 2, 70, "Input"],
Cell[29216, 1006, 73, 2, 70, "Input"],
Cell[29292, 1010, 54, 0, 70, "Text"],
Cell[29349, 1012, 71, 2, 70, "Input"],
Cell[29423, 1016, 67, 2, 70, "Input"],
Cell[29493, 1020, 71, 2, 70, "Input"],
Cell[29567, 1024, 70, 2, 70, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[29686, 1032, 81, 1, 70, "Subsection"],
Cell[29770, 1035, 718, 16, 70, "Text"],
Cell[30491, 1053, 71, 2, 70, "Input"],
Cell[30565, 1057, 74, 2, 70, "Input"],
Cell[30642, 1061, 235, 7, 70, "Text"],
Cell[30880, 1070, 289, 8, 70, "Input",
  InitializationCell->True],
Cell[31172, 1080, 2755, 68, 70, "Input",
  InitializationCell->True],
Cell[33930, 1150, 199, 7, 70, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[34166, 1162, 79, 1, 70, "Subsection"],
Cell[34248, 1165, 238, 6, 70, "Text"],

Cell[CellGroupData[{
Cell[34511, 1175, 149, 4, 70, "Subsubsection"],
Cell[34663, 1181, 598, 11, 70, "Text"],
Cell[35264, 1194, 71, 2, 70, "Input"],
Cell[35338, 1198, 83, 1, 70, "Text"],
Cell[35424, 1201, 70, 2, 70, "Input"],
Cell[35497, 1205, 168, 6, 70, "Text"],
Cell[35668, 1213, 74, 2, 70, "Input"],
Cell[35745, 1217, 68, 0, 70, "Text"],
Cell[35816, 1219, 486, 9, 70, "Input",
  Evaluatable->False],
Cell[36305, 1230, 472, 9, 70, "Input",
  Evaluatable->False],
Cell[36780, 1241, 608, 11, 70, "Input",
  Evaluatable->False],
Cell[37391, 1254, 203, 5, 70, "Text"],
Cell[37597, 1261, 81, 2, 70, "Input"],
Cell[37681, 1265, 201, 6, 70, "Text"],
Cell[37885, 1273, 209, 4, 70, "Input"],
Cell[38097, 1279, 106, 3, 70, "Input"],
Cell[38206, 1284, 109, 1, 70, "Text"],
Cell[38318, 1287, 210, 4, 70, "Input"],
Cell[38531, 1293, 74, 2, 70, "Input"],
Cell[38608, 1297, 100, 3, 70, "Input"],
Cell[38711, 1302, 210, 4, 70, "Input"],
Cell[38924, 1308, 107, 3, 70, "Input"],
Cell[39034, 1313, 171, 5, 70, "Text"],
Cell[39208, 1320, 210, 4, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[39455, 1329, 81, 1, 70, "Subsubsection"],
Cell[39539, 1332, 102, 3, 70, "Input"],
Cell[39644, 1337, 102, 3, 70, "Input"],
Cell[39749, 1342, 107, 3, 70, "Input"],
Cell[39859, 1347, 102, 3, 70, "Input"],
Cell[39964, 1352, 107, 3, 70, "Input"],
Cell[40074, 1357, 120, 3, 70, "Input"],
Cell[40197, 1362, 105, 3, 70, "Input"],
Cell[40305, 1367, 110, 3, 70, "Input"],
Cell[40418, 1372, 155, 6, 70, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[40610, 1383, 52, 0, 70, "Subsubsection"],
Cell[40665, 1385, 103, 3, 70, "Text"],
Cell[40771, 1390, 129, 3, 70, "Input"],
Cell[40903, 1395, 67, 2, 70, "Input"],
Cell[40973, 1399, 76, 2, 70, "Input"],
Cell[41052, 1403, 72, 2, 70, "Input"],
Cell[41127, 1407, 60, 0, 70, "Text"],
Cell[41190, 1409, 71, 2, 70, "Input"],
Cell[41264, 1413, 76, 2, 70, "Input"],
Cell[41343, 1417, 72, 2, 70, "Input"],
Cell[41418, 1421, 83, 2, 70, "Input"],
Cell[41504, 1425, 74, 2, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[41615, 1432, 105, 1, 70, "Subsubsection"],
Cell[41723, 1435, 490, 9, 70, "Text"],
Cell[42216, 1446, 101, 2, 70, "Input"],
Cell[42320, 1450, 101, 2, 70, "Input"],
Cell[42424, 1454, 119, 3, 70, "Text"],
Cell[42546, 1459, 66, 2, 70, "Input"],
Cell[42615, 1463, 148, 4, 70, "Input",
  Evaluatable->False],
Cell[42766, 1469, 52, 0, 70, "Text"],
Cell[42821, 1471, 71, 2, 70, "Input"],
Cell[42895, 1475, 146, 4, 70, "Input",
  Evaluatable->False],
Cell[43044, 1481, 48, 0, 70, "Text"],
Cell[43095, 1483, 75, 2, 70, "Input"],
Cell[43173, 1487, 203, 5, 70, "Input",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[43413, 1497, 72, 1, 70, "Subsubsection"],
Cell[43488, 1500, 97, 3, 70, "Input"],
Cell[43588, 1505, 98, 3, 70, "Input"],
Cell[43689, 1510, 101, 3, 70, "Input"],
Cell[43793, 1515, 118, 3, 70, "Input"],
Cell[43914, 1520, 118, 3, 70, "Input"],
Cell[44035, 1525, 65, 2, 70, "Input"],
Cell[44103, 1529, 64, 2, 70, "Input"],
Cell[44170, 1533, 74, 2, 70, "Input"],
Cell[44247, 1537, 108, 2, 70, "Input"],
Cell[44358, 1541, 57, 0, 70, "Text"],
Cell[44418, 1543, 74, 2, 70, "Input"],
Cell[44495, 1547, 125, 3, 70, "Text"],
Cell[44623, 1552, 159, 4, 70, "Input"],
Cell[44785, 1558, 66, 2, 70, "Input"],
Cell[44854, 1562, 74, 2, 70, "Input"],
Cell[44931, 1566, 75, 2, 70, "Input"],
Cell[45009, 1570, 458, 14, 70, "Text"],
Cell[45470, 1586, 108, 2, 70, "Input"],
Cell[45581, 1590, 277, 5, 70, "Text"],
Cell[45861, 1597, 162, 4, 70, "Input"],
Cell[46026, 1603, 66, 2, 70, "Input"],
Cell[46095, 1607, 74, 2, 70, "Input"],
Cell[46172, 1611, 32, 0, 70, "Text"],
Cell[46207, 1613, 75, 2, 70, "Input"],
Cell[46285, 1617, 49, 0, 70, "Text"],
Cell[46337, 1619, 101, 2, 70, "Input"],
Cell[46441, 1623, 103, 3, 70, "Text"],
Cell[46547, 1628, 66, 2, 70, "Input"],
Cell[46616, 1632, 34, 0, 70, "Text"],
Cell[46653, 1634, 85, 2, 70, "Input"],
Cell[46741, 1638, 75, 2, 70, "Input"],
Cell[46819, 1642, 353, 6, 70, "Text"],
Cell[47175, 1650, 108, 2, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[47320, 1657, 84, 1, 70, "Subsubsection"],
Cell[47407, 1660, 242, 5, 70, "Text"],
Cell[47652, 1667, 72, 2, 70, "Input"],
Cell[47727, 1671, 78, 2, 70, "Input"],
Cell[47808, 1675, 74, 0, 70, "Text"],
Cell[47885, 1677, 74, 2, 70, "Input"],
Cell[47962, 1681, 52, 0, 70, "Text"],
Cell[48017, 1683, 100, 2, 70, "Input"],
Cell[48120, 1687, 73, 2, 70, "Input"],
Cell[48196, 1691, 76, 0, 70, "Text"],
Cell[48275, 1693, 69, 2, 70, "Input"],
Cell[48347, 1697, 104, 2, 70, "Input"],
Cell[48454, 1701, 94, 2, 70, "Input"],
Cell[48551, 1705, 112, 2, 70, "Input"],
Cell[48666, 1709, 73, 2, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[48776, 1716, 81, 1, 70, "Subsubsection"],
Cell[48860, 1719, 109, 3, 70, "Input"],
Cell[48972, 1724, 116, 3, 70, "Input"],
Cell[49091, 1729, 141, 3, 70, "Text"],
Cell[49235, 1734, 172, 4, 70, "Input"],
Cell[49410, 1740, 184, 6, 70, "Text"],
Cell[49597, 1748, 110, 3, 70, "Input"],
Cell[49710, 1753, 113, 3, 70, "Input"],
Cell[49826, 1758, 120, 3, 70, "Input"],
Cell[49949, 1763, 110, 3, 70, "Input"],
Cell[50062, 1768, 118, 3, 70, "Input"],
Cell[50183, 1773, 108, 3, 70, "Input"],
Cell[50294, 1778, 218, 7, 70, "Text"],
Cell[50515, 1787, 16, 0, 70, "Text"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[50592, 1794, 82, 1, 41, "Section"],
Cell[50677, 1797, 791, 12, 170, "Text"],

Cell[CellGroupData[{
Cell[51493, 1813, 71, 1, 68, "Subsection"],
Cell[51567, 1816, 219, 6, 45, "Text"],
Cell[51789, 1824, 65, 2, 38, "Input"],
Cell[51857, 1828, 112, 3, 39, "Input"],
Cell[51972, 1833, 82, 2, 38, "Input"],
Cell[52057, 1837, 51, 1, 45, "Text"],
Cell[52111, 1840, 65, 2, 38, "Input"],
Cell[52179, 1844, 126, 3, 39, "Input"],
Cell[52308, 1849, 129, 3, 39, "Input"],
Cell[52440, 1854, 319, 7, 70, "Text"],
Cell[52762, 1863, 112, 3, 39, "Input"],
Cell[52877, 1868, 128, 4, 45, "Text"],
Cell[53008, 1874, 165, 4, 39, "Input"],
Cell[53176, 1880, 166, 4, 39, "Input"],

Cell[CellGroupData[{
Cell[53367, 1888, 66, 1, 57, "Subsubsection"],
Cell[53436, 1891, 202, 4, 70, "Text"],
Cell[53641, 1897, 113, 3, 70, "Input"],
Cell[53757, 1902, 113, 3, 70, "Input"],
Cell[53873, 1907, 73, 2, 70, "Input"],
Cell[53949, 1911, 70, 2, 70, "Input"],
Cell[54022, 1915, 113, 3, 70, "Input"],
Cell[54138, 1920, 113, 3, 70, "Input"],
Cell[54254, 1925, 68, 0, 70, "Text"],
Cell[54325, 1927, 80, 2, 70, "Input"],
Cell[54408, 1931, 80, 2, 70, "Input"],
Cell[54491, 1935, 113, 3, 70, "Input"],
Cell[54607, 1940, 98, 3, 70, "Text"],
Cell[54708, 1945, 116, 3, 70, "Input"],
Cell[54827, 1950, 116, 3, 70, "Input"],
Cell[54946, 1955, 113, 3, 70, "Input"],
Cell[55062, 1960, 120, 3, 70, "Input"],
Cell[55185, 1965, 120, 3, 70, "Input"],
Cell[55308, 1970, 107, 3, 70, "Input"],
Cell[55418, 1975, 131, 3, 70, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[55598, 1984, 78, 1, 68, "Subsection"],
Cell[55679, 1987, 143, 3, 70, "Input"],
Cell[55825, 1992, 141, 3, 70, "Input"],
Cell[55969, 1997, 381, 7, 70, "Text"],
Cell[56353, 2006, 226, 4, 70, "Input"],
Cell[56582, 2012, 63, 1, 70, "Text"],
Cell[56648, 2015, 113, 3, 70, "Input"],
Cell[56764, 2020, 246, 7, 70, "Text"],
Cell[57013, 2029, 164, 4, 70, "Input"],
Cell[57180, 2035, 63, 1, 70, "Text"],
Cell[57246, 2038, 164, 4, 70, "Input"],
Cell[57413, 2044, 143, 3, 70, "Input"],
Cell[57559, 2049, 143, 3, 70, "Input"],
Cell[57705, 2054, 147, 3, 70, "Input"],
Cell[57855, 2059, 61, 1, 70, "Text"],
Cell[57919, 2062, 196, 5, 70, "Input",
  Evaluatable->False],
Cell[58118, 2069, 698, 12, 70, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[58865, 2087, 116, 2, 41, "Section"],
Cell[58984, 2091, 705, 16, 70, "Text"],

Cell[CellGroupData[{
Cell[59714, 2111, 94, 2, 70, "Subsection",
  CellTags->"CrRatio"],

Cell[CellGroupData[{
Cell[59833, 2117, 78, 1, 70, "Subsubsection"],
Cell[59914, 2120, 77, 1, 70, "Text"],
Cell[59994, 2123, 105, 2, 70, "Input"],
Cell[60102, 2127, 92, 1, 70, "Text"],
Cell[60197, 2130, 88, 2, 70, "Input"],
Cell[60288, 2134, 311, 10, 70, "Text"],
Cell[60602, 2146, 73, 2, 70, "Input"],
Cell[60678, 2150, 70, 0, 70, "Text"],
Cell[60751, 2152, 1941, 39, 70, "Input",
  Evaluatable->False],
Cell[62695, 2193, 151, 4, 70, "Input",
  Evaluatable->False],
Cell[62849, 2199, 65, 0, 70, "Text"],
Cell[62917, 2201, 88, 2, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[63042, 2208, 72, 1, 70, "Subsubsection"],
Cell[63117, 2211, 117, 3, 70, "Input"],
Cell[63237, 2216, 120, 3, 70, "Input"],
Cell[63360, 2221, 123, 3, 70, "Input"],
Cell[63486, 2226, 120, 3, 70, "Input"],
Cell[63609, 2231, 123, 3, 70, "Input"],
Cell[63735, 2236, 123, 3, 70, "Input"],
Cell[63861, 2241, 117, 3, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[64015, 2249, 93, 1, 70, "Subsubsection"],
Cell[64111, 2252, 87, 1, 70, "Text"],
Cell[64201, 2255, 169, 4, 70, "Input"],
Cell[64373, 2261, 169, 4, 70, "Input"],
Cell[64545, 2267, 177, 4, 70, "Input"],
Cell[64725, 2273, 179, 4, 70, "Input"],
Cell[64907, 2279, 103, 3, 70, "Input"],
Cell[65013, 2284, 181, 4, 70, "Input"],
Cell[65197, 2290, 103, 3, 70, "Input"],
Cell[65303, 2295, 187, 4, 70, "Input"],
Cell[65493, 2301, 103, 3, 70, "Input"],
Cell[65599, 2306, 225, 5, 70, "Input"],
Cell[65827, 2313, 103, 3, 70, "Input"],
Cell[65933, 2318, 248, 5, 70, "Text"],
Cell[66184, 2325, 71, 2, 70, "Input"],
Cell[66258, 2329, 46, 0, 70, "Text"],
Cell[66307, 2331, 238, 6, 70, "Input",
  Evaluatable->False],
Cell[66548, 2339, 69, 2, 70, "Input"],
Cell[66620, 2343, 138, 4, 70, "Text"],
Cell[66761, 2349, 102, 3, 70, "Input"],
Cell[66866, 2354, 135, 5, 70, "Text"],
Cell[67004, 2361, 107, 3, 70, "Input"],
Cell[67114, 2366, 163, 6, 70, "Text",
  CellTags->"equith"],
Cell[67280, 2374, 122, 3, 70, "Input"],
Cell[67405, 2379, 122, 3, 70, "Input"],
Cell[67530, 2384, 178, 4, 70, "Text"],
Cell[67711, 2390, 119, 3, 70, "Input"],
Cell[67833, 2395, 119, 3, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[67989, 2403, 81, 1, 70, "Subsubsection"],
Cell[68073, 2406, 145, 4, 70, "Text"],
Cell[68221, 2412, 69, 2, 70, "Input"],
Cell[68293, 2416, 319, 8, 70, "Text"],
Cell[68615, 2426, 68, 2, 70, "Input"],
Cell[68686, 2430, 44, 0, 70, "Text"],
Cell[68733, 2432, 174, 5, 70, "Input",
  Evaluatable->False],
Cell[68910, 2439, 79, 2, 70, "Input"],
Cell[68992, 2443, 169, 4, 70, "Input"],
Cell[69164, 2449, 427, 8, 70, "Text"],
Cell[69594, 2459, 79, 2, 70, "Input"],
Cell[69676, 2463, 79, 2, 70, "Input"],
Cell[69758, 2467, 82, 2, 70, "Input"],
Cell[69843, 2471, 48, 0, 70, "Text"],
Cell[69894, 2473, 233, 5, 70, "Input"],
Cell[70130, 2480, 118, 3, 70, "Text"],
Cell[70251, 2485, 93, 2, 70, "Input"],
Cell[70347, 2489, 92, 2, 70, "Input"],
Cell[70442, 2493, 65, 2, 70, "Input"],
Cell[70510, 2497, 69, 2, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[70616, 2504, 93, 1, 70, "Subsubsection"],
Cell[70712, 2507, 132, 4, 70, "Text"],
Cell[70847, 2513, 127, 3, 70, "Input"],
Cell[70977, 2518, 122, 3, 70, "Input"],
Cell[71102, 2523, 128, 3, 70, "Input"],
Cell[71233, 2528, 99, 3, 70, "Input"],
Cell[71335, 2533, 122, 3, 70, "Input"],
Cell[71460, 2538, 107, 3, 70, "Input"],
Cell[71570, 2543, 121, 3, 70, "Input"],
Cell[71694, 2548, 103, 3, 70, "Input"],
Cell[71800, 2553, 178, 4, 70, "Text"],
Cell[71981, 2559, 105, 3, 70, "Input"],
Cell[72089, 2564, 110, 3, 70, "Input"],
Cell[72202, 2569, 190, 4, 70, "Input"],
Cell[72395, 2575, 103, 3, 70, "Input"],
Cell[72501, 2580, 107, 3, 70, "Input"],
Cell[72611, 2585, 110, 3, 70, "Input"],
Cell[72724, 2590, 530, 10, 70, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[73303, 2606, 127, 2, 70, "Subsection"],
Cell[73433, 2610, 678, 15, 70, "Text"],

Cell[CellGroupData[{
Cell[74136, 2629, 76, 1, 70, "Subsubsection"],
Cell[74215, 2632, 363, 7, 70, "Text"],
Cell[74581, 2641, 74, 2, 70, "Input"],
Cell[74658, 2645, 46, 0, 70, "Text"],
Cell[74707, 2647, 926, 17, 70, "Input",
  Evaluatable->False],
Cell[75636, 2666, 151, 6, 70, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[75824, 2677, 216, 8, 70, "Subsubsection"],
Cell[76043, 2687, 210, 5, 70, "Text"],
Cell[76256, 2694, 73, 2, 70, "Input"],
Cell[76332, 2698, 44, 0, 70, "Text"],
Cell[76379, 2700, 355, 8, 70, "Input",
  Evaluatable->False],
Cell[76737, 2710, 146, 6, 70, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[76920, 2721, 85, 1, 70, "Subsubsection"],
Cell[77008, 2724, 268, 6, 70, "Text"],
Cell[77279, 2732, 216, 4, 70, "Input",
  Evaluatable->False],
Cell[77498, 2738, 63, 1, 70, "Text"],
Cell[77564, 2741, 76, 2, 70, "Input"],
Cell[77643, 2745, 44, 0, 70, "Text"],
Cell[77690, 2747, 641, 13, 70, "Input",
  Evaluatable->False],
Cell[78334, 2762, 140, 4, 70, "Text"],
Cell[78477, 2768, 543, 15, 70, "Input",
  InitializationCell->True],
Cell[79023, 2785, 330, 12, 70, "Text"],
Cell[79356, 2799, 100, 3, 70, "Input"],
Cell[79459, 2804, 109, 1, 70, "Text"],
Cell[79571, 2807, 122, 3, 70, "Input"],
Cell[79696, 2812, 106, 3, 70, "Input"],
Cell[79805, 2817, 122, 3, 70, "Input"],
Cell[79930, 2822, 106, 3, 70, "Input"],
Cell[80039, 2827, 72, 0, 70, "Text"],
Cell[80114, 2829, 72, 2, 70, "Input"],
Cell[80189, 2833, 97, 2, 70, "Input"],
Cell[80289, 2837, 116, 2, 70, "Input"],
Cell[80408, 2841, 52, 0, 70, "Text"],
Cell[80463, 2843, 121, 3, 70, "Input"],
Cell[80587, 2848, 196, 4, 70, "Text"],
Cell[80786, 2854, 132, 3, 70, "Input"],
Cell[80921, 2859, 72, 2, 70, "Input"],
Cell[80996, 2863, 91, 2, 70, "Input"],
Cell[81090, 2867, 87, 2, 70, "Input"],
Cell[81180, 2871, 250, 5, 70, "Text"],
Cell[81433, 2878, 91, 2, 70, "Input"],
Cell[81527, 2882, 96, 2, 70, "Input"],
Cell[81626, 2886, 91, 2, 70, "Input"],
Cell[81720, 2890, 93, 2, 70, "Input"],
Cell[81816, 2894, 88, 1, 70, "Text"],
Cell[81907, 2897, 129, 3, 70, "Input"],
Cell[82039, 2902, 105, 3, 70, "Input"],
Cell[82147, 2907, 106, 3, 70, "Input"],
Cell[82256, 2912, 113, 3, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[82406, 2920, 90, 1, 70, "Subsubsection"],
Cell[82499, 2923, 360, 7, 70, "Text"],
Cell[82862, 2932, 128, 3, 70, "Input"],
Cell[82993, 2937, 110, 3, 70, "Text"],
Cell[83106, 2942, 124, 3, 70, "Input"],
Cell[83233, 2947, 87, 2, 70, "Input"],
Cell[83323, 2951, 122, 3, 70, "Input"],
Cell[83448, 2956, 106, 3, 70, "Input"],
Cell[83557, 2961, 86, 1, 70, "Input"],
Cell[83646, 2964, 127, 4, 70, "Input"],
Cell[83776, 2970, 290, 7, 70, "Input"],
Cell[84069, 2979, 296, 6, 70, "Input"],
Cell[84368, 2987, 97, 3, 70, "Text"],
Cell[84468, 2992, 434, 10, 70, "Input",
  InitializationCell->True],
Cell[84905, 3004, 38, 0, 70, "Text"],
Cell[84946, 3006, 108, 3, 70, "Input"],
Cell[85057, 3011, 114, 4, 70, "Text"],
Cell[85174, 3017, 111, 3, 70, "Input"],
Cell[85288, 3022, 106, 3, 70, "Input"],
Cell[85397, 3027, 121, 3, 70, "Input"],
Cell[85521, 3032, 637, 14, 70, "Text"],
Cell[86161, 3048, 92, 1, 70, "Text"],
Cell[86256, 3051, 122, 3, 70, "Input"],
Cell[86381, 3056, 160, 4, 70, "Input"],
Cell[86544, 3062, 96, 2, 70, "Input"],
Cell[86643, 3066, 109, 2, 70, "Input"],
Cell[86755, 3070, 155, 4, 70, "Text"],
Cell[86913, 3076, 67, 2, 70, "Input"],
Cell[86983, 3080, 135, 3, 70, "Input"],
Cell[87121, 3085, 56, 1, 70, "Text"],
Cell[87180, 3088, 455, 14, 70, "Input",
  InitializationCell->True],
Cell[87638, 3104, 455, 14, 70, "Input",
  InitializationCell->True],
Cell[88096, 3120, 132, 4, 70, "Text"],
Cell[88231, 3126, 109, 3, 70, "Input"],
Cell[88343, 3131, 147, 5, 70, "Text"],
Cell[88493, 3138, 109, 3, 70, "Input"],
Cell[88605, 3143, 107, 3, 70, "Input"],
Cell[88715, 3148, 39, 0, 70, "Text"],
Cell[88757, 3150, 77, 2, 70, "Input"],
Cell[88837, 3154, 126, 4, 70, "Text"],
Cell[88966, 3160, 77, 2, 70, "Input"],
Cell[89046, 3164, 130, 4, 70, "Text"],
Cell[89179, 3170, 136, 3, 70, "DisplayFormula"],
Cell[89318, 3175, 89, 1, 70, "Text"],
Cell[89410, 3178, 151, 4, 70, "DisplayFormula",
  Evaluatable->False],
Cell[89564, 3184, 619, 12, 70, "Text"],
Cell[90186, 3198, 170, 5, 70, "Text"],
Cell[90359, 3205, 114, 3, 70, "Input"],
Cell[90476, 3210, 114, 3, 70, "Input"],
Cell[90593, 3215, 114, 3, 70, "Input"],
Cell[90710, 3220, 114, 3, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[90861, 3228, 100, 1, 70, "Subsubsection"],
Cell[90964, 3231, 560, 9, 70, "Text"],
Cell[91527, 3242, 501, 15, 70, "Input",
  InitializationCell->True],
Cell[92031, 3259, 688, 20, 70, "Input",
  InitializationCell->True],
Cell[92722, 3281, 413, 12, 70, "Input",
  InitializationCell->True],
Cell[93138, 3295, 186, 4, 70, "Input"],
Cell[93327, 3301, 186, 4, 70, "Input"],
Cell[93516, 3307, 93, 1, 70, "Text"],
Cell[93612, 3310, 502, 15, 70, "Input",
  InitializationCell->True],
Cell[94117, 3327, 689, 20, 70, "Input",
  InitializationCell->True],
Cell[94809, 3349, 97, 1, 70, "Text"],
Cell[94909, 3352, 1579, 40, 70, "Input",
  InitializationCell->True],
Cell[96491, 3394, 188, 6, 70, "Text"],
Cell[96682, 3402, 271, 5, 70, "Input"],
Cell[96956, 3409, 106, 3, 70, "Input"],
Cell[97065, 3414, 238, 5, 70, "Text"],
Cell[97306, 3421, 125, 3, 70, "Input"],
Cell[97434, 3426, 99, 3, 70, "Input"],
Cell[97536, 3431, 462, 12, 70, "Input"],
Cell[98001, 3445, 105, 3, 70, "Input"],
Cell[98109, 3450, 260, 5, 70, "Text"],
Cell[98372, 3457, 432, 12, 70, "Input",
  InitializationCell->True],
Cell[98807, 3471, 138, 3, 70, "Input"],
Cell[98948, 3476, 241, 5, 70, "Text"],
Cell[99192, 3483, 162, 4, 70, "Input"],
Cell[99357, 3489, 106, 3, 70, "Input"],
Cell[99466, 3494, 90, 3, 70, "Text"],
Cell[99559, 3499, 361, 8, 70, "Input"],
Cell[99923, 3509, 100, 3, 70, "Input"],
Cell[100026, 3514, 106, 3, 70, "Input"],
Cell[100135, 3519, 166, 4, 70, "Input"],
Cell[100304, 3525, 67, 1, 70, "Text"],
Cell[100374, 3528, 550, 17, 70, "Input",
  InitializationCell->True],
Cell[100927, 3547, 402, 7, 70, "Text"],
Cell[101332, 3556, 60, 0, 70, "Text"],
Cell[101395, 3558, 70, 2, 70, "Input"],
Cell[101468, 3562, 70, 2, 70, "Input"],
Cell[101541, 3566, 49, 0, 70, "Text"],
Cell[101593, 3568, 69, 2, 70, "Input"],
Cell[101665, 3572, 61, 0, 70, "Text"],
Cell[101729, 3574, 111, 3, 70, "Input"],
Cell[101843, 3579, 39, 0, 70, "Text"],
Cell[101885, 3581, 65, 2, 70, "Input"],
Cell[101953, 3585, 65, 2, 70, "Input"],
Cell[102021, 3589, 33, 0, 70, "Text"],
Cell[102057, 3591, 110, 2, 70, "Input"],
Cell[102170, 3595, 70, 2, 70, "Input"],
Cell[102243, 3599, 109, 3, 70, "Text"],
Cell[102355, 3604, 106, 3, 70, "Input"],
Cell[102464, 3609, 87, 2, 70, "Input"],
Cell[102554, 3613, 87, 2, 70, "Input"],
Cell[102644, 3617, 73, 2, 70, "Input"],
Cell[102720, 3621, 189, 4, 70, "Text"],
Cell[102912, 3627, 102, 3, 70, "Input"],
Cell[103017, 3632, 95, 1, 70, "Text"],
Cell[103115, 3635, 112, 3, 70, "Input"],
Cell[103230, 3640, 143, 4, 70, "Text"],
Cell[103376, 3646, 122, 3, 70, "Input"],
Cell[103501, 3651, 116, 3, 70, "Input"],
Cell[103620, 3656, 107, 3, 70, "Input"],
Cell[103730, 3661, 114, 3, 70, "Input"],
Cell[103847, 3666, 107, 3, 70, "Input"],
Cell[103957, 3671, 121, 3, 70, "Input"],
Cell[104081, 3676, 107, 3, 70, "Input"],
Cell[104191, 3681, 445, 9, 70, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[104673, 3695, 96, 4, 70, "Subsubsection"],
Cell[104772, 3701, 430, 10, 70, "Text"],
Cell[105205, 3713, 223, 5, 70, "Input",
  Evaluatable->False],
Cell[105431, 3720, 238, 5, 70, "Text"],
Cell[105672, 3727, 128, 3, 70, "Input",
  Evaluatable->False],
Cell[105803, 3732, 138, 3, 70, "Input",
  Evaluatable->False],
Cell[105944, 3737, 151, 4, 70, "Text"],
Cell[106098, 3743, 181, 4, 70, "Input"],
Cell[106282, 3749, 160, 4, 70, "Input"],
Cell[106445, 3755, 189, 4, 70, "Input"],
Cell[106637, 3761, 134, 3, 70, "Input"],
Cell[106774, 3766, 129, 3, 70, "Input"],
Cell[106906, 3771, 109, 2, 70, "Input"],
Cell[107018, 3775, 99, 2, 70, "Input"],
Cell[107120, 3779, 19, 0, 70, "Text"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[107200, 3786, 61, 1, 41, "Section"],
Cell[107264, 3789, 1511, 31, 220, "Text"],

Cell[CellGroupData[{
Cell[108800, 3824, 53, 0, 68, "Subsection"],

Cell[CellGroupData[{
Cell[108878, 3828, 87, 1, 70, "Subsubsection"],
Cell[108968, 3831, 478, 10, 70, "Text"],
Cell[109449, 3843, 106, 3, 70, "Input"],
Cell[109558, 3848, 73, 2, 70, "Input"],
Cell[109634, 3852, 73, 2, 70, "Input"],
Cell[109710, 3856, 101, 2, 70, "Input"],
Cell[109814, 3860, 79, 2, 70, "Input"],
Cell[109896, 3864, 242, 5, 70, "Input"],
Cell[110141, 3871, 87, 3, 70, "Text"],
Cell[110231, 3876, 134, 3, 70, "Input"],
Cell[110368, 3881, 134, 3, 70, "Input"],
Cell[110505, 3886, 167, 4, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[110709, 3895, 84, 1, 70, "Subsubsection"],
Cell[110796, 3898, 108, 1, 70, "Text"],
Cell[110907, 3901, 550, 11, 70, "Input"],
Cell[111460, 3914, 416, 9, 70, "Input"],
Cell[111879, 3925, 233, 7, 70, "Text"],
Cell[112115, 3934, 133, 3, 70, "Input"],
Cell[112251, 3939, 106, 3, 70, "Input"],
Cell[112360, 3944, 132, 3, 70, "Input"],
Cell[112495, 3949, 112, 3, 70, "Input"],
Cell[112610, 3954, 106, 3, 70, "Input"],
Cell[112719, 3959, 135, 3, 70, "Input"],
Cell[112857, 3964, 205, 4, 70, "Input"],
Cell[113065, 3970, 145, 2, 70, "Text"],
Cell[113213, 3974, 251, 7, 70, "Text"],
Cell[113467, 3983, 75, 2, 70, "Input"],
Cell[113545, 3987, 75, 2, 70, "Input"],
Cell[113623, 3991, 79, 2, 70, "Input"],
Cell[113705, 3995, 70, 0, 70, "Text"],
Cell[113778, 3997, 296, 8, 70, "Input",
  Evaluatable->False],
Cell[114077, 4007, 271, 8, 70, "Input",
  Evaluatable->False],
Cell[114351, 4017, 780, 15, 70, "Input",
  Evaluatable->False],
Cell[115134, 4034, 916, 16, 70, "Input",
  Evaluatable->False],
Cell[116053, 4052, 154, 6, 70, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[116244, 4063, 83, 1, 70, "Subsubsection"],
Cell[116330, 4066, 85, 1, 70, "Text"],
Cell[116418, 4069, 75, 2, 70, "Input"],
Cell[116496, 4073, 200, 5, 70, "Input",
  Evaluatable->False],
Cell[116699, 4080, 83, 1, 70, "Text"],
Cell[116785, 4083, 897, 15, 70, "Text",
  CellTags->"Orient"],
Cell[117685, 4100, 115, 3, 70, "Input"],
Cell[117803, 4105, 119, 3, 70, "Input"],
Cell[117925, 4110, 112, 3, 70, "Input"],
Cell[118040, 4115, 84, 2, 70, "Input"],
Cell[118127, 4119, 117, 3, 70, "Input"],
Cell[118247, 4124, 101, 3, 70, "Input"],
Cell[118351, 4129, 82, 2, 70, "Input"],
Cell[118436, 4133, 77, 2, 70, "Input"],
Cell[118516, 4137, 69, 2, 70, "Input"],
Cell[118588, 4141, 82, 2, 70, "Input"],
Cell[118673, 4145, 80, 2, 70, "Input"],
Cell[118756, 4149, 74, 2, 70, "Input"],
Cell[118833, 4153, 85, 2, 70, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[118967, 4161, 77, 1, 40, "Subsection"],

Cell[CellGroupData[{
Cell[119069, 4166, 46, 0, 57, "Subsubsection"],
Cell[119118, 4168, 126, 4, 45, "Text"],
Cell[119247, 4174, 76, 2, 38, "Input"],
Cell[119326, 4178, 82, 2, 38, "Input"],
Cell[119411, 4182, 68, 2, 38, "Input"],
Cell[119482, 4186, 79, 2, 38, "Input"],
Cell[119564, 4190, 82, 1, 45, "Text"],
Cell[119649, 4193, 70, 2, 38, "Input"],
Cell[119722, 4197, 171, 4, 58, "Input"],
Cell[119896, 4203, 112, 2, 38, "Input"],
Cell[120011, 4207, 178, 4, 58, "Input"],
Cell[120192, 4213, 112, 2, 38, "Input"],
Cell[120307, 4217, 140, 3, 45, "Text"],
Cell[120450, 4222, 196, 4, 70, "Text"],
Cell[120649, 4228, 78, 2, 38, "Input"],
Cell[120730, 4232, 125, 3, 39, "Input"],
Cell[120858, 4237, 115, 3, 39, "Input"],
Cell[120976, 4242, 119, 3, 39, "Input"],
Cell[121098, 4247, 115, 3, 39, "Input"],
Cell[121216, 4252, 70, 2, 38, "Input"],
Cell[121289, 4256, 126, 3, 39, "Input"],
Cell[121418, 4261, 73, 2, 38, "Input"],
Cell[121494, 4265, 114, 3, 45, "Text"],
Cell[121611, 4270, 71, 2, 38, "Input"],
Cell[121685, 4274, 126, 3, 39, "Input"],
Cell[121814, 4279, 106, 3, 39, "Input"],
Cell[121923, 4284, 186, 4, 45, "Text"],
Cell[122112, 4290, 131, 3, 39, "Input"],
Cell[122246, 4295, 106, 3, 39, "Input"],
Cell[122355, 4300, 145, 3, 39, "Input"],
Cell[122503, 4305, 94, 3, 45, "Text"],
Cell[122600, 4310, 105, 3, 39, "Input"],
Cell[122708, 4315, 511, 11, 135, "Input",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[123256, 4331, 39, 0, 57, "Subsubsection"],
Cell[123298, 4333, 60, 0, 70, "Text"],
Cell[123361, 4335, 95, 2, 70, "Input"],
Cell[123459, 4339, 34, 0, 70, "Text"],
Cell[123496, 4341, 114, 3, 70, "Input"],
Cell[123613, 4346, 79, 2, 70, "Input"],
Cell[123695, 4350, 90, 3, 70, "Text"],
Cell[123788, 4355, 102, 2, 70, "Input"],
Cell[123893, 4359, 103, 3, 70, "Input"],
Cell[123999, 4364, 102, 3, 70, "Input"],
Cell[124104, 4369, 59, 0, 70, "Text"],
Cell[124166, 4371, 107, 3, 70, "Input"],
Cell[124276, 4376, 125, 3, 70, "Input"],
Cell[124404, 4381, 132, 3, 70, "Text"],
Cell[124539, 4386, 99, 2, 70, "Input"],
Cell[124641, 4390, 106, 3, 70, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[124796, 4399, 138, 4, 68, "Subsection"],

Cell[CellGroupData[{
Cell[124959, 4407, 70, 0, 70, "Subsubsection"],
Cell[125032, 4409, 315, 8, 70, "Text"],
Cell[125350, 4419, 311, 8, 70, "Input",
  InitializationCell->True],
Cell[125664, 4429, 134, 3, 70, "Text"],
Cell[125801, 4434, 179, 4, 70, "Input"],
Cell[125983, 4440, 108, 3, 70, "Input"],
Cell[126094, 4445, 116, 3, 70, "Input"],
Cell[126213, 4450, 92, 1, 70, "Text"],
Cell[126308, 4453, 72, 2, 70, "Input"],
Cell[126383, 4457, 81, 2, 70, "Input"],
Cell[126467, 4461, 394, 7, 70, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[126898, 4473, 38, 0, 70, "Subsubsection"],
Cell[126939, 4475, 421, 7, 70, "Text"],
Cell[127363, 4484, 112, 3, 70, "Input"],
Cell[127478, 4489, 114, 3, 70, "Input"],
Cell[127595, 4494, 197, 4, 70, "Input"],
Cell[127795, 4500, 92, 3, 70, "Text"],
Cell[127890, 4505, 132, 3, 70, "Input"],
Cell[128025, 4510, 20, 0, 70, "Text"],
Cell[128048, 4512, 101, 2, 70, "Input"],
Cell[128152, 4516, 687, 12, 70, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[128888, 4534, 120, 2, 40, "Subsection"],

Cell[CellGroupData[{
Cell[129033, 4540, 108, 1, 57, "Subsubsection"],
Cell[129144, 4543, 410, 9, 70, "Text"],
Cell[129557, 4554, 191, 4, 70, "Input",
  Evaluatable->False],
Cell[129751, 4560, 32, 0, 70, "Text"],
Cell[129786, 4562, 163, 4, 70, "Input",
  Evaluatable->False],
Cell[129952, 4568, 25, 0, 70, "Text"],
Cell[129980, 4570, 77, 2, 70, "Input"],
Cell[130060, 4574, 75, 2, 70, "Input"],
Cell[130138, 4578, 45, 0, 70, "Text"],
Cell[130186, 4580, 333, 8, 70, "Input",
  InitializationCell->True],
Cell[130522, 4590, 1248, 31, 70, "Input",
  InitializationCell->True],
Cell[131773, 4623, 82, 2, 70, "Input"],
Cell[131858, 4627, 72, 0, 70, "Text"],
Cell[131933, 4629, 82, 2, 70, "Input"],
Cell[132018, 4633, 21, 0, 70, "Text"],
Cell[132042, 4635, 78, 2, 70, "Input"],
Cell[132123, 4639, 209, 5, 70, "Text"],
Cell[132335, 4646, 82, 2, 70, "Input"],
Cell[132420, 4650, 86, 2, 70, "Input"],
Cell[132509, 4654, 86, 2, 70, "Input"],
Cell[132598, 4658, 557, 9, 70, "Text"],
Cell[133158, 4669, 94, 2, 70, "Input"],
Cell[133255, 4673, 66, 2, 70, "Input"],
Cell[133324, 4677, 81, 2, 70, "Input"],
Cell[133408, 4681, 69, 2, 70, "Input"],
Cell[133480, 4685, 59, 0, 70, "Text"],
Cell[133542, 4687, 85, 2, 70, "Input"],
Cell[133630, 4691, 425, 9, 70, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[134092, 4705, 115, 2, 35, "Subsubsection"],
Cell[134210, 4709, 147, 3, 70, "Text"],
Cell[134360, 4714, 84, 2, 70, "Input"],
Cell[134447, 4718, 94, 2, 70, "Input"],
Cell[134544, 4722, 84, 2, 70, "Input"],
Cell[134631, 4726, 103, 2, 70, "Input"],
Cell[134737, 4730, 115, 3, 70, "Text"],
Cell[134855, 4735, 502, 12, 70, "Text"],
Cell[135360, 4749, 832, 24, 70, "Input",
  InitializationCell->True],
Cell[136195, 4775, 303, 9, 70, "Text"],
Cell[136501, 4786, 336, 6, 70, "Text"],
Cell[136840, 4794, 420, 9, 70, "Text"],
Cell[137263, 4805, 211, 5, 70, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[137523, 4816, 83, 1, 68, "Subsection"],
Cell[137609, 4819, 180, 4, 70, "Text"],

Cell[CellGroupData[{
Cell[137814, 4827, 152, 5, 70, "Subsubsection"],
Cell[137969, 4834, 114, 3, 70, "Input"],
Cell[138086, 4839, 126, 3, 70, "Input"],
Cell[138215, 4844, 124, 3, 70, "Input"],
Cell[138342, 4849, 177, 5, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[138556, 4859, 165, 5, 70, "Subsubsection"],
Cell[138724, 4866, 81, 1, 70, "Text"],
Cell[138808, 4869, 125, 3, 70, "Input"],
Cell[138936, 4874, 103, 2, 70, "Input"],
Cell[139042, 4878, 96, 3, 70, "Text"],
Cell[139141, 4883, 99, 2, 70, "Input"],
Cell[139243, 4887, 178, 5, 70, "Input"],
Cell[139424, 4894, 397, 8, 70, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[139858, 4907, 153, 2, 70, "Subsubsection"],
Cell[140014, 4911, 67, 2, 70, "Input"],
Cell[140084, 4915, 127, 3, 70, "Input"],
Cell[140214, 4920, 193, 4, 70, "Input"],
Cell[140410, 4926, 106, 3, 70, "Input"],
Cell[140519, 4931, 581, 20, 70, "Text"],
Cell[141103, 4953, 240, 5, 70, "Text"],
Cell[141346, 4960, 183, 5, 70, "Input"],
Cell[141532, 4967, 59, 2, 70, "Input"],
Cell[141594, 4971, 183, 5, 70, "Input"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[141838, 4983, 68, 1, 41, "Section"],

Cell[CellGroupData[{
Cell[141931, 4988, 95, 1, 68, "Subsection"],
Cell[142029, 4991, 511, 9, 120, "Text"],
Cell[142543, 5002, 132, 3, 39, "Input"],
Cell[142678, 5007, 144, 3, 39, "Input"],
Cell[142825, 5012, 97, 3, 39, "Input"],
Cell[142925, 5017, 107, 3, 39, "Input"],
Cell[143035, 5022, 125, 4, 45, "Text"],
Cell[143163, 5028, 158, 3, 37, "Input",
  InitializationCell->True],
Cell[143324, 5033, 105, 3, 45, "Text"],
Cell[143432, 5038, 132, 3, 39, "Input"],
Cell[143567, 5043, 54, 1, 45, "Text"],
Cell[143624, 5046, 155, 4, 78, "Input",
  Evaluatable->False],
Cell[143782, 5052, 176, 4, 45, "Text"],
Cell[143961, 5058, 113, 3, 39, "Input"],
Cell[144077, 5063, 148, 3, 39, "Input"],
Cell[144228, 5068, 205, 5, 39, "Input"],
Cell[144436, 5075, 121, 3, 39, "Input"],
Cell[144560, 5080, 105, 3, 39, "Input"],
Cell[144668, 5085, 125, 4, 45, "Text"],
Cell[144796, 5091, 146, 3, 39, "Input"],
Cell[144945, 5096, 168, 4, 39, "Input"],
Cell[145116, 5102, 107, 3, 39, "Input"],
Cell[145226, 5107, 177, 4, 39, "Input"],
Cell[145406, 5113, 169, 4, 39, "Input"],
Cell[145578, 5119, 252, 6, 45, "Text"],
Cell[145833, 5127, 237, 5, 63, "Input"],
Cell[146073, 5134, 118, 3, 39, "Input"],
Cell[146194, 5139, 117, 3, 39, "Input"],
Cell[146314, 5144, 85, 2, 38, "Input"],
Cell[146402, 5148, 82, 2, 38, "Input"],
Cell[146487, 5152, 197, 6, 70, "Text"],
Cell[146687, 5160, 129, 3, 39, "Input"],
Cell[146819, 5165, 85, 2, 38, "Input"],
Cell[146907, 5169, 89, 2, 38, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[147033, 5176, 160, 4, 68, "Subsection"],
Cell[147196, 5182, 205, 5, 45, "Text"],
Cell[147404, 5189, 117, 3, 39, "Input"],
Cell[147524, 5194, 106, 3, 39, "Input"],
Cell[147633, 5199, 109, 2, 38, "Input"],
Cell[147745, 5203, 73, 2, 38, "Input"],
Cell[147821, 5207, 122, 3, 45, "Text"],
Cell[147946, 5212, 112, 2, 38, "Input"],
Cell[148061, 5216, 114, 3, 39, "Input"],
Cell[148178, 5221, 109, 3, 39, "Input"],
Cell[148290, 5226, 79, 2, 38, "Input"],
Cell[148372, 5230, 73, 2, 38, "Input"],
Cell[148448, 5234, 86, 2, 38, "Input"],
Cell[148537, 5238, 174, 4, 45, "Text"],
Cell[148714, 5244, 167, 5, 56, "Input"],
Cell[148884, 5251, 128, 4, 45, "Text"],
Cell[149015, 5257, 125, 3, 39, "Input"],
Cell[149143, 5262, 106, 3, 39, "Input"],
Cell[149252, 5267, 118, 2, 37, "Input"],
Cell[149373, 5271, 131, 4, 45, "Text"],
Cell[149507, 5277, 110, 2, 38, "Input"],
Cell[149620, 5281, 71, 2, 38, "Input"],
Cell[149694, 5285, 81, 2, 38, "Input"],
Cell[149778, 5289, 128, 3, 43, "Input"],
Cell[149909, 5294, 31, 0, 45, "Text"],
Cell[149943, 5296, 234, 6, 42, "Input"],
Cell[150180, 5304, 168, 5, 45, "Text"],
Cell[150351, 5311, 103, 3, 39, "Input"],
Cell[150457, 5316, 103, 3, 39, "Input"],
Cell[150563, 5321, 118, 3, 39, "Input"],
Cell[150684, 5326, 107, 3, 39, "Input"],
Cell[150794, 5331, 113, 3, 39, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[150944, 5339, 115, 2, 40, "Subsection"],
Cell[151062, 5343, 148, 4, 45, "Text"],
Cell[151213, 5349, 154, 4, 39, "Input"],
Cell[151370, 5355, 107, 3, 39, "Input"],
Cell[151480, 5360, 203, 6, 56, "Input",
  InitializationCell->True],
Cell[151686, 5368, 121, 4, 45, "Text"],
Cell[151810, 5374, 100, 2, 38, "Input"],
Cell[151913, 5378, 19, 0, 45, "Text"],
Cell[151935, 5380, 137, 3, 39, "Input"],
Cell[152075, 5385, 105, 3, 39, "Input"],
Cell[152183, 5390, 933, 29, 145, "Text"],
Cell[153119, 5421, 584, 17, 39, "Input",
  InitializationCell->True],
Cell[153706, 5440, 98, 1, 45, "Text"],
Cell[153807, 5443, 112, 3, 39, "Input"],

Cell[CellGroupData[{
Cell[153944, 5450, 72, 1, 57, "Subsubsection"],
Cell[154019, 5453, 408, 8, 111, "Input"],
Cell[154430, 5463, 96, 1, 45, "Text"],
Cell[154529, 5466, 145, 3, 39, "Input"],
Cell[154677, 5471, 275, 10, 45, "Text"],
Cell[154955, 5483, 133, 3, 39, "Input"],
Cell[155091, 5488, 413, 8, 111, "Input"],
Cell[155507, 5498, 145, 3, 39, "Input"],
Cell[155655, 5503, 258, 9, 45, "Text"],
Cell[155916, 5514, 133, 3, 39, "Input"],
Cell[156052, 5519, 86, 1, 45, "Text"],
Cell[156141, 5522, 434, 8, 111, "Input"],
Cell[156578, 5532, 304, 7, 70, "Text"],
Cell[156885, 5541, 136, 3, 39, "Input"],
Cell[157024, 5546, 99, 3, 39, "Input"],
Cell[157126, 5551, 129, 3, 39, "Input"],
Cell[157258, 5556, 163, 4, 45, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[157458, 5565, 134, 4, 35, "Subsubsection"],
Cell[157595, 5571, 355, 7, 70, "Text"],
Cell[157953, 5580, 224, 6, 70, "Input"],
Cell[158180, 5588, 103, 3, 70, "Input"],
Cell[158286, 5593, 244, 5, 70, "Text"],
Cell[158533, 5600, 164, 4, 70, "Input"],
Cell[158700, 5606, 107, 1, 70, "Text"],
Cell[158810, 5609, 182, 4, 70, "Input"],
Cell[158995, 5615, 107, 3, 70, "Input"],
Cell[159105, 5620, 197, 4, 70, "Input"],
Cell[159305, 5626, 108, 3, 70, "Input"],
Cell[159416, 5631, 190, 4, 70, "Input"],
Cell[159609, 5637, 82, 2, 70, "Input"],

Cell[CellGroupData[{
Cell[159716, 5643, 126, 3, 70, "Input",
  Evaluatable->False],
Cell[159845, 5648, 133, 4, 70, "Output"]
}, Closed]],
Cell[159993, 5655, 233, 5, 70, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[160275, 5666, 108, 1, 40, "Subsection"],
Cell[160386, 5669, 190, 6, 45, "Text"],
Cell[160579, 5677, 106, 3, 39, "Input"],
Cell[160688, 5682, 132, 4, 45, "Text"],
Cell[160823, 5688, 138, 3, 39, "Input"],
Cell[160964, 5693, 102, 3, 39, "Input"],
Cell[161069, 5698, 106, 3, 39, "Input"],
Cell[161178, 5703, 120, 3, 45, "Text"],
Cell[161301, 5708, 224, 6, 43, "Input"],
Cell[161528, 5716, 210, 5, 39, "Input"],
Cell[161741, 5723, 107, 3, 39, "Input"],
Cell[161851, 5728, 26, 0, 45, "Text"],
Cell[161880, 5730, 198, 4, 61, "Input"],
Cell[162081, 5736, 173, 4, 45, "Text"],
Cell[162257, 5742, 71, 2, 38, "Input"],
Cell[162331, 5746, 99, 2, 38, "Input"],
Cell[162433, 5750, 84, 2, 38, "Input"],
Cell[162520, 5754, 68, 2, 38, "Input"],
Cell[162591, 5758, 163, 4, 39, "Input"],
Cell[162757, 5764, 79, 2, 38, "Input"],
Cell[162839, 5768, 139, 4, 45, "Text"],
Cell[162981, 5774, 191, 6, 56, "Input"],
Cell[163175, 5782, 98, 1, 45, "Text"],
Cell[163276, 5785, 73, 1, 45, "Text"],
Cell[163352, 5788, 115, 2, 38, "Input"],
Cell[163470, 5792, 167, 4, 38, "Input"],
Cell[163640, 5798, 92, 2, 38, "Input"],
Cell[163735, 5802, 1275, 37, 220, "Text"],

Cell[CellGroupData[{
Cell[165035, 5843, 110, 1, 57, "Subsubsection"],
Cell[165148, 5846, 167, 4, 70, "Input"],
Cell[165318, 5852, 204, 6, 70, "Input"],
Cell[165525, 5860, 137, 3, 70, "Input"],
Cell[165665, 5865, 191, 5, 70, "Input"],
Cell[165859, 5872, 142, 3, 70, "Input"],
Cell[166004, 5877, 121, 3, 70, "Input"],
Cell[166128, 5882, 107, 3, 70, "Input"],
Cell[166238, 5887, 160, 4, 70, "Input"],
Cell[166401, 5893, 132, 3, 70, "Input"],
Cell[166536, 5898, 97, 3, 70, "Input"],
Cell[166636, 5903, 125, 3, 70, "Input"],
Cell[166764, 5908, 141, 4, 70, "Text"],
Cell[166908, 5914, 133, 3, 70, "Input"],
Cell[167044, 5919, 229, 5, 70, "Text"],
Cell[167276, 5926, 136, 3, 70, "Input"],
Cell[167415, 5931, 141, 3, 70, "Input"],
Cell[167559, 5936, 126, 4, 70, "Text"],
Cell[167688, 5942, 123, 3, 70, "Input"],
Cell[167814, 5947, 80, 1, 70, "Text"],
Cell[167897, 5950, 105, 3, 70, "Input"],
Cell[168005, 5955, 120, 3, 70, "Input"],
Cell[168128, 5960, 118, 3, 70, "Input"],
Cell[168249, 5965, 102, 3, 70, "Input"],
Cell[168354, 5970, 97, 2, 70, "Input"],
Cell[168454, 5974, 167, 4, 70, "Text"],
Cell[168624, 5980, 139, 3, 70, "Input"],
Cell[168766, 5985, 203, 5, 70, "Input"],
Cell[168972, 5992, 105, 3, 70, "Input"],
Cell[169080, 5997, 144, 4, 70, "Text"],
Cell[169227, 6003, 169, 4, 70, "Input"],
Cell[169399, 6009, 122, 3, 70, "Input"],
Cell[169524, 6014, 119, 3, 70, "Input"],
Cell[169646, 6019, 147, 4, 70, "Text"],
Cell[169796, 6025, 199, 5, 70, "Input"],
Cell[169998, 6032, 103, 3, 70, "Input"],
Cell[170104, 6037, 174, 4, 70, "Input"],
Cell[170281, 6043, 130, 4, 70, "Text"],
Cell[170414, 6049, 122, 3, 70, "Input"],
Cell[170539, 6054, 116, 3, 70, "Input"],
Cell[170658, 6059, 127, 3, 70, "Input"],
Cell[170788, 6064, 116, 3, 70, "Input"],
Cell[170907, 6069, 85, 1, 70, "Text"],
Cell[170995, 6072, 245, 6, 70, "Input"],
Cell[171243, 6080, 108, 3, 70, "Input"],
Cell[171354, 6085, 184, 4, 70, "Input"],
Cell[171541, 6091, 91, 1, 70, "Text"],
Cell[171635, 6094, 127, 3, 70, "Input"],
Cell[171765, 6099, 240, 5, 70, "Input"],
Cell[172008, 6106, 113, 3, 70, "Input"],
Cell[172124, 6111, 127, 3, 70, "Input"],
Cell[172254, 6116, 118, 3, 70, "Input"],
Cell[172375, 6121, 102, 3, 70, "Input"],
Cell[172480, 6126, 98, 3, 70, "Input"],
Cell[172581, 6131, 107, 3, 70, "Input"],
Cell[172691, 6136, 129, 3, 70, "Input"],
Cell[172823, 6141, 240, 5, 70, "Input"],
Cell[173066, 6148, 113, 3, 70, "Input"],
Cell[173182, 6153, 129, 3, 70, "Input"],
Cell[173314, 6158, 118, 3, 70, "Input"],
Cell[173435, 6163, 106, 3, 70, "Input"],
Cell[173544, 6168, 107, 3, 70, "Input"],
Cell[173654, 6173, 129, 3, 70, "Input"],
Cell[173786, 6178, 153, 4, 70, "Input"],
Cell[173942, 6184, 195, 4, 70, "Input"],
Cell[174140, 6190, 107, 3, 70, "Input"],

Cell[CellGroupData[{
Cell[174272, 6197, 122, 3, 70, "Input",
  Evaluatable->False],
Cell[174397, 6202, 132, 4, 70, "Output"]
}, Closed]],
Cell[174544, 6209, 75, 2, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[174656, 6216, 105, 1, 35, "Subsubsection"],
Cell[174764, 6219, 167, 4, 70, "Input"],
Cell[174934, 6225, 191, 5, 70, "Input"],
Cell[175128, 6232, 142, 3, 70, "Input"],
Cell[175273, 6237, 121, 3, 70, "Input"],
Cell[175397, 6242, 108, 3, 70, "Input"],
Cell[175508, 6247, 161, 4, 70, "Input"],
Cell[175672, 6253, 132, 3, 70, "Input"],
Cell[175807, 6258, 97, 3, 70, "Input"],
Cell[175907, 6263, 125, 3, 70, "Input"],
Cell[176035, 6268, 70, 1, 70, "Text"],
Cell[176108, 6271, 133, 3, 70, "Input"],
Cell[176244, 6276, 136, 3, 70, "Input"],
Cell[176383, 6281, 141, 3, 70, "Input"],
Cell[176527, 6286, 181, 4, 70, "Text"],
Cell[176711, 6292, 191, 4, 70, "Input"],
Cell[176905, 6298, 80, 1, 70, "Text"],
Cell[176988, 6301, 105, 3, 70, "Input"],
Cell[177096, 6306, 120, 3, 70, "Input"],
Cell[177219, 6311, 118, 3, 70, "Input"],
Cell[177340, 6316, 102, 3, 70, "Input"],
Cell[177445, 6321, 167, 4, 70, "Text"],
Cell[177615, 6327, 139, 3, 70, "Input"],
Cell[177757, 6332, 203, 5, 70, "Input"],
Cell[177963, 6339, 105, 3, 70, "Input"],
Cell[178071, 6344, 170, 4, 70, "Input"],
Cell[178244, 6350, 263, 6, 70, "Text"],
Cell[178510, 6358, 108, 3, 70, "Input"],
Cell[178621, 6363, 131, 3, 70, "Input"],
Cell[178755, 6368, 129, 3, 70, "Input"],
Cell[178887, 6373, 122, 3, 70, "Input"],
Cell[179012, 6378, 119, 3, 70, "Input"],
Cell[179134, 6383, 147, 4, 70, "Text"],
Cell[179284, 6389, 199, 5, 70, "Input"],
Cell[179486, 6396, 103, 3, 70, "Input"],
Cell[179592, 6401, 175, 4, 70, "Input"],
Cell[179770, 6407, 106, 3, 70, "Input"],

Cell[CellGroupData[{
Cell[179901, 6414, 120, 3, 70, "Input",
  Evaluatable->False],
Cell[180024, 6419, 131, 4, 70, "Output"]
}, Closed]],
Cell[180170, 6426, 505, 16, 70, "Text"],
Cell[180678, 6444, 114, 3, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[180829, 6452, 112, 1, 35, "Subsubsection"],
Cell[180944, 6455, 158, 4, 70, "Text"],
Cell[181105, 6461, 113, 3, 70, "Input"],
Cell[181221, 6466, 213, 4, 70, "Input"],
Cell[181437, 6472, 141, 4, 70, "Text"],
Cell[181581, 6478, 129, 3, 70, "Input"],
Cell[181713, 6483, 262, 5, 70, "Text"],
Cell[181978, 6490, 191, 5, 70, "Input"],
Cell[182172, 6497, 142, 3, 70, "Input"],
Cell[182317, 6502, 148, 4, 70, "Text"],
Cell[182468, 6508, 132, 3, 70, "Input"],
Cell[182603, 6513, 125, 3, 70, "Input"],
Cell[182731, 6518, 130, 3, 70, "Input"],
Cell[182864, 6523, 135, 3, 70, "Input"],
Cell[183002, 6528, 124, 3, 70, "Input"],
Cell[183129, 6533, 127, 3, 70, "Input"],
Cell[183259, 6538, 247, 6, 70, "Input"],
Cell[183509, 6546, 106, 3, 70, "Input"],
Cell[183618, 6551, 119, 3, 70, "Input"],
Cell[183740, 6556, 241, 6, 70, "Input"],
Cell[183984, 6564, 103, 3, 70, "Input"],
Cell[184090, 6569, 176, 4, 70, "Input"],
Cell[184269, 6575, 107, 3, 70, "Input"],

Cell[CellGroupData[{
Cell[184401, 6582, 124, 3, 70, "Input",
  Evaluatable->False],
Cell[184528, 6587, 132, 4, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[184721, 6598, 90, 1, 40, "Subsection"],
Cell[184814, 6601, 408, 8, 120, "Text"],
Cell[185225, 6611, 109, 2, 38, "Input"],
Cell[185337, 6615, 71, 2, 38, "Input"],
Cell[185411, 6619, 182, 4, 67, "Input"],
Cell[185596, 6625, 74, 2, 38, "Input"],
Cell[185673, 6629, 46, 0, 45, "Text"],
Cell[185722, 6631, 141, 3, 37, "Input",
  InitializationCell->True],
Cell[185866, 6636, 451, 10, 132, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[186342, 6650, 79, 1, 57, "Subsubsection"],
Cell[186424, 6653, 110, 3, 39, "Input"],
Cell[186537, 6658, 129, 3, 39, "Input"],
Cell[186669, 6663, 161, 4, 39, "Input"],
Cell[186833, 6669, 100, 2, 38, "Input"],
Cell[186936, 6673, 70, 2, 38, "Input"],
Cell[187009, 6677, 100, 2, 38, "Input"],
Cell[187112, 6681, 70, 2, 38, "Input"],
Cell[187185, 6685, 102, 2, 38, "Input"],
Cell[187290, 6689, 19, 0, 45, "Text"],
Cell[187312, 6691, 96, 3, 45, "Text"],
Cell[187411, 6696, 110, 3, 39, "Input"],
Cell[187524, 6701, 110, 3, 39, "Input"],
Cell[187637, 6706, 110, 3, 39, "Input"],
Cell[187750, 6711, 100, 3, 39, "Input"],
Cell[187853, 6716, 115, 3, 39, "Input"],
Cell[187971, 6721, 115, 3, 39, "Input"],
Cell[188089, 6726, 135, 3, 39, "Input"],
Cell[188227, 6731, 107, 3, 39, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[188371, 6739, 80, 1, 35, "Subsubsection"],
Cell[188454, 6742, 104, 1, 45, "Text"],
Cell[188561, 6745, 130, 2, 37, "Input"],
Cell[188694, 6749, 123, 4, 45, "Text"],
Cell[188820, 6755, 169, 4, 39, "Input"],
Cell[188992, 6761, 135, 3, 39, "Input"],
Cell[189130, 6766, 140, 3, 39, "Input"],
Cell[189273, 6771, 142, 3, 39, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[189452, 6779, 92, 1, 57, "Subsubsection"],
Cell[189547, 6782, 139, 3, 39, "Input"],
Cell[189689, 6787, 119, 3, 39, "Input"],
Cell[189811, 6792, 175, 4, 45, "Text"],
Cell[189989, 6798, 185, 5, 66, "Input"],
Cell[190177, 6805, 143, 4, 45, "Text"],
Cell[190323, 6811, 125, 3, 39, "Input"],
Cell[190451, 6816, 166, 4, 39, "Input"],
Cell[190620, 6822, 130, 3, 39, "Input"],
Cell[190753, 6827, 99, 1, 45, "Text"],
Cell[190855, 6830, 141, 3, 39, "Input"],
Cell[190999, 6835, 151, 4, 45, "Text"],
Cell[191153, 6841, 144, 3, 39, "Input"],
Cell[191300, 6846, 148, 3, 39, "Input"],
Cell[191451, 6851, 91, 2, 38, "Input"],
Cell[191545, 6855, 69, 2, 38, "Input"],
Cell[191617, 6859, 72, 2, 38, "Input"],
Cell[191692, 6863, 102, 2, 38, "Input"],
Cell[191797, 6867, 72, 2, 38, "Input"],
Cell[191872, 6871, 96, 2, 38, "Input"],
Cell[191971, 6875, 101, 2, 38, "Input"],
Cell[192075, 6879, 76, 2, 38, "Input"],
Cell[192154, 6883, 127, 3, 38, "Input"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[192342, 6893, 116, 4, 41, "Section"],

Cell[CellGroupData[{
Cell[192483, 6901, 81, 1, 68, "Subsection"],
Cell[192567, 6904, 1273, 26, 245, "Text"],
Cell[193843, 6932, 494, 13, 39, "Input",
  InitializationCell->True],
Cell[194340, 6947, 128, 4, 45, "Text"],
Cell[194471, 6953, 492, 13, 39, "Input",
  InitializationCell->True],
Cell[194966, 6968, 70, 2, 38, "Input"],
Cell[195039, 6972, 73, 2, 38, "Input"],

Cell[CellGroupData[{
Cell[195137, 6978, 43, 0, 57, "Subsubsection"],
Cell[195183, 6980, 147, 4, 45, "Text"],
Cell[195333, 6986, 127, 3, 39, "Input"],
Cell[195463, 6991, 100, 3, 39, "Input"],
Cell[195566, 6996, 109, 3, 39, "Input"],
Cell[195678, 7001, 108, 3, 39, "Input"],
Cell[195789, 7006, 168, 4, 39, "Input"],
Cell[195960, 7012, 167, 4, 39, "Input"],
Cell[196130, 7018, 161, 6, 45, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[196340, 7030, 50, 0, 40, "Subsection"],
Cell[196393, 7032, 49, 0, 45, "Text"],
Cell[196445, 7034, 76, 2, 38, "Input"],
Cell[196524, 7038, 83, 2, 38, "Input"],
Cell[196610, 7042, 43, 0, 45, "Text"],
Cell[196656, 7044, 83, 2, 38, "Input"],
Cell[196742, 7048, 46, 0, 45, "Text"],
Cell[196791, 7050, 85, 2, 38, "Input"],
Cell[196879, 7054, 48, 0, 45, "Text"],
Cell[196930, 7056, 90, 2, 38, "Input"],
Cell[197023, 7060, 96, 2, 38, "Input"],
Cell[197122, 7064, 90, 2, 38, "Input"],
Cell[197215, 7068, 90, 2, 38, "Input"],
Cell[197308, 7072, 96, 2, 38, "Input"],
Cell[197407, 7076, 631, 12, 170, "Text"],
Cell[198041, 7090, 156, 4, 45, "Text"],
Cell[198200, 7096, 94, 2, 38, "Input",
  InitializationCell->True],
Cell[198297, 7100, 146, 4, 38, "Input",
  InitializationCell->True],
Cell[198446, 7106, 94, 2, 38, "Input",
  InitializationCell->True],
Cell[198543, 7110, 146, 4, 38, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[198726, 7119, 60, 0, 40, "Subsection"],

Cell[CellGroupData[{
Cell[198811, 7123, 38, 0, 57, "Subsubsection"],
Cell[198852, 7125, 107, 3, 45, "Text"],
Cell[198962, 7130, 106, 2, 38, "Input"],
Cell[199071, 7134, 125, 3, 38, "Input"],
Cell[199199, 7139, 123, 3, 45, "Text"],
Cell[199325, 7144, 90, 2, 38, "Input"],
Cell[199418, 7148, 96, 2, 38, "Input"],
Cell[199517, 7152, 96, 2, 38, "Input"],
Cell[199616, 7156, 90, 2, 38, "Input"],
Cell[199709, 7160, 90, 2, 38, "Input"],
Cell[199802, 7164, 70, 2, 38, "Input"],
Cell[199875, 7168, 68, 2, 38, "Input"],
Cell[199946, 7172, 120, 3, 45, "Text"],
Cell[200069, 7177, 154, 3, 70, "Text"],
Cell[200226, 7182, 72, 2, 38, "Input"],
Cell[200301, 7186, 72, 2, 38, "Input"],
Cell[200376, 7190, 72, 2, 38, "Input"],
Cell[200451, 7194, 72, 2, 38, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[200560, 7201, 44, 0, 35, "Subsubsection"],
Cell[200607, 7203, 83, 2, 38, "Input"],
Cell[200693, 7207, 89, 2, 38, "Input"],
Cell[200785, 7211, 72, 2, 38, "Input"],
Cell[200860, 7215, 75, 2, 38, "Input"],
Cell[200938, 7219, 200, 4, 38, "Input"],
Cell[201141, 7225, 132, 4, 66, "Input"],
Cell[201276, 7231, 71, 2, 38, "Input"],
Cell[201350, 7235, 86, 2, 38, "Input"],
Cell[201439, 7239, 70, 2, 38, "Input"],
Cell[201512, 7243, 73, 2, 38, "Input"],
Cell[201588, 7247, 195, 5, 90, "Input"],
Cell[201786, 7254, 200, 4, 38, "Input"],
Cell[201989, 7260, 255, 5, 107, "Input"],
Cell[202247, 7267, 70, 2, 38, "Input"],
Cell[202320, 7271, 238, 5, 61, "Input"],
Cell[202561, 7278, 79, 2, 38, "Input"],
Cell[202643, 7282, 200, 4, 38, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[202880, 7291, 44, 0, 35, "Subsubsection"],
Cell[202927, 7293, 83, 2, 38, "Input"],
Cell[203013, 7297, 89, 2, 38, "Input"],
Cell[203105, 7301, 75, 2, 38, "Input"],
Cell[203183, 7305, 72, 2, 38, "Input"],
Cell[203258, 7309, 194, 4, 61, "Input"],
Cell[203455, 7315, 79, 1, 42, "Input"],
Cell[203537, 7318, 98, 3, 42, "Input"],
Cell[203638, 7323, 86, 2, 38, "Input"],
Cell[203727, 7327, 78, 2, 38, "Input"],
Cell[203808, 7331, 212, 5, 61, "Input"],
Cell[204023, 7338, 135, 4, 66, "Input"],
Cell[204161, 7344, 71, 2, 38, "Input"],
Cell[204235, 7348, 78, 2, 38, "Input"],
Cell[204316, 7352, 243, 4, 64, "Input"],
Cell[204562, 7358, 200, 4, 38, "Input"],
Cell[204765, 7364, 299, 6, 118, "Input"],
Cell[205067, 7372, 70, 2, 38, "Input"],
Cell[205140, 7376, 180, 5, 90, "Input"],
Cell[205323, 7383, 79, 2, 38, "Input"],
Cell[205405, 7387, 200, 4, 38, "Input"],
Cell[205608, 7393, 79, 2, 38, "Input"],
Cell[205690, 7397, 200, 4, 38, "Input"],
Cell[205893, 7403, 19, 0, 45, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[205949, 7408, 44, 0, 35, "Subsubsection"],
Cell[205996, 7410, 85, 2, 38, "Input"],
Cell[206084, 7414, 87, 2, 38, "Input"],
Cell[206174, 7418, 72, 2, 38, "Input"],
Cell[206249, 7422, 75, 2, 38, "Input"],
Cell[206327, 7426, 200, 4, 38, "Input"],
Cell[206530, 7432, 78, 2, 38, "Input"],
Cell[206611, 7436, 211, 5, 90, "Input"],
Cell[206825, 7443, 71, 2, 38, "Input"],
Cell[206899, 7447, 78, 2, 38, "Input"],
Cell[206980, 7451, 212, 5, 61, "Input"],
Cell[207195, 7458, 270, 6, 114, "Input"],
Cell[207468, 7466, 79, 2, 38, "Input"],
Cell[207550, 7470, 200, 4, 38, "Input"],
Cell[207753, 7476, 79, 2, 38, "Input"],
Cell[207835, 7480, 200, 4, 38, "Input"],
Cell[208038, 7486, 79, 2, 38, "Input"],
Cell[208120, 7490, 200, 4, 38, "Input"],
Cell[208323, 7496, 19, 0, 45, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[208379, 7501, 44, 0, 35, "Subsubsection"],
Cell[208426, 7503, 93, 3, 45, "Text"],
Cell[208522, 7508, 101, 2, 38, "Input"],
Cell[208626, 7512, 200, 4, 38, "Input"],
Cell[208829, 7518, 270, 6, 114, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[209136, 7529, 62, 0, 35, "Subsubsection"],
Cell[209201, 7531, 80, 2, 38, "Input"],
Cell[209284, 7535, 70, 2, 38, "Input"],
Cell[209357, 7539, 200, 4, 61, "Input"],
Cell[209560, 7545, 136, 4, 38, "Input"],
Cell[209699, 7551, 200, 4, 61, "Input"],
Cell[209902, 7557, 150, 3, 70, "Text"],
Cell[210055, 7562, 334, 6, 130, "Input",
  Evaluatable->False],
Cell[210392, 7570, 1015, 19, 306, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[211456, 7595, 57, 0, 40, "Subsection"],
Cell[211516, 7597, 474, 16, 70, "Text"],
Cell[211993, 7615, 108, 2, 38, "Input"],
Cell[212104, 7619, 33, 0, 45, "Text"],
Cell[212140, 7621, 106, 2, 38, "Input"],
Cell[212249, 7625, 125, 3, 38, "Input"],
Cell[212377, 7630, 102, 2, 38, "Input"],
Cell[212482, 7634, 72, 2, 38, "Input"],
Cell[212557, 7638, 200, 4, 38, "Input"],
Cell[212760, 7644, 185, 4, 70, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[212982, 7653, 50, 0, 40, "Subsection"],
Cell[213035, 7655, 107, 2, 38, "Input"],
Cell[213145, 7659, 33, 0, 45, "Text"],
Cell[213181, 7661, 105, 2, 38, "Input"],
Cell[213289, 7665, 124, 3, 38, "Input"],
Cell[213416, 7670, 106, 3, 45, "Text"],
Cell[213525, 7675, 84, 2, 38, "Input"],
Cell[213612, 7679, 190, 4, 70, "Text"],
Cell[213805, 7685, 114, 2, 38, "Input"],
Cell[213922, 7689, 55, 0, 45, "Text"],
Cell[213980, 7691, 79, 2, 38, "Input"],
Cell[214062, 7695, 203, 4, 61, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[214302, 7704, 60, 0, 40, "Subsection"],
Cell[214365, 7706, 297, 5, 95, "Text"],
Cell[214665, 7713, 184, 4, 40, "Input",
  Evaluatable->False],
Cell[214852, 7719, 170, 4, 70, "Text"],
Cell[215025, 7725, 314, 5, 40, "Input",
  Evaluatable->False],
Cell[215342, 7732, 92, 3, 45, "Text"],
Cell[215437, 7737, 80, 2, 38, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[215554, 7744, 67, 0, 40, "Subsection"],
Cell[215624, 7746, 107, 2, 38, "Input"],
Cell[215734, 7750, 33, 0, 45, "Text"],
Cell[215770, 7752, 105, 2, 38, "Input"],
Cell[215878, 7756, 124, 3, 38, "Input"],
Cell[216005, 7761, 134, 5, 45, "Text"],
Cell[216142, 7768, 75, 2, 38, "Input"],
Cell[216220, 7772, 148, 4, 38, "Input"],
Cell[216371, 7778, 107, 2, 38, "Input"],
Cell[216481, 7782, 33, 0, 45, "Text"],
Cell[216517, 7784, 105, 2, 38, "Input"],
Cell[216625, 7788, 124, 3, 38, "Input"],
Cell[216752, 7793, 304, 6, 84, "Input"],
Cell[217059, 7801, 143, 3, 45, "Text"],
Cell[217205, 7806, 101, 2, 38, "Input"],
Cell[217309, 7810, 138, 3, 45, "Text"],
Cell[217450, 7815, 147, 3, 40, "Input",
  Evaluatable->False],
Cell[217600, 7820, 24, 0, 45, "Text"],
Cell[217627, 7822, 135, 3, 40, "Input",
  Evaluatable->False],
Cell[217765, 7827, 91, 3, 45, "Text"],
Cell[217859, 7832, 79, 1, 38, "Input"],
Cell[217941, 7835, 75, 0, 45, "Text"],
Cell[218019, 7837, 87, 1, 38, "Input"],
Cell[218109, 7840, 110, 3, 45, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[218268, 7849, 28, 0, 66, "Subtitle"],

Cell[CellGroupData[{
Cell[218321, 7853, 76, 1, 69, "Section"],
Cell[218400, 7856, 302, 7, 70, "Text"],

Cell[CellGroupData[{
Cell[218727, 7867, 71, 1, 70, "Subsection"],
Cell[218801, 7870, 305, 7, 70, "Text",
  Evaluatable->False],
Cell[219109, 7879, 203, 5, 70, "Text",
  Evaluatable->False],
Cell[219315, 7886, 175, 4, 70, "Input",
  InitializationCell->True],
Cell[219493, 7892, 82, 2, 70, "Input"],
Cell[219578, 7896, 171, 5, 70, "Text",
  Evaluatable->False],
Cell[219752, 7903, 126, 3, 70, "Input",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[219915, 7911, 89, 2, 70, "Subsection",
  CellTags->"MathGL"],
Cell[220007, 7915, 836, 19, 70, "Text"],
Cell[220846, 7936, 149, 4, 70, "Input",
  CellTags->"getMGL3D"],
Cell[220998, 7942, 219, 5, 70, "Text"],
Cell[221220, 7949, 143, 3, 70, "Input"],
Cell[221366, 7954, 85, 1, 70, "Text"],
Cell[221454, 7957, 58, 1, 70, "Text"],
Cell[221515, 7960, 174, 4, 70, "Text"],
Cell[221692, 7966, 503, 10, 70, "Input"],
Cell[222198, 7978, 141, 3, 70, "Input"],
Cell[222342, 7983, 110, 2, 70, "Input"],
Cell[222455, 7987, 111, 2, 70, "Input"],
Cell[222569, 7991, 81, 2, 70, "Input"],
Cell[222653, 7995, 83, 2, 70, "Input"],
Cell[222739, 7999, 101, 3, 70, "Input"],
Cell[222843, 8004, 190, 4, 70, "Text"],
Cell[223036, 8010, 103, 3, 70, "Input"],
Cell[223142, 8015, 73, 1, 70, "Text"],
Cell[223218, 8018, 143, 3, 70, "Input"],
Cell[223364, 8023, 253, 5, 70, "Text"],

Cell[CellGroupData[{
Cell[223642, 8032, 99, 1, 70, "Subsubsection",
  CellTags->"equipict"],
Cell[223744, 8035, 162, 4, 70, "Text"],
Cell[223909, 8041, 141, 3, 70, "Input"],
Cell[224053, 8046, 101, 3, 70, "Input"],
Cell[224157, 8051, 104, 3, 70, "Input"],
Cell[224264, 8056, 130, 3, 70, "Input"],
Cell[224397, 8061, 145, 3, 70, "Input"],
Cell[224545, 8066, 181, 5, 70, "Input"],
Cell[224729, 8073, 147, 3, 70, "Input"],
Cell[224879, 8078, 103, 3, 70, "Input"],
Cell[224985, 8083, 117, 3, 70, "Input"],
Cell[225105, 8088, 112, 3, 70, "Input"],
Cell[225220, 8093, 145, 3, 70, "Input"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[225426, 8103, 32, 0, 41, "Section"],
Cell[225461, 8105, 186, 5, 45, "Text",
  Evaluatable->False],
Cell[225650, 8112, 106, 3, 39, "Input"],
Cell[225759, 8117, 110, 3, 39, "Input"],
Cell[225872, 8122, 120, 4, 45, "Text"],
Cell[225995, 8128, 99, 3, 39, "Input"],
Cell[226097, 8133, 65, 2, 38, "Input"],
Cell[226165, 8137, 356, 7, 95, "Text",
  Evaluatable->False],
Cell[226524, 8146, 81, 2, 38, "Input"],
Cell[226608, 8150, 96, 2, 38, "Input"],
Cell[226707, 8154, 524, 11, 120, "Text"],

Cell[CellGroupData[{
Cell[227256, 8169, 96, 1, 57, "Subsubsection"],
Cell[227355, 8172, 1423, 34, 111, "Input"],
Cell[228781, 8208, 90, 1, 45, "Text"],
Cell[228874, 8211, 1524, 32, 111, "Input"],
Cell[230401, 8245, 87, 2, 38, "Input"],
Cell[230491, 8249, 130, 3, 39, "Input"],
Cell[230624, 8254, 98, 3, 39, "Input"],
Cell[230725, 8259, 117, 3, 39, "Input"],
Cell[230845, 8264, 125, 3, 39, "Input"],
Cell[230973, 8269, 154, 4, 39, "Input"],
Cell[231130, 8275, 79, 2, 38, "Input"],
Cell[231212, 8279, 83, 2, 38, "Input"],
Cell[231298, 8283, 142, 3, 39, "Input"],
Cell[231443, 8288, 96, 2, 39, "Input"],
Cell[231542, 8292, 98, 2, 39, "Input"],
Cell[231643, 8296, 107, 2, 39, "Input"],
Cell[231753, 8300, 77, 2, 38, "Input"],
Cell[231833, 8304, 83, 2, 38, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[231953, 8311, 105, 1, 35, "Subsubsection"],
Cell[232061, 8314, 279, 5, 63, "Input"],
Cell[232343, 8321, 90, 1, 45, "Text"],
Cell[232436, 8324, 310, 6, 63, "Input"],
Cell[232749, 8332, 132, 3, 39, "Input"],
Cell[232884, 8337, 134, 3, 39, "Input"],
Cell[233021, 8342, 128, 3, 39, "Input"],
Cell[233152, 8347, 164, 4, 39, "Input"],
Cell[233319, 8353, 104, 3, 39, "Input"],
Cell[233426, 8358, 104, 3, 39, "Input"],
Cell[233533, 8363, 105, 3, 39, "Input"],
Cell[233641, 8368, 102, 3, 39, "Input"],
Cell[233746, 8373, 102, 3, 39, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[233885, 8381, 77, 1, 35, "Subsubsection"],
Cell[233965, 8384, 1040, 25, 87, "Input"],
Cell[235008, 8411, 90, 1, 45, "Text"],
Cell[235101, 8414, 988, 20, 87, "Input"],
Cell[236092, 8436, 113, 3, 39, "Input"],
Cell[236208, 8441, 135, 3, 39, "Input"],
Cell[236346, 8446, 173, 4, 39, "Input"],
Cell[236522, 8452, 409, 11, 39, "Input"],
Cell[236934, 8465, 622, 17, 39, "Input"],
Cell[237559, 8484, 86, 2, 39, "Input"],
Cell[237648, 8488, 133, 3, 39, "Input"],
Cell[237784, 8493, 167, 4, 39, "Input"],
Cell[237954, 8499, 98, 2, 39, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[238089, 8506, 76, 1, 35, "Subsubsection"],
Cell[238168, 8509, 136, 4, 45, "Text"],
Cell[238307, 8515, 1474, 36, 111, "Input"],
Cell[239784, 8553, 90, 1, 45, "Text"],
Cell[239877, 8556, 1610, 32, 135, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[241524, 8593, 45, 0, 35, "Subsubsection"],
Cell[241572, 8595, 103, 3, 45, "Text"],
Cell[241678, 8600, 102, 2, 38, "Input"],
Cell[241783, 8604, 90, 1, 45, "Text"],
Cell[241876, 8607, 1358, 28, 130, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[243283, 8641, 65, 1, 41, "Section"],

Cell[CellGroupData[{
Cell[243373, 8646, 90, 1, 57, "Subsubsection"],
Cell[243466, 8649, 154, 4, 70, "Input",
  Evaluatable->False],
Cell[243623, 8655, 100, 3, 70, "Input"],
Cell[243726, 8660, 96, 3, 70, "Input"],
Cell[243825, 8665, 138, 3, 70, "Input",
  Evaluatable->False],
Cell[243966, 8670, 101, 3, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[244104, 8678, 91, 1, 35, "Subsubsection"],
Cell[244198, 8681, 152, 4, 70, "Text"],
Cell[244353, 8687, 101, 3, 70, "Input"],
Cell[244457, 8692, 105, 3, 70, "Input"],
Cell[244565, 8697, 251, 6, 70, "Input",
  Evaluatable->False],
Cell[244819, 8705, 126, 3, 70, "Input"],
Cell[244948, 8710, 126, 3, 70, "Input"],
Cell[245077, 8715, 139, 3, 70, "Input"],
Cell[245219, 8720, 126, 3, 70, "Input"],
Cell[245348, 8725, 366, 10, 70, "Input",
  InitializationCell->True],
Cell[245717, 8737, 124, 3, 70, "Input"],
Cell[245844, 8742, 128, 3, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[246009, 8750, 82, 1, 35, "Subsubsection"],
Cell[246094, 8753, 97, 1, 70, "Text"],
Cell[246194, 8756, 106, 3, 70, "Input"],
Cell[246303, 8761, 113, 3, 70, "Text"],
Cell[246419, 8766, 119, 3, 70, "Input"],
Cell[246541, 8771, 127, 4, 70, "Text"],
Cell[246671, 8777, 123, 3, 70, "Input"],
Cell[246797, 8782, 150, 3, 70, "Input"],
Cell[246950, 8787, 75, 1, 70, "Text"],
Cell[247028, 8790, 119, 3, 70, "Input"],
Cell[247150, 8795, 143, 3, 70, "Input"],
Cell[247296, 8800, 109, 3, 70, "Input"],
Cell[247408, 8805, 127, 3, 70, "Input"],
Cell[247538, 8810, 131, 3, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[247706, 8818, 83, 1, 35, "Subsubsection"],
Cell[247792, 8821, 165, 5, 70, "Text",
  Evaluatable->False],
Cell[247960, 8828, 1105, 30, 70, "Input",
  InitializationCell->True],
Cell[249068, 8860, 196, 5, 70, "Text",
  Evaluatable->False],
Cell[249267, 8867, 57, 1, 70, "Text"],
Cell[249327, 8870, 129, 3, 70, "Input"],
Cell[249459, 8875, 123, 3, 70, "Input"],
Cell[249585, 8880, 117, 3, 70, "Input"],
Cell[249705, 8885, 261, 6, 70, "Input"],
Cell[249969, 8893, 108, 3, 70, "Input"],
Cell[250080, 8898, 162, 4, 70, "Text"],
Cell[250245, 8904, 131, 3, 70, "Input"],
Cell[250379, 8909, 130, 3, 70, "Input"],
Cell[250512, 8914, 131, 3, 70, "Input"],
Cell[250646, 8919, 130, 3, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[250813, 8927, 67, 1, 35, "Subsubsection"],
Cell[250883, 8930, 327, 8, 70, "Text"],
Cell[251213, 8940, 219, 5, 70, "Input",
  Evaluatable->False]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[251481, 8951, 28, 0, 41, "Section"],

Cell[CellGroupData[{
Cell[251534, 8955, 52, 0, 68, "Subsection"],

Cell[CellGroupData[{
Cell[251611, 8959, 124, 2, 70, "Subsubsection",
  CellTags->"crtest"],
Cell[251738, 8963, 120, 3, 70, "Input"],
Cell[251861, 8968, 127, 4, 70, "Text"],
Cell[251991, 8974, 130, 3, 70, "Input"],
Cell[252124, 8979, 134, 3, 70, "Input"],
Cell[252261, 8984, 105, 1, 70, "Text"],
Cell[252369, 8987, 131, 3, 70, "Input"],
Cell[252503, 8992, 87, 2, 70, "Input"],
Cell[252593, 8996, 87, 2, 70, "Input"],
Cell[252683, 9000, 85, 2, 70, "Input"],
Cell[252771, 9004, 66, 2, 70, "Input"],
Cell[252840, 9008, 74, 2, 70, "Input"],
Cell[252917, 9012, 167, 4, 70, "Input"],
Cell[253087, 9018, 103, 3, 70, "Input"],
Cell[253193, 9023, 80, 1, 70, "Text"],
Cell[253276, 9026, 107, 3, 70, "Input"],
Cell[253386, 9031, 65, 1, 70, "Text"],
Cell[253454, 9034, 177, 4, 70, "Input"],
Cell[253634, 9040, 100, 3, 70, "Input"],
Cell[253737, 9045, 111, 3, 70, "Input"],
Cell[253851, 9050, 107, 3, 70, "Input"],
Cell[253961, 9055, 126, 3, 70, "Input"],
Cell[254090, 9060, 74, 2, 70, "Input"],
Cell[254167, 9064, 105, 3, 70, "Input"],
Cell[254275, 9069, 126, 3, 70, "Input"],
Cell[254404, 9074, 137, 3, 70, "Input"],
Cell[254544, 9079, 118, 3, 70, "Input"],
Cell[254665, 9084, 116, 3, 70, "Input"],
Cell[254784, 9089, 115, 3, 70, "Input"],
Cell[254902, 9094, 144, 3, 70, "Input"],
Cell[255049, 9099, 88, 1, 70, "Text"],
Cell[255140, 9102, 107, 3, 70, "Input"],
Cell[255250, 9107, 66, 1, 70, "Text"],
Cell[255319, 9110, 105, 3, 70, "Input"],
Cell[255427, 9115, 103, 3, 70, "Input"],
Cell[255533, 9120, 140, 3, 70, "Input"],
Cell[255676, 9125, 107, 3, 70, "Input"],
Cell[255786, 9130, 83, 1, 70, "Text"],
Cell[255872, 9133, 140, 3, 70, "Input"],
Cell[256015, 9138, 121, 4, 70, "Text"],
Cell[256139, 9144, 107, 3, 70, "Input"],
Cell[256249, 9149, 74, 1, 70, "Text"],
Cell[256326, 9152, 104, 3, 70, "Input"],
Cell[256433, 9157, 119, 3, 70, "Input"],
Cell[256555, 9162, 129, 3, 70, "Input"],
Cell[256687, 9167, 125, 3, 70, "Input"],
Cell[256815, 9172, 78, 1, 70, "Text"],
Cell[256896, 9175, 128, 3, 70, "Input"],
Cell[257027, 9180, 103, 3, 70, "Input"],
Cell[257133, 9185, 72, 1, 70, "Text"],
Cell[257208, 9188, 107, 3, 70, "Input"],
Cell[257318, 9193, 99, 3, 70, "Input"],
Cell[257420, 9198, 119, 3, 70, "Input"],
Cell[257542, 9203, 107, 3, 70, "Input"],
Cell[257652, 9208, 115, 2, 70, "Input"],
Cell[257770, 9212, 70, 2, 70, "Input"],
Cell[257843, 9216, 66, 1, 70, "Text"],
Cell[257912, 9219, 131, 3, 70, "Input"],
Cell[258046, 9224, 141, 3, 70, "Input"],
Cell[258190, 9229, 128, 3, 70, "Input"],
Cell[258321, 9234, 133, 3, 70, "Input"],
Cell[258457, 9239, 103, 3, 70, "Input"],
Cell[258563, 9244, 118, 3, 70, "Input"],
Cell[258684, 9249, 126, 3, 70, "Input"],
Cell[258813, 9254, 122, 3, 70, "Input"],
Cell[258938, 9259, 94, 2, 70, "Input"],
Cell[259035, 9263, 70, 2, 70, "Input"],
Cell[259108, 9267, 74, 2, 70, "Input"],
Cell[259185, 9271, 132, 3, 70, "Input"],
Cell[259320, 9276, 126, 3, 70, "Input"],
Cell[259449, 9281, 103, 3, 70, "Input"],
Cell[259555, 9286, 100, 3, 70, "Input"],
Cell[259658, 9291, 110, 3, 70, "Input"],
Cell[259771, 9296, 131, 3, 70, "Input"],
Cell[259905, 9301, 104, 3, 70, "Input"],
Cell[260012, 9306, 140, 3, 70, "Input"],
Cell[260155, 9311, 107, 3, 70, "Input"],
Cell[260265, 9316, 123, 4, 70, "Text"],
Cell[260391, 9322, 127, 3, 70, "Input"],
Cell[260521, 9327, 103, 3, 70, "Input"],
Cell[260627, 9332, 61, 1, 70, "Text"],
Cell[260691, 9335, 134, 3, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[260862, 9343, 102, 2, 70, "Subsubsection",
  CellTags->"riemT"],
Cell[260967, 9347, 105, 3, 70, "Input"],
Cell[261075, 9352, 107, 3, 70, "Input"],
Cell[261185, 9357, 116, 3, 70, "Input"],
Cell[261304, 9362, 107, 3, 70, "Input"],
Cell[261414, 9367, 102, 3, 70, "Input"],
Cell[261519, 9372, 107, 3, 70, "Input"],
Cell[261629, 9377, 100, 3, 70, "Input"],
Cell[261732, 9382, 108, 3, 70, "Input"],
Cell[261843, 9387, 108, 3, 70, "Input"],
Cell[261954, 9392, 112, 3, 70, "Input"],
Cell[262069, 9397, 108, 3, 70, "Input"],
Cell[262180, 9402, 104, 3, 70, "Input"],
Cell[262287, 9407, 107, 3, 70, "Input"],
Cell[262397, 9412, 130, 3, 70, "Input"],
Cell[262530, 9417, 128, 3, 70, "Input"],
Cell[262661, 9422, 107, 3, 70, "Input"],
Cell[262771, 9427, 103, 3, 70, "Input"],
Cell[262877, 9432, 105, 3, 70, "Input"],
Cell[262985, 9437, 116, 3, 70, "Input"],
Cell[263104, 9442, 116, 3, 70, "Input"],
Cell[263223, 9447, 126, 3, 70, "Input"],
Cell[263352, 9452, 116, 3, 70, "Input"],
Cell[263471, 9457, 121, 3, 70, "Input"],
Cell[263595, 9462, 131, 3, 70, "Input"],
Cell[263729, 9467, 131, 3, 70, "Input"],
Cell[263863, 9472, 116, 3, 70, "Input"],
Cell[263982, 9477, 126, 3, 70, "Input"],
Cell[264111, 9482, 126, 3, 70, "Input"],
Cell[264240, 9487, 136, 3, 70, "Input"],
Cell[264379, 9492, 128, 3, 70, "Input"],
Cell[264510, 9497, 138, 3, 70, "Input"],
Cell[264651, 9502, 102, 3, 70, "Input"],
Cell[264756, 9507, 103, 3, 70, "Input"],
Cell[264862, 9512, 120, 3, 70, "Input"],
Cell[264985, 9517, 111, 3, 70, "Input"],
Cell[265099, 9522, 103, 3, 70, "Input"],
Cell[265205, 9527, 107, 3, 70, "Input"],
Cell[265315, 9532, 154, 4, 70, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[265518, 9542, 103, 1, 57, "Subsection",
  CellTags->"spectrans"],
Cell[265624, 9545, 147, 5, 45, "Text"],
Cell[265774, 9552, 133, 3, 39, "Input"],
Cell[265910, 9557, 186, 4, 39, "Input"],
Cell[266099, 9563, 71, 2, 38, "Input"],
Cell[266173, 9567, 87, 2, 38, "Input"],
Cell[266263, 9571, 69, 2, 38, "Input"],
Cell[266335, 9575, 114, 2, 45, "Text"],
Cell[266452, 9579, 234, 4, 63, "Input"],
Cell[266689, 9585, 77, 2, 39, "Input"],
Cell[266769, 9589, 82, 2, 39, "Input"],
Cell[266854, 9593, 77, 2, 39, "Input"],
Cell[266934, 9597, 80, 2, 39, "Input"],
Cell[267017, 9601, 77, 2, 39, "Input"],
Cell[267097, 9605, 82, 2, 39, "Input"],
Cell[267182, 9609, 191, 3, 63, "Input"],
Cell[267376, 9614, 196, 3, 63, "Input"],
Cell[267575, 9619, 191, 3, 63, "Input"],
Cell[267769, 9624, 191, 3, 63, "Input"],
Cell[267963, 9629, 196, 3, 63, "Input"],
Cell[268162, 9634, 196, 3, 63, "Input"],
Cell[268361, 9639, 180, 4, 39, "Input"],
Cell[268544, 9645, 180, 4, 39, "Input"],
Cell[268727, 9651, 123, 2, 39, "Input"],
Cell[268853, 9655, 141, 3, 39, "Input"],
Cell[268997, 9660, 81, 2, 39, "Input"],
Cell[269081, 9664, 111, 2, 45, "Text"],
Cell[269195, 9668, 390, 9, 63, "Input"],
Cell[269588, 9679, 295, 8, 39, "Input"],
Cell[269886, 9689, 112, 2, 45, "Text"],
Cell[270001, 9693, 218, 4, 63, "Input"],
Cell[270222, 9699, 109, 2, 39, "Input"],
Cell[270334, 9703, 109, 2, 45, "Text"],
Cell[270446, 9707, 246, 5, 63, "Input"],
Cell[270695, 9714, 110, 2, 45, "Text"],
Cell[270808, 9718, 208, 4, 39, "Input"],
Cell[271019, 9724, 114, 3, 39, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[271182, 9733, 99, 2, 58, "Section",
  CellTags->"Declare"],
Cell[271284, 9737, 372, 6, 70, "Text"],

Cell[CellGroupData[{
Cell[271681, 9747, 45, 0, 70, "Subsection"],
Cell[271729, 9749, 841, 14, 70, "Text"],
Cell[272573, 9765, 243, 5, 70, "Input",
  Evaluatable->False],
Cell[272819, 9772, 192, 5, 70, "Input",
  Evaluatable->False],
Cell[273014, 9779, 183, 4, 70, "Text"],
Cell[273200, 9785, 126, 3, 70, "Input",
  Evaluatable->False],
Cell[273329, 9790, 66, 1, 70, "Text"],
Cell[273398, 9793, 137, 3, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[273572, 9801, 32, 0, 70, "Subsection"],

Cell[CellGroupData[{
Cell[273629, 9805, 101, 1, 70, "Subsubsection"],
Cell[273733, 9808, 78, 2, 70, "Input"],
Cell[273814, 9812, 81, 2, 70, "Input"],
Cell[273898, 9816, 76, 2, 70, "Input"],
Cell[273977, 9820, 47, 1, 70, "Input"],
Cell[274027, 9823, 83, 2, 70, "Input"],
Cell[274113, 9827, 75, 2, 70, "Input"],
Cell[274191, 9831, 106, 2, 70, "Input"],
Cell[274300, 9835, 83, 1, 70, "Text"],
Cell[274386, 9838, 34, 1, 70, "Input"],
Cell[274423, 9841, 60, 0, 70, "Text"],
Cell[274486, 9843, 84, 2, 70, "Input"],
Cell[274573, 9847, 73, 2, 70, "Input"],
Cell[274649, 9851, 41, 1, 70, "Input"],
Cell[274693, 9854, 52, 1, 70, "Input"],
Cell[274748, 9857, 44, 1, 70, "Input"],
Cell[274795, 9860, 37, 1, 70, "Input"],
Cell[274835, 9863, 77, 2, 70, "Input"],
Cell[274915, 9867, 79, 2, 70, "Input"],
Cell[274997, 9871, 92, 2, 70, "Input"],
Cell[275092, 9875, 78, 2, 70, "Input"],
Cell[275173, 9879, 78, 2, 70, "Input"],
Cell[275254, 9883, 76, 2, 70, "Input"],
Cell[275333, 9887, 76, 2, 70, "Input"],
Cell[275412, 9891, 93, 2, 70, "Input"],
Cell[275508, 9895, 93, 2, 70, "Input"],
Cell[275604, 9899, 58, 0, 70, "Text"],
Cell[275665, 9901, 77, 2, 70, "Input"],
Cell[275745, 9905, 77, 2, 70, "Input"],
Cell[275825, 9909, 76, 2, 70, "Input"],
Cell[275904, 9913, 78, 2, 70, "Input"],
Cell[275985, 9917, 76, 2, 70, "Input"],
Cell[276064, 9921, 76, 2, 70, "Input"],
Cell[276143, 9925, 86, 2, 70, "Input"],
Cell[276232, 9929, 151, 4, 70, "Text"],
Cell[276386, 9935, 79, 2, 70, "Input"],
Cell[276468, 9939, 78, 2, 70, "Input"],
Cell[276549, 9943, 86, 2, 70, "Input"],
Cell[276638, 9947, 76, 2, 70, "Input"],
Cell[276717, 9951, 74, 2, 70, "Input"],
Cell[276794, 9955, 76, 2, 70, "Input"],
Cell[276873, 9959, 76, 2, 70, "Input"],
Cell[276952, 9963, 77, 2, 70, "Input"],
Cell[277032, 9967, 76, 2, 70, "Input"],
Cell[277111, 9971, 78, 2, 70, "Input"],
Cell[277192, 9975, 86, 2, 70, "Input"],
Cell[277281, 9979, 87, 2, 70, "Input"],
Cell[277371, 9983, 94, 2, 70, "Input"],
Cell[277468, 9987, 81, 2, 70, "Input"],
Cell[277552, 9991, 77, 2, 70, "Input"],
Cell[277632, 9995, 146, 3, 70, "Input"],
Cell[277781, 10000, 81, 2, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[277899, 10007, 83, 1, 70, "Subsubsection"],
Cell[277985, 10010, 79, 2, 70, "Input"],
Cell[278067, 10014, 80, 2, 70, "Input"],
Cell[278150, 10018, 84, 2, 70, "Input"],
Cell[278237, 10022, 79, 2, 70, "Input"],
Cell[278319, 10026, 82, 2, 70, "Input"],
Cell[278404, 10030, 84, 2, 70, "Input"],
Cell[278491, 10034, 83, 2, 70, "Input"],
Cell[278577, 10038, 84, 2, 70, "Input"],
Cell[278664, 10042, 83, 2, 70, "Input"],
Cell[278750, 10046, 84, 2, 70, "Input"],
Cell[278837, 10050, 83, 2, 70, "Input"],
Cell[278923, 10054, 84, 2, 70, "Input"],
Cell[279010, 10058, 83, 2, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[279130, 10065, 70, 1, 70, "Subsubsection"],
Cell[279203, 10068, 106, 2, 70, "Input"],
Cell[279312, 10072, 79, 2, 70, "Input"],
Cell[279394, 10076, 79, 2, 70, "Input"],
Cell[279476, 10080, 81, 2, 70, "Input"],
Cell[279560, 10084, 81, 2, 70, "Input"],
Cell[279644, 10088, 81, 2, 70, "Input"],
Cell[279728, 10092, 75, 2, 70, "Input"],
Cell[279806, 10096, 76, 2, 70, "Input"],
Cell[279885, 10100, 76, 2, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[279998, 10107, 74, 1, 70, "Subsubsection"],
Cell[280075, 10110, 74, 2, 70, "Input"],
Cell[280152, 10114, 79, 2, 70, "Input"],
Cell[280234, 10118, 79, 2, 70, "Input"],
Cell[280316, 10122, 79, 2, 70, "Input"],
Cell[280398, 10126, 79, 2, 70, "Input"],
Cell[280480, 10130, 80, 2, 70, "Input"],
Cell[280563, 10134, 81, 2, 70, "Input"],
Cell[280647, 10138, 79, 2, 70, "Input"],
Cell[280729, 10142, 81, 2, 70, "Input"],
Cell[280813, 10146, 83, 2, 70, "Input"],
Cell[280899, 10150, 87, 2, 70, "Input"],
Cell[280989, 10154, 87, 2, 70, "Input"],
Cell[281079, 10158, 89, 2, 70, "Input"],
Cell[281171, 10162, 93, 2, 70, "Input"],
Cell[281267, 10166, 101, 2, 70, "Input"],
Cell[281371, 10170, 88, 2, 70, "Input"],
Cell[281462, 10174, 74, 2, 70, "Input"],
Cell[281539, 10178, 82, 2, 70, "Input"],
Cell[281624, 10182, 85, 2, 70, "Input"],
Cell[281712, 10186, 124, 4, 70, "Text"],
Cell[281839, 10192, 90, 2, 70, "Input"],
Cell[281932, 10196, 96, 2, 70, "Input"],
Cell[282031, 10200, 93, 2, 70, "Input"],
Cell[282127, 10204, 93, 2, 70, "Input"],
Cell[282223, 10208, 77, 2, 70, "Input"],
Cell[282303, 10212, 279, 5, 70, "Input"],
Cell[282585, 10219, 96, 2, 70, "Input"],
Cell[282684, 10223, 110, 2, 70, "Input"],
Cell[282797, 10227, 105, 2, 70, "Input"],
Cell[282905, 10231, 93, 2, 70, "Input"],
Cell[283001, 10235, 93, 2, 70, "Input"],
Cell[283097, 10239, 81, 2, 70, "Input"],
Cell[283181, 10243, 166, 5, 70, "Text"],
Cell[283350, 10250, 99, 2, 70, "Input"],
Cell[283452, 10254, 93, 2, 70, "Input"],
Cell[283548, 10258, 93, 2, 70, "Input"],
Cell[283644, 10262, 88, 2, 70, "Input"],
Cell[283735, 10266, 94, 2, 70, "Input"],
Cell[283832, 10270, 85, 2, 70, "Input"],
Cell[283920, 10274, 91, 2, 70, "Input"],
Cell[284014, 10278, 94, 2, 70, "Input"],
Cell[284111, 10282, 93, 2, 70, "Input"],
Cell[284207, 10286, 74, 2, 70, "Input"],
Cell[284284, 10290, 88, 2, 70, "Input"],
Cell[284375, 10294, 90, 2, 70, "Input"],
Cell[284468, 10298, 81, 2, 70, "Input"],
Cell[284552, 10302, 86, 2, 70, "Input"],
Cell[284641, 10306, 86, 2, 70, "Input"],
Cell[284730, 10310, 85, 2, 70, "Input"],
Cell[284818, 10314, 85, 2, 70, "Input"],
Cell[284906, 10318, 74, 2, 70, "Input"],
Cell[284983, 10322, 85, 2, 70, "Input"],
Cell[285071, 10326, 84, 2, 70, "Input"],
Cell[285158, 10330, 84, 2, 70, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[285291, 10338, 142, 4, 70, "Subsection"],
Cell[285436, 10344, 270, 6, 70, "Text"],
Cell[285709, 10352, 78, 2, 70, "Input"],
Cell[285790, 10356, 76, 2, 70, "Input"],
Cell[285869, 10360, 69, 2, 70, "Input"],
Cell[285941, 10364, 74, 2, 70, "Input"],
Cell[286018, 10368, 57, 0, 70, "Text"],
Cell[286078, 10370, 82, 2, 70, "Input"],
Cell[286163, 10374, 67, 2, 70, "Input"],
Cell[286233, 10378, 76, 2, 70, "Input"],
Cell[286312, 10382, 69, 2, 70, "Input"],
Cell[286384, 10386, 74, 2, 70, "Input"],
Cell[286461, 10390, 67, 0, 70, "Text"],
Cell[286531, 10392, 77, 2, 70, "Input"],
Cell[286611, 10396, 67, 2, 70, "Input"],
Cell[286681, 10400, 76, 2, 70, "Input"],
Cell[286760, 10404, 69, 2, 70, "Input"],
Cell[286832, 10408, 74, 2, 70, "Input"],
Cell[286909, 10412, 30, 0, 70, "Text"],
Cell[286942, 10414, 97, 2, 70, "Input"],
Cell[287042, 10418, 74, 2, 70, "Input"],
Cell[287119, 10422, 160, 5, 70, "Text"],
Cell[287282, 10429, 152, 3, 70, "Text"],
Cell[287437, 10434, 69, 2, 70, "Input"],
Cell[287509, 10438, 92, 2, 70, "Input"],
Cell[287604, 10442, 69, 2, 70, "Input"],
Cell[287676, 10446, 101, 3, 70, "Text"],
Cell[287780, 10451, 106, 2, 70, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[287935, 10459, 97, 2, 58, "Section",
  CellTags->"W.matrix"],

Cell[CellGroupData[{
Cell[288057, 10465, 71, 1, 68, "Subsection"],
Cell[288131, 10468, 286, 8, 95, "Text"],
Cell[288420, 10478, 223, 6, 39, "Input",
  InitializationCell->True],
Cell[288646, 10486, 1271, 35, 63, "Input",
  InitializationCell->True],
Cell[289920, 10523, 295, 7, 63, "Input"],
Cell[290218, 10532, 101, 1, 45, "Text"],
Cell[290322, 10535, 1239, 34, 63, "Input",
  InitializationCell->True],
Cell[291564, 10571, 295, 7, 63, "Input"],
Cell[291862, 10580, 295, 7, 63, "Input"],
Cell[292160, 10589, 1775, 46, 87, "Input",
  InitializationCell->True],
Cell[293938, 10637, 295, 7, 63, "Input"],
Cell[294236, 10646, 295, 7, 63, "Input"],
Cell[294534, 10655, 295, 7, 63, "Input"],
Cell[294832, 10664, 1775, 46, 87, "Input",
  InitializationCell->True],
Cell[296610, 10712, 295, 7, 63, "Input"],
Cell[296908, 10721, 295, 7, 63, "Input"],
Cell[297206, 10730, 295, 7, 63, "Input"],
Cell[297504, 10739, 295, 7, 63, "Input"],
Cell[297802, 10748, 183, 4, 70, "Text"],
Cell[297988, 10754, 374, 9, 87, "Input",
  InitializationCell->True],
Cell[298365, 10765, 771, 19, 63, "Input",
  InitializationCell->True],
Cell[299139, 10786, 84, 2, 39, "Input"],
Cell[299226, 10790, 121, 3, 39, "Input"],
Cell[299350, 10795, 109, 1, 45, "Text"],
Cell[299462, 10798, 151, 4, 40, "Input"],
Cell[299616, 10804, 365, 7, 63, "Input"],
Cell[299984, 10813, 124, 3, 39, "Input"],
Cell[300111, 10818, 76, 2, 39, "Input"],
Cell[300190, 10822, 99, 2, 39, "Input"],
Cell[300292, 10826, 99, 2, 39, "Input"],
Cell[300394, 10830, 75, 2, 39, "Input"],
Cell[300472, 10834, 75, 2, 39, "Input"],
Cell[300550, 10838, 218, 4, 39, "Input"],
Cell[300771, 10844, 105, 2, 39, "Input"],
Cell[300879, 10848, 71, 2, 39, "Input"],
Cell[300953, 10852, 114, 2, 39, "Input"],
Cell[301070, 10856, 71, 2, 39, "Input"],
Cell[301144, 10860, 112, 2, 39, "Input"],
Cell[301259, 10864, 359, 7, 87, "Input"],
Cell[301621, 10873, 88, 1, 45, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[301746, 10879, 99, 1, 40, "Subsection"],
Cell[301848, 10882, 125, 4, 45, "Text"],
Cell[301976, 10888, 312, 7, 87, "Input"],
Cell[302291, 10897, 206, 6, 39, "Input"],
Cell[302500, 10905, 169, 4, 39, "Input"],
Cell[302672, 10911, 174, 4, 39, "Input"],
Cell[302849, 10917, 105, 3, 39, "Input"],
Cell[302957, 10922, 192, 5, 39, "Input"],
Cell[303152, 10929, 173, 4, 39, "Input"],
Cell[303328, 10935, 112, 3, 39, "Input"],
Cell[303443, 10940, 114, 3, 39, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[303594, 10948, 127, 4, 40, "Subsection"],
Cell[303724, 10954, 126, 4, 45, "Text"],
Cell[303853, 10960, 142, 3, 39, "Input"],
Cell[303998, 10965, 395, 8, 87, "Input"],
Cell[304396, 10975, 403, 8, 111, "Input"],
Cell[304802, 10985, 99, 3, 39, "Input"],
Cell[304904, 10990, 109, 3, 39, "Input"],
Cell[305016, 10995, 107, 3, 39, "Input"],
Cell[305126, 11000, 98, 3, 39, "Input"],
Cell[305227, 11005, 293, 7, 63, "Input"],
Cell[305523, 11014, 169, 4, 39, "Input"],
Cell[305695, 11020, 192, 5, 39, "Input"],
Cell[305890, 11027, 173, 4, 39, "Input"],
Cell[306066, 11033, 118, 3, 39, "Input"],
Cell[306187, 11038, 198, 5, 70, "Text"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[306446, 11050, 30, 0, 66, "Subtitle"],
Cell[306479, 11052, 224, 6, 87, "Text",
  CellTags->"Alfred"],
Cell[306706, 11060, 161, 5, 62, "Text",
  CellTags->"Kuska"],
Cell[306870, 11067, 197, 5, 62, "Text",
  CellTags->"M."],
Cell[307070, 11074, 210, 6, 87, "Text",
  CellTags->"O.-S."],
Cell[307283, 11082, 540, 17, 87, "Text",
  Evaluatable->False,
  CellTags->"S1"],
Cell[307826, 11101, 269, 9, 87, "Text",
  CellTags->"S2"],
Cell[308098, 11112, 281, 10, 87, "Text",
  CellTags->"S3"],
Cell[308382, 11124, 184, 5, 62, "Text",
  CellTags->"W."],
Cell[308569, 11131, 185, 6, 87, "Text",
  CellTags->"J."],

Cell[CellGroupData[{
Cell[308779, 11141, 81, 1, 74, "Subsubsection",
  CellTags->"pack"],
Cell[308863, 11144, 242, 9, 220, "Text"],
Cell[309108, 11155, 289, 7, 70, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[309434, 11167, 63, 1, 67, "Subsubtitle"],
Cell[309500, 11170, 80, 1, 45, "Text"],
Cell[309583, 11173, 125, 2, 62, "Text",
  CellTags->"hopa"],
Cell[309711, 11177, 123, 4, 45, "Text"]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

